@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.ajax.customizer.folder;
 
+import java.util.List;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.tools.session.ServerSession;
 
@@ -81,11 +82,11 @@ public class SimFolderField implements AdditionalFolderField {
     public Object renderJSON(Object value) {
         return jsonValue;
     }
-    
+
     public void setColumnId(int columnId) {
         this.columnId = columnId;
     }
-    
+
     public void setColumnName(String columnName) {
         this.columnName = columnName;
     }
@@ -93,9 +94,13 @@ public class SimFolderField implements AdditionalFolderField {
     public void setValue(Object value) {
         this.value = value;
     }
-    
+
     public void setJsonValue(Object jsonValue) {
         this.jsonValue = jsonValue;
     }
 
+    public List<Object> getValues(List<FolderObject> folder, ServerSession session) {
+        return AdditionalFieldsUtils.bulk(this, folder, session);
+    }
+
 }
