@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,6 +80,8 @@ public class SimMailAccount implements MailAccount {
 
     private String personal;
 
+    private String replyTo;
+
     private String password;
 
     private String name;
@@ -87,7 +89,7 @@ public class SimMailAccount implements MailAccount {
     private String mailServer;
 
     private Map<String, String> properties;
-    
+
     public void setProperties(final Map<String, String> properties) {
         this.properties = properties;
     }
@@ -140,6 +142,10 @@ public class SimMailAccount implements MailAccount {
         this.personal = personal;
     }
 
+    public void setReplyTo(final String replyTo) {
+        this.replyTo = replyTo;
+    }
+
     public void setPassword(final String password) {
         this.password = password;
     }
@@ -234,6 +240,10 @@ public class SimMailAccount implements MailAccount {
         return personal;
     }
 
+    public String getReplyTo() {
+        return replyTo;
+    }
+
     public Map<String, String> getProperties() {
         return properties;
     }
