@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,6 @@ import java.io.Writer;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
-import java.util.regex.Matcher;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -82,8 +81,8 @@ import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.upload.impl.UploadException;
-import com.openexchange.groupware.upload.impl.UploadQuotaChecker;
 import com.openexchange.groupware.upload.impl.UploadException.UploadCode;
+import com.openexchange.groupware.upload.impl.UploadQuotaChecker;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -94,7 +93,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * AJAXFile
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class AJAXFile extends PermissionServlet {
@@ -104,7 +103,7 @@ public final class AJAXFile extends PermissionServlet {
      */
     private static final long serialVersionUID = 1L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(AJAXFile.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(AJAXFile.class));
 
     private static final String MIME_TEXT_HTML_CHARSET_UTF_8 = "text/html; charset=UTF-8";
 
@@ -256,28 +255,25 @@ public final class AJAXFile extends PermissionServlet {
             } catch (final JSONException e1) {
                 LOG.error(e1.getMessage(), e1);
             }
-            throw new UploadServletException(resp, JS_FRAGMENT.replaceFirst(
-                JS_FRAGMENT_JSON,
-                responseObj == null ? STR_NULL : Matcher.quoteReplacement(responseObj.toString())).replaceFirst(
-                JS_FRAGMENT_ACTION,
-                e.getAction() == null ? STR_NULL : e.getAction()), e.getMessage(), e);
+			throw new UploadServletException(resp, substituteJS(
+					responseObj == null ? STR_NULL : responseObj.toString(),
+					e.getAction() == null ? STR_NULL : e.getAction()),
+					e.getMessage(), e);
         } catch (final AbstractOXException e) {
             LOG.error(e.getMessage(), e);
-            resp.setContentType(MIME_TEXT_HTML_CHARSET_UTF_8);
+            resp.setStatus(HttpServletResponse.SC_OK);
+            resp.setContentType(CONTENTTYPE_JAVASCRIPT);
             Tools.disableCaching(resp);
-            JSONObject responseObj = null;
+            final Response response = new Response();
+            response.setException(e);
             try {
-                final Response response = new Response();
-                response.setException(e);
-                responseObj = ResponseWriter.getJSON(response);
+                ResponseWriter.write(response, resp.getWriter());
             } catch (final JSONException e1) {
                 LOG.error(e1.getMessage(), e1);
+                final ServletException se = new ServletException(e1.getMessage(), e1);
+                se.initCause(e1);
+                throw se;
             }
-            throw new UploadServletException(resp, JS_FRAGMENT.replaceFirst(
-                JS_FRAGMENT_JSON,
-                responseObj == null ? STR_NULL : Matcher.quoteReplacement(responseObj.toString())).replaceFirst(
-                JS_FRAGMENT_ACTION,
-                ACTION_GET), e.getMessage(), e);
         }
     }
 
@@ -373,17 +369,14 @@ public final class AJAXFile extends PermissionServlet {
                  */
                 final Response response = new Response();
                 response.setData(jArray);
-                final String jsResponse =
-                    JS_FRAGMENT.replaceFirst(JS_FRAGMENT_JSON, Matcher.quoteReplacement(ResponseWriter.getJSON(response).toString())).replaceFirst(
-                        JS_FRAGMENT_ACTION,
-                        action);
+				final String jsResponse = substituteJS(
+						ResponseWriter.getJSON(response).toString(), action);
                 final Writer writer = resp.getWriter();
                 writer.write(jsResponse);
                 writer.flush();
 
             }
         } catch (final UploadException e) {
-            LOG.error(e.getMessage(), e);
             JSONObject responseObj = null;
             try {
                 final Response response = new Response();
@@ -392,11 +385,10 @@ public final class AJAXFile extends PermissionServlet {
             } catch (final JSONException e1) {
                 LOG.error(e1.getMessage(), e1);
             }
-            throw new UploadServletException(resp, JS_FRAGMENT.replaceFirst(
-                JS_FRAGMENT_JSON,
-                responseObj == null ? STR_NULL : Matcher.quoteReplacement(responseObj.toString())).replaceFirst(
-                JS_FRAGMENT_ACTION,
-                e.getAction() == null ? STR_NULL : e.getAction()), e.getMessage(), e);
+			throw new UploadServletException(resp, substituteJS(
+					responseObj == null ? STR_NULL : responseObj.toString(),
+					e.getAction() == null ? STR_NULL : e.getAction()),
+					e.getMessage(), e);
         } catch (final JSONException e) {
             final OXJSONException oje = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e, new Object[0]);
             JSONObject responseObj = null;
@@ -407,17 +399,15 @@ public final class AJAXFile extends PermissionServlet {
             } catch (final JSONException e1) {
                 LOG.error(e1.getMessage(), e1);
             }
-            throw new UploadServletException(resp, JS_FRAGMENT.replaceFirst(
-                JS_FRAGMENT_JSON,
-                responseObj == null ? STR_NULL : Matcher.quoteReplacement(responseObj.toString())).replaceFirst(
-                JS_FRAGMENT_ACTION,
-                action == null ? STR_NULL : action), e.getMessage(), e);
+			throw new UploadServletException(resp, substituteJS(
+					responseObj == null ? STR_NULL : responseObj.toString(),
+					action == null ? STR_NULL : action), e.getMessage(), e);
         }
     }
 
     /**
      * Checks if specified {@link FileItem file item} denotes a valid file.
-     * 
+     *
      * @param fileItem The file item to check
      * @return <code>true</code> if file item denotes a valid file; otherwise <code>false</code>
      */
