@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,9 @@
 
 package com.openexchange.ajax;
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
-import java.io.InputStreamReader;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
 import java.io.Writer;
@@ -64,6 +64,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import javax.servlet.ServletException;
+import javax.servlet.ServletInputStream;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -84,22 +85,27 @@ import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.ajax.writer.ResponseWriter;
 import com.openexchange.api.OXConflictException;
 import com.openexchange.api2.OXException;
+import com.openexchange.configuration.ConfigurationException;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.groupware.upload.impl.UploadEvent;
 import com.openexchange.groupware.upload.impl.UploadException;
-import com.openexchange.groupware.upload.impl.UploadFile;
+import com.openexchange.groupware.upload.impl.UploadException.UploadCode;
+import com.openexchange.groupware.upload.impl.UploadFileImpl;
 import com.openexchange.groupware.upload.impl.UploadListener;
 import com.openexchange.groupware.upload.impl.UploadRegistry;
-import com.openexchange.groupware.upload.impl.UploadException.UploadCode;
+import com.openexchange.groupware.upload.impl.UploadUtility;
 import com.openexchange.monitoring.MonitoringInfo;
 import com.openexchange.tools.servlet.AjaxException;
+import com.openexchange.tools.servlet.CountingHttpServletRequest;
 import com.openexchange.tools.servlet.UploadServletException;
+import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * This is a super class of all AJAX servlets providing common methods.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public abstract class AJAXServlet extends HttpServlet implements UploadRegistry {
@@ -109,11 +115,13 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
      */
     private static final long serialVersionUID = 718576864014891156L;
 
-    private static final transient Log LOG = LogFactory.getLog(AJAXServlet.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AJAXServlet.class));
 
     // Modules
     public static final String MODULE_TASK = "tasks";
 
+    public static final String MODULE_ATTACHMENTS = "attachment";
+
     public static final String MODULE_CALENDAR = "calendar";
 
     public static final String MODULE_CONTACT = "contacts";
@@ -183,6 +191,8 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String ACTION_ZIP_MATTACH = "zip_attachments";
 
+    public static final String ACTION_ZIP_MESSAGES = "zip_messages";
+
     public static final String ACTION_MAIL_RECEIPT_ACK = "receipt_ack";
 
     public static final String ACTION_NEW_MSGS = "newmsgs";
@@ -226,9 +236,9 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     public static final String ACTION_LOGOUT = "logout";
 
     public static final String ACTION_REDIRECT = "redirect";
-    
+
     public static final String ACTION_REDEEM = "redeem";
-    
+
     public static final String ACTION_AUTOLOGIN = "autologin";
 
     public static final String ACTION_SAVE_VERSIT = "saveVersit";
@@ -236,11 +246,19 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     public static final String ACTION_CLEAR = "clear";
 
     public static final String ACTION_KEEPALIVE = "keepalive";
-    
+
     public static final String ACTION_RESOLVE_UID = "resolveuid";
 
     public static final String ACTION_IMPORT = "import";
 
+    public static final String ACTION_REFRESH = "refresh";
+
+    public static final String ACTION_REFRESH_SECRET = "refreshSecret";
+
+    public static final String ACTION_TERMSEARCH = "advancedSearch";
+    
+    public static final String ACTION_TEMPLATE = "template";
+
     /**
      * The parameter 'from' specifies index of starting entry in list of objects dependent on given order criteria and folder id
      */
@@ -277,7 +295,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     public static final String PARAMETER_INFOLDER = "folder";
 
     public static final String PARAMETER_MODULE = "module";
-    
+
     public static final String PARAMETER_MAIL = "mail";
 
     /**
@@ -335,11 +353,18 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     public static final String PARAMETER_USER = "user";
 
     public static final String PARAMETER_TEMPLATE = "template";
-    
+
     public static final String PARAMETER_UID = "uid";
-    
+
     public static final String PARAMETER_SHOW_PRIVATE_APPOINTMENTS = "showPrivate";
 
+    public static final String PARAMETER_USERNAME = "name";
+
+    public static final String PARAMETER_PASSWORD= "password";
+
+    public static final String PARAMETER_FILTER = "filter";
+
+    public static final String PARAMETER_COLLATION = "collation";
 
     /**
      * The content type if the response body contains javascript data. Set it with
@@ -368,7 +393,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 			+ "(parent.callback_**action** || window.opener && "
 			+ "window.opener.callback_**action**)(**json**)"
 			+ "</script></head></html>";
-	
+
     protected static final String SAVE_AS_TYPE = "application/octet-stream";
 
     protected static final String _doGet = "doGet";
@@ -381,7 +406,14 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     protected static final String RESPONSE_ERROR = "Error while writing response object.";
 
     /**
-     * The service method of HttpServlet is extended to catch bad exceptions and keep the AJP socket alive. Otherwise apache things in a
+     * Initializes a new {@link AJAXServlet}.
+     */
+    protected AJAXServlet() {
+        super();
+    }
+
+    /**
+     * The service method of HttpServlet is extended to catch bad exceptions and keep the AJP socket alive. Otherwise Apache thinks in a
      * balancer environment this AJP container is temporarily dead and redirects requests to other AJP containers. This will kill the users
      * session.
      */
@@ -389,7 +421,12 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         incrementRequests();
         try {
-            super.service(req, resp);
+            /*
+             * Set 200 OK status code and JSON content by default
+             */
+            resp.setStatus(HttpServletResponse.SC_OK);
+            resp.setContentType(CONTENTTYPE_JAVASCRIPT);
+            super.service(new CountingHttpServletRequest(req), resp);
         } catch (final ServletException x) {
             throw x;
         } catch (final Exception e) {
@@ -422,43 +459,57 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
         return (req.getParameter(name) != null);
     }
 
-    /**
-     * 8K buffer
-     */
-    private static final int BUF_SIZE = 0x2000;
+    private static int getMaxBodySize() {
+        try {
+            return ServerConfig.getInt(ServerConfig.Property.MAX_BODY_SIZE);
+        } catch (final ConfigurationException e) {
+            return Integer.parseInt(ServerConfig.Property.MAX_BODY_SIZE.getDefaultValue());
+        }
+    }
 
     /**
-     * Initialize with 16K
+     * 2K buffer
      */
-    private static final int SB_SIZE = 0x4000;
+    private static final int BUF_SIZE = 0x800;
+
+    /**
+     * Initialize with 8K
+     */
+    private static final int SB_SIZE = 0x2000;
 
     /**
      * Returns the complete body as a string. Be careful when getting big request bodies.
-     * 
+     *
      * @param req The HTTP servlet request.
      * @return A string with the complete body.
-     * @throws IOException If an error occurs while reading the body.
+     * @throws IOException If an error occurs while reading the body or body size exceeded configured max. size (see "MAX_BODY_SIZE" property)
      */
     public static String getBody(final HttpServletRequest req) throws IOException {
-        InputStreamReader isr = null;
+        final ServletInputStream inputStream = req.getInputStream();
         try {
-            {
-                final String characterEncoding = req.getCharacterEncoding();
-                isr =
-                    new InputStreamReader(
-                        req.getInputStream(),
-                        null == characterEncoding ? ServerConfig.getProperty(Property.DefaultEncoding) : characterEncoding);
+            final int buflen = BUF_SIZE;
+            final byte[] buf = new byte[buflen];
+            final ByteArrayOutputStream baos = new UnsynchronizedByteArrayOutputStream(SB_SIZE);
+            final int maxBodySize = getMaxBodySize();
+            if (maxBodySize > 0) {
+                int count = 0;
+                for (int read = inputStream.read(buf, 0, buflen); read > 0; read = inputStream.read(buf, 0, buflen)) {
+                    count += read;
+                    if (count > maxBodySize) {
+                        throw new IOException("Max. body size (" + UploadUtility.getSize(maxBodySize, 2, false, true) + ") exceeded.");
+                    }
+                    baos.write(buf, 0, read);
+                }
+            } else {
+                for (int read = inputStream.read(buf, 0, buflen); read > 0; read = inputStream.read(buf, 0, buflen)) {
+                    baos.write(buf, 0, read);
+                }
             }
-            final char[] c = new char[BUF_SIZE];
-            int count = 0;
-            if ((count = isr.read(c)) > 0) {
-                final StringBuilder sb = new StringBuilder(SB_SIZE);
-                do {
-                    sb.append(c, 0, count);
-                } while ((count = isr.read(c)) > 0);
-                return sb.toString();
+            String charEnc = req.getCharacterEncoding();
+            if (charEnc == null) {
+                charEnc = ServerConfig.getProperty(ServerConfig.Property.DefaultEncoding);
             }
-            return STR_EMPTY;
+            return new String(baos.toByteArray(), charEnc);
         } catch (final UnsupportedEncodingException e) {
             /*
              * Should never occur
@@ -466,19 +517,17 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
             LOG.error("Unsupported encoding in request", e);
             return STR_EMPTY;
         } finally {
-            if (null != isr) {
-                try {
-                    isr.close();
-                } catch (final IOException e) {
-                    LOG.error(e.getMessage(), e);
-                }
+            try {
+                inputStream.close();
+            } catch (final IOException e) {
+                LOG.debug(e.getMessage(), e);
             }
         }
     }
 
     /**
      * Returns the URI part after path to the servlet.
-     * 
+     *
      * @param req the request that url should be parsed
      * @return the URI part after the path to your servlet.
      */
@@ -504,7 +553,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     /**
      * Gets the action parameter ({@link #PARAMETER_ACTION}) from specified servlet request.
-     * 
+     *
      * @param req The servlet request
      * @return The action parameter's value
      * @throws OXConflictException If action parameter is missing in specified servlet request
@@ -519,7 +568,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     /**
      * This method sends the given error message as a java script error object to the client.
-     * 
+     *
      * @param resp This response will be used to send the java script error object.
      * @param errorMessage The error message to send to the client.
      * @throws IOException if writing to the response fails.
@@ -614,7 +663,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     /**
      * Processes specified request's upload provided that request is of content type <code>multipart/*</code>.
-     * 
+     *
      * @param req The request whose upload shall be processed
      * @return The processed instance of {@link UploadEvent}
      * @throws UploadException Id processing the upload fails
@@ -627,7 +676,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     /**
      * Gets the {@link ServletFileUpload} instance.
-     * 
+     *
      * @return The {@link ServletFileUpload} instance
      */
     private static ServletFileUpload getFileUploadBase() {
@@ -650,7 +699,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     /**
      * Creates a new {@link ServletFileUpload} instance.
-     * 
+     *
      * @return A new {@link ServletFileUpload} instance
      */
     private static ServletFileUpload newFileUploadBase() {
@@ -678,9 +727,10 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
         new HashSet<String>(Arrays.asList(ACTION_NEW, ACTION_UPLOAD, ACTION_APPEND, ACTION_UPDATE, ACTION_ATTACH, ACTION_COPY));
 
 
+
     /**
      * (Statically) Processes specified request's upload provided that request is of content type <code>multipart/*</code>.
-     * 
+     *
      * @param req The request whose upload shall be processed
      * @return The processed instance of {@link UploadEvent}
      * @throws UploadException Id processing the upload fails
@@ -701,12 +751,12 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
         }
         /*-
          * Check proper action value
-         * 
+         *
          * ###########################################################################################################
          * ######################### ENSURE YOUR ACTION IS CONTAINED IN UPLOAD_ACTIONS ! ! ! #########################
          * ###########################################################################################################
          */
-        if (!UPLOAD_ACTIONS.contains(action) && !com.openexchange.groupware.importexport.Format.containsConstantName(action)) {
+        if (mayUpload(action)) {
             throw new UploadException(UploadCode.UNKNOWN_ACTION_VALUE, null, action);
         }
         /*
@@ -760,13 +810,17 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
         return uploadEvent;
     }
 
+    protected static boolean mayUpload(final String action) {
+        return !UPLOAD_ACTIONS.contains(action) && !com.openexchange.groupware.importexport.Format.containsConstantName(action);
+    }
+
     private static final boolean isEmpty(final String str) {
         return null == str || 0 == str.length();
     }
 
-    private static final UploadFile processUploadedFile(final FileItem item, final String uploadDir) throws Exception {
+ 	private static final UploadFile processUploadedFile(final FileItem item, final String uploadDir) throws Exception {
         try {
-            final UploadFile retval = new UploadFile();
+            final UploadFile retval = new UploadFileImpl();
             retval.setFieldName(item.getFieldName());
             retval.setFileName(item.getName());
             retval.setContentType(item.getContentType());
