@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,7 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.session.Session;
+import com.openexchange.tools.servlet.http.Tools;
 
 /**
  * This class implements the servlet for authenticating the user at the
@@ -78,7 +79,7 @@ public class ConfigJump extends SessionServlet {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(ConfigJump.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConfigJump.class));
 
     /**
      * For serialization.
@@ -103,12 +104,7 @@ public class ConfigJump extends SessionServlet {
         try {
             final Context ctx = ContextStorage.getInstance().getContext(
                 sessionObj.getContextId());
-            final String protocol;
-            if (req.isSecure()) {
-                protocol = "https";
-            } else {
-                protocol = "http";
-            }
+            final String protocol = Tools.getProtocol(req);
             final URL url = com.openexchange.configjump.client.ConfigJump.getLink(new Replacements() {
                 public int getContextId() {
                     return sessionObj.getContextId();
