@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,8 +74,8 @@ import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.groupware.upload.impl.UploadEvent;
-import com.openexchange.groupware.upload.impl.UploadFile;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.Logging;
 import com.openexchange.tools.servlet.AjaxException;
@@ -84,21 +84,21 @@ import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 
 public class Contact extends DataServlet {
-    
+
     /**
      * For serialization.
      */
     private static final long serialVersionUID = 1635881627528234660L;
-    
-    private static final transient Log LOG = LogFactory.getLog(Contact.class);
-    
+
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Contact.class));
+
     @Override
     protected void doGet(final HttpServletRequest httpServletRequest, final HttpServletResponse httpServletResponse) throws ServletException, IOException {
         final Response response = new Response();
         try {
             final String action = parseMandatoryStringParameter(httpServletRequest, PARAMETER_ACTION);
             final ServerSession session = getSessionObject(httpServletRequest);
-            
+
             JSONObject jsonObj = null;
             try {
                 jsonObj = convertParameter2JSONObject(httpServletRequest);
@@ -108,14 +108,14 @@ public class Contact extends DataServlet {
                 writeResponse(response, httpServletResponse);
                 return;
             }
-            
+
             if (action.equals(ACTION_IMAGE)) {
                 final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
                 final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
-                
+
                 OutputStream os = null;
-                
-                
+
+
                 final Context ctx = session.getContext();
 
                 final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
@@ -144,14 +144,14 @@ public class Contact extends DataServlet {
                     LOG.error("actionImage", e);
                     httpServletResponse.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, "");
                 }
-                
+
                 if (os != null) {
                     os.flush();
                 }
-                
+
                 return;
             }
-            
+
             final ContactRequest contactRequest = new ContactRequest(session);
             final JSONValue responseObj = contactRequest.action(action, jsonObj);
             response.setTimestamp(contactRequest.getTimestamp());
@@ -165,22 +165,22 @@ public class Contact extends DataServlet {
             Logging.log(LOG, e);
             response.setException(e);
         }
-        
+
         writeResponse(response, httpServletResponse);
-        
+
     }
-    
+
     @Override
     protected void doPut(final HttpServletRequest httpServletRequest, final HttpServletResponse httpServletResponse) throws ServletException, IOException {
         final Response response = new Response();
         try {
             final String action = parseMandatoryStringParameter(httpServletRequest, PARAMETER_ACTION);
             final ServerSession session = getSessionObject(httpServletRequest);
-            
+
             final String data = getBody(httpServletRequest);
             if (data.length() > 0) {
                 final JSONObject jsonObj;
-                
+
                 try {
                     jsonObj = convertParameter2JSONObject(httpServletRequest);
                 } catch (final JSONException e) {
@@ -191,18 +191,18 @@ public class Contact extends DataServlet {
                 }
 
                 final ContactRequest contactRequest = new ContactRequest(session);
-                
+
                 if (data.charAt(0) == '[') {
                     final JSONArray jsonDataArray = new JSONArray(data);
                     jsonObj.put(AJAXServlet.PARAMETER_DATA, jsonDataArray);
-                    
+
                     final JSONValue responseObj = contactRequest.action(action, jsonObj);
                     response.setTimestamp(contactRequest.getTimestamp());
                     response.setData(responseObj);
                 } else if (data.charAt(0) == '{') {
                     final JSONObject jsonDataObj = new JSONObject(data);
                     jsonObj.put(AJAXServlet.PARAMETER_DATA, jsonDataObj);
-                    
+
                     final Object responseObj = contactRequest.action(action, jsonObj);
                     response.setTimestamp(contactRequest.getTimestamp());
                     response.setData(responseObj);
@@ -224,9 +224,9 @@ public class Contact extends DataServlet {
             Logging.log(LOG, e);
             response.setException(e);
         }
-        
+
         writeResponse(response, httpServletResponse);
-        
+
     }
 
     @Override
@@ -334,10 +334,31 @@ public class Contact extends DataServlet {
                         contactobject.setImageContentType(uploadFile.getContentType());
                     }
 
-                    final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
-                        ContactInterfaceDiscoveryService.class).newContactInterface(contactobject.getParentFolderID(), session);
-                    //final ContactSQLInterface contactsql = new RdbContactSQLInterface(session);
-                    contactInterface.updateContactObject(contactobject, inFolder, timestamp);
+                    final ContactInterfaceDiscoveryService discoveryService = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class);
+                    final int folderId = contactobject.getParentFolderID();
+                    final ContactInterface targetContactInterface = discoveryService.newContactInterface(folderId, session);
+
+                    boolean doUpdate = true;
+                    {
+                        final ContactInterface srcContactIface = discoveryService.newContactInterface(inFolder, session);
+                        if (!targetContactInterface.getClass().equals(srcContactIface.getClass())) {
+                            doUpdate = false;
+                            ContactRequest.move2AnotherProvider(
+                                id,
+                                inFolder,
+                                contactobject,
+                                srcContactIface,
+                                folderId,
+                                targetContactInterface,
+                                session,
+                                timestamp);
+                        }
+                    }
+
+                    if (doUpdate) {
+                        //final ContactSQLInterface contactsql = new RdbContactSQLInterface(session);
+                        targetContactInterface.updateContactObject(contactobject, inFolder, timestamp);
+                    }
                 } finally {
                     if (upload != null) {
                         upload.cleanUp();
@@ -366,7 +387,7 @@ public class Contact extends DataServlet {
         }
 
     }
-    
+
     @Override
     protected boolean hasModulePermission(final ServerSession session) {
         return session.getUserConfiguration().hasContact();
