@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,22 +55,26 @@ import java.io.IOException;
 import java.util.Properties;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.springframework.beans.factory.BeanFactory;
 import com.openexchange.config.ConfigurationService;
-import com.openexchange.configuration.SystemConfig;
-import com.openexchange.groupware.contact.mappers.PropertyDrivenMapper;
+import com.openexchange.groupware.contact.mappers.PropertyDrivenContactFieldMapper;
 import com.openexchange.groupware.importexport.Importer;
 import com.openexchange.groupware.importexport.ImporterExporter;
+import com.openexchange.groupware.importexport.exporters.CSVContactExporter;
+import com.openexchange.groupware.importexport.exporters.ICalExporter;
+import com.openexchange.groupware.importexport.exporters.VCardExporter;
 import com.openexchange.groupware.importexport.importers.CSVContactImporter;
+import com.openexchange.groupware.importexport.importers.FacebookArchiveImporter;
+import com.openexchange.groupware.importexport.importers.FacebookFriendsImporter;
+import com.openexchange.groupware.importexport.importers.ICalImporter;
 import com.openexchange.groupware.importexport.importers.OutlookCSVContactImporter;
+import com.openexchange.groupware.importexport.importers.VCardImporter;
 import com.openexchange.server.osgi.CSVTranslator;
 import com.openexchange.server.services.ServerServiceRegistry;
-import com.openexchange.xml.spring.SpringParser;
 
 /**
  * Abtract class for both importers and exporters that does the configuration via Spring. This means importers and exporters are loaded from
  * a configuration file and you do not need to hardcode them somewhere.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a> (spring configuration)
  */
@@ -81,12 +85,10 @@ public abstract class ImportExport extends SessionServlet {
 
     public static final String AJAX_TYPE = "type";
 
-    private static final Log LOG = LogFactory.getLog(ImportExport.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ImportExport.class));
 
     protected ImporterExporter importerExporter = null;
 
-    private static BeanFactory beanFactory = null;
-
     private static CSVTranslator translator;
 
     public static CSVTranslator getTranslator() {
@@ -99,29 +101,25 @@ public abstract class ImportExport extends SessionServlet {
 
     @Override
     public void init() {
-        if (importerExporter != null) {
+        if (importerExporter != null)
             return;
-        }
-        if (beanFactory == null) {
-            final String beanPath = SystemConfig.getProperty("IMPORTEREXPORTER");
-            if (beanPath != null) {
-                final SpringParser springParser = ServerServiceRegistry.getInstance().getService(SpringParser.class);
-                beanFactory = springParser.parseFile(beanPath, ImportExport.class.getClassLoader());
-            } else {
-                LOG.error("missing property: IMPORTEREXPORTER");
-            }
-        }
-        if (beanFactory != null) {
-            importerExporter = (ImporterExporter) beanFactory.getBean("importerExporter");
-        }
 
+        importerExporter = new ImporterExporter();
+
+        importerExporter.addExporter(new ICalExporter());
+        importerExporter.addExporter(new VCardExporter());
+        importerExporter.addExporter(new CSVContactExporter());
+
+        importerExporter.addImporter(new ICalImporter());
+        importerExporter.addImporter(new VCardImporter());
         importerExporter.addImporter(new CSVContactImporter());
-
+        importerExporter.addImporter(new FacebookFriendsImporter());
+        importerExporter.addImporter(new FacebookArchiveImporter());
         importerExporter.addImporter(getOutlookImporter());
     }
 
     /**
-     * @return
+     * reads out the .properies files and creates all importers given there.
      */
     public static Importer getOutlookImporter() {
         OutlookCSVContactImporter outlook = new OutlookCSVContactImporter();
@@ -146,7 +144,7 @@ public abstract class ImportExport extends SessionServlet {
                     continue;
                 Properties props = new Properties();
                 props.load(new FileInputStream(file));
-                PropertyDrivenMapper mapper = new PropertyDrivenMapper(props);
+                PropertyDrivenContactFieldMapper mapper = new PropertyDrivenContactFieldMapper(props);
                 outlook.addFieldMappers(mapper);
                 mapperAmount++;
             }
