@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -77,13 +77,13 @@ import com.openexchange.ajax.request.ServletRequestAdapter;
 import com.openexchange.ajax.writer.ResponseWriter;
 import com.openexchange.api.OXPermissionException;
 import com.openexchange.api2.OXException;
+import com.openexchange.database.provider.DBPoolProvider;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreFacade;
-import com.openexchange.groupware.infostore.SearchEngine;
-import com.openexchange.groupware.infostore.ThreadLocalSessionHolder;
+import com.openexchange.groupware.infostore.InfostoreSearchEngine;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.infostore.database.impl.GetSwitch;
 import com.openexchange.groupware.infostore.database.impl.SetSwitch;
@@ -93,22 +93,22 @@ import com.openexchange.groupware.infostore.search.impl.SearchEngineImpl;
 import com.openexchange.groupware.infostore.utils.InfostoreConfigUtils;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.DBPoolProvider;
-import com.openexchange.groupware.tx.TransactionException;
+import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.groupware.upload.impl.UploadEvent;
 import com.openexchange.groupware.upload.impl.UploadException;
-import com.openexchange.groupware.upload.impl.UploadFile;
 import com.openexchange.groupware.upload.impl.UploadSizeExceededException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
+import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 import com.openexchange.tools.UnsynchronizedStringWriter;
 import com.openexchange.tools.exceptions.LoggingLogic;
 import com.openexchange.tools.servlet.UploadServletException;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tx.TransactionException;
 
 public class Infostore extends PermissionServlet {
 
@@ -132,7 +132,7 @@ public class Infostore extends PermissionServlet {
         FACADE.setSessionHolder(ThreadLocalSessionHolder.getInstance());
     }
 
-    public static final SearchEngine SEARCH_ENGINE = new SearchEngineImpl(new DBPoolProvider());
+    public static final InfostoreSearchEngine SEARCH_ENGINE = new SearchEngineImpl(new DBPoolProvider());
     static {
         SEARCH_ENGINE.setTransactional(true);
     }
@@ -140,7 +140,7 @@ public class Infostore extends PermissionServlet {
     // public static final Exception2Message OXEXCEPTION_HANDLER = new
     // InfostoreException2Message();
 
-    private static final Log LOG = LogFactory.getLog(Infostore.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Infostore.class));
 
     private static final LoggingLogic LL = LoggingLogic.getLoggingLogic(Infostore.class, LOG);
 
@@ -388,7 +388,7 @@ public class Infostore extends PermissionServlet {
         res.setContentType(MIME_TEXT_HTML);
 
         final InfostoreFacade infostore = getInfostore(newDocument.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
         FileInputStream in = null;
         try {
 
@@ -413,6 +413,9 @@ public class Infostore extends PermissionServlet {
         } catch (final FileNotFoundException e) {
             rollback(infostore, searchEngine, res, e, ACTION_NEW, true);
             return;
+        } catch (TransactionException e) {
+            rollback(infostore, searchEngine, res, e, ACTION_NEW, true);
+            return;
         } finally {
             try {
                 infostore.finish();
@@ -466,7 +469,7 @@ public class Infostore extends PermissionServlet {
         res.setContentType(MIME_TEXT_HTML);
 
         final InfostoreFacade infostore = getInfostore(updated.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
 
         try {
 
@@ -488,6 +491,9 @@ public class Infostore extends PermissionServlet {
         } catch (final FileNotFoundException e) {
             rollback(infostore, null, res, e, ACTION_UPDATE, true);
             return;
+        } catch (TransactionException e) {
+            rollback(infostore, null, res, e, ACTION_UPDATE, true);
+            return;
         } finally {
             try {
                 infostore.finish();
@@ -513,7 +519,7 @@ public class Infostore extends PermissionServlet {
         res.setContentType(MIME_TEXT_HTML);
 
         final InfostoreFacade infostore = getInfostore();
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
         DocumentMetadata metadata = null;
 
         try {
@@ -557,6 +563,9 @@ public class Infostore extends PermissionServlet {
         } catch (final FileNotFoundException e) {
             rollback(infostore, searchEngine, res, e, ACTION_COPY, true);
             return;
+        } catch (TransactionException e) {
+            rollback(infostore, searchEngine, res, e, ACTION_COPY, true);
+            return;
         } finally {
             try {
                 infostore.finish();
@@ -595,7 +604,14 @@ public class Infostore extends PermissionServlet {
 
             res.setContentLength((int) metadata.getFileSize());
             if (SAVE_AS_TYPE.equals(contentType)) {
-                Tools.setHeaderForFileDownload(userAgent, res, metadata.getFileName());
+                String contentDisposition = null;
+                if (null == contentDisposition) {
+                    final StringBuilder sb = new StringBuilder(32).append("attachment");
+                    DownloadUtility.appendFilenameParameter(metadata.getFileName(), SAVE_AS_TYPE, userAgent, sb);
+                    res.setHeader("Content-Disposition", sb.toString());
+                } else {
+                    Tools.setHeaderForFileDownload(userAgent, res, metadata.getFileName());
+                }
                 res.setContentType(contentType);
             } else {
                 final CheckedDownload checkedDownload = DownloadUtility.checkInlineDownload(
@@ -655,7 +671,7 @@ public class Infostore extends PermissionServlet {
         if (t instanceof AbstractOXException) {
             e = (AbstractOXException) t;
         } else {
-            e = new AbstractOXException(t); 
+            e = new AbstractOXException(t);
         }
         final Response resp = new Response();
         resp.setException(e);
@@ -732,7 +748,7 @@ public class Infostore extends PermissionServlet {
         }
     }
 
-    protected void rollback(final InfostoreFacade infostore, final SearchEngine searchEngine, final HttpServletResponse res, final Throwable t, final String action, final boolean post) {
+    protected void rollback(final InfostoreFacade infostore, final InfostoreSearchEngine searchEngine, final HttpServletResponse res, final Throwable t, final String action, final boolean post) {
         if (infostore != null) {
             try {
                 infostore.rollback();
@@ -787,7 +803,7 @@ public class Infostore extends PermissionServlet {
         return FACADE;
     }
 
-    protected SearchEngine getSearchEngine() {
+    protected InfostoreSearchEngine getSearchEngine() {
         return SEARCH_ENGINE;
     }
 
