@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,19 +62,19 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.ajax.parser.DataParser;
+import com.openexchange.ajax.request.AttachmentRequest;
 import com.openexchange.ajax.request.FolderRequest;
-import com.openexchange.ajax.request.InfostoreRequest;
 import com.openexchange.ajax.request.JSONSimpleRequest;
 import com.openexchange.ajax.request.MailRequest;
-import com.openexchange.ajax.request.QuotaRequest;
 import com.openexchange.ajax.writer.ResponseWriter;
-import com.openexchange.api.OXPermissionException;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.multiple.MultipleHandler;
 import com.openexchange.multiple.MultipleHandlerFactoryService;
+import com.openexchange.multiple.PathAware;
 import com.openexchange.multiple.internal.MultipleHandlerRegistry;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.exceptions.LoggingLogic;
@@ -96,55 +96,59 @@ public class Multiple extends SessionServlet {
 
     protected static final String MODULE_FOLDERS = "folders";
 
-    protected static final String MODULE_QUOTA = "quota";
-
     private static final String ATTRIBUTE_MAIL_INTERFACE = "mi";
 
     private static final String ATTRIBUTE_MAIL_REQUEST = "mr";
 
-    private static final transient Log LOG = LogFactory.getLog(Multiple.class);
-    
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Multiple.class));
+
     private static final LoggingLogic LL = LoggingLogic.getLoggingLogic(Multiple.class, LOG);
 
     @Override
     protected void doPut(final HttpServletRequest req, final HttpServletResponse resp) throws IOException {
-        JSONArray dataArray = null;
-        final String data = getBody(req);
-
-        try {
-            dataArray = new JSONArray(data);
-        } catch (final JSONException e) {
-            final AbstractOXException exc = new OXJSONException(OXJSONException.Code.JSON_READ_ERROR, e, data);
-            LOG.error(exc.getMessage() + Tools.logHeaderForError(req), exc);
-            dataArray = new JSONArray();
-        }
-
-        final JSONArray respArr = new JSONArray();
-        try {
-            final ServerSession session = getSessionObject(req);
-            for (int a = 0; a < dataArray.length(); a++) {
-                parseActionElement(respArr, dataArray, a, session, req);
+        JSONArray dataArray;
+        {
+            final String data = getBody(req);
+            try {
+                dataArray = new JSONArray(data);
+            } catch (final JSONException e) {
+                final AbstractOXException exc = new OXJSONException(OXJSONException.Code.JSON_READ_ERROR, e, data);
+                LOG.warn(exc.getMessage() + Tools.logHeaderForError(req), exc);
+                dataArray = new JSONArray();
             }
-            /*
-             * Don't forget to write mail request
-             */
-            writeMailRequest(req);
-        } catch (final JSONException e) {
-            log(RESPONSE_ERROR, e);
-            sendError(resp);
-        } catch (final AjaxException e) {
-            log(RESPONSE_ERROR, e);
-            sendError(resp);
-        } catch (final AbstractOXException e) {
-            log(RESPONSE_ERROR, e);
-            sendError(resp);
-        } finally {
-            final MailServletInterface mi = (MailServletInterface) req.getAttribute(ATTRIBUTE_MAIL_INTERFACE);
-            if (mi != null) {
-                try {
-                    mi.close(true);
-                } catch (final MailException e) {
-                    LOG.error(e.getMessage(), e);
+        }
+        final JSONArray respArr = new JSONArray();
+        final int length = dataArray.length();
+        if (length > 0) {
+            try {
+                final ServerSession session = getSessionObject(req);
+                for (int a = 0; a < length; a++) {
+                    parseActionElement(respArr, dataArray, a, session, req);
+                }
+                /*
+                 * Don't forget to write mail request
+                 */
+                writeMailRequest(req);
+            } catch (final JSONException e) {
+                log(RESPONSE_ERROR, e);
+                sendError(resp);
+            } catch (final AjaxException e) {
+                log(RESPONSE_ERROR, e);
+                sendError(resp);
+            } catch (final AbstractOXException e) {
+                log(RESPONSE_ERROR, e);
+                sendError(resp);
+            } catch (final RuntimeException e) {
+                log(RESPONSE_ERROR, e);
+                sendError(resp);
+            } finally {
+                final MailServletInterface mi = (MailServletInterface) req.getAttribute(ATTRIBUTE_MAIL_INTERFACE);
+                if (mi != null) {
+                    try {
+                        mi.close(true);
+                    } catch (final MailException e) {
+                        LOG.error(e.getMessage(), e);
+                    }
                 }
             }
         }
@@ -167,11 +171,7 @@ public class Multiple extends SessionServlet {
             throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, MODULE);
         }
 
-        if (jsonObj.has(PARAMETER_ACTION)) {
-            action = DataParser.checkString(jsonObj, PARAMETER_ACTION);
-        } else {
-            throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, PARAMETER_ACTION);
-        }
+        action = jsonObj.optString(PARAMETER_ACTION);
 
         final OXJSONWriter jWriter = new OXJSONWriter(respArr);
 
@@ -200,12 +200,24 @@ public class Multiple extends SessionServlet {
             /*
              * Look up appropriate multiple handler first, then step through if-else-statement
              */
+            {
+                final HostnameService hostnameService = ServerServiceRegistry.getInstance().getService(HostnameService.class);
+                if (null == hostnameService) {
+                    jsonObj.put(MultipleHandler.HOSTNAME, req.getServerName());
+                } else {
+                    final String hn = hostnameService.getHostname(session.getUserId(), session.getContextId());
+                    jsonObj.put(MultipleHandler.HOSTNAME, null == hn ? req.getServerName() : hn);
+                }
+            }
+            jsonObj.put(MultipleHandler.ROUTE, Tools.getRoute(req.getSession(true).getId()));
+            jsonObj.put(MultipleHandler.REMOTE_ADDRESS, req.getRemoteAddr());
+
             final MultipleHandler multipleHandler = lookUpMultipleHandler(module);
             if (null != multipleHandler) {
                 writeMailRequest(req);
                 jsonWriter.object();
                 try {
-                    final Object tmp = multipleHandler.performRequest(action, jsonObj, session, req.isSecure());
+                    final Object tmp = multipleHandler.performRequest(action, jsonObj, session, Tools.considerSecure(req));
                     jsonWriter.key(ResponseFields.DATA);
                     jsonWriter.value(tmp);
                     final Date timestamp = multipleHandler.getTimestamp();
@@ -233,7 +245,7 @@ public class Multiple extends SessionServlet {
                     multipleHandler.close();
                     jsonWriter.endObject();
                 }
-            } else if (MODULE_INFOSTORE.equals(module)) {
+            /*} else if (MODULE_INFOSTORE.equals(module)) {
                 writeMailRequest(req);
                 final InfostoreRequest infoRequest = new InfostoreRequest(session, jsonWriter);
                 try {
@@ -242,11 +254,7 @@ public class Multiple extends SessionServlet {
                     jsonWriter.object();
                     ResponseWriter.writeException(e, jsonWriter);
                     jsonWriter.endObject();
-                }
-            } else if (MODULE_QUOTA.equals(module)) {
-                writeMailRequest(req);
-                final QuotaRequest quotaRequest = new QuotaRequest(session, jsonWriter);
-                quotaRequest.action(action);
+                } */
             } else if (MODULE_FOLDER.equals(module) || MODULE_FOLDERS.equals(module)) {
                 writeMailRequest(req);
                 final FolderRequest folderequest = new FolderRequest(session, jsonWriter);
@@ -313,6 +321,9 @@ public class Multiple extends SessionServlet {
                     ResponseWriter.writeException(oje, jsonWriter);
                     jsonWriter.endObject();
                 }
+            } else if (MODULE_ATTACHMENTS.equals(module)) {
+                    final AttachmentRequest request = new AttachmentRequest(session, jsonWriter);
+                    request.action(action, new JSONSimpleRequest(jsonObj));
             } else {
                 final AjaxException ajaxException = new AjaxException(AjaxException.Code.UNKNOWN_MODULE, module);
                 LOG.error(ajaxException.getMessage(), ajaxException);
@@ -333,7 +344,12 @@ public class Multiple extends SessionServlet {
         if (null != registry) {
             final MultipleHandlerFactoryService factoryService = registry.getFactoryService(module);
             if (null != factoryService) {
-                return factoryService.createMultipleHandler();
+                final MultipleHandler multipleHandler = factoryService.createMultipleHandler();
+                if(PathAware.class.isInstance(multipleHandler)) {
+                    final PathAware pa = (PathAware) multipleHandler;
+                    pa.setPath(module.substring(factoryService.getSupportedModule().length()));
+                }
+                return multipleHandler;
             }
         }
         return null;
