@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,11 +63,12 @@ import org.json.JSONObject;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.AbstractOXException.Category;
+import com.openexchange.groupware.EnumComponent;
 import com.openexchange.multiple.MultipleHandler;
 import com.openexchange.tools.exceptions.LoggingLogic;
 import com.openexchange.tools.servlet.AjaxException;
+import com.openexchange.tools.servlet.http.Tools;
 
 
 /**
@@ -78,28 +79,32 @@ import com.openexchange.tools.servlet.AjaxException;
  */
 public abstract class MultipleAdapterServlet extends PermissionServlet {
 
-    private static final Log LOG = LogFactory.getLog(MultipleAdapterServlet.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MultipleAdapterServlet.class));
     private static final LoggingLogic LL = LoggingLogic.getLoggingLogic(MultipleAdapterServlet.class, LOG);
-    
+
 
     @Override
     protected void doGet(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         handle(req, resp);
     }
-    
+
     @Override
     protected void doPut(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         handle(req, resp);
     }
-    
+
     @Override
     protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         handle(req, resp);
     }
-    
-    
+
+
     protected void handle(final HttpServletRequest req, final HttpServletResponse resp) {
-        if(handleOverride(req, resp)) {
+        resp.setStatus(HttpServletResponse.SC_OK);
+        resp.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT);
+        Tools.disableCaching(resp);
+
+        if (handleOverride(req, resp)) {
             return;
         }
         try {
@@ -107,12 +112,12 @@ public abstract class MultipleAdapterServlet extends PermissionServlet {
             final JSONObject request = toJSON(req, action);
             final MultipleHandler handler = createMultipleHandler();
 
-            if(action == null) {
+            if (action == null) {
                 throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, PARAMETER_ACTION);
             }
-            final Object response = handler.performRequest(action, request, getSessionObject(req), req.isSecure());
+            final Object response = handler.performRequest(action, request, getSessionObject(req), Tools.considerSecure(req));
             final Date timestamp = handler.getTimestamp();
-            writeResponseSafely(response, timestamp, handler.getWarnings(), resp);       
+            writeResponseSafely(response, timestamp, handler.getWarnings(), resp);
         } catch (final AbstractOXException x) {
             writeException(x, resp);
         } catch (final Throwable t) {
@@ -145,7 +150,7 @@ public abstract class MultipleAdapterServlet extends PermissionServlet {
             LOG.error(e.getMessage(), e);
         }
     }
-    
+
     private void writeException(final AbstractOXException x, final HttpServletResponse resp) {
         LL.log(x);
         final Response response = new Response();
