@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,12 +51,16 @@ package com.openexchange.ajax;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.StringWriter;
 import java.util.Collection;
-import java.util.Set;
+import java.util.Iterator;
 import java.util.Map.Entry;
+import java.util.Set;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.apache.commons.fileupload.FileUploadBase;
+import org.apache.commons.fileupload.servlet.ServletRequestContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
@@ -69,14 +73,20 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.writer.ResponseWriter;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.notify.hostname.HostnameService;
+import com.openexchange.groupware.upload.UploadFile;
+import com.openexchange.groupware.upload.impl.UploadEvent;
+import com.openexchange.groupware.upload.impl.UploadException;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.servlet.http.Tools;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link MultipleAdapterServletNew} is a rewrite of the really good {@link MultipleAdapterServlet} with smarter handling of the request
  * parameters.
- * 
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public abstract class MultipleAdapterServletNew extends PermissionServlet {
@@ -96,13 +106,13 @@ public abstract class MultipleAdapterServletNew extends PermissionServlet {
 
     private static final long serialVersionUID = -8060034833311074781L;
 
-    private static final Log LOG = LogFactory.getLog(MultipleAdapterServletNew.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MultipleAdapterServletNew.class));
 
     private final AJAXActionServiceFactory factory;
 
     /**
      * Initializes a new {@link MultipleAdapterServletNew}.
-     * 
+     *
      * @param factory The factory to map incoming request to an appropriate {@link AJAXActionService}
      * @throws NullPointerException If factory is <code>null</code>
      */
@@ -131,7 +141,7 @@ public abstract class MultipleAdapterServletNew extends PermissionServlet {
 
     /**
      * Handles given HTTP request and generates an appropriate result using referred {@link AJAXActionService}.
-     * 
+     *
      * @param req The HTTP request to handle
      * @param resp The HTTP response to write to
      * @param preferStream <code>true</code> to prefer passing request's body as binary data using an {@link InputStream} (typically for
@@ -139,18 +149,30 @@ public abstract class MultipleAdapterServletNew extends PermissionServlet {
      * @throws IOException If an I/O error occurs
      */
     protected final void handle(final HttpServletRequest req, final HttpServletResponse resp, final boolean preferStream) throws IOException, ServletException {
+        resp.setStatus(HttpServletResponse.SC_OK);
+        resp.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT);
+        Tools.disableCaching(resp);
+
+        final String action = req.getParameter(PARAMETER_ACTION);
+        final boolean isFileUpload = FileUploadBase.isMultipartContent(new ServletRequestContext(req));
+
         final Response response = new Response();
         try {
-            final String action = req.getParameter(PARAMETER_ACTION);
             if (action == null) {
                 throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, PARAMETER_ACTION);
             }
-            if(handleIndividually(action, req, resp)) {
+            if (handleIndividually(action, req, resp)) {
                 return;
             }
-            
-            final AJAXRequestData data = parseRequest(req, preferStream);
-            final AJAXRequestResult result = factory.createActionService(action).perform(data, getSessionObject(req));
+
+            final ServerSession session = getSessionObject(req);
+
+            final AJAXRequestData data = parseRequest(req, preferStream(action, req, resp, preferStream), isFileUpload, session);
+            if (handleIndividually(action, data, req, resp)) {
+                return;
+            }
+
+            final AJAXRequestResult result = factory.createActionService(action).perform(data, session);
             response.setData(result.getResultObject());
             response.setTimestamp(result.getTimestamp());
             final Collection<AbstractOXException> warnings = result.getWarnings();
@@ -161,32 +183,76 @@ public abstract class MultipleAdapterServletNew extends PermissionServlet {
             LOG.error(e.getMessage(), e);
             response.setException(e);
         }
-        resp.setStatus(HttpServletResponse.SC_OK);
-        resp.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT);
-        Tools.disableCaching(resp);
         try {
-            ResponseWriter.write(response, resp.getWriter());
+            final String param;
+            if (isFileUpload || ((param = req.getParameter("respondWithHTML")) != null && param.equalsIgnoreCase("true"))) {
+                resp.setContentType(AJAXServlet.CONTENTTYPE_HTML);
+                String callback = req.getParameter("callback");
+                if (callback == null) {
+                    callback = action;
+                }
+                final StringWriter w = new StringWriter();
+                ResponseWriter.write(response, w);
+
+                resp.getWriter().print(substituteJS(w.toString(), callback));
+            } else {
+                ResponseWriter.write(response, resp.getWriter());
+            }
         } catch (final JSONException e) {
             final OXJSONException e1 = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e);
             LOG.error(e1.getMessage(), e1);
             sendError(resp);
         }
     }
+    
+    protected boolean preferStream(final String action, final HttpServletRequest req, final HttpServletResponse resp, final boolean suggestion) {
+        return suggestion;
+    }
 
     /**
-     * Override this to handle an action differently from the usual JSON handling. This is primarily useful for handling up / downloads
+     * Override this to handle an action differently from the usual JSON handling. This is primarily useful for handling up- / downloads.
+     *
      * @param action The action parameter given
      * @param req The HTTP request object
      * @param resp The HTTP response object
-     * @return
+     * @return <code>true</code> if operation completed successfully and therefore usual JSON handling must be omitted; otherwise <code>false</code> to fall-back to usual JSON handling
+     * @throws AbstractOXException
      */
-    protected boolean handleIndividually(String action, HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException {
+    protected boolean handleIndividually(final String action, final HttpServletRequest req, final HttpServletResponse resp) throws IOException, ServletException, AbstractOXException {
         return false;
     }
 
-    protected AJAXRequestData parseRequest(final HttpServletRequest req, final boolean preferStream) throws IOException {
+    /**
+     * Override this to handle an action differently from the usual JSON handling. This is primarily useful for handling up- / downloads.
+     *
+     * @param action The action parameter given
+     * @param data The parsed request
+     * @param req The HTTP request object
+     * @param resp The HTTP response object
+     * @return <code>true</code> if operation completed successfully and therefore usual JSON handling must be omitted; otherwise <code>false</code> to fall-back to usual JSON handling
+     * @throws AbstractOXException
+     * @throws ServletException
+     * @throws IOException
+     * @throws AbstractOXException
+     */
+    protected boolean handleIndividually(final String action, final AJAXRequestData data, final HttpServletRequest req, final HttpServletResponse resp) throws IOException, ServletException, AbstractOXException {
+        return false;
+    }
+
+    protected AJAXRequestData parseRequest(final HttpServletRequest req, final boolean preferStream, final boolean isFileUpload, final ServerSession session) throws IOException, UploadException {
         final AJAXRequestData retval = new AJAXRequestData();
-        retval.setSecure(req.isSecure());
+        retval.setSecure(Tools.considerSecure(req));
+        {
+            final HostnameService hostnameService = ServerServiceRegistry.getInstance().getService(HostnameService.class);
+            if (null == hostnameService) {
+                retval.setHostname(req.getServerName());
+            } else {
+                final String hn = hostnameService.getHostname(session.getUserId(), session.getContextId());
+                retval.setHostname(null == hn ? req.getServerName() : hn);
+            }
+        }
+        retval.setRemoteAddress(req.getRemoteAddr());
+        retval.setRoute(Tools.getRoute(req.getSession(true).getId()));
         /*
          * Pass all parameters to AJAX request object
          */
@@ -196,7 +262,19 @@ public abstract class MultipleAdapterServletNew extends PermissionServlet {
                 retval.putParameter(entry.getKey(), entry.getValue()[0]);
             }
         }
-        if (preferStream) {
+        if (isFileUpload) {
+            final UploadEvent upload = processUpload(req);
+            final Iterator<UploadFile> iterator = upload.getUploadFilesIterator();
+            while(iterator.hasNext()) {
+                retval.addFile(iterator.next());
+            }
+            final Iterator<String> names = upload.getFormFieldNames();
+            while(names.hasNext()) {
+                final String name = names.next();
+                retval.putParameter(name, upload.getFormField(name));
+            }
+            retval.setUploadEvent(upload);
+        } else if (preferStream) {
             /*
              * Pass request's stream
              */
