@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,17 +50,16 @@
 package com.openexchange.ajax;
 
 import java.io.IOException;
-import java.io.Writer;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
-import org.json.JSONObject;
+import org.json.JSONValue;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.request.QuotaRequest;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.json.OXJSONWriter;
-import com.openexchange.tools.exceptions.LoggingLogic;
+import com.openexchange.tools.servlet.AjaxException;
+import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.session.ServerSession;
 
 public class Quota extends SessionServlet {
@@ -68,67 +67,43 @@ public class Quota extends SessionServlet {
 	private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
 			.getLog(Quota.class);
 
-    private static final transient LoggingLogic LL = LoggingLogic.getLoggingLogic(Quota.class, LOG);
-
     private static final long serialVersionUID = 6477434510302882905L;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
-	 *      javax.servlet.http.HttpServletResponse)
-	 */
 	@Override
 	protected void doGet(final HttpServletRequest req, final HttpServletResponse res) throws ServletException,
 			IOException {
+        final Response response = new Response();
+        try {
+            final String action = req.getParameter(PARAMETER_ACTION);
+            if (null == action) {
+                throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, PARAMETER_ACTION);
+            }
+            final ServerSession session = getSessionObject(req);
 
-		final String action = req.getParameter(PARAMETER_ACTION);
-		if (action == null) {
-			missingParameter(PARAMETER_ACTION, res, false, null);
-			return;
-		}
+            final QuotaRequest fsReq = new QuotaRequest(session);
+            final JSONValue responseObj = fsReq.action(action);
 
-        final ServerSession session = getSessionObject(req);
-
-
-        final OXJSONWriter writer = new OXJSONWriter();
-		final QuotaRequest fsReq = new QuotaRequest(session, writer);
-		if (!fsReq.action(action)) {
-			unknownAction("GET", action, res, false);
-			return;
-		}
-		try {
-		    ((JSONObject) writer.getObject()).write(res.getWriter());
-		} catch (final JSONException e) {
-			if (e.getCause() instanceof IOException) {
-				/*
-				 * Throw proper I/O error since a serious socket error could
-				 * been occurred which prevents further communication. Just
-				 * throwing a JSON error possibly hides this fact by trying to
-				 * write to/read from a broken socket connection.
-				 */
-				throw (IOException) e.getCause();
-			}
-			LOG.error(e.getMessage(), e);
-		}
+            // response.setTimestamp(fsReq.getTimestamp());
+            response.setData(responseObj);
+        } catch (final JSONException e) {
+            final Throwable cause = e.getCause();
+            if (cause instanceof IOException) {
+                /*
+                 * Throw proper I/O error since a serious socket error could
+                 * been occurred which prevents further communication. Just
+                 * throwing a JSON error possibly hides this fact by trying to
+                 * write to/read from a broken socket connection.
+                 */
+                throw (IOException) cause;
+            }
+            final OXJSONException oje = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e);
+            LOG.error(oje.getMessage(), oje);
+            response.setException(oje);
+        } catch (final AbstractOXException e) {
+            LOG.error(e.getMessage(), e);
+            response.setException(e);
+        }
+        writeResponse(response, res);
 	}
 
-
-    private void handle(final HttpServletResponse res, final AbstractOXException t) {
-		LL.log(t);
-
-		final Response resp = new Response();
-		resp.setException(t);
-
-
-		try {
-			final Writer writer = res.getWriter();
-			Response.write(resp, writer);
-
-		} catch (final JSONException e) {
-			LOG.error("",t);
-		} catch (final IOException e) {
-			LOG.error("",e);
-		}
-	}
 }
