@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,14 +71,14 @@ import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.session.ServerSession;
 
 public class Reminder extends DataServlet {
-	
+
 	/**
 	 * For serialization.
 	 */
 	private static final long serialVersionUID = 7117849531568676025L;
-	
-	private static final Log LOG = LogFactory.getLog(Reminder.class);
-	
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Reminder.class));
+
 	@Override
 	protected void doGet(final HttpServletRequest httpServletRequest, final HttpServletResponse httpServletResponse) throws ServletException, IOException {
 		final Response response = new Response();
@@ -86,7 +86,7 @@ public class Reminder extends DataServlet {
 			final String action = parseMandatoryStringParameter(httpServletRequest, PARAMETER_ACTION);
 			final ServerSession session = getSessionObject(httpServletRequest);
 			JSONObject jsonObj;
-			
+
 			try {
 				jsonObj = convertParameter2JSONObject(httpServletRequest);
 			} catch (final JSONException e) {
@@ -127,20 +127,20 @@ public class Reminder extends DataServlet {
             LOG.error(exc.getMessage(), exc);
             response.setException(exc);
 		}
-		
+
 		writeResponse(response, httpServletResponse);
 	}
-	
+
 	@Override
 	protected void doPut(final HttpServletRequest httpServletRequest, final HttpServletResponse httpServletResponse) throws ServletException, IOException {
 		final Response response = new Response();
 		try {
 			final String action = parseMandatoryStringParameter(httpServletRequest, PARAMETER_ACTION);
 			final ServerSession session = getSessionObject(httpServletRequest);
-			
+
 			final String data = getBody(httpServletRequest);
 			JSONObject jsonObj;
-			
+
 			try {
 				jsonObj = convertParameter2JSONObject(httpServletRequest);
 			} catch (final JSONException e) {
@@ -156,13 +156,13 @@ public class Reminder extends DataServlet {
 				final JSONArray jData = new JSONArray(data);
 
 				jsonObj.put(PARAMETER_DATA, jData);
-				
+
 				final JSONValue responseObj = reminderRequest.action(action, jsonObj);
 				response.setData(responseObj);
 			} else {
 				final JSONObject jData = new JSONObject(data);
 				jsonObj.put(PARAMETER_DATA, jData);
-				
+
 				final Object responseObj = reminderRequest.action(action, jsonObj);
 				response.setData(responseObj);
 			}
@@ -193,10 +193,10 @@ public class Reminder extends DataServlet {
             LOG.error(exc.getMessage(), exc);
             response.setException(exc);
 		}
-		
+
 		writeResponse(response, httpServletResponse);
 	}
-	
+
 	@Override
 	protected boolean hasModulePermission(final ServerSession session) {
 		return true;
