@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,15 +60,8 @@ import org.json.JSONObject;
 import org.json.JSONValue;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.request.TaskRequest;
-import com.openexchange.api.OXConflictException;
-import com.openexchange.api.OXMandatoryFieldException;
-import com.openexchange.api.OXObjectNotFoundException;
-import com.openexchange.api.OXPermissionException;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.AbstractOXException.Category;
-import com.openexchange.tools.iterator.SearchIteratorException;
-import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
-import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.session.ServerSession;
 
@@ -81,7 +74,7 @@ public class Tasks extends DataServlet {
 
     private static final long serialVersionUID = 8092832647688901704L;
 
-    private static final Log LOG = LogFactory.getLog(Tasks.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Tasks.class));
 
     @Override
     protected void doGet(final HttpServletRequest httpServletRequest, final HttpServletResponse httpServletResponse) throws IOException {
@@ -102,41 +95,17 @@ public class Tasks extends DataServlet {
             final JSONValue responseObj = taskRequest.action(action, jsonObj);
             response.setTimestamp(taskRequest.getTimestamp());
             response.setData(responseObj);
-        } catch (final OXMandatoryFieldException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXConflictException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final JSONException e) {
-            final OXJSONException oje = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e);
-            LOG.error(oje.getMessage(), oje);
-            response.setException(oje);
-        } catch (final OXJSONException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXFolderNotFoundException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXObjectNotFoundException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXPermissionException e) {
-            LOG.info(e.getMessage(), e);
-            response.setException(e);
-        } catch (final SearchIteratorException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final AjaxException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXException e) {
+        } catch (final AbstractOXException e) {
             if (e.getCategory() == Category.USER_INPUT) {
                 LOG.debug(e.getMessage(), e);
             } else {
                 LOG.error(e.getMessage(), e);
             }
             response.setException(e);
+         } catch (final JSONException e) {
+            final OXJSONException oje = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e);
+            LOG.error(oje.getMessage(), oje);
+            response.setException(oje);
         }
         writeResponse(response, httpServletResponse);
     }
@@ -186,16 +155,7 @@ public class Tasks extends DataServlet {
             final OXJSONException oje = new OXJSONException(OXJSONException.Code.JSON_WRITE_ERROR, e);
             LOG.error(oje.getMessage(), oje);
             response.setException(oje);
-        } catch (final OXJSONException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final SearchIteratorException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final AjaxException e) {
-            LOG.error(e.getMessage(), e);
-            response.setException(e);
-        } catch (final OXException e) {
+        } catch (final AbstractOXException e) {
             if (e.getCategory() == Category.USER_INPUT) {
                 LOG.debug(e.getMessage(), e);
             } else {
