@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,9 @@
 
 package com.openexchange.ajax.customizer.folder;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -59,7 +60,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link AdditionalFolderFieldList}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -67,14 +68,14 @@ public class AdditionalFolderFieldList {
 
     // TODO: Track service ranking and allow fields to overwrite other fields.
 
-    private static final Log LOG = LogFactory.getLog(AdditionalFolderFieldList.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AdditionalFolderFieldList.class));
 
     private final TIntObjectHashMap<AdditionalFolderField> byColId = new TIntObjectHashMap<AdditionalFolderField>();
     private final Map<String, AdditionalFolderField> byName = new HashMap<String, AdditionalFolderField>();
 
     /**
      * Adds an additional folder field to this list.
-     * 
+     *
      * @param field The additional folder field
      */
     public synchronized void addField(final AdditionalFolderField field) {
@@ -93,7 +94,7 @@ public class AdditionalFolderFieldList {
 
     /**
      * Gets the additional folder field associated with specified column number.
-     * 
+     *
      * @param col The column number
      * @return The additional folder field associated with specified column number or a neutral <code>null</code> field
      */
@@ -102,9 +103,18 @@ public class AdditionalFolderFieldList {
         return null == additionalFolderField ? new NullField(col) : additionalFolderField;
     }
 
+    /**
+     * Gets known fields.
+     *
+     * @return The known fields
+     */
+    public int[] getKnownFields() {
+        return byColId.keys();
+    }
+
     /**
      * Gets the additional folder field associated with specified column name.
-     * 
+     *
      * @param col The column name
      * @return The additional folder field associated with specified column name or a <code>null</code>
      */
@@ -114,7 +124,7 @@ public class AdditionalFolderFieldList {
 
     /**
      * Checks if an additional folder field is associated with specified column number.
-     * 
+     *
      * @param col The column number
      * @return <code>true</code> if an additional folder field is associated with specified column number; otherwise <code>false</code>
      */
@@ -124,7 +134,7 @@ public class AdditionalFolderFieldList {
 
     /**
      * Checks if an additional folder field is associated with specified column name.
-     * 
+     *
      * @param col The column name
      * @return <code>true</code> if an additional folder field is associated with specified column name; otherwise <code>false</code>
      */
@@ -134,7 +144,7 @@ public class AdditionalFolderFieldList {
 
     /**
      * Removes the additional folder field associated with specified column number.
-     * 
+     *
      * @param colId The column number
      */
     public synchronized void remove(final int colId) {
@@ -174,5 +184,9 @@ public class AdditionalFolderFieldList {
             return null;
         }
 
+        public List<Object> getValues(List<FolderObject> folder, ServerSession session) {
+            return AdditionalFieldsUtils.bulk(this, folder, session);
+        }
+
     }
 }
