@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -98,10 +98,16 @@ public interface CalendarFields extends CommonFields {
     public static final String USERS = "users";
 
     public static final String CONFIRMATIONS = "confirmations";
-    
+
     public static final String ORGANIZER = "organizer";
     
-    public static final String UID = "uid";
+    public static final String ORGANIZER_ID = "organizerId";
     
+    public static final String PRINCIPAL = "principal";
+    
+    public static final String PRINCIPAL_ID = "principalId";
+
+    public static final String UID = "uid";
+
     public static final String SEQUENCE = "sequence";
 }
