@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,7 @@ import com.openexchange.tools.servlet.OXJSONException;
 /**
  * Parses JSON to contact objects.
  *
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class ContactParser extends CommonParser {
 
@@ -79,7 +79,7 @@ public class ContactParser extends CommonParser {
     public void parse(final Contact contactobject, final JSONObject jsonobject) throws OXJSONException, ContactException {
         try {
             parseElementContact(contactobject, jsonobject);
-        } catch (JSONException e) {
+        } catch (final JSONException e) {
             throw new OXJSONException(OXJSONException.Code.JSON_READ_ERROR, e);
         }
     }
@@ -901,6 +901,70 @@ public class ContactParser extends CommonParser {
             public void setObject(final Contact contactobject, final JSONObject jsonobject) {
                 contactobject.setUserField20(parseString(jsonobject, ContactFields.USERFIELD20));
             }
+        },
+        new JSONAttributeMapper() {
+        	public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.FILE_AS);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setFileAs(parseString(jsonobject, ContactFields.FILE_AS));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.YOMI_FIRST_NAME);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setYomiFirstName(parseString(jsonobject, ContactFields.YOMI_FIRST_NAME));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.YOMI_LAST_NAME);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setYomiLastName(parseString(jsonobject, ContactFields.YOMI_LAST_NAME));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.YOMI_COMPANY);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setYomiCompany(parseString(jsonobject, ContactFields.YOMI_COMPANY));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.ADDRESS_HOME);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setAddressHome(parseString(jsonobject, ContactFields.ADDRESS_HOME));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.ADDRESS_BUSINESS);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setAddressBusiness(parseString(jsonobject, ContactFields.ADDRESS_BUSINESS));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.ADDRESS_OTHER);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setAddressOther(parseString(jsonobject, ContactFields.ADDRESS_OTHER));
+            }
+        },
+        new JSONAttributeMapper() {
+            public boolean jsonObjectContains(final JSONObject jsonobject) {
+                return jsonobject.has(ContactFields.UID);
+            }
+            public void setObject(final Contact contactobject, final JSONObject jsonobject) {
+                contactobject.setUid(parseString(jsonobject, ContactFields.UID));
+            }
         }
     };
 }
