@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,41 +53,33 @@ import java.util.Date;
 import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.infostore.Classes;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.infostore.utils.URLHelper;
 
-@OXExceptionSource(
-        classId = Classes.COM_OPENEXCHANGE_AJAX_PARSERL_JSONDOCUMENTMETADATA,
-        component = EnumComponent.INFOSTORE
-)
 public class JSONDocumentMetadata implements DocumentMetadata {
 
     private static final long serialVersionUID = -5016635593135118691L;
-    
+
     private static final URLHelper helper = new URLHelper();
-    
-    
+
+
     private final JSONObject jsonObject;
 
-    private static final Log LOG = LogFactory.getLog(JSONDocumentMetadata.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(JSONDocumentMetadata.class));
     private static final String DEFAULT_MIMETYPE = "application/octet-stream";
     //private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(JSONDocumentMetadata.class);
-    
+
     public JSONDocumentMetadata(){
         this.jsonObject = new JSONObject();
     }
-    
+
     public JSONDocumentMetadata(final String json) throws JSONException {
         this.jsonObject = new JSONObject(json);
-        
+
         //Test parsing of complex objects
         if(jsonObject.has(Metadata.URL_LITERAL.getName())) {
             String url = jsonObject.getString(Metadata.URL_LITERAL.getName());
@@ -97,7 +89,7 @@ public class JSONDocumentMetadata implements DocumentMetadata {
             }
         }
     }
-    
+
     public String getProperty(final String key) {
         if(Metadata.get(key) == null) {
             return jsonObject.optString(key);
@@ -144,7 +136,7 @@ public class JSONDocumentMetadata implements DocumentMetadata {
             return -1;
         }
         return jsonObject.optInt(Metadata.MODIFIED_BY_LITERAL.getName());
-    
+
     }
 
     public void setModifiedBy(final int lastEditor) {
@@ -174,7 +166,7 @@ public class JSONDocumentMetadata implements DocumentMetadata {
         if(!jsonObject.has(Metadata.TITLE_LITERAL.getName())) {
             return null;
         }
-        return jsonObject.optString(Metadata.TITLE_LITERAL.getName());    
+        return jsonObject.optString(Metadata.TITLE_LITERAL.getName());
     }
 
     public void setTitle(final String title) {
@@ -360,7 +352,7 @@ public class JSONDocumentMetadata implements DocumentMetadata {
             LOG.error("",e);
         }
     }
-    
+
     public int getColorLabel() {
         return jsonObject.optInt(Metadata.COLOR_LABEL_LITERAL.getName());
     }
@@ -399,12 +391,12 @@ public class JSONDocumentMetadata implements DocumentMetadata {
             LOG.error("",e);
         }
     }
-    
+
     @Override
     public String toString(){
         return jsonObject.toString();
     }
-    
+
     public String toJSONString(){
         return jsonObject.toString();
     }
@@ -425,7 +417,7 @@ public class JSONDocumentMetadata implements DocumentMetadata {
             LOG.error("",e);
         }
     }
-    
+
     public void setNumberOfVersions(final int numberOfVersions) {
         try {
             jsonObject.put(Metadata.NUMBER_OF_VERSIONS_LITERAL.getName(), numberOfVersions);
