@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,22 +50,23 @@
 package com.openexchange.ajax.parser;
 
 import org.json.JSONArray;
+import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.fields.SearchTermFields;
 import com.openexchange.search.CompositeSearchTerm;
+import com.openexchange.search.CompositeSearchTerm.CompositeOperation;
 import com.openexchange.search.Operand;
 import com.openexchange.search.SearchException;
 import com.openexchange.search.SearchExceptionMessages;
 import com.openexchange.search.SearchTerm;
 import com.openexchange.search.SingleSearchTerm;
-import com.openexchange.search.CompositeSearchTerm.CompositeOperation;
 import com.openexchange.search.SingleSearchTerm.SingleOperation;
 import com.openexchange.search.internal.operands.ColumnOperand;
 import com.openexchange.search.internal.operands.ConstantOperand;
 
 /**
  * {@link SearchTermParser}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class SearchTermParser {
@@ -77,18 +78,14 @@ public final class SearchTermParser {
         super();
     }
 
-    public static void parseSingleOperands(final SingleSearchTerm singleSearchTerm, final JSONObject jsonObject, final int maxTerms) throws SearchException {
-        if (!jsonObject.hasAndNotNull(SearchTermFields.OPERANDS)) {
-            throw SearchExceptionMessages.PARSING_FAILED_MISSING_OPERANDS.create(new Object[0]);
-        }
-        final JSONArray array = jsonObject.optJSONArray(SearchTermFields.OPERANDS);
+    public static void parseSingleOperands(final SingleSearchTerm singleSearchTerm, final JSONArray array, final int maxTerms) throws SearchException {
         final int len = array.length();
-        if (len < 1) {
+        if (len < 2) {
             throw SearchExceptionMessages.PARSING_FAILED_INVALID_SEARCH_TERM.create(new Object[0]);
-        } else if (len > maxTerms) {
+        } else if (len > maxTerms + 1) {
             throw SearchExceptionMessages.PARSING_FAILED_INVALID_SEARCH_TERM.create(new Object[0]);
         }
-        for (int i = 0; i < len; i++) {
+        for (int i = 1; i < len; i++) {
             final JSONObject operand = array.optJSONObject(i);
             if (null == operand) {
                 singleSearchTerm.addOperand(parseConstantOperand(array.optString(i)));
@@ -102,6 +99,8 @@ public final class SearchTermParser {
         if (s == null) {
             return ConstantOperand.NULL;
         }
+/* TODO: Get type information from other operands.
+ * Disabled guessing because e.g. "True" is a female first name.
         if ("true".equalsIgnoreCase(s)) {
             return new ConstantOperand<Boolean>(Boolean.TRUE);
         } else if ("false".equalsIgnoreCase(s)) {
@@ -111,23 +110,18 @@ public final class SearchTermParser {
         } else if (isLong(s)) {
             return new ConstantOperand<Long>(Long.valueOf(s));
         } else {
+*/
             return new ConstantOperand<String>(s);
+/*
         }
+*/
     }
 
     private static Operand<?> parseOperand(final JSONObject operand) throws SearchException {
-        if (!operand.hasAndNotNull(SearchTermFields.TYPE)) {
-            throw SearchExceptionMessages.PARSING_FAILED_MISSING_FIELD.create(SearchTermFields.TYPE);
+        if (!operand.hasAndNotNull(SearchTermFields.FIELD)) {
+            throw SearchExceptionMessages.PARSING_FAILED_MISSING_FIELD.create(SearchTermFields.FIELD);
         }
-        if (!operand.hasAndNotNull(SearchTermFields.VALUE)) {
-            throw SearchExceptionMessages.PARSING_FAILED_MISSING_FIELD.create(SearchTermFields.VALUE);
-        }
-        final String type = operand.optString(SearchTermFields.TYPE);
-        final String value = operand.optString(SearchTermFields.VALUE);
-        if (Operand.Type.COLUMN.isType(type)) {
-            return new ColumnOperand(value);
-        }
-        return parseConstantOperand(value);
+        return new ColumnOperand(operand.optString(SearchTermFields.FIELD));
     }
 
     private static boolean isInteger(final String s) {
@@ -149,21 +143,25 @@ public final class SearchTermParser {
     }
 
     /**
-     * Parses specified search term JSON object.
-     * 
-     * @param jsonObject The search term JSON object.
+     * Parses specified search term JSON array.
+     *
+     * @param jsonArray The search term JSON array.
      * @return The parsed instance of search term.
      * @throws SearchException If parsing fails.
      */
-    public static SearchTerm<?> parse(final JSONObject jsonObject) throws SearchException {
-        if (null == jsonObject) {
+    public static SearchTerm<?> parse(final JSONArray jsonArray) throws SearchException {
+        if (null == jsonArray) {
             return null;
         }
-        if (!jsonObject.hasAndNotNull(SearchTermFields.OPERATION)) {
-            throw SearchExceptionMessages.PARSING_FAILED_MISSING_OPERATION.create(new Object[0]);
+
+        final String operation;
+        try {
+            operation = jsonArray.getString(0);
+        } catch (JSONException e) {
+            throw SearchExceptionMessages.PARSING_FAILED_MISSING_OPERATION.create(e, new Object[0]);
         }
+
         final SearchTerm<?> retval;
-        final String operation = jsonObject.optString(SearchTermFields.OPERATION);
         final CompositeOperation compositeOperation = CompositeOperation.getCompositeOperation(operation);
         if (null == compositeOperation) {
             final SingleOperation singleOperation = SingleOperation.getSingleOperation(operation);
@@ -171,72 +169,28 @@ public final class SearchTermParser {
                 throw SearchExceptionMessages.UNKNOWN_OPERATION.create(operation);
             }
             final SingleSearchTerm singleSearchTerm = singleOperation.newInstance();
-            parseSingleOperands(singleSearchTerm, jsonObject, singleOperation.getMaxOperands());
+            parseSingleOperands(singleSearchTerm, jsonArray, singleOperation.getMaxOperands());
             retval = singleSearchTerm;
         } else {
             final CompositeSearchTerm compositeSearchTerm = compositeOperation.newInstance();
-            parseCompositeOperands(compositeSearchTerm, jsonObject, compositeOperation.getMaxTerms());
+            parseCompositeOperands(compositeSearchTerm, jsonArray, compositeOperation.getMaxTerms());
             retval = compositeSearchTerm;
         }
         return retval;
     }
 
-    private static void parseCompositeOperands(final CompositeSearchTerm compositeSearchTerm, final JSONObject jsonObject, final int maxTerms) throws SearchException {
-        if (!jsonObject.hasAndNotNull(SearchTermFields.OPERANDS)) {
-            throw SearchExceptionMessages.PARSING_FAILED_MISSING_OPERANDS.create(new Object[0]);
-        }
-        final JSONArray array = jsonObject.optJSONArray(SearchTermFields.OPERANDS);
+    private static void parseCompositeOperands(final CompositeSearchTerm compositeSearchTerm, final JSONArray array, final int maxTerms) throws SearchException {
         final int len = array.length();
-        if (len < 1) {
+        if (len < 2) {
             throw SearchExceptionMessages.PARSING_FAILED_INVALID_SEARCH_TERM.create(new Object[0]);
-        } else if (len > maxTerms) {
+        } else if (len > maxTerms + 1) {
             throw SearchExceptionMessages.PARSING_FAILED_INVALID_SEARCH_TERM.create(new Object[0]);
         }
-        for (int i = 0; i < len; i++) {
-            final SearchTerm<?> term = parse(array.optJSONObject(i));
+        for (int i = 1; i < len; i++) {
+            final SearchTerm<?> term = parse(array.optJSONArray(i));
             if (null != term) {
                 compositeSearchTerm.addSearchTerm(term);
             }
         }
     }
-
-    /*-
-     * 
-     * For testing purpose
-     * 
-    public static void main(final String[] args) {
-        try {
-            final JSONObject equals = new JSONObject(
-                "{\"operation\":\"equals\",\"operands\":[{\"type\":\"column\",\"value\":\"" + ContactFields.FIRST_NAME + "\"},\"Herbert\"]}");
-
-            final SearchTerm<?> term = SearchTermParser.parse(equals);
-            System.out.println(term);
-
-            final JSONObject lt = new JSONObject(
-                "{\"operation\":\"lt\",\"operands\":[{\"type\":\"column\",\"value\":\"" + ContactFields.COLORLABEL + "\"},5]}");
-            final SearchTerm<?> term2 = SearchTermParser.parse(lt);
-            System.out.println(term2);
-
-            final JSONObject or = new JSONObject("{\"operation\":\"or\", \"operands\":[" + equals + "," + lt + "]}");
-            final SearchTerm<?> term3 = SearchTermParser.parse(or);
-            System.out.println(term3);
-
-            final ContactObject co = new ContactObject();
-            co.setGivenName("Herbert");
-            co.setObjectID(112233);
-            co.setLabel(3);
-
-            final SearchService ss = new SearchServiceImpl();
-
-            final long s = System.currentTimeMillis();
-            final boolean matches = ss.matches(co, term3, ContactAttributeFetcher.getInstance());
-            final long d = System.currentTimeMillis() - s;
-
-            System.out.println("Matches: " + matches + " | Duration: " + d + "msec");
-            
-        } catch (final Exception e) {
-            e.printStackTrace();
-        }
-    }*/
-
 }
