@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,16 +62,16 @@ import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.tools.exceptions.LoggingLogic;
 
 public abstract class CommonRequest {
-	
+
 	protected JSONWriter w;
-	
-	private final Log LOG = LogFactory.getLog(CommonRequest.class);
+
+	private final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CommonRequest.class));
 	private final LoggingLogic LL = LoggingLogic.getLoggingLogic(CommonRequest.class, LOG);
-	
+
 	public CommonRequest(final JSONWriter w) {
 		this.w = w;
 	}
-	
+
 	protected void sendErrorAsJS(final String error, final String...errorParams) {
 		//final JSONObject response = new JSONObject();
 		try {
@@ -87,7 +87,7 @@ public abstract class CommonRequest {
 			LOG.debug(e.getMessage(),e);
 		}
 	}
-	
+
 	protected void handle(final Throwable t) {
 		final Response res = new Response();
 		if(t instanceof AbstractOXException) {
@@ -103,7 +103,7 @@ public abstract class CommonRequest {
 			LOG.error("",t);
 		}
 	}
-	
+
 	protected void invalidParameter(final String parameter, final String value) {
 		sendErrorAsJS("Invalid parameter value '%s' for parameter %s",value,parameter);
 	}
@@ -121,10 +121,10 @@ public abstract class CommonRequest {
 		}
 		return true;
 	}
-	
+
 	protected void missingParameter(final String parameter, final String action) {
 		sendErrorAsJS("Missing Parameter: %s for action: %s",parameter,action);
-		
+
 	}
-	
+
 }
