@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,11 @@
 
 package com.openexchange.ajax.request;
 
-import gnu.trove.TIntArrayList;
-import gnu.trove.TIntHashSet;
-import gnu.trove.TIntIntHashMap;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.map.hash.TIntIntHashMap;
+import gnu.trove.set.TIntSet;
+import gnu.trove.set.hash.TIntHashSet;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
@@ -81,10 +83,10 @@ import com.openexchange.groupware.attach.AttachmentBase;
 import com.openexchange.groupware.attach.AttachmentField;
 import com.openexchange.groupware.attach.AttachmentMetadata;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.infostore.CreatedByComparator;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreFacade;
-import com.openexchange.groupware.infostore.SearchEngine;
-import com.openexchange.groupware.infostore.ThreadLocalSessionHolder;
+import com.openexchange.groupware.infostore.InfostoreSearchEngine;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.infostore.database.impl.GetSwitch;
 import com.openexchange.groupware.infostore.database.impl.SetSwitch;
@@ -92,13 +94,14 @@ import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.results.Delta;
 import com.openexchange.groupware.results.TimedResult;
-import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.exceptions.LoggingLogic;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tx.TransactionException;
 
 public class InfostoreRequest extends CommonRequest {
 
@@ -112,7 +115,7 @@ public class InfostoreRequest extends CommonRequest {
 
     private final UserConfiguration userConfiguration;
 
-    private static final Log LOG = LogFactory.getLog(InfostoreRequest.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreRequest.class));
 
     private static final LoggingLogic LL = LoggingLogic.getLoggingLogic(InfostoreRequest.class);
 
@@ -364,7 +367,7 @@ public class InfostoreRequest extends CommonRequest {
         return ids;
     }
 
-    protected void doSortedSearch(final SimpleRequest req) throws JSONException, SearchIteratorException {
+    protected void doSortedSearch(final SimpleRequest req) throws JSONException, AbstractOXException {
         Metadata[] cols = null;
 
         try {
@@ -408,25 +411,25 @@ public class InfostoreRequest extends CommonRequest {
             final int folderId = Integer.parseInt(req.getParameter(AJAXServlet.PARAMETER_FOLDERID));
 
             final String timeZoneId = req.getParameter(AJAXServlet.PARAMETER_TIMEZONE);
-            
+
             final String stringLeftHandLimit = req.getParameter(AJAXServlet.LEFT_HAND_LIMIT);
             final String stringRightHandLimit = req.getParameter(AJAXServlet.RIGHT_HAND_LIMIT);
 
             final int leftHandLimit;
             final int rightHandLimit;
-            
+
             if (stringLeftHandLimit == null) {
                 leftHandLimit = 0;
             } else {
                 leftHandLimit = Integer.parseInt(AJAXServlet.LEFT_HAND_LIMIT);
             }
-            
+
             if (stringRightHandLimit == null) {
                 rightHandLimit = 0;
             } else {
                 rightHandLimit = Integer.parseInt(AJAXServlet.RIGHT_HAND_LIMIT);
             }
-            
+
             all(folderId, cols, sortedBy, dir, timeZoneId, leftHandLimit, rightHandLimit);
         } else if (action.equals(AJAXServlet.ACTION_VERSIONS)) {
             if (!checkRequired(req, action, AJAXServlet.PARAMETER_ID)) {
@@ -449,25 +452,25 @@ public class InfostoreRequest extends CommonRequest {
             final JSONObject queryObject = (JSONObject) req.getBody();
             final String query = queryObject.getString(SearchFields.PATTERN);
 
-            int folderId = SearchEngine.NO_FOLDER;
+            int folderId = InfostoreSearchEngine.NO_FOLDER;
             final String folderS = req.getParameter(AJAXServlet.PARAMETER_FOLDERID);
             if (null != folderS) {
                 folderId = Integer.parseInt(folderS);
             }
 
-            int start = SearchEngine.NOT_SET;
+            int start = InfostoreSearchEngine.NOT_SET;
             final String startS = req.getParameter(AJAXServlet.PARAMETER_START);
             if (null != startS) {
                 start = Integer.parseInt(startS);
             }
 
-            int end = SearchEngine.NOT_SET;
+            int end = InfostoreSearchEngine.NOT_SET;
             final String endS = req.getParameter(AJAXServlet.PARAMETER_END);
             if (null != endS) {
                 end = Integer.parseInt(endS);
             }
 
-            if (start == SearchEngine.NOT_SET && end == SearchEngine.NOT_SET) {
+            if (start == InfostoreSearchEngine.NOT_SET && end == InfostoreSearchEngine.NOT_SET) {
                 final String limitS = req.getParameter(AJAXServlet.PARAMETER_LIMIT);
                 if (limitS != null) {
                     final int limit = Integer.parseInt(limitS);
@@ -484,7 +487,7 @@ public class InfostoreRequest extends CommonRequest {
 
     // Actions
 
-    protected void list(final int[] ids, final Metadata[] cols, final String timeZoneId) throws SearchIteratorException {
+    protected void list(final int[] ids, final Metadata[] cols, final String timeZoneId) throws AbstractOXException {
         final InfostoreFacade infostore = getInfostore();
         TimedResult<DocumentMetadata> result = null;
         SearchIterator<DocumentMetadata> iter = null;
@@ -548,7 +551,7 @@ public class InfostoreRequest extends CommonRequest {
                 throw new OXConflictException();
             }
             iter = result.results();
-            final TIntArrayList versions;
+            final TIntList versions;
             try {
                 versions = new TIntArrayList();
                 while (iter.hasNext()) {
@@ -561,7 +564,7 @@ public class InfostoreRequest extends CommonRequest {
             } finally {
                 iter.close();
             }
-            infostore.removeVersion(id, versions.toNativeArray(), session);
+            infostore.removeVersion(id, versions.toArray(), session);
             timestamp = infostore.getDocumentMetadata(id, InfostoreFacade.CURRENT_VERSION, ctx,
                     user, userConfiguration).getSequenceNumber();
             infostore.commit();
@@ -580,7 +583,7 @@ public class InfostoreRequest extends CommonRequest {
             if (iter != null) {
                 try {
                     iter.close();
-                } catch (final SearchIteratorException e) {
+                } catch (final AbstractOXException e) {
                     LOG.error("", e);
                 }
             }
@@ -593,7 +596,7 @@ public class InfostoreRequest extends CommonRequest {
     }
 
     protected void all(final int folderId, final Metadata[] cols, final Metadata sortedBy, final int dir, final String timeZoneId, final int leftHandLimit, final int rightHandLimit)
-            throws SearchIteratorException {
+            throws AbstractOXException {
         /**
          * System.out.println("ALL: "+System.currentTimeMillis());
          * System.out.println("---------all-------------");
@@ -615,6 +618,9 @@ public class InfostoreRequest extends CommonRequest {
             }
 
             iter = result.results();
+            if (Metadata.CREATED_BY_LITERAL.equals(sortedBy)) {
+                iter = CreatedByComparator.resort(iter, new CreatedByComparator(user.getLocale(), ctx).setDescending(dir < 0));
+            }
 
             final InfostoreWriter iWriter = new InfostoreWriter(w);
             iWriter.timedResult(result.sequenceNumber());
@@ -632,7 +638,7 @@ public class InfostoreRequest extends CommonRequest {
     }
 
     protected void versions(final int id, final Metadata[] cols, final Metadata sortedBy, final int dir, final String timeZoneId)
-            throws SearchIteratorException {
+            throws AbstractOXException {
         final InfostoreFacade infostore = getInfostore();
         TimedResult<DocumentMetadata> result = null;
         SearchIterator<DocumentMetadata> iter = null;
@@ -646,6 +652,9 @@ public class InfostoreRequest extends CommonRequest {
                         userConfiguration);
             }
             iter = result.results();
+            if (Metadata.CREATED_BY_LITERAL.equals(sortedBy)) {
+                iter = CreatedByComparator.resort(iter, new CreatedByComparator(user.getLocale(), ctx).setDescending(dir < 0));
+            }
             final InfostoreWriter iWriter = new InfostoreWriter(w);
             iWriter.timedResult(result.sequenceNumber());
             iWriter.writeMetadata(skipVersion0(iter), cols, TimeZoneUtils.getTimeZone(null == timeZoneId ? user.getTimeZone() : timeZoneId));
@@ -684,7 +693,7 @@ public class InfostoreRequest extends CommonRequest {
                 iter.addWarning(warning);
             }
 
-            public void close() throws SearchIteratorException {
+            public void close() throws AbstractOXException {
                 iter.close();
             }
 
@@ -692,7 +701,7 @@ public class InfostoreRequest extends CommonRequest {
                 return iter.getWarnings();
             }
 
-            public boolean hasNext() {
+            public boolean hasNext() throws AbstractOXException{
                 try {
                     scrollToNext();
                 } catch (final SearchIteratorException e) {
@@ -703,15 +712,12 @@ public class InfostoreRequest extends CommonRequest {
                 return next != null;
             }
 
-            public boolean hasSize() {
-                return false;
-            }
 
             public boolean hasWarnings() {
                 return iter.hasWarnings();
             }
 
-            public DocumentMetadata next() throws SearchIteratorException, OXException {
+            public DocumentMetadata next() throws AbstractOXException {
                 if(se != null) {
                     throw se;
                 }
@@ -726,7 +732,7 @@ public class InfostoreRequest extends CommonRequest {
                 return nextResult;
             }
 
-            private void scrollToNext() throws SearchIteratorException, OXException {
+            private void scrollToNext() throws AbstractOXException {
                 while(iter.hasNext()) {
                     next = iter.next();
                     if(next.getVersion() != 0) {
@@ -738,14 +744,14 @@ public class InfostoreRequest extends CommonRequest {
             }
 
             public int size() {
-                throw new UnsupportedOperationException("Don't know my size!");
+                return -1;
             }
-            
+
         };
     }
 
     protected void updates(final int folderId, final Metadata[] cols, final Metadata sortedBy, final int dir,
-            final long timestamp, final boolean ignoreDelete, final String timeZoneId) throws SearchIteratorException {
+            final long timestamp, final boolean ignoreDelete, final String timeZoneId) throws AbstractOXException {
         final InfostoreFacade infostore = getInfostore(folderId);
         Delta<DocumentMetadata> delta = null;
 
@@ -764,6 +770,11 @@ public class InfostoreRequest extends CommonRequest {
 
             iter = delta.results();
             iter2 = delta.getDeleted();
+            if (Metadata.CREATED_BY_LITERAL.equals(sortedBy)) {
+                final CreatedByComparator comparator = new CreatedByComparator(user.getLocale(), ctx).setDescending(dir < 0);
+                iter = CreatedByComparator.resort(iter, comparator);
+                iter2 = CreatedByComparator.resort(iter2, comparator);
+            }
 
             final InfostoreWriter iWriter = new InfostoreWriter(w);
             iWriter.timedResult(delta.sequenceNumber());
@@ -785,7 +796,7 @@ public class InfostoreRequest extends CommonRequest {
 
     protected void delete(final int[] ids, final TIntIntHashMap folderMapping, final long timestamp) {
         final InfostoreFacade infostore = getInfostore();
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
 
         int[] notDeleted = new int[0];
         if (ids.length != 0) {
@@ -796,7 +807,7 @@ public class InfostoreRequest extends CommonRequest {
 
                 notDeleted = infostore.removeDocument(ids, timestamp, session);
 
-                final TIntHashSet notDeletedSet = new TIntHashSet();
+                final TIntSet notDeletedSet = new TIntHashSet();
                 for (final int nd : notDeleted) {
                     notDeletedSet.add(nd);
                 }
@@ -854,7 +865,7 @@ public class InfostoreRequest extends CommonRequest {
 
     protected void detach(final int objectId, final int[] ids, final long timestamp) {
         final InfostoreFacade infostore = getInfostore();
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
 
         int[] notDetached = new int[0];
         long newTimestamp = 0;
@@ -911,7 +922,7 @@ public class InfostoreRequest extends CommonRequest {
 
     protected void newDocument(final DocumentMetadata newDocument) throws JSONException {
         final InfostoreFacade infostore = getInfostore(newDocument.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
         try {
 
             infostore.startTransaction();
@@ -960,7 +971,7 @@ public class InfostoreRequest extends CommonRequest {
 
         final AttachmentBase attachmentBase = Attachment.ATTACHMENT_BASE;
         final InfostoreFacade infostore = getInfostore(newDocument.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
         InputStream in = null;
         try {
             attachmentBase.startTransaction();
@@ -1032,7 +1043,7 @@ public class InfostoreRequest extends CommonRequest {
 
     protected void update(final int id, final DocumentMetadata updated, final long timestamp, final Metadata[] presentFields) {
         final InfostoreFacade infostore = getInfostore(updated.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
 
         try {
 
@@ -1086,7 +1097,7 @@ public class InfostoreRequest extends CommonRequest {
             final Metadata[] presentFields) {
 
         final InfostoreFacade infostore = getInfostore(updated.getFolderId());
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
         DocumentMetadata metadata = null;
 
         try {
@@ -1224,14 +1235,18 @@ public class InfostoreRequest extends CommonRequest {
 
     protected void search(final String query, final Metadata[] cols, final int folderId, final Metadata sortedBy,
             final int dir, final int start, final int end, final String timeZoneId) {
-        final SearchEngine searchEngine = getSearchEngine();
+        final InfostoreSearchEngine searchEngine = getSearchEngine();
 
         try {
             searchEngine.startTransaction();
 
-            final SearchIterator<DocumentMetadata> results = searchEngine.search(query, cols, folderId, sortedBy, dir, start, end,
+            SearchIterator<DocumentMetadata> results = searchEngine.search(query, cols, folderId, sortedBy, dir, start, end,
                     ctx, user, userConfiguration);
 
+            if (Metadata.CREATED_BY_LITERAL.equals(sortedBy)) {
+                results = CreatedByComparator.resort(results, new CreatedByComparator(user.getLocale(), ctx).setDescending(dir < 0));
+            }
+
             final InfostoreWriter iWriter = new InfostoreWriter(w);
             iWriter.timedResult(System.currentTimeMillis());
             iWriter.writeMetadata(results, cols, TimeZoneUtils.getTimeZone(null == timeZoneId ? user.getTimeZone() : timeZoneId));
@@ -1262,7 +1277,7 @@ public class InfostoreRequest extends CommonRequest {
         return Infostore.getInfostore(folderId);
     }
 
-    protected SearchEngine getSearchEngine() {
+    protected InfostoreSearchEngine getSearchEngine() {
         return Infostore.SEARCH_ENGINE;
     }
 
