@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,18 +59,18 @@ import com.openexchange.ajax.fields.CommonFields;
 import com.openexchange.ajax.fields.FolderFields;
 import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.api.OXPermissionException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailJSONField;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.session.Session;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.session.ServerSession;
 
 public final class MailRequest {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailRequest.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailRequest.class));
 
     private static enum CollectableOperation {
         MOVE, COPY, STORE_FLAG, COLOR_LABEL;
@@ -90,7 +90,7 @@ public final class MailRequest {
 
     /**
      * Constructor
-     * 
+     *
      * @param session - the session reference keeping user-specific data
      * @param writer - the instance of <code>{@link OXJSONWriter}</code> to whom response data is written
      */
@@ -102,12 +102,12 @@ public final class MailRequest {
 
     /**
      * Performs the action associated with given <code>action</code> parameter
-     * 
+     *
      * @param action - the action to perform
      * @param jsonObject - the instance of <code>{@link JSONObject}</code> keeping request's data
      * @param mailInterface - the instance of <code>{@link MailServletInterface}</code> to access mail module
      */
-    public void action(final String action, final JSONObject jsonObject, final MailServletInterface mailInterface) throws SearchIteratorException, JSONException, MailException, OXPermissionException {
+    public void action(final String action, final JSONObject jsonObject, final MailServletInterface mailInterface) throws AbstractOXException, JSONException {
         if (!session.getUserConfiguration().hasWebMail()) {
             throw new OXPermissionException(OXPermissionException.Code.NoPermissionForModul, "mail");
         }
@@ -152,6 +152,8 @@ public final class MailRequest {
             MAIL_SERVLET.actionGetStructure(session, writer, jsonObject, mailInterface);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_MATTACH)) {
             MAIL_SERVLET.actionGetAttachment();
+        } else if (action.equalsIgnoreCase("attachmentToken")) {
+            MAIL_SERVLET.actionGetAttachmentToken(session, writer, jsonObject, mailInterface);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_NEW_MSGS)) {
             MAIL_SERVLET.actionGetNew(session, writer, jsonObject, mailInterface);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_LIST)) {
@@ -168,6 +170,8 @@ public final class MailRequest {
             } else {
                 MAIL_SERVLET.actionPutUpdateMail(session, writer, jsonObject, mailInterface);
             }
+        }  else if (action.equalsIgnoreCase("transport")) {
+            MAIL_SERVLET.actionPutTransportMail(session, writer, jsonObject, mailInterface);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_COPY)) {
             handleMultiple(jsonObject, mailInterface, CollectableOperation.COPY);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_MATTACH)) {
@@ -209,7 +213,7 @@ public final class MailRequest {
 
     /**
      * Indicates if this {@link MailRequest mail request} is collecting contiguously
-     * 
+     *
      * @return <code>true</code> if this {@link MailRequest mail request} is collecting contiguously; otherwise <code>false</code>
      */
     public boolean isContiguousCollect() {
@@ -219,7 +223,7 @@ public final class MailRequest {
     /**
      * Executes gathered actions and writes their response to the instance of <code>{@link OXJSONWriter}</code> given through constructor
      * <code>{@link #MailRequest(Session, Context, OXJSONWriter)}</code>
-     * 
+     *
      * @param mailInterface The mail interface
      * @throws JSONException If writing JSON response fails
      */
@@ -231,11 +235,13 @@ public final class MailRequest {
     }
 
     private void performMultipleInternal(final MailServletInterface mailInterface) throws JSONException {
-        final long start = System.currentTimeMillis();
-        collectObj.performOperations(session, writer, mailInterface);
         if (LOG.isDebugEnabled()) {
+            final long start = System.currentTimeMillis();
+            collectObj.performOperations(session, writer, mailInterface);
             LOG.debug(new StringBuilder(128).append("Multiple '").append(getOpName(collectObj.getOperation())).append(
                 "' mail request successfully performed: ").append(System.currentTimeMillis() - start).append("msec").toString());
+        } else {
+            collectObj.performOperations(session, writer, mailInterface);
         }
     }
 
@@ -277,7 +283,7 @@ public final class MailRequest {
 
         /**
          * Initializes a new {@link CollectObject}
-         * 
+         *
          * @param mailServlet The mail servlet
          */
         protected CollectObject(final Mail mailServlet) {
@@ -289,7 +295,7 @@ public final class MailRequest {
         /**
          * Checks if given collectable operation can be further added to previous collectable operation stored in this {@link CollectObject}
          * and thus needs no direct execution.
-         * 
+         *
          * @param dataObject The JSON object containing request's data and parameters
          * @param op The identified collectable operation
          * @return <code>true</code> f given collectable operation can be further collected; otherwise <code>false</code>
@@ -299,7 +305,7 @@ public final class MailRequest {
 
         /**
          * Performs the collected operations
-         * 
+         *
          * @param session The currently active user session
          * @param writer The JSON writer to write responses to
          * @param mailInterface The mail interface
@@ -309,14 +315,14 @@ public final class MailRequest {
 
         /**
          * Gets the collectable operation identifier
-         * 
+         *
          * @return The collectable operation identifier
          */
         public abstract CollectableOperation getOperation();
 
         /**
          * Adds a collectable operation which has previously been checked by {@link #collectable(JSONObject, CollectableOperation)}
-         * 
+         *
          * @param dataObject
          * @throws JSONException If a JSON error occurs
          */
@@ -326,7 +332,7 @@ public final class MailRequest {
 
         /**
          * Gets a newly created array of long containing this object's mail IDs.
-         * 
+         *
          * @return A newly created array of long containing this object's mail IDs.
          */
         protected final String[] getMailIDs() {
