@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,6 +62,7 @@ import org.json.JSONObject;
 import org.json.JSONValue;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.parser.DataParser;
+import com.openexchange.ajax.parser.ReminderParser;
 import com.openexchange.ajax.writer.ReminderWriter;
 import com.openexchange.api.OXMandatoryFieldException;
 import com.openexchange.api.OXObjectNotFoundException;
@@ -79,6 +80,7 @@ import com.openexchange.groupware.calendar.RecurringResultInterface;
 import com.openexchange.groupware.calendar.RecurringResultsInterface;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.reminder.ReminderException;
 import com.openexchange.groupware.reminder.ReminderHandler;
 import com.openexchange.groupware.reminder.ReminderObject;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -92,7 +94,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link ReminderRequest} - Handles request to reminder servlet.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public final class ReminderRequest {
@@ -105,11 +107,11 @@ public final class ReminderRequest {
 
     private final AppointmentSqlFactoryService appointmentFactory;
 
-    private static final Log LOG = LogFactory.getLog(ReminderRequest.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ReminderRequest.class));
 
     /**
      * Gets the time stamp.
-     * 
+     *
      * @return The time stamp.
      */
     public Date getTimestamp() {
@@ -118,7 +120,7 @@ public final class ReminderRequest {
 
     /**
      * Initializes a new {@link ReminderRequest}.
-     * 
+     *
      * @param session The session
      */
     public ReminderRequest(final ServerSession session) {
@@ -130,7 +132,7 @@ public final class ReminderRequest {
 
     /**
      * Handles the request dependent on specified action string.
-     * 
+     *
      * @param action The action string
      * @param jsonObject The JSON object containing request's data & parameters
      * @return A JSON result object dependent on triggered action method
@@ -141,13 +143,15 @@ public final class ReminderRequest {
      * @throws AjaxException If an AJAX error occurs
      * @throws OXJSONException If a JSON error occurs
      */
-    public JSONValue action(final String action, final JSONObject jsonObject) throws OXMandatoryFieldException, OXException, JSONException, SearchIteratorException, AjaxException, OXJSONException {
+    public JSONValue action(final String action, final JSONObject jsonObject) throws JSONException, AbstractOXException{
         if (action.equalsIgnoreCase(AJAXServlet.ACTION_DELETE)) {
             return actionDelete(jsonObject);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_UPDATES)) {
             return actionUpdates(jsonObject);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_RANGE)) {
             return actionRange(jsonObject);
+        } else if (action.equalsIgnoreCase("remindAgain")) {
+            return actionRemindAgain(jsonObject);
         } else {
             throw new AjaxException(AjaxException.Code.UnknownAction, action);
         }
@@ -186,7 +190,7 @@ public final class ReminderRequest {
         return jsonArray;
     }
 
-    private JSONArray actionUpdates(final JSONObject jsonObject) throws OXMandatoryFieldException, JSONException, OXException, SearchIteratorException, OXJSONException, AjaxException {
+    private JSONArray actionUpdates(final JSONObject jsonObject) throws JSONException, AbstractOXException {
         timestamp = DataParser.checkDate(jsonObject, AJAXServlet.PARAMETER_TIMESTAMP);
         final TimeZone timeZone;
         {
@@ -206,8 +210,8 @@ public final class ReminderRequest {
                 final ReminderObject reminderObj = (ReminderObject) it.next();
 
                 if (reminderObj.isRecurrenceAppointment()) {
-                    final int targetId = reminderObj.getTargetId();
-                    final int inFolder = reminderObj.getFolder();
+                    reminderObj.getTargetId();
+                    reminderObj.getFolder();
 
                     // currently disabled because not used by the UI
                     // final ReminderObject latestReminder = getLatestReminder(targetId, inFolder, sessionObj, end);
@@ -237,6 +241,60 @@ public final class ReminderRequest {
         }
     }
 
+    private JSONObject actionRemindAgain(final JSONObject jsonObject) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
+        // timestamp = DataParser.checkDate(jsonObject, AJAXServlet.PARAMETER_TIMESTAMP);
+        final int reminderId = DataParser.checkInt(jsonObject, AJAXServlet.PARAMETER_ID);
+        final TimeZone tz = TimeZoneUtils.getTimeZone(userObj.getTimeZone());
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObject, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? tz : getTimeZone(timeZoneId);
+        }
+        /*
+         * Parse reminder from JSON
+         */
+        final JSONObject jreminder = jsonObject.getJSONObject(AJAXServlet.PARAMETER_DATA);
+        final ReminderObject reminder = new ReminderObject();
+        new ReminderParser(tz).parse(reminder, jreminder);
+        if (null == reminder.getDate()) {
+            throw new ReminderException(ReminderException.Code.MANDATORY_FIELD_ALARM);
+        }
+        reminder.setObjectId(reminderId);
+        /*
+         * Load storage version and check permission
+         */
+        final ReminderService reminderSql = new ReminderHandler(session.getContext());
+        {
+            final ReminderObject storageReminder = reminderSql.loadReminder(reminder.getObjectId());
+            /*
+             * Check module permission
+             */
+            if (!hasModulePermission(storageReminder)) {
+                throw new ReminderException(ReminderException.Code.UNEXPECTED_ERROR, "No module permission.");
+            }
+            /*
+             * Set other fields
+             */
+            reminder.setModule(storageReminder.getModule());
+            reminder.setDescription(storageReminder.getDescription());
+            reminder.setFolder(storageReminder.getFolder());
+            reminder.setTargetId(storageReminder.getTargetId());
+            reminder.setUser(storageReminder.getUser());
+        }
+        /*
+         * Trigger action
+         */
+        reminderSql.remindAgain(reminder, session, session.getContext());
+        timestamp = reminder.getLastModified();
+        /*
+         * Write updated reminder
+         */
+        final ReminderWriter reminderWriter = new ReminderWriter(timeZone);
+        final JSONObject jsonReminderObj = new JSONObject();
+        reminderWriter.writeObject(reminder, jsonReminderObj);
+        return jsonReminderObj;
+    }
+
     private JSONArray actionRange(final JSONObject jsonObject) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
         final Date end = DataParser.checkDate(jsonObject, AJAXServlet.PARAMETER_END);
         final TimeZone tz = TimeZoneUtils.getTimeZone(userObj.getTimeZone());
@@ -245,7 +303,7 @@ public final class ReminderRequest {
             final String timeZoneId = DataParser.parseString(jsonObject, AJAXServlet.PARAMETER_TIMEZONE);
             timeZone = null == timeZoneId ? tz : getTimeZone(timeZoneId);
         }
-        
+
         final ReminderWriter reminderWriter = new ReminderWriter(timeZone);
         try {
             final ReminderService reminderSql = new ReminderHandler(session.getContext());
@@ -303,7 +361,7 @@ public final class ReminderRequest {
     /**
      * This method returns the lastest reminder object of the recurrence appointment. The reminder object contains only the alarm attribute
      * and the recurrence position.
-     * 
+     *
      * @return <code>true</code> if a latest reminder was found.
      */
     protected boolean getLatestRecurringReminder(final Session sessionObj, final TimeZone tz, final Date endRange, final ReminderObject reminder) throws OXException {
@@ -345,23 +403,21 @@ public final class ReminderRequest {
         final AppointmentSQLInterface calendarSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(sessionObj);
         final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
         final Appointment calendarDataObject;
+
         try {
             calendarDataObject = calendarSql.getObjectById(reminder.getTargetId(), reminder.getFolder());
         } catch (final SQLException e) {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, e);
         }
+
         final RecurringResultsInterface recurringResults;
         try {
             // Until is always set to 00:00:00 UTC so we have to recalculate it to get the last occurrence too.
-            long end_mod = calendarDataObject.getEndDate().getTime() % Constants.MILLI_DAY;
+            final long end_mod = calendarDataObject.getEndDate().getTime() % Constants.MILLI_DAY;
             Date until = null;
-            until = new Date(calendarDataObject.getUntil().getTime() + end_mod);
-            
-            recurringResults = recColl.calculateRecurring(
-                calendarDataObject,
-                calendarDataObject.getStartDate().getTime(),
-                until.getTime(),
-                0);
+            until = new Date(calendarDataObject.getUntil().getTime() + end_mod + tz.getOffset(calendarDataObject.getUntil().getTime()));
+
+            recurringResults = recColl.calculateRecurring(calendarDataObject, reminder.getDate().getTime(), until.getTime(), 0);
         } catch (final OXException e) {
             LOG.error(
                 "Can't calculate next recurrence for appointment " + reminder.getTargetId() + " in context " + sessionObj.getContextId(),
