@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,9 +50,11 @@
 package com.openexchange.ajax.request;
 
 import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
-import gnu.trove.TIntArrayList;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
 import java.util.Date;
-import java.util.TimeZone;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -74,6 +76,7 @@ import com.openexchange.api.OXObjectNotFoundException;
 import com.openexchange.api.OXPermissionException;
 import com.openexchange.api2.OXException;
 import com.openexchange.api2.TasksSQLInterface;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.container.DataObject;
@@ -86,13 +89,14 @@ import com.openexchange.groupware.tasks.TasksSQLImpl;
 import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.session.ServerSession;
 
-public class TaskRequest {
+public class TaskRequest extends CalendarRequest {
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TaskRequest.class));
 
     protected final static int[] _taskFields = {
         DataObject.OBJECT_ID,
@@ -109,6 +113,7 @@ public class TaskRequest {
         CalendarObject.NOTE,
         CalendarObject.RECURRENCE_TYPE,
         CalendarObject.PARTICIPANTS,
+        CalendarObject.UID,
         Task.ACTUAL_COSTS,
         Task.ACTUAL_DURATION,
         Task.ALARM,
@@ -126,12 +131,6 @@ public class TaskRequest {
         Task.COLOR_LABEL
     };
 
-    private final ServerSession session;
-
-    private Date timestamp;
-
-    private TimeZone timeZone;
-
     public TaskRequest(ServerSession session) {
         super();
         this.session = session;
@@ -142,7 +141,7 @@ public class TaskRequest {
         return timestamp;
     }
 
-    public JSONValue action(String action, JSONObject json) throws OXMandatoryFieldException, JSONException, OXObjectNotFoundException, OXConflictException, OXPermissionException, OXFolderNotFoundException, SearchIteratorException, AjaxException, OXException, OXJSONException {
+    public JSONValue action(String action, JSONObject json) throws JSONException, AbstractOXException {
         if (!session.getUserConfiguration().hasTask()) {
             throw new OXPermissionException(OXPermissionException.Code.NoPermissionForModul, "task");
         }
@@ -184,6 +183,8 @@ public class TaskRequest {
         taskParser.parse(task, jsonobject);
 
         final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
+
+        convertExternalToInternalUsersIfPossible(task, session.getContext(), LOG);
         sqlinterface.insertTaskObject(task);
         timestamp = task.getLastModified();
 
@@ -207,6 +208,8 @@ public class TaskRequest {
 
         task.setObjectID(id);
 
+        convertExternalToInternalUsersIfPossible(task, session.getContext(), LOG);
+
         final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
         sqlinterface.updateTaskObject(task, inFolder, timestamp);
         timestamp = task.getLastModified();
@@ -214,7 +217,7 @@ public class TaskRequest {
         return new JSONObject();
     }
 
-    public JSONArray actionUpdates(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, SearchIteratorException, OXException, OXJSONException, AjaxException {
+    public JSONArray actionUpdates(final JSONObject jsonObj) throws JSONException, AbstractOXException {
         final String[] sColumns = DataParser.checkString(jsonObj, AJAXServlet.PARAMETER_COLUMNS).split(",");
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtualColumns(columns);
@@ -294,7 +297,7 @@ public class TaskRequest {
         return new JSONArray();
     }
 
-    public JSONArray actionList(final JSONObject jsonObj) throws JSONException, OXMandatoryFieldException, SearchIteratorException, OXException, OXJSONException, AjaxException {
+    public JSONArray actionList(final JSONObject jsonObj) throws JSONException, AbstractOXException {
         timestamp = new Date(0);
 
         Date lastModified = null;
@@ -341,7 +344,7 @@ public class TaskRequest {
         }
     }
 
-    public JSONArray actionAll(final JSONObject jsonObj) throws JSONException, OXMandatoryFieldException, SearchIteratorException, OXException, OXJSONException, AjaxException {
+    public JSONArray actionAll(final JSONObject jsonObj) throws JSONException, AbstractOXException {
         final String[] sColumns = DataParser.checkString(jsonObj, AJAXServlet.PARAMETER_COLUMNS).split(",");
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtualColumns(columns);
@@ -427,7 +430,7 @@ public class TaskRequest {
         return new JSONObject();
     }
 
-    public JSONArray actionSearch(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXConflictException, SearchIteratorException, OXException, OXJSONException, AjaxException {
+    public JSONArray actionSearch(final JSONObject jsonObj) throws JSONException, AbstractOXException {
         final String[] sColumns = DataParser.checkString(jsonObj, AJAXServlet.PARAMETER_COLUMNS).split(",");
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtualColumns(columns);
@@ -532,12 +535,12 @@ public class TaskRequest {
     }
 
     private int[] removeVirtualColumns(final int[] columns) {
-        final TIntArrayList tmp = new TIntArrayList(columns.length);
+        final TIntList tmp = new TIntArrayList(columns.length);
         for (final int col : columns) {
             if (col != Task.LAST_MODIFIED_UTC) {
                 tmp.add(col);
             }
         }
-        return tmp.toNativeArray();
+        return tmp.toArray();
     }
 }
