@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,7 @@
 
 package com.openexchange.ajax.writer;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.util.Date;
 import java.util.TimeZone;
 import org.apache.commons.logging.Log;
@@ -58,10 +58,16 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.fields.AppointmentFields;
+import com.openexchange.ajax.fields.CalendarFields;
+import com.openexchange.api2.OXException;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.container.Appointment;
+import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.container.UserParticipant;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.tools.oxfolder.OXFolderAccess;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link AppointmentWriter} - Writer for appointments
@@ -71,10 +77,14 @@ import com.openexchange.server.services.ServerServiceRegistry;
  */
 public class AppointmentWriter extends CalendarWriter {
 
-    private static final Log LOG = LogFactory.getLog(AppointmentWriter.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AppointmentWriter.class));
 
     private CalendarCollectionService calColl;
 
+    private ServerSession session;
+
+    private final boolean forTesting;
+
     /**
      * Initializes a new {@link AppointmentWriter}
      *
@@ -82,7 +92,21 @@ public class AppointmentWriter extends CalendarWriter {
      *            The user time zone
      */
     public AppointmentWriter(final TimeZone timeZone) {
+        this(timeZone, false);
+    }
+
+    public AppointmentWriter(final TimeZone timeZone, final boolean forTesting) {
         super(timeZone, null);
+        this.forTesting = forTesting;
+    }
+
+    /**
+     * Applies specified session to this writer.
+     *
+     * @param session The session to set
+     */
+    public void setSession(final ServerSession session) {
+        this.session = session;
     }
 
     public CalendarCollectionService getCalendarCollectionService(){
@@ -96,24 +120,26 @@ public class AppointmentWriter extends CalendarWriter {
         this.calColl = calColl;
     }
 
-    public void writeArray(final Appointment appointmentObj, final int cols[], final Date betweenStart,
+    public JSONArray writeArray(final Appointment appointmentObj, final int cols[], final Date betweenStart,
             final Date betweenEnd, final JSONArray jsonArray) throws JSONException {
         if (appointmentObj.getFullTime() && betweenStart != null && betweenEnd != null) {
             if (getCalendarCollectionService().inBetween(appointmentObj.getStartDate().getTime(), appointmentObj.getEndDate()
                     .getTime(), betweenStart.getTime(), betweenEnd.getTime())) {
-                writeArray(appointmentObj, cols, jsonArray);
+                return writeArray(appointmentObj, cols, jsonArray);
             }
         } else {
-            writeArray(appointmentObj, cols, jsonArray);
+            return writeArray(appointmentObj, cols, jsonArray);
         }
+        return null;
     }
 
-    public void writeArray(final Appointment appointment, final int[] columns, final JSONArray json) throws JSONException {
+    public JSONArray writeArray(final Appointment appointment, final int[] columns, final JSONArray json) throws JSONException {
         final JSONArray array = new JSONArray();
         for (final int column : columns) {
             writeField(appointment, column, timeZone, array);
         }
         json.put(array);
+        return array;
     }
 
     public void writeAppointment(final Appointment appointmentObject, final JSONObject jsonObj) throws JSONException {
@@ -150,9 +176,25 @@ public class AppointmentWriter extends CalendarWriter {
         }
         if (appointmentObject.containsAlarm()) {
             writeParameter(AppointmentFields.ALARM, appointmentObject.getAlarm(), jsonObj);
+        } else if (appointmentObject.containsUserParticipants() && null != session && isPublicFolder(appointmentObject)) {
+            final int userId  = session.getUserId();
+            /*
+             * Check for alarm for requesting user in user participants
+             */
+            NextUser: for (final UserParticipant userParticipant : appointmentObject.getUsers()) {
+                if (userId == userParticipant.getIdentifier() && userParticipant.getAlarmMinutes() > 0) {
+                    /*
+                     * Set appropriate alarm in appointment
+                     */
+                    writeParameter(AppointmentFields.ALARM, userParticipant.getAlarmMinutes(), jsonObj);
+                    break NextUser;
+                }
+            }
         }
         if (appointmentObject.containsRecurrenceType()) {
             writeRecurrenceParameter(appointmentObject, jsonObj);
+        } else if (!forTesting) {
+            writeParameter(CalendarFields.RECURRENCE_TYPE, Appointment.NO_RECURRENCE, jsonObj);
         }
         if (appointmentObject.containsRecurrenceID()) {
             writeParameter(AppointmentFields.RECURRENCE_ID, appointmentObject.getRecurrenceID(), jsonObj);
@@ -184,6 +226,15 @@ public class AppointmentWriter extends CalendarWriter {
         }
     }
 
+    private boolean isPublicFolder(final Appointment appointmentObject) {
+        try {
+            final int folderID = appointmentObject.getParentFolderID();
+            return folderID > 0 && new OXFolderAccess(session.getContext()).getFolderType(folderID) == FolderObject.PUBLIC;
+        } catch (final OXException e) {
+            return false;
+        }
+    }
+
     protected void writeField(final Appointment appointment, final int column, final TimeZone tz, final JSONArray json) throws JSONException {
         final AppointmentFieldWriter writer = WRITER_MAP.get(column);
         if (null != writer) {
@@ -417,6 +468,21 @@ public class AppointmentWriter extends CalendarWriter {
                 writeValue(appointmentObject.getSequence(), jsonArray, appointmentObject.containsSequence());
             }
         });
+        m.put(Appointment.ORGANIZER_ID, new AppointmentFieldWriter() {
+            public void write(final Appointment appointmentObject, final JSONArray jsonArray) {
+                writeValue(appointmentObject.getOrganizerId(), jsonArray, appointmentObject.containsOrganizerId());
+            }
+        });
+        m.put(Appointment.PRINCIPAL, new AppointmentFieldWriter() {
+            public void write(final Appointment appointmentObject, final JSONArray jsonArray) {
+                writeValue(appointmentObject.getPrincipal(), jsonArray, appointmentObject.containsPrincipal());
+            }
+        });
+        m.put(Appointment.PRINCIPAL_ID, new AppointmentFieldWriter() {
+            public void write(final Appointment appointmentObject, final JSONArray jsonArray) {
+                writeValue(appointmentObject.getPrincipalId(), jsonArray, appointmentObject.containsPrincipalId());
+            }
+        });
         WRITER_MAP = m;
     }
 }
