@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,9 @@
 package com.openexchange.ajax.writer;
 
 import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.sql.SQLException;
-import java.util.HashMap;
 import java.util.Locale;
-import java.util.Map;
 import java.util.TimeZone;
 import org.json.JSONArray;
 import org.json.JSONException;
@@ -84,12 +83,12 @@ import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * FolderWriter
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FolderWriter extends DataWriter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(FolderWriter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FolderWriter.class));
 
     private static final int[] mapping = { 0, -1, 1, -1, 2, -1, -1, -1, 4 };
 
@@ -98,14 +97,14 @@ public final class FolderWriter extends DataWriter {
     final UserConfiguration userConfig;
 
     final Context ctx;
-    
+
     final ServerSession session;
-    
+
     private AdditionalFolderFieldList fields = null;
 
     /**
      * {@link FolderFieldWriter} - A writer for folder fields
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     public static abstract class FolderFieldWriter {
@@ -119,7 +118,7 @@ public final class FolderWriter extends DataWriter {
 
         /**
          * Writes this writer's folder field from given {@link FolderObject} to specified {@link JSONWriter}.
-         * 
+         *
          * @param jsonwriter The JSON writer to write to
          * @param fo The folder object
          * @param withKey <code>true</code> to include JSON key; otherwise <code>false</code>
@@ -133,7 +132,7 @@ public final class FolderWriter extends DataWriter {
 
         /**
          * Writes this writer's folder field from given {@link FolderObject} to specified {@link JSONWriter}.
-         * 
+         *
          * @param jsonwriter The JSON writer to write to
          * @param fo The folder object
          * @param withKey <code>true</code> to include JSON key; otherwise <code>false</code>
@@ -146,10 +145,10 @@ public final class FolderWriter extends DataWriter {
         public abstract void writeField(JSONWriter jsonwriter, FolderObject fo, boolean withKey, String name, int hasSubfolders) throws JSONException, SQLException, AbstractOXException;
     }
 
-    private static final Map<Integer, FolderFieldWriter> STATIC_WRITERS_MAP = new HashMap<Integer, FolderFieldWriter>(15);
+    private static final TIntObjectHashMap<FolderFieldWriter> STATIC_WRITERS_MAP = new TIntObjectHashMap<FolderFieldWriter>(15);
 
     static {
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.OBJECT_ID), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.OBJECT_ID, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -170,7 +169,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(fo.getObjectID());
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.CREATED_BY), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.CREATED_BY, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -184,7 +183,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.MODIFIED_BY), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.MODIFIED_BY, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -198,7 +197,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.FOLDER_ID), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.FOLDER_ID, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -212,7 +211,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.FOLDER_NAME), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.FOLDER_NAME, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -226,7 +225,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.MODULE), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.MODULE, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -240,7 +239,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.SUMMARY), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.SUMMARY, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -250,7 +249,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value("");
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.STANDARD_FOLDER), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.STANDARD_FOLDER, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -264,7 +263,7 @@ public final class FolderWriter extends DataWriter {
                 }
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.TOTAL), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.TOTAL, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -274,7 +273,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.NEW), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.NEW, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -284,7 +283,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.UNREAD), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.UNREAD, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -294,7 +293,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.DELETED), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.DELETED, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -304,7 +303,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.CAPABILITIES), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.CAPABILITIES, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -314,7 +313,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.SUBSCRIBED), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.SUBSCRIBED, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -324,7 +323,7 @@ public final class FolderWriter extends DataWriter {
                 jsonwriter.value(JSONObject.NULL);
             }
         });
-        STATIC_WRITERS_MAP.put(Integer.valueOf(FolderObject.SUBSCR_SUBFLDS), new FolderFieldWriter() {
+        STATIC_WRITERS_MAP.put(FolderObject.SUBSCR_SUBFLDS, new FolderFieldWriter() {
 
             @Override
             public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
@@ -338,13 +337,13 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Initializes a new {@link FolderWriter}
-     * 
+     *
      * @param jw The JSON writer to write to
      * @param session The session providing needed user data
      * @param ctx The session's context
      * @param timeZone The time zone identifier
      */
-    public FolderWriter(final JSONWriter jw, final Session session, final Context ctx, final String timeZone, AdditionalFolderFieldList fields) {
+    public FolderWriter(final JSONWriter jw, final Session session, final Context ctx, final String timeZone, final AdditionalFolderFieldList fields) {
         super(null == timeZone ? getTimeZoneBySession(session, ctx) : getTimeZone(timeZone), jw);
         this.user = UserStorage.getStorageUser(session.getUserId(), ctx);
         this.userConfig = UserConfigurationStorage.getInstance().getUserConfigurationSafe(session.getUserId(), ctx);
@@ -362,7 +361,7 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Writes specified fields from given folder into a JSON object
-     * 
+     *
      * @param customizer The customizer to call back
      * @param fields The fields to write
      * @param fo The folder object
@@ -375,7 +374,7 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Writes specified fields from given folder into a JSON object
-     * 
+     *
      * @param customizer The customizer to call back
      * @param fields The fields to write
      * @param fo The folder object
@@ -412,7 +411,7 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Writes specified fields from given folder into a JSON array
-     * 
+     *
      * @param customizer The customizer to call back
      * @param fields The fields to write
      * @param fo The folder object
@@ -425,7 +424,7 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Writes specified fields from given folder into a JSON array
-     * 
+     *
      * @param customizer The customizer to call back
      * @param fields The fields to write
      * @param fo The folder object
@@ -463,7 +462,7 @@ public final class FolderWriter extends DataWriter {
 
     /**
      * Returns all known folder fields
-     * 
+     *
      * @return All known folder fields
      */
     public static int[] getAllFolderFields() {
@@ -479,7 +478,7 @@ public final class FolderWriter extends DataWriter {
             /*
              * Check if current field can be handled by a static writer implementation
              */
-            final FolderFieldWriter ffw = STATIC_WRITERS_MAP.get(Integer.valueOf(field));
+            final FolderFieldWriter ffw = STATIC_WRITERS_MAP.get(field);
             if (ffw == null) {
                 /*
                  * No static writer available, generate a new one
@@ -629,57 +628,64 @@ public final class FolderWriter extends DataWriter {
                                     throw new OXFolderException(FolderCode.MISSING_PARAMETER, e, FolderFields.PERMISSIONS);
                                 }
                             }
+                            /*
+                             * Create JSON array
+                             */
+                            final JSONArray ja = new JSONArray();
+                            {
+                                final OCLPermission[] perms = fo.getPermissionsAsArray();
+                                final UserConfigurationStorage userConfStorage = UserConfigurationStorage.getInstance();
+                                try {
+                                    for (int k = 0; k < perms.length; k++) {
+                                        final OCLPermission permission = perms[k];
+                                        if (!permission.isSystem()) {
+                                            final int entity = permission.getEntity();
+                                            final OCLPermission effectPerm;
+                                            if (permission.isGroupPermission()) {
+                                                effectPerm = permission;
+                                            } else if (OCLPermission.ALL_GROUPS_AND_USERS == entity) {
+                                                effectPerm = permission;
+                                                effectPerm.setGroupPermission(true);
+                                            } else {
+                                                effectPerm =
+                                                    fo.getEffectiveUserPermission(entity, userConfStorage.getUserConfiguration(entity, ctx));
+                                            }
+                                            final JSONObject jo = new JSONObject();
+                                            jo.put(FolderFields.BITS, createPermissionBits(effectPerm));
+                                            jo.put(FolderFields.ENTITY, entity);
+                                            jo.put(FolderFields.GROUP, effectPerm.isGroupPermission());
+                                            ja.put(jo);
+                                        }
+                                    }
+                                } catch (final DBPoolingException e) {
+                                    throw new OXException(e);
+                                } catch (final SQLException e) {
+                                    throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
+                                }
+                            }
+                            /*
+                             * Write to JSON writer
+                             */
                             if (withKey) {
                                 jsonwriter.key(FolderFields.PERMISSIONS);
                             }
-                            final JSONArray ja = new JSONArray();
-                            final OCLPermission[] perms = fo.getPermissionsAsArray();
-                            final UserConfigurationStorage userConfStorage = UserConfigurationStorage.getInstance();
-                            try {
-                                NextPerm: for (int k = 0; k < perms.length; k++) {
-                                    if (perms[k].isSystem()) {
-                                        /*
-                                         * Withhold system permissions
-                                         */
-                                        continue NextPerm;
-                                    }
-                                    final OCLPermission perm;
-                                    if (perms[k].isGroupPermission()) {
-                                        perm = perms[k];
-                                    } else {
-                                        perm =
-                                            fo.getEffectiveUserPermission(perms[k].getEntity(), userConfStorage.getUserConfiguration(
-                                                perms[k].getEntity(),
-                                                ctx));
-                                    }
-                                    final JSONObject jo = new JSONObject();
-                                    jo.put(FolderFields.BITS, createPermissionBits(perm));
-                                    jo.put(FolderFields.ENTITY, perm.getEntity());
-                                    jo.put(FolderFields.GROUP, perm.isGroupPermission());
-                                    ja.put(jo);
-                                }
-                            } catch (final DBPoolingException e) {
-                                throw new OXException(e);
-                            } catch (final SQLException e) {
-                                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
-                            }
                             jsonwriter.value(ja);
                         }
                     };
                     break Fields;
                 default:
-                    
+
                     if (!this.fields.knows(field) && LOG.isWarnEnabled()) {
                         LOG.warn("Unknown folder field: " + field);
                     }
-                    
+
                     final AdditionalFolderField folderField = this.fields.get(field);
                     retval[i] = new FolderFieldWriter() {
 
                         @Override
                         public void writeField(final JSONWriter jsonwriter, final FolderObject fo, final boolean withKey, final String name, final int hasSubfolders) throws JSONException {
                             if (withKey) {
-                                if(folderField.getColumnName() == null) {
+                                if (folderField.getColumnName() == null) {
                                     return;
                                 }
                                 jsonwriter.key(folderField.getColumnName());
