@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,36 +57,35 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.json.JSONException;
 import org.json.JSONWriter;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.infostore.utils.MetadataSwitcher;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 
 public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
-	
-	public static final Log LOG = LogFactory.getLog(InfostoreWriter.class);
-	
+
+	public static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreWriter.class));
+
 	public InfostoreWriter(final JSONWriter w) {
 		super(w);
 	}
-	
-	public void writeMetadata(final SearchIterator<DocumentMetadata> iter, final Metadata[] cols, final TimeZone tz) throws SearchIteratorException, JSONException, OXException {
+
+	public void writeMetadata(final SearchIterator<DocumentMetadata> iter, final Metadata[] cols, final TimeZone tz) throws JSONException, AbstractOXException {
 		jsonWriter.array();
-		
+
 		fillArray(iter,cols,tz);
 		jsonWriter.endArray();
-		
+
 	}
-	
-	
+
+
 	@Override
-	protected void fillArray(final SearchIterator<DocumentMetadata> iter, final Object[] cols, final TimeZone tz) throws SearchIteratorException, JSONException, OXException {
+	protected void fillArray(final SearchIterator<DocumentMetadata> iter, final Object[] cols, final TimeZone tz) throws JSONException, AbstractOXException {
 		final WriterSwitch sw = new WriterSwitch(jsonWriter, tz);
-		
+
 		//The array contains one array for every DocumentMetadata, and filled according to the requested columns
-		
+
 		while (iter.hasNext()) {
 			sw.setDocumentMetadata(iter.next());
 			jsonWriter.array();
@@ -99,7 +98,7 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 
 	public void write(final DocumentMetadata dm, final TimeZone tz) throws JSONException {
 		jsonWriter.object();
-		
+
 		final WriterSwitch w = new WriterSwitch(jsonWriter, tz);
 		w.setDocumentMetadata(dm);
 		for(final Metadata metadata : Metadata.HTTPAPI_VALUES) {
@@ -108,22 +107,22 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 		}
 		jsonWriter.endObject();
 	}
-	
+
 	private static final class WriterSwitch implements MetadataSwitcher{
-		
+
 		private DocumentMetadata dm;
 		private final JSONWriter writer;
 		private final TimeZone tz;
-		
+
 		public WriterSwitch(final JSONWriter writer, final TimeZone tz) {
 			this.writer = writer;
 			this.tz = tz;
 		}
-	
+
 		public void setDocumentMetadata(final DocumentMetadata dm) {
 			this.dm = dm;
 		}
-		
+
 		public void setMetadata(final Metadata current) {
 			try {
 				writer.key(current.getName());
@@ -131,82 +130,82 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 				LOG.error("",e);
 			}
 		}
-	
+
 		public Object lastModified() {
 			writeDate(dm.getLastModified());
 			return null;
 		}
-	
+
 		public Object creationDate() {
 			writeDate(dm.getCreationDate());
 			return null;
 		}
-	
+
 		public Object modifiedBy() {
 			writeId(dm.getModifiedBy());
 			return null;
 		}
-	
+
 		public Object folderId() {
 			writeId(dm.getFolderId());
 			return null;
 		}
-	
+
 		public Object title() {
 			writeString(dm.getTitle());
 			return null;
 		}
-		
+
 		public Object version() {
 			writeInteger(dm.getVersion());
 			return null;
 		}
-	
+
 		public Object content() {
 			writeString(dm.getContent());
 			return null;
 		}
-	
+
 		public Object id() {
 			writeId(dm.getId());
 			return null;
 		}
-	
+
 		public Object fileSize() {
 			writeInteger(dm.getFileSize());
 			return null;
 		}
-	
+
 		public Object description() {
 			writeString(dm.getDescription());
 			return null;
 		}
-	
+
 		public Object url() {
 			writeString(dm.getURL());
 			return null;
 		}
-	
+
 		public Object createdBy() {
 			writeId(dm.getCreatedBy());
 			return null;
 		}
-	
+
 		public Object fileName() {
 			writeString(dm.getFileName());
 			return null;
 		}
-	
+
 		public Object fileMIMEType() {
 			writeString(dm.getFileMIMEType());
 			return null;
 		}
-	
+
 		public Object sequenceNumber() {
 			return null;
-			
+
 		}
-	
+
 		public Object categories() {
 			final String categoriesString = dm.getCategories();
 			if(categoriesString==null || categoriesString.equals("")) {
@@ -219,7 +218,7 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 				return null;
 			}
 			final String[] categoriesArray = categoriesString.split("\\s*,\\s*");
-			
+
 			try {
 				writer.array();
 				for(final String cat : categoriesArray) {
@@ -255,12 +254,12 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 			}
 			return null;
 		}
-	
+
 		public Object fileMD5Sum() {
 			writeString(dm.getFileMD5Sum());
 			return null;
 		}
-		
+
 		private void writeDate(final Date date) {
 			if (date == null) {
                 writeNull();
@@ -274,11 +273,11 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 				writeInteger(time);
 			}
 		}
-		
+
 		private void writeId(final long id) {
 			writeString(String.valueOf(id));
 		}
-	
+
 		private void writeString(final String string) {
             if(string == null) {
                 writeNull();
@@ -290,7 +289,7 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 				LOG.error("",e);
 			}
 		}
-	
+
 		private void writeInteger(final long l) {
 			try {
 				writer.value(l);
@@ -339,5 +338,5 @@ public class InfostoreWriter extends TimedWriter<DocumentMetadata> {
 	protected int getId(final Object object) {
 		return ((DocumentMetadata)object).getId();
 	}
-	
+
 }
