@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,18 +53,17 @@ import java.util.TimeZone;
 import org.json.JSONException;
 import org.json.JSONWriter;
 import com.openexchange.ajax.fields.ResponseFields;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 
 public abstract class TimedWriter<T> {
-	
+
 	protected JSONWriter jsonWriter;
 
 	public TimedWriter(final JSONWriter w){
 		jsonWriter = w;
 	}
-	
+
 	public void timedResult(final long timestamp) throws JSONException {
 		jsonWriter.object();
 		jsonWriter.key(ResponseFields.TIMESTAMP);
@@ -75,8 +74,8 @@ public abstract class TimedWriter<T> {
 	public void endTimedResult() throws JSONException {
 		jsonWriter.endObject();
 	}
-	
-	public void writeDelta(final SearchIterator<T> iterator, final SearchIterator<T> deleted, final Object[] cols, final boolean ignoreDeleted, final TimeZone tz) throws JSONException, SearchIteratorException, OXException {
+
+	public void writeDelta(final SearchIterator<T> iterator, final SearchIterator<T> deleted, final Object[] cols, final boolean ignoreDeleted, final TimeZone tz) throws JSONException, AbstractOXException {
 		jsonWriter.array();
 		fillArray(iterator,cols, tz);
 		while(deleted.hasNext() && !ignoreDeleted) {
@@ -88,5 +87,5 @@ public abstract class TimedWriter<T> {
 
 	protected abstract int getId(Object object);
 
-	protected abstract void fillArray(SearchIterator<T> iterator, Object[] cols, TimeZone tz) throws SearchIteratorException, JSONException, OXException;
+	protected abstract void fillArray(SearchIterator<T> iterator, Object[] cols, TimeZone tz) throws JSONException, AbstractOXException;
 }
