@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,81 +49,76 @@
 
 package com.openexchange.api2;
 
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 
 /**
  * OXException.
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class OXException extends AbstractOXException {
 
-	/**
-     * For serialization.
-	 */
     private static final long serialVersionUID = -7503880425356541331L;
 
-	/**
-     * @deprecated use constructor with component, category and detailNumber.
-	 */
-    @Deprecated
-	public OXException() {
-		super();
-	}
-
     /**
      * @deprecated use constructor with component, category and detailNumber.
      */
-	@Deprecated
-	public OXException(final String message) {
-		super(message);
-	}
+    @Deprecated
+    public OXException() {
+        super();
+    }
 
-	/**
+    /**
+     * @deprecated use constructor with component, category and detailNumber.
+     */
+    @Deprecated
+    public OXException(final String message) {
+        super(message);
+    }
+
+    /**
      * Used by OXConcurrentModificationException.
      * @param component Component.
      * @param message Message.
-	 */
+     */
     protected OXException(final EnumComponent component, final String message) {
-		super(component, message);
-	}
+        super(component, message);
+    }
 
     /**
      * @deprecated use constructor with component, category and detailNumber.
      */
-	@Deprecated
-	public OXException(final String message, final Throwable cause) {
-		super(message, cause);
-	}
+    @Deprecated
+    public OXException(final String message, final Throwable cause) {
+        super(message, cause);
+    }
 
     /**
      * @deprecated use constructor with component, category and detailNumber.
      */
-	@Deprecated
-	public OXException(final EnumComponent component, final String message,
+    @Deprecated
+    public OXException(final EnumComponent component, final String message,
         final Throwable cause) {
-		super(component, message, cause);
-	}
+        super(component, message, cause);
+    }
 
     /**
      * @deprecated use constructor with component, category and detailNumber.
      */
-	@Deprecated
-	public OXException(final Throwable cause) {
-		super(cause);
-	}
+    @Deprecated
+    public OXException(final Throwable cause) {
+        super(cause);
+    }
 
     /**
      * @deprecated use constructor with component, category and detailNumber.
      */
-	@Deprecated
-	public OXException(final EnumComponent component, final Exception exc) {
-		super(component, exc);
-	}
+    @Deprecated
+    public OXException(final EnumComponent component, final Exception exc) {
+        super(component, exc);
+    }
 
-    /**
-     * {@inheritDoc}
-	 */
     public OXException(final AbstractOXException cause) {
         super(cause);
     }
@@ -142,4 +137,8 @@ public class OXException extends AbstractOXException {
         super(component, category, number, message, cause);
         super.setMessageArgs(messageArgs);
     }
+
+    public OXException(ErrorMessage message, Throwable cause) {
+        super(message, cause);
+    }
 }
