@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.authentication.service;
 
+import java.util.Map;
+import java.util.concurrent.atomic.AtomicReference;
 import com.openexchange.authentication.Authenticated;
 import com.openexchange.authentication.AuthenticationService;
 import com.openexchange.authentication.LoginException;
@@ -57,18 +59,13 @@ import com.openexchange.server.ServiceException;
 
 /**
  * Provides a static method for the login servlet to do the authentication.
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class Authentication {
 
-    /**
-     * Handles the reference to the authentication service.
-     */
-    private static AuthenticationService service;
+    private static final AtomicReference<AuthenticationService> SERVICE_REF = new AtomicReference<AuthenticationService>();
 
-    /**
-     * Default constructor.
-     */
     private Authentication() {
         super();
     }
@@ -77,15 +74,14 @@ public final class Authentication {
      * Performs a login using an authentication service.
      * @param login entered login.
      * @param pass entered password.
-     * @return a string array with two elements in which the first contains the
-     * login info for the context and the second contains the login info for the
-     * user.
+     * @param properties The optional properties
+     * @return a string array with two elements in which the first contains the login info for the context and the second contains the
+     * login info for the user.
      * @throws LoginException if something with the login info is wrong.
      * @throws ServiceException if the authentication service is not available.
      */
-    public static Authenticated login(final String login, final String pass)
-        throws LoginException, ServiceException {
-        final AuthenticationService auth = service;
+    public static Authenticated login(final String login, final String pass, final Map<String, Object> properties) throws LoginException, ServiceException {
+        final AuthenticationService auth = SERVICE_REF.get();
         if (null == auth) {
             throw new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, AuthenticationService.class.getName());
         }
@@ -96,20 +92,21 @@ public final class Authentication {
             public String getUsername() {
                 return login;
             }
+            public Map<String, Object> getProperties() {
+                return properties;
+            }
         });
     }
 
-    /**
-     * @return the service
-     */
     public static AuthenticationService getService() {
-        return service;
+        return SERVICE_REF.get();
     }
 
-    /**
-     * @param service the service to set
-     */
-    public static void setService(final AuthenticationService service) {
-        Authentication.service = service;
+    public static boolean setService(final AuthenticationService service) {
+        return SERVICE_REF.compareAndSet(null, service);
+    }
+
+    public static boolean dropService(final AuthenticationService service) {
+        return SERVICE_REF.compareAndSet(service, null);
     }
 }
