@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,33 +61,34 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.ajax.fields.FolderFields;
 import com.openexchange.api2.OXException;
-import com.openexchange.cache.dynamic.impl.OXObjectFactory;
-import com.openexchange.cache.dynamic.impl.Refresher;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
 import com.openexchange.caching.CacheKey;
 import com.openexchange.caching.CacheService;
 import com.openexchange.caching.ElementAttributes;
+import com.openexchange.caching.dynamic.OXObjectFactory;
+import com.openexchange.caching.dynamic.Refresher;
+import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.oxfolder.OXFolderException;
+import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 import com.openexchange.tools.oxfolder.OXFolderProperties;
-import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 
 /**
  * {@link FolderCacheManager} - Holds a cache for instances of {@link FolderObject}
  * <p>
  * <b>NOTE:</b> Only cloned versions of {@link FolderObject} instances are put into or received from cache. That prevents the danger of
  * further working on and therefore changing cached instances.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FolderCacheManager {
 
-    private static final Log LOG = LogFactory.getLog(FolderCacheManager.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FolderCacheManager.class));
 
     private static volatile FolderCacheManager instance;
 
@@ -99,7 +100,7 @@ public final class FolderCacheManager {
 
     /**
      * Initializes a new {@link FolderCacheManager}.
-     * 
+     *
      * @throws OXException If initialization fails
      */
     private FolderCacheManager() throws OXException {
@@ -110,7 +111,7 @@ public final class FolderCacheManager {
 
     /**
      * Checks if folder cache has been initialized.
-     * 
+     *
      * @return <code>true</code> if folder cache has been initialized; otherwise <code>false</code>
      */
     public static boolean isInitialized() {
@@ -119,7 +120,7 @@ public final class FolderCacheManager {
 
     /**
      * Checks if folder cache is enabled (through configuration).
-     * 
+     *
      * @return <code>true</code> if folder cache is enabled; otherwise <code>false</code>
      */
     public static boolean isEnabled() {
@@ -128,7 +129,7 @@ public final class FolderCacheManager {
 
     /**
      * Initializes the singleton instance of folder cache {@link FolderCacheManager manager}.
-     * 
+     *
      * @throws OXException If initialization fails
      */
     public static void initInstance() throws OXException {
@@ -143,7 +144,7 @@ public final class FolderCacheManager {
 
     /**
      * Gets the singleton instance of folder cache {@link FolderCacheManager manager}.
-     * 
+     *
      * @return The singleton instance of folder cache {@link FolderCacheManager manager}.
      * @throws FolderCacheNotEnabledException If folder cache is explicitly disabled through
      *             {@link OXFolderProperties#isEnableFolderCache() property}
@@ -186,7 +187,7 @@ public final class FolderCacheManager {
 
     /**
      * Initializes cache reference.
-     * 
+     *
      * @throws OXFolderException If initializing the cache reference fails
      */
     public void initCache() throws OXFolderException {
@@ -202,7 +203,7 @@ public final class FolderCacheManager {
 
     /**
      * Releases cache reference.
-     * 
+     *
      * @throws OXFolderException If clearing cache fails
      */
     public void releaseCache() throws OXFolderException {
@@ -225,43 +226,59 @@ public final class FolderCacheManager {
         return cacheLock;
     }
 
+    private class FolderFactory implements OXObjectFactory<FolderObject> {
+
+        private final Context ctx;
+
+        private final int folderId;
+
+        FolderFactory(final Context ctx, final int folderId) {
+            super();
+            this.ctx = ctx;
+            this.folderId = folderId;
+        }
+
+        public Lock getCacheLock() {
+            return FolderCacheManager.this.getCacheLock();
+        }
+
+        public Serializable getKey() {
+            return getCacheKey(ctx.getContextId(), folderId);
+        }
+
+        public FolderObject load() throws AbstractOXException {
+            return loadFolderObjectInternal(folderId, ctx, null);
+        }
+    }
+
     /**
      * Fetches <code>FolderObject</code> which matches given object id. If none found or <code>fromCache</code> is not set the folder will
      * be loaded from underlying database store and automatically put into cache.
      * <p>
      * <b>NOTE:</b> This method returns a clone of cached <code>FolderObject</code> instance. Thus any modifications made to the referenced
      * object will not affect cached version
-     * 
+     *
      * @throws OXException If a caching error occurs
      */
-    public FolderObject getFolderObject(final int objectId, final boolean fromCache, final Context ctx, final Connection readConArg) throws OXException {
-        final OXObjectFactory<FolderObject> factory = new OXObjectFactory<FolderObject>() {
-
-            public Lock getCacheLock() {
-                return FolderCacheManager.this.getCacheLock();
-            }
-
-            public Serializable getKey() {
-                return getCacheKey(ctx.getContextId(), objectId);
-            }
-
-            public FolderObject load() throws AbstractOXException {
-                // Connection can not be remembered.
-                return loadFolderObjectInternal(objectId, ctx, null);
-            }
-        };
+    public FolderObject getFolderObject(final int objectId, final boolean fromCache, final Context ctx, final Connection readCon) throws OXException {
+        if (null == folderCache) {
+            throw new FolderCacheNotEnabledException();
+        }
         try {
-            if (!fromCache) {
-                removeFolderObject(objectId, ctx);
+            if (fromCache) {
+                // Conditional put into cache: Put only if absent.
+                if (null != readCon) {
+                    putIfAbsentInternal(new LoadingFolderProvider(objectId, ctx, readCon), ctx, null);
+                }
+            } else {
+                // Forced put into cache: Always put.
+                putFolderObject(loadFolderObjectInternal(objectId, ctx, readCon), ctx, true, null);
             }
-            if (null != readConArg) {
-                putIfAbsent(loadFolderObjectInternal(objectId, ctx, readConArg), ctx, null);
-            }
-            return Refresher.refresh(FOLDER_CACHE_REGION_NAME, folderCache, factory).clone();
+            // Return refreshable object
+            return Refresher.refresh(FOLDER_CACHE_REGION_NAME, folderCache, new FolderFactory(ctx, objectId), true).clone();
+        } catch (final OXException e) {
+            throw e;
         } catch (final AbstractOXException e) {
-            if (e instanceof OXException) {
-                throw (OXException) e;
-            }
             throw new OXException(e);
         }
     }
@@ -274,24 +291,27 @@ public final class FolderCacheManager {
      * <b>NOTE:</b> This method returns a clone of cached <code>FolderObject</code> instance. Thus any modifications made to the referenced
      * object will not affect cached version
      * </p>
-     * 
+     *
      * @return The matching <code>FolderObject</code> instance else <code>null</code>
      */
     public FolderObject getFolderObject(final int objectId, final Context ctx) {
         if (null == folderCache) {
             return null;
         }
+        final FolderObject retval;
         cacheLock.lock();
         try {
-            Object tmp = folderCache.get(getCacheKey(ctx.getContextId(), objectId));
+            final Object tmp = folderCache.get(getCacheKey(ctx.getContextId(), objectId));
             // Refresher uses Condition objects to prevent multiple threads loading same folder.
-            if (tmp != null && tmp instanceof FolderObject) {
-                return ((FolderObject) tmp).clone();
+            if (tmp instanceof FolderObject) {
+                retval = ((FolderObject) tmp);
+            } else {
+                retval = null;
             }
-            return null;
         } finally {
             cacheLock.unlock();
         }
+        return null == retval ? retval : retval.clone();
     }
 
     /**
@@ -299,31 +319,28 @@ public final class FolderCacheManager {
      * <p>
      * <b>NOTE:</b> This method returns a clone of cached <code>FolderObject</code> instance. Thus any modifications made to the referenced
      * object will not affect cached version
-     * 
+     *
      * @return The matching <code>FolderObject</code> instance fetched from storage else <code>null</code>
      * @throws OXException If a caching error occurs
      */
     public FolderObject loadFolderObject(final int folderId, final Context ctx, final Connection readCon) throws OXException {
-        final OXObjectFactory<FolderObject> factory = new OXObjectFactory<FolderObject>() {
-
-            public Lock getCacheLock() {
-                return FolderCacheManager.this.getCacheLock();
-            }
-
-            public Serializable getKey() {
-                return getCacheKey(ctx.getContextId(), folderId);
-            }
-
-            public FolderObject load() throws AbstractOXException {
-                return loadFolderObjectInternal(folderId, ctx, readCon);
-            }
-        };
-        CacheKey key = getCacheKey(ctx.getContextId(), folderId);
+        final CacheKey key = getCacheKey(ctx.getContextId(), folderId);
         cacheLock.lock();
         try {
-            Object tmp = folderCache.get(key);
+            final Object tmp = folderCache.get(key);
             if (tmp instanceof FolderObject) {
                 folderCache.remove(key);
+                // Dirty hack
+                final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+                if (null != cacheService) {
+                    try {
+                        final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                        final CacheKey cacheKey = cacheService.newCacheKey(ctx.getContextId(), FolderStorage.REAL_TREE_ID, String.valueOf(key));
+                        globalCache.remove(cacheKey);
+                    } catch (final CacheException e) {
+                        LOG.warn(e.getMessage(), e);
+                    }
+                }
             }
         } catch (final CacheException e) {
             throw new OXException(e);
@@ -334,7 +351,7 @@ public final class FolderCacheManager {
             putIfAbsent(loadFolderObjectInternal(folderId, ctx, readCon), ctx, null);
         }
         try {
-            return Refresher.refresh(FOLDER_CACHE_REGION_NAME, folderCache, factory).clone();
+            return Refresher.refresh(FOLDER_CACHE_REGION_NAME, folderCache, new FolderFactory(ctx, folderId), true).clone();
         } catch (final AbstractOXException e) {
             if (e instanceof OXException) {
                 throw (OXException) e;
@@ -346,7 +363,7 @@ public final class FolderCacheManager {
     /**
      * Loads the folder object from underlying database storage whose id matches given parameter <code>folderId</code>.
      * <p>
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @param readCon A readable connection (<b>optional</b>), pass <code>null</code> to fetch a new one from connection pool
@@ -365,7 +382,7 @@ public final class FolderCacheManager {
      * <p>
      * <b>NOTE:</b> This method puts a clone of given <code>FolderObject</code> instance into cache. Thus any modifications made to the
      * referenced object will not affect cached version
-     * 
+     *
      * @param folderObj The folder object
      * @param ctx The context
      * @param elemAttribs The element's attributes (<b>optional</b>), pass <code>null</code> to use the default attributes
@@ -379,41 +396,55 @@ public final class FolderCacheManager {
         if (!folderObj.containsObjectID()) {
             throw new OXFolderException(FolderCode.MISSING_FOLDER_ATTRIBUTE, FolderFields.ID, I(-1), I(ctx.getContextId()));
         }
-        final CacheKey key = getCacheKey(ctx.getContextId(), folderObj.getObjectID());
+        return putIfAbsentInternal(new InstanceFolderProvider(folderObj.clone()), ctx, elemAttribs);
+    }
+
+    private FolderObject putIfAbsentInternal(final FolderProvider folderProvider, final Context ctx, final ElementAttributes elemAttribs) throws OXException {
+        final CacheKey key = getCacheKey(ctx.getContextId(), folderProvider.getObjectID());
+        final FolderObject retval;
         cacheLock.lock();
         try {
-            Object tmp = folderCache.get(key);
+            final Object tmp = folderCache.get(key);
             if (tmp instanceof FolderObject) {
                 // Already in cache
-                return ((FolderObject) tmp).clone();
-            }
-            Condition cond = null;
-            if (tmp instanceof Condition) {
-                cond = (Condition) tmp;
+                retval = ((FolderObject) tmp);
             } else {
-                // Remove to distribute PUT as REMOVE
-                folderCache.remove(key);
+                Condition cond = null;
+                if (tmp instanceof Condition) {
+                    cond = (Condition) tmp;
+                } else {
+                    // Remove to distribute PUT as REMOVE
+                    folderCache.remove(key);
+                    // Dirty hack
+                    final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+                    if (null != cacheService) {
+                        try {
+                            final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                            final CacheKey cacheKey = cacheService.newCacheKey(ctx.getContextId(), FolderStorage.REAL_TREE_ID, String.valueOf(key));
+                            globalCache.remove(cacheKey);
+                        } catch (final CacheException e) {
+                            LOG.warn(e.getMessage(), e);
+                        }
+                    }
+                }
+                if (elemAttribs == null) {
+                    // Put with default attributes
+                    folderCache.put(key, folderProvider.getFolderObject());
+                } else {
+                    folderCache.put(key, folderProvider.getFolderObject(), elemAttribs);
+                }
+                if (null != cond) {
+                    cond.signalAll();
+                }
+                // Return null to indicate successful insertion
+                retval = null;
             }
-            if (elemAttribs == null) {
-                /*
-                 * Put with default attributes
-                 */
-                folderCache.put(key, folderObj.clone());
-            } else {
-                folderCache.put(key, folderObj.clone(), elemAttribs);
-            }
-            if (null != cond) {
-                cond.signalAll();
-            }
-            /*
-             * Return null to indicate successful insertion
-             */
-            return null;
         } catch (final CacheException e) {
             throw new OXException(e);
         } finally {
             cacheLock.unlock();
         }
+        return null == retval ? retval : retval.clone();
     }
 
     /**
@@ -421,7 +452,7 @@ public final class FolderCacheManager {
      * <p>
      * <b>NOTE:</b> This method puts a clone of given <code>FolderObject</code> instance into cache. Thus any modifications made to the
      * referenced object will not affect cached version
-     * 
+     *
      * @param folderObj The folder object
      * @param ctx The context
      * @throws OXException If a caching error occurs
@@ -439,7 +470,7 @@ public final class FolderCacheManager {
      * <b>NOTE:</b> This method puts a clone of given <code>FolderObject</code> instance into cache. Thus any modifications made to the
      * referenced object will not affect cached version
      * </p>
-     * 
+     *
      * @param folderObj The folder object
      * @param ctx The context
      * @param overwrite <code>true</code> to overwrite; otherwise <code>false</code>
@@ -466,13 +497,24 @@ public final class FolderCacheManager {
         final CacheKey key = getCacheKey(ctx.getContextId(), folderObj.getObjectID());
         cacheLock.lock();
         try {
-            Object tmp = folderCache.get(key);
+            final Object tmp = folderCache.get(key);
             // If there is currently an object associated with this key in the region it is replaced.
             Condition cond = null;
             if (overwrite) {
                 if (tmp instanceof FolderObject) {
                     // Remove to distribute PUT as REMOVE
                     folderCache.remove(key);
+                    // Dirty hack
+                    final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+                    if (null != cacheService) {
+                        try {
+                            final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                            final CacheKey cacheKey = cacheService.newCacheKey(ctx.getContextId(), FolderStorage.REAL_TREE_ID, String.valueOf(key));
+                            globalCache.remove(cacheKey);
+                        } catch (final CacheException e) {
+                            LOG.warn(e.getMessage(), e);
+                        }
+                    }
                 } else if (tmp instanceof Condition) {
                     cond = (Condition) tmp;
                 }
@@ -502,7 +544,7 @@ public final class FolderCacheManager {
 
     /**
      * Removes matching folder object from cache
-     * 
+     *
      * @param key The key
      * @param ctx The context
      * @throws OXException If a caching error occurs
@@ -516,7 +558,7 @@ public final class FolderCacheManager {
             final CacheKey cacheKey = getCacheKey(ctx.getContextId(), key);
             cacheLock.lock();
             try {
-                Object tmp = folderCache.get(cacheKey);
+                final Object tmp = folderCache.get(cacheKey);
                 if (!(tmp instanceof Condition)) {
                     folderCache.remove(cacheKey);
                 }
@@ -526,11 +568,22 @@ public final class FolderCacheManager {
                 cacheLock.unlock();
             }
         }
+        // Dirty hack
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (null != cacheService) {
+            try {
+                final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                final CacheKey cacheKey = cacheService.newCacheKey(ctx.getContextId(), FolderStorage.REAL_TREE_ID, String.valueOf(key));
+                globalCache.remove(cacheKey);
+            } catch (final CacheException e) {
+                LOG.warn(e.getMessage(), e);
+            }
+        }
     }
 
     /**
      * Removes matching folder objects from cache
-     * 
+     *
      * @param keys The keys
      * @param ctx The context
      * @throws OXException If a caching error occurs
@@ -553,7 +606,7 @@ public final class FolderCacheManager {
         cacheLock.lock();
         try {
             for (final CacheKey cacheKey : cacheKeys) {
-                Object tmp = folderCache.get(cacheKey);
+                final Object tmp = folderCache.get(cacheKey);
                 if (!(tmp instanceof Condition)) {
                     folderCache.remove(cacheKey);
                 }
@@ -563,11 +616,24 @@ public final class FolderCacheManager {
         } finally {
             cacheLock.unlock();
         }
+        // Dirty hack
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (null != cacheService) {
+            try {
+                final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                for (final int key : keys) {
+                    final CacheKey cacheKey = cacheService.newCacheKey(ctx.getContextId(), FolderStorage.REAL_TREE_ID, String.valueOf(key));
+                    globalCache.remove(cacheKey);
+                }
+            } catch (final CacheException e) {
+                LOG.warn(e.getMessage(), e);
+            }
+        }
     }
 
     /**
      * Removes all folder objects from this cache
-     * 
+     *
      * @throws OXException If folder cache cannot be cleared
      */
     public void clearAll() throws OXException {
@@ -579,11 +645,21 @@ public final class FolderCacheManager {
         } catch (final CacheException e) {
             throw new OXException(e);
         }
+        // Dirty hack
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (null != cacheService) {
+            try {
+                final Cache globalCache = cacheService.getCache("GlobalFolderCache");
+                globalCache.clear();
+            } catch (final CacheException e) {
+                LOG.warn(e.getMessage(), e);
+            }
+        }
     }
 
     /**
      * Returns default element attributes for this cache
-     * 
+     *
      * @return default element attributes for this cache or <code>null</code>
      * @throws CacheException If a caching error occurs
      */
@@ -596,4 +672,57 @@ public final class FolderCacheManager {
          */
         return folderCache.getDefaultElementAttributes();
     }
+
+    private static interface FolderProvider {
+
+        FolderObject getFolderObject() throws OXException;
+
+        int getObjectID();
+    }
+
+    private static final class InstanceFolderProvider implements FolderProvider {
+
+        private final FolderObject folderObject;
+
+        public InstanceFolderProvider(final FolderObject folderObject) {
+            super();
+            this.folderObject = folderObject;
+        }
+
+        public FolderObject getFolderObject() {
+            return folderObject;
+        }
+
+        public int getObjectID() {
+            return folderObject.getObjectID();
+        }
+
+    }
+
+    private static final class LoadingFolderProvider implements FolderProvider {
+
+        private final Connection readCon;
+
+        private final int folderId;
+
+        private final Context ctx;
+
+        public LoadingFolderProvider(final int folderId, final Context ctx, final Connection readCon) {
+            super();
+            this.folderId = folderId;
+            this.ctx = ctx;
+            this.readCon = readCon;
+        }
+
+        public FolderObject getFolderObject() throws OXException {
+            if (folderId <= 0) {
+                throw new OXFolderNotFoundException(folderId, ctx);
+            }
+            return FolderObject.loadFolderObjectFromDB(folderId, ctx, readCon);
+        }
+
+        public int getObjectID() {
+            return folderId;
+        }
+    }
 }
