@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,15 +49,13 @@
 
 package com.openexchange.cache.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.Serializable;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.locks.Lock;
-import java.util.concurrent.locks.ReadWriteLock;
-import java.util.concurrent.locks.ReentrantReadWriteLock;
+import java.util.concurrent.locks.ReentrantLock;
 import com.openexchange.api2.OXException;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
@@ -70,34 +68,22 @@ import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 
 /**
  * {@link FolderQueryCacheManager}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FolderQueryCacheManager {
 
-    private static final ConcurrentMap<Integer, ReadWriteLock> contextLocks = new ConcurrentHashMap<Integer, ReadWriteLock>();
-
     private static final String REGION_NAME = "OXFolderQueryCache";
 
     private static volatile FolderQueryCacheManager instance;
 
     private Cache folderQueryCache;
 
-    private static ReadWriteLock getContextLock(final int cid) {
-        final Integer key = Integer.valueOf(cid);
-        ReadWriteLock l = contextLocks.get(key);
-        if (l == null) {
-            final ReadWriteLock tmp = new ReentrantReadWriteLock();
-            l = contextLocks.putIfAbsent(key, tmp);
-            if (null == l) {
-                l = tmp;
-            }
-        }
-        return l;
-    }
+    private Lock cacheLock;
 
     private FolderQueryCacheManager() throws OXException {
         super();
+        cacheLock = new ReentrantLock(true);
         initCache();
     }
 
@@ -107,7 +93,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Initializes the singleton instance of folder query cache {@link FolderQueryCacheManager manager}
-     * 
+     *
      * @throws OXException If initialization fails
      */
     public static void initInstance() throws OXException {
@@ -131,7 +117,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Initializes cache reference.
-     * 
+     *
      * @throws OXFolderException If initializing the cache reference fails
      */
     public void initCache() throws OXFolderException {
@@ -147,7 +133,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Releases cache reference.
-     * 
+     *
      * @throws OXFolderException If clearing cache fails
      */
     public void releaseCache() throws OXFolderException {
@@ -164,7 +150,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Releases the singleton instance of {@link FolderQueryCacheManager} and frees its cache resources
-     * 
+     *
      * @throws OXException If cache cannot be freed
      */
     public static void releaseInstance() throws OXException {
@@ -187,7 +173,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Gets a query result from cache if present, otherwise <code>null</code> is returned
-     * 
+     *
      * @return query result if present, otherwise <code>null</code>
      */
     public LinkedList<Integer> getFolderQuery(final int queryNum, final Session session) {
@@ -196,33 +182,36 @@ public final class FolderQueryCacheManager {
 
     /**
      * Gets a query result from cache if present, otherwise <code>null</code> is returned
-     * 
+     *
      * @return query result if present, otherwise <code>null</code>
      */
-    @SuppressWarnings("unchecked")
     public LinkedList<Integer> getFolderQuery(final int queryNum, final int userId, final int cid) {
         if (null == folderQueryCache) {
             return null;
         }
-        final Lock ctxReadLock = getContextLock(cid).readLock();
-        ctxReadLock.lock();
+        cacheLock.lock();
         try {
-            final Map<CacheKey, LinkedList<Integer>> map = (Map<CacheKey, LinkedList<Integer>>) folderQueryCache.getFromGroup(
-                createUserKey(userId),
-                createContextKey(cid));
-            final LinkedList<Integer> q;
-            if (map == null || (q = map.get(createQueryKey(queryNum))) == null) {
+            Object tmp = folderQueryCache.getFromGroup(createUserKey(userId), createContextKey(cid));
+            if (null == tmp) {
                 return null;
             }
-            return (LinkedList<Integer>) q.clone();
+            @SuppressWarnings("unchecked")
+            final Map<CacheKey, LinkedList<Integer>> map = (Map<CacheKey, LinkedList<Integer>>) tmp;
+            final LinkedList<Integer> q = map.get(createQueryKey(queryNum));
+            if (null == q) {
+                return null;
+            }
+            @SuppressWarnings("unchecked")
+            LinkedList<Integer> retval = (LinkedList<Integer>) q.clone();
+            return retval;
         } finally {
-            ctxReadLock.unlock();
+            cacheLock.unlock();
         }
     }
 
     /**
      * Puts a query result into cache
-     * 
+     *
      * @throws OXException If a caching error occurs
      */
     public void putFolderQuery(final int queryNum, final LinkedList<Integer> q, final Session session) throws OXException {
@@ -231,7 +220,7 @@ public final class FolderQueryCacheManager {
 
     /**
      * Puts a query result into cache
-     * 
+     *
      * @throws OXException If a caching error occurs
      */
     public void putFolderQuery(final int queryNum, final LinkedList<Integer> q, final int userId, final int cid) throws OXException {
@@ -241,7 +230,7 @@ public final class FolderQueryCacheManager {
     /**
      * Puts a query result into cache. If <code>append</code> is set and cache already contains a query result belonging to given
      * <code>queryNum</code>, given result is going to appended to existing one. Otherwise existing entries are replaced.
-     * 
+     *
      * @throws OXException If a caching error occurs
      */
     public void putFolderQuery(final int queryNum, final LinkedList<Integer> q, final Session session, final boolean append) throws OXException {
@@ -251,33 +240,34 @@ public final class FolderQueryCacheManager {
     /**
      * Puts a query result into cache. If <code>append</code> is set and cache already contains a query result belonging to given
      * <code>queryNum</code>, given result is going to appended to existing one. Otherwise existing entries are replaced.
-     * 
+     *
      * @throws OXException If a caching error occurs
      */
-    @SuppressWarnings("unchecked")
     public void putFolderQuery(final int queryNum, final LinkedList<Integer> q, final int userId, final int cid, final boolean append) throws OXException {
         if (null == folderQueryCache) {
             return;
         } else if (q == null) {
             return;
         }
-        final Lock ctxWriteLock = getContextLock(cid).writeLock();
-        ctxWriteLock.lock();
+        final CacheKey queryKey = createQueryKey(queryNum);
+        cacheLock.lock();
         try {
             boolean insertMap = false;
-            Map<CacheKey, LinkedList<Integer>> map = (Map<CacheKey, LinkedList<Integer>>) folderQueryCache.getFromGroup(
-                createUserKey(userId),
-                createContextKey(cid));
+            @SuppressWarnings("unchecked")
+            Map<CacheKey, LinkedList<Integer>> map = (Map<CacheKey, LinkedList<Integer>>) folderQueryCache.getFromGroup(createUserKey(userId), createContextKey(cid));
             if (map == null) {
                 map = new HashMap<CacheKey, LinkedList<Integer>>();
                 insertMap = true;
             }
-            final CacheKey queryKey = createQueryKey(queryNum);
             final LinkedList<Integer> tmp = map.get(queryKey);
             if (tmp == null || !append) {
-                map.put(queryKey, (LinkedList<Integer>) q.clone());
+                @SuppressWarnings("unchecked")
+                LinkedList<Integer> clone = (LinkedList<Integer>) q.clone();
+                map.put(queryKey, clone);
             } else {
-                tmp.addAll((LinkedList<Integer>) q.clone());
+                @SuppressWarnings("unchecked")
+                LinkedList<Integer> clone = (LinkedList<Integer>) q.clone();
+                tmp.addAll(clone);
             }
             if (insertMap) {
                 folderQueryCache.putInGroup(createUserKey(userId), createContextKey(cid), (Serializable) map);
@@ -285,7 +275,7 @@ public final class FolderQueryCacheManager {
         } catch (final CacheException e) {
             throw new OXException(e);
         } finally {
-            ctxWriteLock.unlock();
+            cacheLock.unlock();
         }
     }
 
@@ -303,12 +293,11 @@ public final class FolderQueryCacheManager {
         if (null == folderQueryCache) {
             return;
         }
-        final Lock ctxWriteLock = getContextLock(cid).writeLock();
-        ctxWriteLock.lock();
+        cacheLock.lock();
         try {
             folderQueryCache.invalidateGroup(createContextKey(cid));
         } finally {
-            ctxWriteLock.unlock();
+            cacheLock.unlock();
         }
     }
 
@@ -319,11 +308,11 @@ public final class FolderQueryCacheManager {
     }
 
     private static Integer createUserKey(final int userId) {
-        return Integer.valueOf(userId);
+        return I(userId);
     }
 
     private static String createContextKey(final int cid) {
-        return String.valueOf(cid);
+        return Integer.toString(cid);
     }
 
 }
