@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.cache.impl.FolderCacheNotEnabledException;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 
 
 /**
@@ -64,25 +65,20 @@ import com.openexchange.groupware.contexts.impl.ContextStorage;
  *
  */
 public class FolderCacheInvalidation implements GenericCacheInvalidationInterface {
-	
+
 	private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
 			.getLog(FolderCacheInvalidation.class);
-	
+
 	private static final String REMOTE_NAME = "FolderCacheInvalidation";
-	
+
 	private static final String ERR = "Folder could not be remote-removed";
 
-	/* (non-Javadoc)
-	 * @see com.openexchange.cache.remote.GenericCacheInvalidationInterface#getRemoteName()
-	 */
 	public String getRemoteName() {
 		return REMOTE_NAME;
 	}
 
-	/* (non-Javadoc)
-	 * @see com.openexchange.cache.remote.GenericCacheInvalidationInterface#invalidateCacheElement(int, int)
-	 */
 	public void invalidateCacheElement(final int contextId, final int objectId) throws RemoteException {
+	    ConditionTreeMapManagement.dropFor(contextId);
 		if (FolderCacheManager.isEnabled() && FolderCacheManager.isInitialized()) {
 			try {
 				FolderCacheManager.getInstance().removeFolderObject(objectId, ContextStorage.getInstance().getContext(contextId));
