@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,6 +54,7 @@ import java.nio.charset.IllegalCharsetNameException;
 import java.nio.charset.UnsupportedCharsetException;
 import java.nio.charset.spi.CharsetProvider;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -64,7 +65,7 @@ import java.util.concurrent.ConcurrentMap;
 
 /**
  * {@link CustomCharsetProvider} - A custom charset provider which maps unknown charset names to supported charsets.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CustomCharsetProvider extends CharsetProvider {
@@ -72,7 +73,7 @@ public final class CustomCharsetProvider extends CharsetProvider {
     /**
      * The logger instance.
      */
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CustomCharsetProvider.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CustomCharsetProvider.class));
 
     /**
      * The charset map.
@@ -130,7 +131,7 @@ public final class CustomCharsetProvider extends CharsetProvider {
      * <p>
      * If charset look-up for given <tt>delegateName</tt> throws an {@link IllegalCharsetNameException} or an
      * {@link UnsupportedCharsetException}, <code>false</code> is returned and exception is logged.
-     * 
+     *
      * @param delegateName The name of the delegate charset; e.g. <code>&quot;UTF-8&quot;</code>
      * @param canonicalName The canonical name of the alias charset; e.g. <code>&quot;UTF_8&quot;</code>
      * @param aliases The aliases of the alias charset
@@ -155,7 +156,7 @@ public final class CustomCharsetProvider extends CharsetProvider {
 
     /**
      * Adds an {@link AliasCharset alias charset} to this charset provider.
-     * 
+     *
      * @param delegate The delegate charset
      * @param canonicalName The canonical name of the alias charset; e.g. <code>&quot;UTF_8&quot;</code>
      * @param aliases The aliases of the alias charset
@@ -164,7 +165,14 @@ public final class CustomCharsetProvider extends CharsetProvider {
     public boolean addAliasCharset(final Charset delegate, final String canonicalName, final String... aliases) {
         final AliasCharset aliasCharset = new AliasCharset(canonicalName, null == aliases || aliases.length == 0 ? null : aliases, delegate);
         String key = aliasCharset.name().toLowerCase();
-        boolean added = (null == name2charset.putIfAbsent(key, aliasCharset));
+        final ConcurrentMap<String, Charset> map = name2charset;
+        if (null == map) {
+            /*
+             * Not initialized, yet
+             */
+            return false;
+        }
+        boolean added = (null == map.putIfAbsent(key, aliasCharset));
         // Add aliases one-by-one
         final Set<String> aliasSet = aliasCharset.aliases();
         if (added && !aliasSet.isEmpty()) {
@@ -172,12 +180,12 @@ public final class CustomCharsetProvider extends CharsetProvider {
             for (final Iterator<String> iter = aliasSet.iterator(); added && iter.hasNext();) {
                 addedKeys.add(key);
                 key = iter.next().toLowerCase();
-                added = (null == name2charset.putIfAbsent(key, aliasCharset));
+                added = (null == map.putIfAbsent(key, aliasCharset));
             }
             if (!added) {
                 // Charset could not be added with all its aliases
                 for (final String removeMe : addedKeys) {
-                    name2charset.remove(removeMe);
+                    map.remove(removeMe);
                 }
             }
         }
@@ -190,7 +198,7 @@ public final class CustomCharsetProvider extends CharsetProvider {
      * <p>
      * If charset look-up for given <tt>delegateName</tt> throws an {@link IllegalCharsetNameException} or an
      * {@link UnsupportedCharsetException}, <code>false</code> is returned and exception is logged.
-     * 
+     *
      * @param delegateName The name of the delegate charset; e.g. <code>&quot;UTF-8&quot;</code>
      * @param startsWithName The starts-with name of the starts-with charset; e.g. <code>&quot;UTF_8&quot;</code>
      * @return <code>true</code> if an appropriate starts-with charset could be added to this provider; otherwise <code>false</code>
@@ -214,19 +222,23 @@ public final class CustomCharsetProvider extends CharsetProvider {
 
     /**
      * Adds a {@link StartsWithCharset starts-with charset} to this charset provider.
-     * 
+     *
      * @param delegate The delegate charset
      * @param startsWithName The starts-with name of the starts-with charset; e.g. <code>&quot;UTF_8&quot;</code>
      * @return <code>true</code> if an appropriate starts-with charset could be added to this provider; otherwise <code>false</code>
      */
     public boolean addStartsWithCharset(final Charset delegate, final String startsWithName) {
+        final ConcurrentMap<String, Charset> startsWithMap = startsWith2charset;
+        if (null == startsWithMap) {
+            return false;
+        }
         final StartsWithCharset startsWithCharset = new StartsWithCharset(startsWithName, delegate);
-        return (null == startsWith2charset.putIfAbsent(startsWithName.toLowerCase(), startsWithCharset));
+        return (null == startsWithMap.putIfAbsent(startsWithName.toLowerCase(), startsWithCharset));
     }
 
     /**
      * Retrieves a charset for the given charset name.
-     * 
+     *
      * @param charsetName The name of the requested charset; may be either a canonical name or an alias
      * @return A charset object for the named charset, or <tt>null</tt> if the named charset is not supported by this provider
      */
@@ -235,7 +247,14 @@ public final class CustomCharsetProvider extends CharsetProvider {
         /*
          * Get charset instance for given name (case insensitive)
          */
-        Charset retval = name2charset.get(charsetName.toLowerCase());
+        final ConcurrentMap<String, Charset> map = name2charset;
+        if (null == map) {
+            /*
+             * Not initialized, yet
+             */
+            return null;
+        }
+        Charset retval = map.get(charsetName.toLowerCase());
         if (null != retval) {
             // Direct hit
             return retval;
@@ -243,8 +262,9 @@ public final class CustomCharsetProvider extends CharsetProvider {
         /*
          * Traverse starts-with charsets
          */
-        if (!startsWith2charset.isEmpty()) {
-            for (final Iterator<Map.Entry<String, Charset>> iter = startsWith2charset.entrySet().iterator(); (null == retval) && iter.hasNext();) {
+        final ConcurrentMap<String, Charset> startsWithMap = startsWith2charset;
+        if (!startsWithMap.isEmpty()) {
+            for (final Iterator<Map.Entry<String, Charset>> iter = startsWithMap.entrySet().iterator(); (null == retval) && iter.hasNext();) {
                 final Map.Entry<String, Charset> entry = iter.next();
                 if (charsetName.toLowerCase().startsWith(entry.getKey())) {
                     retval = entry.getValue();
@@ -257,12 +277,19 @@ public final class CustomCharsetProvider extends CharsetProvider {
     /**
      * Creates an iterator that iterates over the charsets supported by this provider. This method is used in the implementation of the
      * {@link java.nio.charset.Charset#availableCharsets Charset.availableCharsets} method.
-     * 
+     *
      * @return The new iterator with the <tt>remove()</tt> functionality stripped.
      */
     @Override
     public Iterator<Charset> charsets() {
-        final Set<Charset> set = new HashSet<Charset>(name2charset.values());
+        final ConcurrentMap<String, Charset> map = name2charset;
+        if (null == map) {
+            /*
+             * Not initialized, yet
+             */
+            return Collections.<Charset> emptyList().iterator();
+        }
+        final Set<Charset> set = new HashSet<Charset>(map.values());
         set.addAll(startsWith2charset.values());
         return unmodifiableIterator(set.iterator());
     }
@@ -272,7 +299,7 @@ public final class CustomCharsetProvider extends CharsetProvider {
      * <p>
      * Wraps the supplied iterator into a new one that will always throw an <tt>UnsupportedOperationException</tt> if its <tt>remove()</tt>
      * method is called.
-     * 
+     *
      * @param iterator The iterator to turn into an unmodifiable iterator.
      * @return An iterator with no remove functionality.
      */
