@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,12 +56,12 @@ import com.openexchange.server.Initialization;
 
 /**
  * {@link CustomCharsetProviderInit} - Initialization for custom charset provider.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CustomCharsetProviderInit implements Initialization {
 
-    private static final Log LOG = LogFactory.getLog(CustomCharsetProviderInit.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CustomCharsetProviderInit.class));
 
     /**
      * Initializes a new {@link CustomCharsetProviderInit}.
