@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -47,8 +47,6 @@
  *
  */
 
-
-
 package com.openexchange.configuration;
 
 import com.openexchange.groupware.AbstractOXException;
@@ -60,9 +58,6 @@ import com.openexchange.groupware.EnumComponent;
  */
 public class ConfigurationException extends AbstractOXException {
 
-    /**
-     * For serialization.
-     */
     private static final long serialVersionUID = 7857242456684578343L;
 
     /**
@@ -70,7 +65,7 @@ public class ConfigurationException extends AbstractOXException {
      * @param cause The cause exception
      */
     public ConfigurationException(final AbstractOXException cause) {
-    	super(cause);
+        super(cause);
     }
 
     /**
@@ -89,10 +84,8 @@ public class ConfigurationException extends AbstractOXException {
      * @param cause the cause of the exception.
      * @param messageArgs arguments that will be formatted into the message.
      */
-    public ConfigurationException(final Code code, final Throwable cause,
-        final Object... messageArgs) {
-        super(EnumComponent.CONFIGURATION, code.category, code.detailNumber,
-            code.message, cause);
+    public ConfigurationException(final Code code, final Throwable cause, final Object... messageArgs) {
+        super(EnumComponent.CONFIGURATION, code.getCategory(), code.getDetailNumber(), code.getMessage(), cause);
         setMessageArgs(messageArgs);
     }
 
@@ -101,68 +94,31 @@ public class ConfigurationException extends AbstractOXException {
      * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
      */
     public static enum Code {
-        /**
-         * Filename for property file is not defined.
-         */
-        NO_FILENAME("Filename for property file is not defined.",
-            Category.SETUP_ERROR, 1),
-        /**
-         * File "%1$s" does not exist.
-         */
+        /** Filename for property file is not defined. */
+        NO_FILENAME("Filename for property file is not defined.", Category.SETUP_ERROR, 1),
+        /** File "%1$s" does not exist. */
         FILE_NOT_FOUND("File \"%1$s\" does not exist.", Category.SETUP_ERROR, 2),
-        /**
-         * File "%1$s" is not readable.
-         */
+        /** File "%1$s" is not readable. */
         NOT_READABLE("File \"%1$s\" is not readable.", Category.SETUP_ERROR, 3),
-        /**
-         * Cannot read file "%1$s".
-         */
+        /** Cannot read file "%1$s". */
         READ_ERROR("Cannot read file \"%1$s\".", Category.SETUP_ERROR, 4),
-        /**
-         * Property "%1$s" is not defined.
-         */
-        PROPERTY_MISSING("Property \"%1$s\" is not defined.",
-            Category.SETUP_ERROR, 5),
-        /**
-         * Cannot load class "%1$s".
-         */
+        /** Property "%1$s" is not defined. */
+        PROPERTY_MISSING("Property \"%1$s\" is not defined.", Category.SETUP_ERROR, 5),
+        /** Cannot load class "%1$s". */
         CLASS_NOT_FOUND("Cannot load class \"%1$s\".", Category.SETUP_ERROR, 6),
-        
-        /**
-         * Invalid configuration: %1$s
-         */
+        /** Invalid configuration: %1$s */
         INVALID_CONFIGURATION("Invalid configuration: %1$s", Category.SETUP_ERROR, 7),
-        
-        /**
-         * Property %1$s is not an integer
-         */
+        /** Property %1$s is not an integer */
         PROPERTY_NOT_AN_INTEGER("Property %1$s is not an integer", Category.CODE_ERROR, 8),
-        /**
-         * An I/O error occurred: %1$s
-         */
+        /** An I/O error occurred: %1$s */
         IO_ERROR("An I/O error occurred: %1$s", Category.CODE_ERROR, 9);
 
-        /**
-         * Message of the exception.
-         */
         private final String message;
 
-        /**
-         * Category of the exception.
-         */
         private final Category category;
 
-        /**
-         * Detail number of the exception.
-         */
         private final int detailNumber;
 
-        /**
-         * Default constructor.
-         * @param message message.
-         * @param category category.
-         * @param detailNumber detail number.
-         */
         private Code(final String message, final Category category,
             final int detailNumber) {
             this.message = message;
@@ -170,17 +126,16 @@ public class ConfigurationException extends AbstractOXException {
             this.detailNumber = detailNumber;
         }
 
-		public Category getCategory() {
-			return category;
-		}
+        public Category getCategory() {
+            return category;
+        }
 
-		public int getDetailNumber() {
-			return detailNumber;
-		}
+        public int getDetailNumber() {
+            return detailNumber;
+        }
 
-		public String getMessage() {
-			return message;
-		}
+        public String getMessage() {
+            return message;
+        }
     }
-
 }
