@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,17 +54,18 @@ import java.io.File;
 import java.util.Properties;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigTools;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ConfigurationException.Code;
 
 /**
  * This class handles the configuration parameters read from the configuration property file server.properties.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class ServerConfig {
 
-    private static final Log LOG = LogFactory.getLog(ServerConfig.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServerConfig.class));
 
     /**
      * Singleton object.
@@ -94,17 +95,28 @@ public final class ServerConfig {
 
     private Boolean checkIP;
 
+    private final ClientWhitelist clientWhitelist;
+
     private String uiWebPath;
 
+    private int cookieTTL;
+
+    private boolean cookieHttpOnly;
+
+    private int maxBodySize;
+
+    private int defaultMaxConcurrentAJAXRequests;
+
     private ServerConfig() {
         super();
+        clientWhitelist = new ClientWhitelist();
     }
 
     public static ServerConfig getInstance() {
         return SINGLETON;
     }
 
-    public void initialize(ConfigurationService confService) {
+    public void initialize(final ConfigurationService confService) {
         final Properties newProps = confService.getFile(FILENAME);
         if (null == newProps) {
             LOG.info("Configuration file " + FILENAME + " is missing. Using defaults.");
@@ -123,7 +135,7 @@ public final class ServerConfig {
 
     private void reinit() {
         // UPLOAD_DIRECTORY
-        uploadDirectory = props.getProperty(Property.UploadDirectory.getPropertyName(), "/tmp/");
+        uploadDirectory = getPropertyInternal(Property.UploadDirectory);
         if (!uploadDirectory.endsWith("/")) {
             uploadDirectory += "/";
         }
@@ -141,32 +153,47 @@ public final class ServerConfig {
         }
         // MAX_FILE_UPLOAD_SIZE
         try {
-            maxFileUploadSize = Integer.parseInt(getProperty(Property.MaxFileUploadSize.getPropertyName()));
+            maxFileUploadSize = Integer.parseInt(getPropertyInternal(Property.MaxFileUploadSize));
         } catch (final NumberFormatException e) {
             maxFileUploadSize = 10000;
         }
         // MAX_UPLOAD_IDLE_TIME_MILLIS
         try {
-            maxUploadIdleTimeMillis = Integer.parseInt(getProperty(Property.MaxUploadIdleTimeMillis.getPropertyName()));
+            maxUploadIdleTimeMillis = Integer.parseInt(getPropertyInternal(Property.MaxUploadIdleTimeMillis));
         } catch (final NumberFormatException e) {
             maxUploadIdleTimeMillis = 300000;
         }
         // PrefetchEnabled
-        prefetchEnabled = Boolean.parseBoolean(props.getProperty(Property.PrefetchEnabled.getPropertyName(), Boolean.FALSE.toString()));
+        prefetchEnabled = Boolean.parseBoolean(getPropertyInternal(Property.PrefetchEnabled));
         // Default encoding
-        defaultEncoding = props.getProperty(Property.DefaultEncoding.getPropertyName(), "UTF-8");
+        defaultEncoding = getPropertyInternal(Property.DefaultEncoding);
         // JMX port
-        jmxPort = Integer.parseInt(props.getProperty(Property.JMX_PORT.getPropertyName(), "9999"));
+        jmxPort = Integer.parseInt(getPropertyInternal(Property.JMX_PORT));
         // JMX bind address
-        jmxBindAddress = props.getProperty(Property.JMX_BIND_ADDRESS.getPropertyName(), "localhost");
-        checkIP = Boolean.valueOf(props.getProperty(Property.IP_CHECK.getPropertyName(), Boolean.TRUE.toString()));
-        uiWebPath = props.getProperty(Property.UI_WEB_PATH.getPropertyName(), "/ox6/index.html");
+        jmxBindAddress = getPropertyInternal(Property.JMX_BIND_ADDRESS);
+        // Check IP
+        checkIP = Boolean.valueOf(getPropertyInternal(Property.IP_CHECK));
+        // IP check whitelist
+        clientWhitelist.clear();
+        clientWhitelist.add(getPropertyInternal(Property.IP_CHECK_WHITELIST));
+        // UI web path
+        uiWebPath = getPropertyInternal(Property.UI_WEB_PATH);
+        cookieTTL = (int) ConfigTools.parseTimespan(getPropertyInternal(Property.COOKIE_TTL));
+        cookieHttpOnly = Boolean.parseBoolean(getPropertyInternal(Property.COOKIE_HTTP_ONLY));
+        // The max. body size
+        maxBodySize = Integer.parseInt(getPropertyInternal(Property.MAX_BODY_SIZE));
+        // Default max. concurrent AJAX requests
+        defaultMaxConcurrentAJAXRequests = Integer.parseInt(getPropertyInternal(Property.DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS));
+    }
+
+    private String getPropertyInternal(final Property property) {
+        return props.getProperty(property.getPropertyName(), property.getDefaultValue());
     }
 
     /**
      * Returns the value of the property with the specified key. This method
      * returns <code>null</code> if the property is not found.
-     * 
+     *
      * @param key
      *            the property key.
      * @return the value of the property or <code>null</code> if the property
@@ -176,6 +203,68 @@ public final class ServerConfig {
         return SINGLETON.props.getProperty(key);
     }
 
+    /**
+     * @param property
+     *            wanted property.
+     * @return the value of the property.
+     */
+    @SuppressWarnings("unchecked")
+    public static <V> V getPropertyObject(final Property property) {
+        try {
+            final Object value;
+            switch (property) {
+            case UploadDirectory:
+                value = SINGLETON.uploadDirectory;
+                break;
+            case MaxFileUploadSize:
+                value = Integer.valueOf(SINGLETON.maxFileUploadSize);
+                break;
+            case MaxUploadIdleTimeMillis:
+                value = Integer.valueOf(SINGLETON.maxUploadIdleTimeMillis);
+                break;
+            case PrefetchEnabled:
+                value = Boolean.valueOf(SINGLETON.prefetchEnabled);
+                break;
+            case DefaultEncoding:
+                value = SINGLETON.defaultEncoding;
+                break;
+            case JMX_PORT:
+                value = Integer.valueOf(SINGLETON.jmxPort);
+                break;
+            case JMX_BIND_ADDRESS:
+                value = SINGLETON.jmxBindAddress;
+                break;
+            case UI_WEB_PATH:
+                value = SINGLETON.uiWebPath;
+                break;
+            case COOKIE_TTL:
+                value = Integer.valueOf(SINGLETON.cookieTTL);
+                break;
+            case COOKIE_HTTP_ONLY:
+                value = Boolean.valueOf(SINGLETON.cookieHttpOnly);
+                break;
+            case IP_CHECK:
+                value = SINGLETON.checkIP;
+                break;
+            case IP_CHECK_WHITELIST:
+                value = SINGLETON.clientWhitelist;
+                break;
+            case MAX_BODY_SIZE:
+                value = Integer.valueOf(SINGLETON.maxBodySize);
+                break;
+            case DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS:
+                value = Integer.valueOf(SINGLETON.defaultMaxConcurrentAJAXRequests);
+                break;
+            default:
+                value = getProperty(property.getPropertyName());
+            }
+            return (V) value;
+        } catch (final ClassCastException e) {
+            LOG.debug(e.getMessage(), e);
+            return null;
+        }
+    }
+
     /**
      * @param property
      *            wanted property.
@@ -188,10 +277,10 @@ public final class ServerConfig {
             value = SINGLETON.uploadDirectory;
             break;
         case MaxFileUploadSize:
-            value = String.valueOf(SINGLETON.maxFileUploadSize);
+            value = Integer.toString(SINGLETON.maxFileUploadSize);
             break;
         case MaxUploadIdleTimeMillis:
-            value = String.valueOf(SINGLETON.maxUploadIdleTimeMillis);
+            value = Integer.toString(SINGLETON.maxUploadIdleTimeMillis);
             break;
         case PrefetchEnabled:
             value = String.valueOf(SINGLETON.prefetchEnabled);
@@ -200,7 +289,7 @@ public final class ServerConfig {
             value = SINGLETON.defaultEncoding;
             break;
         case JMX_PORT:
-            value = String.valueOf(SINGLETON.jmxPort);
+            value = Integer.toString(SINGLETON.jmxPort);
             break;
         case JMX_BIND_ADDRESS:
             value = SINGLETON.jmxBindAddress;
@@ -208,6 +297,21 @@ public final class ServerConfig {
         case UI_WEB_PATH:
             value = SINGLETON.uiWebPath;
             break;
+        case COOKIE_TTL:
+            value = Integer.toString(SINGLETON.cookieTTL);
+            break;
+        case COOKIE_HTTP_ONLY:
+            value = String.valueOf(SINGLETON.cookieHttpOnly);
+            break;
+        case IP_CHECK:
+            value = SINGLETON.checkIP.toString();
+            break;
+        case MAX_BODY_SIZE:
+            value = Integer.toString(SINGLETON.maxBodySize);
+            break;
+        case DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS:
+            value = Integer.toString(SINGLETON.defaultMaxConcurrentAJAXRequests);
+            break;
         default:
             value = getProperty(property.getPropertyName());
         }
@@ -221,7 +325,7 @@ public final class ServerConfig {
      * <p>
      * If there is no property with the specified name, or if the specified name
      * is empty or null, then <code>false</code> is returned.
-     * 
+     *
      * @param property
      *            the property.
      * @return the <code>boolean</code> value of the property.
@@ -230,13 +334,15 @@ public final class ServerConfig {
         final boolean value;
         if (Property.PrefetchEnabled == property) {
             value = SINGLETON.prefetchEnabled;
+        } else if (Property.COOKIE_HTTP_ONLY == property) {
+            value = SINGLETON.cookieHttpOnly;
         } else {
             value = Boolean.parseBoolean(SINGLETON.props.getProperty(property.getPropertyName()));
         }
         return value;
     }
 
-    public static Integer getInteger(Property property) throws ConfigurationException {
+    public static Integer getInteger(final Property property) throws ConfigurationException {
         final Integer value;
         switch (property) {
         case MaxFileUploadSize:
@@ -248,14 +354,23 @@ public final class ServerConfig {
         case JMX_PORT:
             value = I(SINGLETON.jmxPort);
             break;
+        case COOKIE_TTL:
+            value = I(SINGLETON.cookieTTL);
+            break;
+        case MAX_BODY_SIZE:
+            value = I(SINGLETON.maxBodySize);
+            break;
+        case DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS:
+            value = I(SINGLETON.defaultMaxConcurrentAJAXRequests);
+            break;
         default:
             try {
-                String prop = getProperty(property.getPropertyName());
+                final String prop = getProperty(property.getPropertyName());
                 if (prop == null) {
                     throw new ConfigurationException(Code.PROPERTY_MISSING, property.getPropertyName());
                 }
                 value = Integer.valueOf(getProperty(property.getPropertyName()));
-            } catch (NumberFormatException e) {
+            } catch (final NumberFormatException e) {
                 throw new ConfigurationException(Code.PROPERTY_NOT_AN_INTEGER, property.getPropertyName());
             }
         }
@@ -271,13 +386,26 @@ public final class ServerConfig {
      */
     public static int getInt(final Property property) throws ConfigurationException {
         final int value;
-        if (Property.MaxFileUploadSize == property) {
+        switch (property) {
+        case MaxFileUploadSize:
             value = SINGLETON.maxFileUploadSize;
-        } else if (Property.MaxUploadIdleTimeMillis == property) {
+            break;
+        case MaxUploadIdleTimeMillis:
             value = SINGLETON.maxUploadIdleTimeMillis;
-        } else if (Property.JMX_PORT == property) {
+            break;
+        case JMX_PORT:
             value = SINGLETON.jmxPort;
-        } else {
+            break;
+        case COOKIE_TTL:
+            value = SINGLETON.cookieTTL;
+            break;
+        case MAX_BODY_SIZE:
+            value = SINGLETON.maxBodySize;
+            break;
+        case DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS:
+            value = SINGLETON.defaultMaxConcurrentAJAXRequests;
+            break;
+        default:
             try {
                 final String prop = getProperty(property.getPropertyName());
                 if (prop == null) {
@@ -285,81 +413,119 @@ public final class ServerConfig {
                 }
                 value = Integer.parseInt(getProperty(property.getPropertyName()));
             } catch (final NumberFormatException e) {
-                throw new ConfigurationException(Code.PROPERTY_NOT_AN_INTEGER,
-                        property.getPropertyName());
+                throw new ConfigurationException(Code.PROPERTY_NOT_AN_INTEGER, property.getPropertyName());
             }
         }
         return value;
     }
 
-    public Boolean isCheckIP() {
-        return checkIP;
-    }
-
     public static enum Property {
         /**
          * Upload directory.
          */
-        UploadDirectory("UPLOAD_DIRECTORY"),
+        UploadDirectory("UPLOAD_DIRECTORY", "/tmp/"),
         /**
          * Max upload file size.
          */
         @Deprecated
-        MaxFileUploadSize("MAX_UPLOAD_FILE_SIZE"),
+        MaxFileUploadSize("MAX_UPLOAD_FILE_SIZE", "10000"),
         /**
          * Enable/Disable SearchIterator's ResultSet prefetch.
          */
-        PrefetchEnabled("PrefetchEnabled"),
-        /**
-         * Implementation of the file storage.
-         */
-        FileStorageImpl("FileStorageImpl"),
+        PrefetchEnabled("PrefetchEnabled", Boolean.FALSE.toString()),
         /**
          * Default encoding.
          */
-        DefaultEncoding("DefaultEncoding"),
+        DefaultEncoding("DefaultEncoding", "UTF-8"),
         /**
          * The maximum size of accepted uploads. Max be overridden in
          * specialized module configs and user settings.
          */
-        MAX_UPLOAD_SIZE("MAX_UPLOAD_SIZE"),
+        MAX_UPLOAD_SIZE("MAX_UPLOAD_SIZE", "0"),
         /**
          * JMXPort
          */
-        JMX_PORT("JMXPort"),
+        JMX_PORT("JMXPort", "9999"),
         /**
          * JMXBindAddress
          */
-        JMX_BIND_ADDRESS("JMXBindAddress"),
+        JMX_BIND_ADDRESS("JMXBindAddress", "localhost"),
         /**
          * Max idle time for uploaded files in milliseconds
          */
-        MaxUploadIdleTimeMillis("MAX_UPLOAD_IDLE_TIME_MILLIS"),
+        MaxUploadIdleTimeMillis("MAX_UPLOAD_IDLE_TIME_MILLIS", "300000"),
         /**
          * Number of characters a search pattern must contain to prevent slow
          * search queries and big responses in large contexts.
          */
-        MINIMUM_SEARCH_CHARACTERS("com.openexchange.MinimumSearchCharacters"),
+        MINIMUM_SEARCH_CHARACTERS("com.openexchange.MinimumSearchCharacters", "0"),
         /**
          * On session validation of every request the client IP address is compared with the client IP address used for the login request.
          * If this connfiguration parameter is set to <code>true</code> and the client IP addresses do not match the request will be denied.
          * Setting this parameter to <code>false</code> will only log the different client IP addresses with debug level.
          */
-        IP_CHECK("com.openexchange.IPCheck"),
+        IP_CHECK("com.openexchange.IPCheck", Boolean.TRUE.toString()),
+        /**
+         * The comma-separated list of client patterns that do bypass IP check
+         */
+        IP_CHECK_WHITELIST("com.openexchange.IPCheckWhitelist", ""),
         /**
          * Configures the path on the web server where the UI is located. This path is used to generate links directly into the UI. The
          * default conforms to the path where the UI is installed by the standard packages on the web server.
          */
-        UI_WEB_PATH("com.openexchange.UIWebPath");
+        UI_WEB_PATH("com.openexchange.UIWebPath", "/ox6/index.html"),
+        /**
+         * The cookie time-to-live
+         */
+        COOKIE_TTL("com.openexchange.cookie.ttl", "1W"),
+        /**
+         * The cookie HttpOnly flag
+         */
+        COOKIE_HTTP_ONLY("com.openexchange.cookie.httpOnly", Boolean.TRUE.toString()),
+        /**
+         * The fields used to calculate the hash value which is part of Cookie name.
+         * <p>
+         * This option only has effect if "com.openexchange.cookie.hash" option is set to "calculate".
+         */
+        COOKIE_HASH_FIELDS("com.openexchange.cookie.hash.fields", ""),
+        /**
+         * The method how to generate the hash value which is part of Cookie name
+         */
+        COOKIE_HASH("com.openexchange.cookie.hash", "calculate"),
+        /**
+         * Whether to force secure flag for Cookies
+         */
+        COOKIE_FORCE_HTTPS("com.openexchange.cookie.forceHTTPS", Boolean.FALSE.toString()),
+        /**
+         * Whether to force HTTPS protocol.
+         */
+        FORCE_HTTPS("com.openexchange.forceHTTPS", Boolean.FALSE.toString()),
+        /**
+         * The max. allowed size of a HTTP request
+         */
+        MAX_BODY_SIZE("MAX_BODY_SIZE", "0"),
+        /**
+         * The default value for max. concurrent AJAX requests.
+         */
+        DEFAULT_MAX_CONCURRENT_AJAX_REQUESTS("com.openexchange.defaultMaxConcurrentAJAXRequests", "-1"),
+        
+        ;
 
-        private String propertyName;
+        private final String propertyName;
 
-        private Property(final String propertyName) {
+        private final String defaultValue;
+
+        private Property(final String propertyName, final String defaultValue) {
             this.propertyName = propertyName;
+            this.defaultValue = defaultValue;
         }
 
         public String getPropertyName() {
             return propertyName;
         }
+
+        public String getDefaultValue() {
+            return defaultValue;
+        }
     }
 }
