@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,11 +73,11 @@ import com.openexchange.groupware.infostore.database.impl.DatabaseImpl;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.server.ServiceException;
 import com.openexchange.tools.file.FileStorage;
 import com.openexchange.tools.file.QuotaFileStorage;
 import com.openexchange.tools.file.external.FileStorageException;
+import com.openexchange.tx.TransactionException;
 
 /**
  * Provides the Business Logic for the consistency tool. Concrete subclasses must provide integration
@@ -88,7 +88,7 @@ import com.openexchange.tools.file.external.FileStorageException;
  */
 public abstract class Consistency implements ConsistencyMBean {
 
-    private static final Log LOG = LogFactory.getLog(Consistency.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Consistency.class));
 
     public List<String> listMissingFilesInContext(final int contextId) throws AbstractOXException {
         LOG.info("Listing missing files in context "+contextId);
@@ -367,7 +367,7 @@ public abstract class Consistency implements ConsistencyMBean {
     }
 
     private static interface ProblemSolver {
-        public void solve(Context ctx, Set<String> problems) throws OXException ;
+        public void solve(Context ctx, Set<String> problems) throws AbstractOXException;
 
         String description();
     }
@@ -431,7 +431,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class CreateDummyFileForInfoitem extends CreateDummyFile implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(CreateDummyFileForInfoitem.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CreateDummyFileForInfoitem.class));
 
         private final DatabaseImpl database;
 
@@ -440,7 +440,7 @@ public abstract class Consistency implements ConsistencyMBean {
             this.database = database;
         }
 
-        public void solve(final Context ctx, final Set<String> problems) throws OXException {
+        public void solve(final Context ctx, final Set<String> problems) throws AbstractOXException {
             /*
             * Here we operate in two stages. First we create a dummy entry in the
             * filestore. Second we update the Entries in the database
@@ -485,7 +485,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class CreateDummyFileForAttachment extends CreateDummyFile implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(CreateDummyFileForAttachment.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CreateDummyFileForAttachment.class));
 
         private final AttachmentBase attachments;
 
@@ -551,7 +551,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class RemoveFile implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(RemoveFile.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(RemoveFile.class));
 
         private final FileStorage storage;
 
@@ -582,7 +582,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class DeleteInfoitem implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(DeleteInfoitem.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DeleteInfoitem.class));
 
         private final DatabaseImpl database;
 
@@ -607,7 +607,7 @@ public abstract class Consistency implements ConsistencyMBean {
                         LOG1.info("Deleted entry " + identifier + " from " +
                                 "infostore_documents.");
                     }
-                } catch (final OXException e) {
+                } catch (final AbstractOXException e) {
                     LOG1.error("", e);
                     try {
                         database.rollback();
@@ -632,7 +632,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class DeleteAttachment implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(DeleteAttachment.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DeleteAttachment.class));
 
         private final AttachmentBase attachments;
         public DeleteAttachment(final AttachmentBase attachments) {
@@ -690,7 +690,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
     private static class CreateInfoitem implements ProblemSolver {
 
-        private static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(CreateInfoitem.class);
+        private static final org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CreateInfoitem.class));
 
         private static final String description = "This file needs attention";
         private static final String title = "Restoredfile";
@@ -738,7 +738,7 @@ public abstract class Consistency implements ConsistencyMBean {
                         } catch (final TransactionException e1) {
                             LOG1.debug("", e1);
                         }
-                    } catch (final OXException e) {
+                    } catch (final AbstractOXException e) {
                         LOG1.error("", e);
                         try {
                             database.rollback();
