@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.management.MBeanServerConnection;
+import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 import javax.management.remote.JMXConnector;
 import javax.management.remote.JMXConnectorFactory;
@@ -99,7 +100,7 @@ public class ConsistencyCheck {
         lexer.noise("files");
         lexer.noise("errors");
         lexer.noise("in");
-        
+
         if(lexer.consume("database")) {
             config.setSource("database");
             if (! parseId(lexer, config)) {
@@ -137,7 +138,7 @@ public class ConsistencyCheck {
             } else if (lexer.consume("missing_file_for_attachment")) {
                 lexer.noise(":");
                 if(lexer.consume("create_dummy")){
-                    config.addPolicy("missing_file_for_attachment" , "create_dummy");                    
+                    config.addPolicy("missing_file_for_attachment" , "create_dummy");
                 } else if(lexer.consume("delete")) {
                     config.addPolicy("missing_file_for_attachment" , "delete");
                 } else {
@@ -311,7 +312,7 @@ public class ConsistencyCheck {
             }
         }
 
-        private void listMissing() throws AbstractOXException, IOException {
+        private void listMissing() throws AbstractOXException, IOException, MalformedObjectNameException, NullPointerException {
 
             Map<Integer, List<String>> result = null;
             try {
@@ -333,7 +334,7 @@ public class ConsistencyCheck {
             print(result);
         }
 
-        private void repair() throws AbstractOXException, IOException {
+        private void repair() throws AbstractOXException, IOException, MalformedObjectNameException, NullPointerException {
             if(policies.isEmpty()) {
                 System.out.println("Nothing to be done. Please specify one or more resolver policies");
                 return;
@@ -366,14 +367,14 @@ public class ConsistencyCheck {
         private void disconnect() {
             try {
                 if(jmxConnector != null) {
-                    jmxConnector.close();                     
+                    jmxConnector.close();
                 }
             } catch (final IOException e) {
                 //IGNORE
             }
         }
 
-        private void connect() throws IOException {
+        private void connect() throws IOException, MalformedObjectNameException, NullPointerException {
             final JMXServiceURL url = new JMXServiceURL("service:jmx:rmi:///jndi/rmi://"
                     + host + ":" + port + "/server");
 
@@ -381,12 +382,12 @@ public class ConsistencyCheck {
 
             final MBeanServerConnection mbsc = jmxConnector.getMBeanServerConnection();
 
-            final ObjectName name = JMXToolkit.getObjectName();
+            final ObjectName name = MBeanNamer.getName();
 
             consistency = new MBeanConsistency(mbsc, name);
         }
 
-        private void listUnassigned() throws AbstractOXException, IOException {
+        private void listUnassigned() throws AbstractOXException, IOException, MalformedObjectNameException, NullPointerException {
 
             Map<Integer, List<String>> result = null;
             try {
