@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -165,7 +165,15 @@ public class ConversionWarning extends AbstractOXException {
         /**
          * Empty "CLASS" element.
          */
-        EMPTY_CLASS("Empty \"CLASS\" element.", Category.USER_INPUT, 17);
+        EMPTY_CLASS("Empty \"CLASS\" element.", Category.USER_INPUT, 17),
+        /**
+         *
+         */
+        INSUFFICIENT_INFORMATION("Insufficient information for parsing/writing this element.",Category.CODE_ERROR, 18),
+        /**
+         * No parent recurring appointment found for series exception: %s
+         */
+        NO_RECURRENCE_MASTER_FOUND("No parent recurring appointment found for series exception: %s", Category.USER_INPUT, 20);        
 
         /**
          * Message of the exception.
