@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,13 +51,14 @@ package com.openexchange.data.conversion.ical;
 
 import java.io.OutputStream;
 import java.util.List;
+import com.openexchange.data.conversion.ical.itip.ITipContainer;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.tasks.Task;
 
 /**
  * {@link ICalEmitter}
- * 
+ *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 public interface ICalEmitter {
@@ -69,10 +70,30 @@ public interface ICalEmitter {
 
     public String writeTasks(List<Task> tasks, List<ConversionError> errors, List<ConversionWarning> warnings, Context ctx) throws ConversionError;
 
-    public ICalSession createSession();
+    /**
+     * Writes a free/busy-reply, using the supplied free/busy information to
+     * reflect the free/busy-times and the corresponding attendee.
+     * 
+     * @param freeBusyRequest the free/busy-information 
+     * @param ctx the context
+     * @param errors the list of conversion errors
+     * @param warnings the list of conversion warnings
+     * @return the free/busy-reply
+     * @throws ConversionError
+     */
+    String writeFreeBusyReply(FreeBusyInformation freeBusyInfo, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError;
+
+    /**
+     * Creates a new {@link ICalSession} to collect the iCal information.
+     * @param mode Operation mode to use.
+     * @return a newly generated {@link ICalSession}.
+     */
+    public ICalSession createSession(Mode mode);
+
+    ICalSession createSession();
 
     public ICalItem writeAppointment(ICalSession session, Appointment appointment, Context ctx, ITipContainer iTip, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError;
-    
+
     /**
      * @throws ConversionError if a wrong session is given that is not created with this implementations {@link #createSession()} method.
      */
@@ -88,4 +109,6 @@ public interface ICalEmitter {
      */
     public void writeSession(ICalSession session, OutputStream stream) throws ConversionError;
 
+	public void flush(ICalSession session, OutputStream stream) throws ConversionError;
+
 }
