@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.database;
 
 import java.sql.Connection;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.update.UpdateTask;
 
 /**
  * If your bundle needs to create database tables for working properly this service must be implemented. Its method are called if a new
@@ -58,6 +59,9 @@ import com.openexchange.groupware.AbstractOXException;
  * the methods {@link #requiredTables()} and {@link #tablesToCreate()}. The {@link #perform(Connection)} method should then create the
  * tables needed for your bundle.
  *
+ * The table must be created in its newest version. {@link UpdateTask}s are not executed after all tables have been created and the schema
+ * is marked in that way that all {@link UpdateTask}s have already been executed.
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public interface CreateTableService {
