@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.database.internal;
 
+import javax.mail.internet.IDNA;
 import com.openexchange.database.DBPoolingException;
 
 /**
@@ -62,17 +63,17 @@ public final class ConfigDatabaseLifeCycle implements PoolLifeCycle {
 
     private final ConnectionPool configDBRead;
 
-    ConfigDatabaseLifeCycle(Configuration configuration, Management management, Timer timer) {
+    ConfigDatabaseLifeCycle(final Configuration configuration, final Management management, final Timer timer) {
         super();
-        configDBWrite = new ConnectionPool(configuration.getWriteUrl(), configuration.getWriteProps(), configuration.getPoolConfig());
+        configDBWrite = new ConnectionPool(IDNA.toASCII(configuration.getWriteUrl()), configuration.getWriteProps(), configuration.getPoolConfig());
         timer.addTask(configDBWrite.getCleanerTask());
         management.addPool(Constants.CONFIGDB_WRITE_ID, configDBWrite);
-        configDBRead = new ConnectionPool(configuration.getReadUrl(), configuration.getReadProps(), configuration.getPoolConfig());
+        configDBRead = new ConnectionPool(IDNA.toASCII(configuration.getReadUrl()), configuration.getReadProps(), configuration.getPoolConfig());
         timer.addTask(configDBRead.getCleanerTask());
         management.addPool(Constants.CONFIGDB_READ_ID, configDBRead);
     }
 
-    public ConnectionPool create(int poolId) throws DBPoolingException {
+    public ConnectionPool create(final int poolId) throws DBPoolingException {
         switch (poolId) {
         case Constants.CONFIGDB_WRITE_ID:
             return configDBWrite;
@@ -83,7 +84,7 @@ public final class ConfigDatabaseLifeCycle implements PoolLifeCycle {
         }
     }
 
-    public boolean destroy(int poolId) {
+    public boolean destroy(final int poolId) {
         // Pools to configuration database will not be destroyed.
         return poolId == Constants.CONFIGDB_WRITE_ID || poolId == Constants.CONFIGDB_READ_ID;
     }
