@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,6 @@ package com.openexchange.database.internal;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
-
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -60,9 +59,9 @@ import java.util.ArrayList;
 import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import com.openexchange.database.DBPoolingExceptionCodes;
 import com.openexchange.database.ConfigDatabaseService;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.DBPoolingExceptionCodes;
 import com.openexchange.pooling.PoolingException;
 
 /**
@@ -72,7 +71,7 @@ import com.openexchange.pooling.PoolingException;
  */
 public final class ConfigDatabaseServiceImpl implements ConfigDatabaseService {
 
-    private static final Log LOG = LogFactory.getLog(ConfigDatabaseServiceImpl.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConfigDatabaseServiceImpl.class));
 
     private final boolean forceWriteOnly;
 
@@ -104,7 +103,7 @@ public final class ConfigDatabaseServiceImpl implements ConfigDatabaseService {
         }
         // TODO Enable the following if the configuration database gets a table replicationMonitor.
         // return ReplicationMonitor.checkActualAndFallback(pools, assign, false, write || forceWriteOnly);
-        
+
     }
 
     private void back(Connection con, boolean write) {
@@ -179,4 +178,8 @@ public final class ConfigDatabaseServiceImpl implements ConfigDatabaseService {
         }
         return retval;
     }
+
+    public int getServerId() throws DBPoolingException {
+        return Server.getServerId();
+    }
 }
