@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,12 +49,14 @@
 
 package com.openexchange.event.impl;
 
+import java.util.Map;
+import java.util.Set;
 import com.openexchange.event.CommonEvent;
 import com.openexchange.session.Session;
 
 /**
  * {@link CommonEventImpl} - Implementation of {@link CommonEvent}.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public final class CommonEventImpl implements CommonEvent {
@@ -63,6 +65,8 @@ public final class CommonEventImpl implements CommonEvent {
 
     private final int userId;
 
+    private final Map<Integer, Set<Integer>> affectedUsersWithFolder;
+
     private final int module;
 
     private final Object actionObj;
@@ -77,9 +81,11 @@ public final class CommonEventImpl implements CommonEvent {
 
     private final Session session;
 
-    public CommonEventImpl(final int userId, final int contextId, final int action, final int module, final Object actionObj, final Object oldObj, final Object sourceFolder, final Object destinationFolder, final Session session) {
-        this.userId = userId;
+    public CommonEventImpl(final int contextId, int userId, Map<Integer, Set<Integer>> affectedUsersWithFolder, final int action, final int module, final Object actionObj, final Object oldObj, final Object sourceFolder, final Object destinationFolder, final Session session) {
+        super();
         this.contextId = contextId;
+        this.userId = userId;
+        this.affectedUsersWithFolder = affectedUsersWithFolder;
         this.action = action;
         this.module = module;
         this.actionObj = actionObj;
@@ -124,4 +130,8 @@ public final class CommonEventImpl implements CommonEvent {
     public Session getSession() {
         return session;
     }
+
+    public Map<Integer, Set<Integer>> getAffectedUsersWithFolder() {
+        return affectedUsersWithFolder;
+    }
 }
