@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.event.impl;
 
+import java.util.Map;
+import java.util.Set;
 import com.openexchange.event.CommonEvent;
 import com.openexchange.event.EventFactoryService;
 import com.openexchange.event.RemoteEvent;
@@ -56,7 +58,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link EventFactoryServiceImpl} - Implementation of {@link EventFactoryService}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class EventFactoryServiceImpl implements EventFactoryService {
@@ -68,8 +70,8 @@ public final class EventFactoryServiceImpl implements EventFactoryService {
         super();
     }
 
-    public CommonEvent newCommonEvent(final int userId, final int contextId, final int action, final int module, final Object actionObj, final Object oldObj, final Object sourceFolder, final Object destinationFolder, final Session session) {
-        return new CommonEventImpl(userId, contextId, action, module, actionObj, oldObj, sourceFolder, destinationFolder, session);
+    public CommonEvent newCommonEvent(final int contextId, final int userId, Map<Integer, Set<Integer>> affectedUsers, final int action, final int module, final Object actionObj, final Object oldObj, final Object sourceFolder, final Object destinationFolder, final Session session) {
+        return new CommonEventImpl(contextId, userId, affectedUsers, action, module, actionObj, oldObj, sourceFolder, destinationFolder, session);
     }
 
     public RemoteEvent newRemoteEvent(final int folderId, final int userId, final int contextId, final int action, final int module, final long timestamp) {
