@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.event.impl;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.configuration.SystemConfig;
+import com.openexchange.database.provider.DBPoolProvider;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.attach.AttachmentCleaner;
 import com.openexchange.groupware.impl.FolderLockManagerImpl;
@@ -61,18 +62,17 @@ import com.openexchange.groupware.infostore.webdav.PropertyCleaner;
 import com.openexchange.groupware.infostore.webdav.PropertyStoreImpl;
 import com.openexchange.groupware.links.LinksEventHandler;
 import com.openexchange.groupware.notify.ParticipantNotify;
-import com.openexchange.groupware.tx.DBPoolProvider;
 import com.openexchange.server.Initialization;
 
 /**
  * EventInit
  *
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 
 public class EventInit implements Initialization {
-	
-	private static final Log LOG = LogFactory.getLog(EventInit.class);
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(EventInit.class));
     private boolean started;
 
 
