@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,13 +65,14 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 
 /**
  * {@link EventQueue} - The event queue.
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class EventQueue {
@@ -127,12 +128,12 @@ public final class EventQueue {
                         shutdownLock.unlock();
                     }
                 }
-            } catch (Throwable t) {
+            } catch (final Throwable t) {
                 LOG.error(t.getMessage(), t);
             }
         }
 
-        public void setScheduledTimerTask(ScheduledTimerTask scheduledTimerTask) {
+        public void setScheduledTimerTask(final ScheduledTimerTask scheduledTimerTask) {
             this.scheduledTimerTask = scheduledTimerTask;
         }
     }
@@ -151,7 +152,7 @@ public final class EventQueue {
 
     private static boolean isEnabled;
 
-    static final Log LOG = LogFactory.getLog(EventQueue.class);
+    static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(EventQueue.class));
 
     /*
      * +++++++++++++++ Appointment Event Lists +++++++++++++++
@@ -203,7 +204,7 @@ public final class EventQueue {
 
     private static ScheduledTimerTask timerTask;
 
-    private static EventDispatcher newEventDispatcher = null;
+    private static volatile EventDispatcher newEventDispatcher;
 
     private EventQueue() {
         super();
@@ -215,7 +216,7 @@ public final class EventQueue {
 
     /**
      * Initializes the {@link EventQueue}.
-     * 
+     *
      * @param config The configuration with which event queue is going to be configured
      */
     static void init(final EventConfig config) {
@@ -234,14 +235,15 @@ public final class EventQueue {
             if (!noDelay) {
                 final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
                 if (timer != null) {
-                    final EventQueueTimerTask task2schedule = new EventQueueTimerTask(
-                        ALL_EVENTS_PROCESSED,
-                        SHUTDOWN_LOCK,
-                        isFirst,
-                        queue1,
-                        queue2,
-                        shutdownComplete,
-                        shuttingDown);
+                    final EventQueueTimerTask task2schedule =
+                        new EventQueueTimerTask(
+                            ALL_EVENTS_PROCESSED,
+                            SHUTDOWN_LOCK,
+                            isFirst,
+                            queue1,
+                            queue2,
+                            shutdownComplete,
+                            shuttingDown);
                     timerTask = timer.scheduleWithFixedDelay(task2schedule, delay, delay);
                     task2schedule.setScheduledTimerTask(timerTask);
                 }
@@ -337,59 +339,67 @@ public final class EventQueue {
         if (appointmentEventList.isEmpty()) {
             return;
         }
+        final Appointment appointment = (Appointment) eventObj.getObject();
+        final Session session = eventObj.getSessionObject();
         final int action = eventObj.getAction();
         switch (action) {
         case EventClient.CREATED:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentCreated((Appointment) eventObj.getObject(), eventObj.getSessionObject());
+                    next.appointmentCreated(appointment, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CHANGED:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentModified((Appointment) eventObj.getObject(), eventObj.getSessionObject());
+                    next.appointmentModified(appointment, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.DELETED:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentDeleted((Appointment) eventObj.getObject(), eventObj.getSessionObject());
+                    next.appointmentDeleted(appointment, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_ACCEPTED:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentAccepted((Appointment) eventObj.getObject(), eventObj.getSessionObject());
+                    next.appointmentAccepted(appointment, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_DECLINED:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentDeclined((Appointment) eventObj.getObject(), eventObj.getSessionObject());
+                    next.appointmentDeclined(appointment, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_TENTATIVE:
-            for (int a = 0; a < appointmentEventList.size(); a++) {
+            for (final AppointmentEventInterface next : appointmentEventList) {
                 try {
-                    appointmentEventList.get(a).appointmentTentativelyAccepted(
-                        (Appointment) eventObj.getObject(),
-                        eventObj.getSessionObject());
+                    next.appointmentTentativelyAccepted(appointment, session);
+                } catch (final Throwable t) {
+                    LOG.error(t.getMessage(), t);
+                }
+            }
+        case EventClient.CONFIRM_WAITING:
+        	for (final AppointmentEventInterface next : appointmentEventList) {
+                try {
+                    next.appointmentModified(appointment, session); // TODO: We need an explicit method for that
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
@@ -405,29 +415,31 @@ public final class EventQueue {
             return;
         }
         final int action = eventObj.getAction();
+        final Contact contact = (Contact) eventObj.getObject();
+        final Session session = eventObj.getSessionObject();
         switch (action) {
         case EventClient.CREATED:
-            for (int a = 0; a < contactEventList.size(); a++) {
+            for (final ContactEventInterface next : contactEventList) {
                 try {
-                    contactEventList.get(a).contactCreated((Contact) eventObj.getObject(), eventObj.getSessionObject());
+                    next.contactCreated(contact, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CHANGED:
-            for (int a = 0; a < contactEventList.size(); a++) {
+            for (final ContactEventInterface next : contactEventList) {
                 try {
-                    contactEventList.get(a).contactModified((Contact) eventObj.getObject(), eventObj.getSessionObject());
+                    next.contactModified(contact, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.DELETED:
-            for (int a = 0; a < contactEventList.size(); a++) {
+            for (final ContactEventInterface next : contactEventList) {
                 try {
-                    contactEventList.get(a).contactDeleted((Contact) eventObj.getObject(), eventObj.getSessionObject());
+                    next.contactDeleted(contact, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
@@ -443,56 +455,58 @@ public final class EventQueue {
             return;
         }
         final int action = eventObj.getAction();
+        final Task task = (Task) eventObj.getObject();
+        final Session session = eventObj.getSessionObject();
         switch (action) {
         case EventClient.CREATED:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskCreated((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskCreated(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CHANGED:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskModified((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskModified(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.DELETED:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskDeleted((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskDeleted(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_ACCEPTED:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskAccepted((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskAccepted(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_DECLINED:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskDeclined((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskDeclined(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CONFIRM_TENTATIVE:
-            for (int a = 0; a < taskEventList.size(); a++) {
+            for (final TaskEventInterface next : taskEventList) {
                 try {
-                    taskEventList.get(a).taskTentativelyAccepted((Task) eventObj.getObject(), eventObj.getSessionObject());
+                    next.taskTentativelyAccepted(task, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
@@ -508,29 +522,31 @@ public final class EventQueue {
             return;
         }
         final int action = eventObj.getAction();
+        final FolderObject folderObject = (FolderObject) eventObj.getObject();
+        final Session session = eventObj.getSessionObject();
         switch (action) {
         case EventClient.CREATED:
-            for (int a = 0; a < folderEventList.size(); a++) {
+            for (final FolderEventInterface next : folderEventList) {
                 try {
-                    folderEventList.get(a).folderCreated((FolderObject) eventObj.getObject(), eventObj.getSessionObject());
+                    next.folderCreated(folderObject, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CHANGED:
-            for (int a = 0; a < folderEventList.size(); a++) {
+            for (final FolderEventInterface next : folderEventList) {
                 try {
-                    folderEventList.get(a).folderModified((FolderObject) eventObj.getObject(), eventObj.getSessionObject());
+                    next.folderModified(folderObject, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.DELETED:
-            for (int a = 0; a < folderEventList.size(); a++) {
+            for (final FolderEventInterface next : folderEventList) {
                 try {
-                    folderEventList.get(a).folderDeleted((FolderObject) eventObj.getObject(), eventObj.getSessionObject());
+                    next.folderDeleted(folderObject, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
@@ -546,29 +562,31 @@ public final class EventQueue {
             return;
         }
         final int action = eventObj.getAction();
+        final DocumentMetadata documentMetadata = (DocumentMetadata) eventObj.getObject();
+        final Session session = eventObj.getSessionObject();
         switch (action) {
         case EventClient.CREATED:
-            for (int a = 0; a < infostoreEventList.size(); a++) {
+            for (final InfostoreEventInterface next : infostoreEventList) {
                 try {
-                    infostoreEventList.get(a).infoitemCreated((DocumentMetadata) eventObj.getObject(), eventObj.getSessionObject());
+                    next.infoitemCreated(documentMetadata, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.CHANGED:
-            for (int a = 0; a < infostoreEventList.size(); a++) {
+            for (final InfostoreEventInterface next : infostoreEventList) {
                 try {
-                    infostoreEventList.get(a).infoitemModified((DocumentMetadata) eventObj.getObject(), eventObj.getSessionObject());
+                    next.infoitemModified(documentMetadata, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
             }
             break;
         case EventClient.DELETED:
-            for (int a = 0; a < infostoreEventList.size(); a++) {
+            for (final InfostoreEventInterface next : infostoreEventList) {
                 try {
-                    infostoreEventList.get(a).infoitemDeleted((DocumentMetadata) eventObj.getObject(), eventObj.getSessionObject());
+                    next.infoitemDeleted(documentMetadata, session);
                 } catch (final Throwable t) {
                     LOG.error(t.getMessage(), t);
                 }
