@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,12 +55,12 @@ import java.io.InputStream;
 
 /**
  * {@link CallbackInputStream} - Touches given managed file on every access.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class CallbackInputStream extends InputStream implements FileRemovedListener {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CallbackInputStream.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CallbackInputStream.class));
 
     private final InputStream delegate;
 
@@ -70,7 +70,7 @@ final class CallbackInputStream extends InputStream implements FileRemovedListen
 
     /**
      * Initializes a new {@link CallbackInputStream}
-     * 
+     *
      * @param delegate The delegate input stream
      * @param reg The file-removed registry
      */
