@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,12 +63,12 @@ import com.openexchange.filemanagement.ManagedFileExceptionFactory;
 
 /**
  * {@link ManagedFileImpl} - Implementation of a managed file.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class ManagedFileImpl implements ManagedFile, FileRemovedRegistry {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ManagedFileImpl.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ManagedFileImpl.class));
 
     private final String id;
 
@@ -86,7 +86,7 @@ final class ManagedFileImpl implements ManagedFile, FileRemovedRegistry {
 
     /**
      * Initializes a new {@link ManagedFileImpl}.
-     * 
+     *
      * @param id The unique ID
      * @param file The kept file
      */
