@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,19 +50,24 @@
 package com.openexchange.filemanagement.internal;
 
 import java.util.concurrent.atomic.AtomicBoolean;
+import org.osgi.framework.BundleContext;
+import org.osgi.framework.ServiceRegistration;
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.server.Initialization;
+import com.openexchange.server.osgi.ServerActivator;
 import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link ManagedFileInitialization} - Initialization for {@link ManagedFileManagement}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ManagedFileInitialization implements Initialization {
 
     private final AtomicBoolean started;
 
+    private volatile ServiceRegistration registerService;
+
     /**
      * Initializes a new {@link ManagedFileInitialization}
      */
@@ -76,13 +81,23 @@ public final class ManagedFileInitialization implements Initialization {
             return;
         }
         // Simulate bundle registration
-        ServerServiceRegistry.getInstance().addService(ManagedFileManagement.class, ManagedFileManagementImpl.getInstance());
+        final ManagedFileManagementImpl fileManagement = ManagedFileManagementImpl.getInstance();
+        ServerServiceRegistry.getInstance().addService(ManagedFileManagement.class, fileManagement);
+        final BundleContext context = ServerActivator.getContext();
+        if (null != context) {
+            registerService = context.registerService(ManagedFileManagement.class.getName(), fileManagement, null);
+        }
     }
 
     public void stop() {
         if (!started.compareAndSet(true, false)) {
             return;
         }
+        final ServiceRegistration registerService = this.registerService;
+        if (null != registerService) {
+            registerService.unregister();
+            this.registerService = null;
+        }
         // Simulate bundle shut-down
         ServerServiceRegistry.getInstance().removeService(ManagedFileManagement.class);
         ManagedFileManagementImpl.releaseInstance();
