@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -78,12 +78,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 
 /**
  * {@link ManagedFileManagementImpl} - The file management designed to keep large content as a temporary file on disk.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class ManagedFileManagementImpl implements ManagedFileManagement {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ManagedFileManagementImpl.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ManagedFileManagementImpl.class));
 
     private static final int DELAY = 10000;
 
@@ -154,7 +154,7 @@ final class ManagedFileManagementImpl implements ManagedFileManagement {
 
     /**
      * Gets the file management instance.
-     * 
+     *
      * @return The file management instance
      */
     static ManagedFileManagementImpl getInstance() {
@@ -205,7 +205,18 @@ final class ManagedFileManagementImpl implements ManagedFileManagement {
         if (null == cs) {
             throw new IllegalStateException("Missing configuration service");
         }
-        final String path = cs.getProperty("UPLOAD_DIRECTORY", (propertyListener = new FileManagementPropertyListener(tmpDirReference)));
+        final String path;
+        {
+            final String name = "UPLOAD_DIRECTORY";
+            final String tmp = cs.getProperty(name);
+            if (null == tmp) {
+                LOG.warn("Path is null. Probably property \"" + name + "\" is not set. Selecting /tmp as temporary upload directory.");
+                path = "/tmp/";
+            } else {
+                path = cs.getProperty(name, (propertyListener = new FileManagementPropertyListener(tmpDirReference)));
+            }
+
+        }
         tmpDirReference.set(getTmpDirByPath(path));
         // Register timer task
         final TimerService timer = registry.getService(TimerService.class);
@@ -272,7 +283,7 @@ final class ManagedFileManagementImpl implements ManagedFileManagement {
         } while (!tmpDirReference.compareAndSet(directory, directory)); // Directory changed in the meantime
         return tmpFile;
     }
-    
+
     public ManagedFile createManagedFile(final File temporaryFile) throws ManagedFileException {
         final ManagedFile mf = new ManagedFileImpl(UUID.randomUUID().toString(), temporaryFile);
         mf.setSize(temporaryFile.length());
