@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,7 @@ import java.util.Locale;
 
 /**
  * {@link AbstractFolder} - An abstract folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class AbstractFolder implements Folder {
@@ -141,7 +141,7 @@ public abstract class AbstractFolder implements Folder {
                 clone.lastModified = new Date(lastModified.getTime());
             }
             if (permissions != null) {
-                final Permission[] thisPermissions = this.permissions;
+                final Permission[] thisPermissions = permissions;
                 final Permission[] clonePermissions = new Permission[thisPermissions.length];
                 for (int i = 0; i < thisPermissions.length; i++) {
                     clonePermissions[i] = (Permission) thisPermissions[i].clone();
@@ -251,7 +251,7 @@ public abstract class AbstractFolder implements Folder {
     }
 
     public void setParentID(final String parentId) {
-        this.parent = parentId;
+        parent = parentId;
     }
 
     public void setPermissions(final Permission[] permissions) {
@@ -259,11 +259,11 @@ public abstract class AbstractFolder implements Folder {
     }
 
     public void setSubfolderIDs(final String[] subfolderIds) {
-        this.subfolders = subfolderIds;
+        subfolders = subfolderIds;
     }
 
     public void setTreeID(final String id) {
-        this.treeId = id;
+        treeId = id;
     }
 
     public void setType(final Type type) {
@@ -277,11 +277,11 @@ public abstract class AbstractFolder implements Folder {
     public void setSubscribed(final boolean subscribed) {
         this.subscribed = subscribed;
     }
-   
+
     public boolean hasSubscribedSubfolders() {
         return subscribedSubfolders;
     }
-    
+
     public void setSubscribedSubfolders(final boolean subscribedSubfolders) {
         this.subscribedSubfolders = subscribedSubfolders;
     }
