@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.exceptions.LocalizableStrings;
 
 /**
  * {@link FolderExceptionMessages} - Locale-sensitive strings for folder exceptions.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class FolderExceptionMessages implements LocalizableStrings {
@@ -106,11 +106,11 @@ public class FolderExceptionMessages implements LocalizableStrings {
     // Subscribe operation not permitted on tree "%1$s".
     public static final String NO_REAL_SUBSCRIBE_MSG = "Subscribe operation not permitted on tree \"%1$s\".";
 
-    // Un-Subscribe operation not permitted on tree "%1$s".
-    public static final String NO_REAL_UNSUBSCRIBE_MSG = "Un-Subscribe operation not permitted on tree \"%1$s\".";
+    // Unsubscribe operation not permitted on tree "%1$s".
+    public static final String NO_REAL_UNSUBSCRIBE_MSG = "Unsubscribe operation not permitted on tree \"%1$s\".";
 
-    // Un-Subscribe operation not permitted on folder "%1$s" in tree "%2$s".
-    public static final String NO_UNSUBSCRIBE_MSG = "Un-Subscribe operation not permitted on folder \"%1$s\" in tree \"%2$s\".";
+    // Unsubscribe operation not permitted on folder "%1$s" in tree "%2$s". Delete subfolders first.
+    public static final String NO_UNSUBSCRIBE_MSG = "Unsubscribe operation not permitted on folder \"%1$s\" in tree \"%2$s\". Unsubscribe subfolders first.";
 
     // Unknown content type: %1$s.
     public static final String UNKNOWN_CONTENT_TYPE_MSG = "Unknown content type: %1$s.";
@@ -151,6 +151,15 @@ public class FolderExceptionMessages implements LocalizableStrings {
     // No mail folder allowed below a public folder.
     public static final String NO_PUBLIC_MAIL_FOLDER_MSG = "No mail folder allowed below a public folder.";
 
+    // No such tree with identifier "%1$s".
+    public static final String TREE_NOT_FOUND_MSG = "No such tree with identifier \"%1$s\".";
+
+    // The folder name "%1$s" is reserved. Please choose another name.
+    public static final String RESERVED_NAME_MSG = "The folder name \"%1$s\" is reserved. Please choose another name.";
+
+    // Found two folders named "%1$s" located below the parent folder "%2$s". Please rename one of the folders. There should be no two folders with the same name.
+    public static final String DUPLICATE_NAME_MSG = "Found two folders named \"%1$s\" located below the parent folder \"%2$s\". Please rename one of the folders. There should be no two folders with the same name.";
+
     /**
      * Initializes a new {@link FolderExceptionMessages}
      */
