@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,21 +57,21 @@ import com.openexchange.session.Session;
 
 /**
  * {@link FolderService} - The folder service.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface FolderService {
 
     /**
      * Gets a map of available content types registered by folder storages.
-     * 
+     *
      * @return A map of available content types registered by folder storages
      */
     Map<Integer, ContentType> getAvailableContentTypes();
 
     /**
      * Checks the consistency of given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param user The user
      * @param context The context
@@ -81,7 +81,7 @@ public interface FolderService {
 
     /**
      * Checks the consistency of given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param session The session
      * @throws FolderException If check fails
@@ -90,7 +90,7 @@ public interface FolderService {
 
     /**
      * Gets the folder identified by given folder identifier and tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param user The user
@@ -103,7 +103,7 @@ public interface FolderService {
 
     /**
      * Gets the folder identified by given folder identifier and tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param session The session
@@ -115,7 +115,7 @@ public interface FolderService {
 
     /**
      * Gets all visible folders located in given tree for given user.
-     * 
+     *
      * @param treeId The tree identifier
      * @param filter The folder filter
      * @param user The user
@@ -128,7 +128,7 @@ public interface FolderService {
 
     /**
      * Gets all visible folders located in given tree for given session's user.
-     * 
+     *
      * @param treeId The tree identifier
      * @param filter The folder filter
      * @param session The session
@@ -140,7 +140,7 @@ public interface FolderService {
 
     /**
      * Gets this storage's default folder for specified user.
-     * 
+     *
      * @param user The user whose default folder shall be returned
      * @param treeId The tree identifier
      * @param contentType The content type or the default folder
@@ -154,7 +154,7 @@ public interface FolderService {
 
     /**
      * Gets this storage's default folder for specified user.
-     * 
+     *
      * @param user The user whose default folder shall be returned
      * @param treeId The tree identifier
      * @param contentType The content type or the default folder
@@ -169,37 +169,37 @@ public interface FolderService {
      * Subscribes an existing folder from specified source tree to specified (virtual) target tree below given parent.
      * <p>
      * Does only work on virtual trees.
-     * 
+     *
      * @param sourceTreeId The source tree identifier
      * @param folderId The (source) folder identifier
      * @param targetTreeId The target tree identifier
-     * @param targetParentId The target parent identifier
+     * @param optTargetParentId The optional target parent identifier
      * @param user The user
      * @param context The context
      * @param session The session
      * @throws FolderException If folder cannot be added
      */
-    void subscribeFolder(String sourceTreeId, String folderId, String targetTreeId, String targetParentId, User user, Context context) throws FolderException;
+    void subscribeFolder(String sourceTreeId, String folderId, String targetTreeId, String optTargetParentId, User user, Context context) throws FolderException;
 
     /**
      * Subscribes an existing folder from specified source tree to specified (virtual) target tree below given parent.
      * <p>
      * Does only work on virtual trees.
-     * 
+     *
      * @param sourceTreeId The source tree identifier
      * @param folderId The (source) folder identifier
      * @param targetTreeId The target tree identifier
-     * @param targetParentId The target parent identifier
+     * @param optTargetParentId The optional target parent identifier
      * @param session The session
      * @throws FolderException If folder cannot be added
      */
-    void subscribeFolder(String sourceTreeId, String folderId, String targetTreeId, String targetParentId, Session session) throws FolderException;
+    void subscribeFolder(String sourceTreeId, String folderId, String targetTreeId, String optTargetParentId, Session session) throws FolderException;
 
     /**
      * Unsubscribes the specified folder in given (virtual) tree only.
      * <p>
      * Does only work on virtual trees.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param user The user
@@ -212,7 +212,7 @@ public interface FolderService {
      * Unsubscribes the specified folder in given (virtual) tree only.
      * <p>
      * Does only work on virtual trees.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param session The session
@@ -220,9 +220,40 @@ public interface FolderService {
      */
     void unsubscribeFolder(String treeId, String folderId, Session session) throws FolderException;
 
+    /**
+     * Gets all visible folders of specified content type and folder type.
+     *
+     * @param treeId The tree identifier
+     * @param contentType The content type
+     * @param type The folder type
+     * @param all <code>true</code> to deliver all subfolders regardless of their subscribed status; <code>false</code> to deliver
+     *            subscribed folders only.
+     * @param user The user
+     * @param context The context
+     * @param decorator The optional folder service decorator
+     * @return All visible folders of specified content type and folder type.
+     * @throws FolderException If operation fails
+     */
+    FolderResponse<UserizedFolder[]> getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final boolean all, final User user, final Context context, final FolderServiceDecorator decorator) throws FolderException;
+
+    /**
+     * Gets all visible folders of specified content type and folder type.
+     *
+     * @param treeId The tree identifier
+     * @param contentType The content type
+     * @param type The folder type
+     * @param all <code>true</code> to deliver all subfolders regardless of their subscribed status; <code>false</code> to deliver
+     *            subscribed folders only.
+     * @param session The session
+     * @param decorator The optional folder service decorator
+     * @return All visible folders of specified content type and folder type.
+     * @throws FolderException If operation fails
+     */
+    FolderResponse<UserizedFolder[]> getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final boolean all, final Session session, final FolderServiceDecorator decorator) throws FolderException;
+
     /**
      * Gets the subfolders of specified parent in given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param parentId The parent identifier
      * @param all <code>true</code> to deliver all subfolders regardless of their subscribed status; <code>false</code> to deliver
@@ -237,7 +268,7 @@ public interface FolderService {
 
     /**
      * Gets the subfolders of specified parent in given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param parentId The parent identifier
      * @param all <code>true</code> to deliver all subfolders regardless of their subscribed status; <code>false</code> to deliver
@@ -251,7 +282,7 @@ public interface FolderService {
 
     /**
      * Gets the path from given folder to specified tree's root folder.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param user The user
@@ -264,7 +295,7 @@ public interface FolderService {
 
     /**
      * Gets the path from given folder to specified tree's root folder.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param session The session
@@ -276,7 +307,7 @@ public interface FolderService {
 
     /**
      * Gets all new, modified and deleted folders since given time stamp.
-     * 
+     *
      * @param treeId The tree identifier
      * @param timeStamp The time stamp from which to consider changes
      * @param ignoreDeleted <code>true</code> to ignore delete operations; otherwise <code>false</code>
@@ -291,7 +322,7 @@ public interface FolderService {
 
     /**
      * Gets all new, modified and deleted folders since given time stamp.
-     * 
+     *
      * @param treeId The tree identifier
      * @param timeStamp The time stamp from which to consider changes
      * @param ignoreDeleted <code>true</code> to ignore delete operations; otherwise <code>false</code>
@@ -307,7 +338,7 @@ public interface FolderService {
      * Deletes the specified folder in given tree.
      * <p>
      * The folder is deleted from all trees and its subfolders as well
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param timeStamp The requestor's last-modified time stamp
@@ -321,7 +352,7 @@ public interface FolderService {
      * Deletes the specified folder in given tree.
      * <p>
      * The folder is deleted from all trees and its subfolders as well
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param timeStamp The requestor's last-modified time stamp
@@ -332,7 +363,7 @@ public interface FolderService {
 
     /**
      * Clears the content of specified folder in given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param user The user
@@ -343,7 +374,7 @@ public interface FolderService {
 
     /**
      * Clears the content of specified folder in given tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param session The session
@@ -353,7 +384,7 @@ public interface FolderService {
 
     /**
      * Updates a folder identified through given folder object.
-     * 
+     *
      * @param folder The folder object containing tree identifier, folder identifier and modified data.
      * @param timeStamp The requestor's last-modified time stamp
      * @param user The user
@@ -364,7 +395,7 @@ public interface FolderService {
 
     /**
      * Updates a folder identified through given folder object.
-     * 
+     *
      * @param folder The folder object containing tree identifier, folder identifier and modified data.
      * @param timeStamp The requestor's last-modified time stamp
      * @param session The session
@@ -374,24 +405,24 @@ public interface FolderService {
 
     /**
      * Creates a new folder described by given folder object.
-     * 
+     *
      * @param folder The folder object containing tree identifier, parent identifier and data.
      * @param user The user
      * @param context The context
      * @return The identifier of the newly created folder
      * @throws FolderException If creation fails
      */
-    String createFolder(Folder folder, User user, Context context) throws FolderException;
+    FolderResponse<String> createFolder(Folder folder, User user, Context context) throws FolderException;
 
     /**
      * Creates a new folder described by given folder object.
-     * 
+     *
      * @param folder The folder object containing tree identifier, parent identifier and data.
      * @param session The session
      * @return The identifier of the newly created folder
      * @throws FolderException If creation fails
      */
-    String createFolder(Folder folder, Session session) throws FolderException;
+    FolderResponse<String> createFolder(Folder folder, Session session) throws FolderException;
 
     // TODO: default folder? all visible folders
 
