@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,11 +50,12 @@
 package com.openexchange.folderstorage;
 
 import java.util.Date;
+import java.util.List;
 import com.openexchange.groupware.ldap.User;
 
 /**
  * {@link FolderStorage} - A folder storage bound to a certain folder source (e.g database, email, etc).
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface FolderStorage {
@@ -62,71 +63,79 @@ public interface FolderStorage {
     /**
      * The reserved tree identifier for real folder tree: <code>"0"</code>.
      */
-    public static final String REAL_TREE_ID = "0";
+    public static final String REAL_TREE_ID = "0".intern();
 
     /**
      * The reserved tree identifier for all folder trees: <code>"*"</code>.
      */
-    public static final String ALL_TREE_ID = "*";
+    public static final String ALL_TREE_ID = "*".intern();
 
     /**
      * The reserved identifier for root folder: <code>"0"</code>.
      */
-    public static final String ROOT_ID = "0";
+    public static final String ROOT_ID = "0".intern();
 
     /**
      * The reserved identifier for private folder: <code>"1"</code>.
      */
-    public static final String PRIVATE_ID = "1";
+    public static final String PRIVATE_ID = "1".intern();
 
     /**
      * The reserved identifier for public folder: <code>"2"</code>.
      */
-    public static final String PUBLIC_ID = "2";
+    public static final String PUBLIC_ID = "2".intern();
 
     /**
      * The reserved identifier for shared folder: <code>"3"</code>.
      */
-    public static final String SHARED_ID = "3";
+    public static final String SHARED_ID = "3".intern();
 
     /**
      * The reserved identifier for global address book folder: <code>"6"</code>.
      */
-    public static final String GLOBAL_ADDRESS_BOOK_ID = "6";
+    public static final String GLOBAL_ADDRESS_BOOK_ID = "6".intern();
+
+    /**
+     * Clears the cache with respect to specified user.
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     */
+    void clearCache(int userId, int contextId);
 
     /**
      * Gets the content types supported by this folder storage.
      * <p>
      * A zero length array means this folder storage supports all content types for a certain tree identifier.
-     * 
+     *
      * @return The content types supported by this folder storage or a zero length array to indicate no content type limitations
      */
     ContentType[] getSupportedContentTypes();
 
     /**
      * Gets the storage's folder type.
-     * 
+     *
      * @return The storage's folder type
      */
     FolderType getFolderType();
 
     /**
      * Gets the storage's priority.
-     * 
+     *
      * @return The storage's priority
      */
     StoragePriority getStoragePriority();
 
     /**
      * Gets the default content type for this folder storage.
-     * 
+     *
      * @return The default content type or <code>null</code> if this folder storage has no default content type
      */
     ContentType getDefaultContentType();
 
     /**
      * Checks if denoted folder is empty.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageParameters The storage parameters
@@ -137,7 +146,7 @@ public interface FolderStorage {
 
     /**
      * Checks if denoted folder contains user-foreign objects.
-     * 
+     *
      * @param user The user whose default folder shall be returned
      * @param treeId The tree identifier
      * @param folderId The folder identifier
@@ -149,7 +158,7 @@ public interface FolderStorage {
 
     /**
      * Checks if the folder denoted by specified folder ID exists in this folder storage.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageParameters The storage parameters
@@ -160,7 +169,7 @@ public interface FolderStorage {
 
     /**
      * Checks if the folder denoted by specified folder ID exists in this folder storage.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageType The storage type from which to get the folder
@@ -172,7 +181,7 @@ public interface FolderStorage {
 
     /**
      * Checks consistency of the tree.
-     * 
+     *
      * @param treeId The tree identifier
      * @param storageParameters The storage parameters
      * @throws FolderException If consistency check fails
@@ -181,7 +190,7 @@ public interface FolderStorage {
 
     /**
      * Restores the folder with given folder identifier
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageParameters The storage parameters
@@ -189,9 +198,20 @@ public interface FolderStorage {
      */
     void restore(String treeId, String folderId, StorageParameters storageParameters) throws FolderException;
 
+    /**
+     * Prepares specified folder with user-sensitive informations if needed.
+     *
+     * @param treeId The tree identifier
+     * @param folder The folder identifier
+     * @param storageParameters The storage parameters
+     * @return The prepared or unchanged folder
+     * @throws FolderException If preparation fails
+     */
+    Folder prepareFolder(final String treeId, final Folder folder, final StorageParameters storageParameters ) throws FolderException;
+
     /**
      * Gets the folder denoted by specified folder ID.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageParameters The storage parameters
@@ -200,9 +220,20 @@ public interface FolderStorage {
      */
     Folder getFolder(String treeId, String folderId, StorageParameters storageParameters) throws FolderException;
 
+    /**
+     * Gets the folders denoted by specified folder IDs.
+     *
+     * @param treeId The tree identifier
+     * @param folderIds The folder identifiers
+     * @param storageParameters The storage parameters
+     * @return The folder
+     * @throws FolderException If the folder cannot be returned
+     */
+    List<Folder> getFolders(String treeId, List<String> folderIds, StorageParameters storageParameters) throws FolderException;
+
     /**
      * Gets the folder denoted by specified folder ID.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param storageType The storage type from which to get the folder
@@ -212,23 +243,48 @@ public interface FolderStorage {
      */
     Folder getFolder(String treeId, String folderId, StorageType storageType, StorageParameters storageParameters) throws FolderException;
 
+    /**
+     * Gets the folders denoted by specified folder IDs.
+     *
+     * @param treeId The tree identifier
+     * @param folderIds The folder identifiers
+     * @param storageType The storage type from which to get the folder
+     * @param storageParameters The storage parameters
+     * @return The folder
+     * @throws FolderException If the folder cannot be returned
+     */
+    List<Folder> getFolders(String treeId, List<String> folderIds, StorageType storageType, StorageParameters storageParameters) throws FolderException;
+
     /**
      * Gets this storage's default folder identifier for specified user for given content type.
-     * 
+     *
      * @param user The user whose default folder shall be returned
      * @param treeId The tree identifier
      * @param contentType The content type or the default folder
+     * @param type The folder type
      * @param storageParameters The storage parameters
      * @return The default folder identifier for specified user for given content type
      * @throws FolderException If the default folder cannot be returned
      */
-    String getDefaultFolderID(User user, String treeId, ContentType contentType, StorageParameters storageParameters) throws FolderException;
+    String getDefaultFolderID(User user, String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws FolderException;
+
+    /**
+     * Gets the type as indicated by specified parent.
+     *
+     * @param user The user
+     * @param treeId The tree identifier
+     * @param parentId The parent identifier
+     * @param storageParameters The storage parameters
+     * @return The type as indicated by specified parent
+     * @throws FolderException Id determining the type fails
+     */
+    Type getTypeByParent(User user, String treeId, String parentId, StorageParameters storageParameters) throws FolderException;
 
     /**
      * Deletes the folder denoted by specified folder ID.
      * <p>
      * A {@link FolderException} is thrown if denoted folder contains subfolders.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder ID
      * @param storageParameters The storage parameters
@@ -238,7 +294,7 @@ public interface FolderStorage {
 
     /**
      * Clears the content of the folder denoted by specified folder ID.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder ID
      * @param storageParameters The storage parameters
@@ -248,7 +304,7 @@ public interface FolderStorage {
 
     /**
      * Updates the data of the given folder on the storage.
-     * 
+     *
      * @param folder object containing new folder data.
      * @param storageParameters The storage parameters
      * @throws FolderException If changing the folder data fails.
@@ -257,7 +313,7 @@ public interface FolderStorage {
 
     /**
      * Updates the last-modified time stamp of the given folder in the storage.
-     * 
+     *
      * @param lastModified The last-modified time stamp to set
      * @param treeId The tree identifier
      * @param folderId The folder ID
@@ -270,16 +326,28 @@ public interface FolderStorage {
      * Creates the given folder on the storage.
      * <p>
      * Implementation is expected to set the identifier of created folder in passed folder instance through {@link Folder#setID(String)}.
-     * 
+     *
      * @param folder The object containing the new folder data.
      * @param storageParameters The storage parameters
      * @throws FolderException If creating the folder fails.
      */
     void createFolder(Folder folder, StorageParameters storageParameters) throws FolderException;
 
+    /**
+     * Gets the folder identifiers for specified content type and type.
+     *
+     * @param treeId The tree identifier
+     * @param contentType The content type
+     * @param type The type
+     * @param storageParameters The storage parameters
+     * @return The folder identifiers for specified content type and type
+     * @throws FolderException If returning the folder identifiers fails
+     */
+    SortableId[] getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final StorageParameters storageParameters) throws FolderException;
+
     /**
      * Gets the subfolder identifiers for specified parent which are visible to storage parameter's entity.
-     * 
+     *
      * @param treeId The tree identifier
      * @param parentId The parent identifier
      * @param storageParameters The storage parameters
@@ -292,7 +360,7 @@ public interface FolderStorage {
      * Gets the identifiers of all new and modified folders from this storage since given time stamp.
      * <p>
      * If a certain implementation does not support this feature an empty array is supposed to be returned.
-     * 
+     *
      * @param treeId The tree identifier
      * @param timeStamp The time stamp
      * @param includeContentTypes The content types to include
@@ -306,7 +374,7 @@ public interface FolderStorage {
      * Gets the identifiers of all deleted folders from this storage since given time stamp.
      * <p>
      * If a certain implementation does not support this feature an empty array is supposed to be returned.
-     * 
+     *
      * @param treeId The tree identifier
      * @param timeStamp The time stamp
      * @param storageParameters The storage parameters
@@ -317,7 +385,7 @@ public interface FolderStorage {
 
     /**
      * Starts a transaction on folder storage.
-     * 
+     *
      * @param parameters The parameters
      * @param modify <code>true</code> if started transaction is supposed to modify storage's content; otherwise <code>false</code>
      * @return <code>true</code> if call started the transaction; otherwise <code>false</code> if transaction has already been started
@@ -328,7 +396,7 @@ public interface FolderStorage {
 
     /**
      * Publishes made changes on the storage.
-     * 
+     *
      * @param params The storage parameters
      * @throws FolderException If committing the made changes fails.
      */
@@ -337,7 +405,7 @@ public interface FolderStorage {
     /**
      * Discards made changes on the storage. This method does not throw an exception because a rollback should only be used if already some
      * problem or exception occurred. Problems occurred while executing this method should only be logged.
-     * 
+     *
      * @param params The storage parameters.
      */
     void rollback(StorageParameters params);
