@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,14 +51,32 @@ package com.openexchange.folderstorage;
 
 /**
  * {@link FolderType} - The folder type of a certain folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface FolderType {
 
+    /**
+     * The folder type to store global parameters to {@link StorageParameters storage parameters}.
+     */
+    public static final FolderType GLOBAL = new FolderType() {
+
+        public boolean servesTreeId(final String treeId) {
+            return false;
+        }
+
+        public boolean servesParentId(final String parentId) {
+            return false;
+        }
+
+        public boolean servesFolderId(final String folderId) {
+            return false;
+        }
+    };
+
     /**
      * Indicates if this folder type serves specified tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @return <code>true</code> if this folder type serves specified tree identifier; otherwise <code>false</code>
      */
@@ -66,7 +84,7 @@ public interface FolderType {
 
     /**
      * Indicates if this folder type serves specified folder identifier.
-     * 
+     *
      * @param folderId The folder identifier
      * @return <code>true</code> if this folder type serves specified folder identifier; otherwise <code>false</code>
      */
@@ -75,7 +93,7 @@ public interface FolderType {
     /**
      * Indicates if this folder type serves specified parent identifier. If <code>true</code> the
      * {@link FolderStorage#getSubfolders(String, String, StorageParameters)} delivers a non-empty array for this parent identifier.
-     * 
+     *
      * @param parentId The parent identifier
      * @return <code>true</code> if this folder type serves specified parent identifier; otherwise <code>false</code>
      */
