@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,11 +50,13 @@
 package com.openexchange.folderstorage.cache;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
+import java.util.Map.Entry;
+import java.util.Queue;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.CopyOnWriteArrayList;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
@@ -63,7 +65,7 @@ import com.openexchange.folderstorage.StoragePriority;
 
 /**
  * {@link CacheFolderStorageRegistry} - Cache's registry for folder storages.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer {
@@ -72,7 +74,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
 
     /**
      * Gets the {@link CacheFolderStorageRegistry} instance.
-     * 
+     *
      * @return The {@link CacheFolderStorageRegistry} instance
      */
     public static CacheFolderStorageRegistry getInstance() {
@@ -83,22 +85,38 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
      * Member section
      */
 
-    private final ConcurrentMap<String, List<FolderStorage>> registry;
+    private final ConcurrentMap<String, Queue<FolderStorage>> registry;
 
-    private final List<FolderStorage> genStorages;
+    private final Queue<FolderStorage> genStorages;
 
     /**
      * Initializes a new {@link CacheFolderStorageRegistry}.
      */
     private CacheFolderStorageRegistry() {
         super();
-        registry = new ConcurrentHashMap<String, List<FolderStorage>>();
-        genStorages = new CopyOnWriteArrayList<FolderStorage>();
+        registry = new ConcurrentHashMap<String, Queue<FolderStorage>>();
+        genStorages = new ConcurrentLinkedQueue<FolderStorage>();
+    }
+
+    /**
+     * Clears the caches from registered folder storages.
+     */
+    public void clearCaches(final int userId, final int contextId) {
+        for (final FolderStorage fs : genStorages) {
+            fs.clearCache(userId, contextId);
+        }
+        final Set<Entry<String, Queue<FolderStorage>>> entrySet = registry.entrySet();
+        for (final Entry<String, Queue<FolderStorage>> entry : entrySet) {
+            final Queue<FolderStorage> queue = entry.getValue();
+            for (final FolderStorage folderStorage : queue) {
+                folderStorage.clearCache(userId, contextId);
+            }
+        }
     }
 
     /**
      * Associates specified folder storage to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to add
      * @return <code>true</code> If registration was successful; otherwise <code>false</code>
@@ -115,8 +133,8 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
                 success = CacheContentTypeRegistry.getInstance().addContentType(treeId, contentTypes[i], folderStorage);
             }
             if (!success) {
-                for (int i = 0; i < contentTypes.length; i++) {
-                    CacheContentTypeRegistry.getInstance().removeContentType(treeId, contentTypes[i]);
+                for (final ContentType contentType : contentTypes) {
+                    CacheContentTypeRegistry.getInstance().removeContentType(treeId, contentType);
                 }
                 return false;
             }
@@ -129,9 +147,9 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         if (FolderStorage.ALL_TREE_ID.equals(treeId)) {
             genStorages.add(folderStorage);
         } else {
-            List<FolderStorage> storages = registry.get(treeId);
+            Queue<FolderStorage> storages = registry.get(treeId);
             if (null == storages) {
-                final List<FolderStorage> tmp = new CopyOnWriteArrayList<FolderStorage>();
+                final Queue<FolderStorage> tmp = new ConcurrentLinkedQueue<FolderStorage>();
                 storages = registry.putIfAbsent(treeId, tmp);
                 if (null == storages) {
                     storages = tmp;
@@ -147,8 +165,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (folderStorage.getFolderType().servesTreeId(treeId)) {
                     return folderStorage;
                 }
@@ -157,7 +174,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return null;
         }
@@ -174,8 +191,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId) && folderType.servesParentId(parentId)) {
                     return new FolderStorage[] { folderStorage };
@@ -185,7 +201,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -203,8 +219,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -214,7 +229,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -226,8 +241,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (!StoragePriority.HIGHEST.equals(folderStorage.getStoragePriority()) && folderStorage.getFolderType().servesTreeId(
                     treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -237,7 +251,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -250,7 +264,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
 
     /**
      * Removes specified folder storage bound to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to remove
      */
@@ -261,7 +275,7 @@ public final class CacheFolderStorageRegistry implements FolderStorageDiscoverer
         if (FolderStorage.ALL_TREE_ID.equals(treeId)) {
             genStorages.remove(folderStorage);
         } else {
-            final List<FolderStorage> storages = registry.get(treeId);
+            final Queue<FolderStorage> storages = registry.get(treeId);
             if (null == storages) {
                 return;
             }
