@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,17 @@
 
 package com.openexchange.folderstorage.cache;
 
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderType;
+import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
 
 /**
  * {@link CacheFolderType} - The folder type for cache folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CacheFolderType implements FolderType {
@@ -62,7 +68,7 @@ public final class CacheFolderType implements FolderType {
 
     /**
      * Gets the instance.
-     * 
+     *
      * @return The instance.
      */
     public static CacheFolderType getInstance() {
@@ -81,9 +87,14 @@ public final class CacheFolderType implements FolderType {
         return true;
     }
 
+    private static final Set<String> KNOWN_TREES = Collections.<String> unmodifiableSet(new HashSet<String>(Arrays.asList(
+        FolderStorage.REAL_TREE_ID,
+        OutlookFolderStorage.OUTLOOK_TREE_ID)));
+
     public boolean servesTreeId(final String treeId) {
         // Cache folder storage serves every tree identifier
-        return true;
+        return KNOWN_TREES.contains(treeId);
+        // return true;
     }
 
     public boolean servesParentId(final String parentId) {
