@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,6 +54,9 @@ import java.util.ArrayList;
 import java.util.Dictionary;
 import java.util.Hashtable;
 import java.util.List;
+import java.util.Map;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.event.Event;
@@ -62,28 +65,34 @@ import org.osgi.service.event.EventHandler;
 import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.folderstorage.FolderEventConstants;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.cache.CacheFolderStorage;
+import com.openexchange.folderstorage.cache.lock.TreeLockManagement;
+import com.openexchange.folderstorage.cache.lock.UserLockManagement;
+import com.openexchange.folderstorage.cache.memory.FolderMapManagement;
+import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.push.PushEventConstants;
 import com.openexchange.server.osgiservice.DeferredActivator;
 import com.openexchange.server.osgiservice.ServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondEventConstants;
+import com.openexchange.sessiond.SessiondService;
 import com.openexchange.threadpool.ThreadPoolService;
 
 /**
  * {@link CacheFolderStorageActivator} - {@link BundleActivator Activator} for cache folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CacheFolderStorageActivator extends DeferredActivator {
 
     static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(CacheFolderStorageActivator.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CacheFolderStorageActivator.class));
 
-    private ServiceRegistration folderStorageRegistration;
-
-    private ServiceRegistration eventHandlerRegistration;
+    private List<ServiceRegistration> registrations;
 
     private CacheFolderStorage cacheFolderStorage;
 
@@ -98,7 +107,7 @@ public final class CacheFolderStorageActivator extends DeferredActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { CacheService.class, ThreadPoolService.class, ConfigurationService.class };
+        return new Class<?>[] { CacheService.class, ThreadPoolService.class, ConfigurationService.class, SessiondService.class, MailAccountStorageService.class };
     }
 
     @Override
@@ -143,10 +152,10 @@ public final class CacheFolderStorageActivator extends DeferredActivator {
                 final ServiceRegistry registry = getServiceRegistry();
                 registry.clearRegistry();
                 final Class<?>[] classes = getNeededServices();
-                for (int i = 0; i < classes.length; i++) {
-                    final Object service = getService(classes[i]);
+                for (final Class<?> classe : classes) {
+                    final Object service = getService(classe);
                     if (null != service) {
-                        registry.addService(classes[i], service);
+                        registry.addService(classe, service);
                     }
                 }
             }
@@ -197,42 +206,120 @@ public final class CacheFolderStorageActivator extends DeferredActivator {
 
     private void initCacheFolderStorage() throws FolderException {
         // Start-up folder storage
-        cacheFolderStorage = new CacheFolderStorage();
+        cacheFolderStorage = CacheFolderStorage.getInstance();
         cacheFolderStorage.onCacheAvailable();
         // Register folder storage
         final Dictionary<String, String> dictionary = new Hashtable<String, String>();
         dictionary.put("tree", FolderStorage.ALL_TREE_ID);
-        folderStorageRegistration = context.registerService(FolderStorage.class.getName(), cacheFolderStorage, dictionary);
+        registrations = new ArrayList<ServiceRegistration>(4);
+        registrations.add(context.registerService(FolderStorage.class.getName(), cacheFolderStorage, dictionary));
         // Register event handler for content-related changes on a mail folder
         final CacheFolderStorage tmp = cacheFolderStorage;
-        final EventHandler eventHandler = new EventHandler() {
-            
-            public void handleEvent(final Event event) {
-                final Session session = ((Session) event.getProperty(PushEventConstants.PROPERTY_SESSION));
-                final String folderId = (String) event.getProperty(PushEventConstants.PROPERTY_FOLDER);
-                final Boolean contentRelated = (Boolean) event.getProperty(PushEventConstants.PROPERTY_CONTENT_RELATED);
-                try {
-                    tmp.removeFromCache(folderId, FolderStorage.REAL_TREE_ID, contentRelated.booleanValue(), session);
-                } catch (final FolderException e) {
-                    LOG.error(e.getMessage(), e);
+        {
+            final EventHandler eventHandler = new EventHandler() {
+
+                public void handleEvent(final Event event) {
+                    final Session session = ((Session) event.getProperty(PushEventConstants.PROPERTY_SESSION));
+                    final String folderId = (String) event.getProperty(PushEventConstants.PROPERTY_FOLDER);
+                    final Boolean contentRelated = (Boolean) event.getProperty(PushEventConstants.PROPERTY_CONTENT_RELATED);
+                    try {
+                        tmp.removeFromCache(sanitizeFolderId(folderId), FolderStorage.REAL_TREE_ID, null != contentRelated && contentRelated.booleanValue(), session);
+                    } catch (final FolderException e) {
+                        LOG.error(e.getMessage(), e);
+                    }
                 }
+            };
+            final Dictionary<String, Object> dict = new Hashtable<String, Object>(1);
+            dict.put(EventConstants.EVENT_TOPIC, PushEventConstants.getAllTopics());
+            registrations.add(context.registerService(EventHandler.class.getName(), eventHandler, dict));
+        }
+        {
+            final EventHandler eventHandler = new EventHandler() {
+
+                public void handleEvent(final Event event) {
+                    if (FolderEventConstants.TOPIC_IDENTIFIERS.equals(event.getTopic())) {
+                        final Session session = ((Session) event.getProperty(FolderEventConstants.PROPERTY_SESSION));
+                        final String oldFolder = (String) event.getProperty(FolderEventConstants.PROPERTY_OLD_IDENTIFIER);
+                        tmp.removeSingleFromCache(sanitizeFolderId(oldFolder), FolderStorage.REAL_TREE_ID, session.getUserId(), session.getContextId(), true, session);
+                        return;
+                    }
+                    final Session session = ((Session) event.getProperty(FolderEventConstants.PROPERTY_SESSION));
+                    final Integer contextId = ((Integer) event.getProperty(FolderEventConstants.PROPERTY_CONTEXT));
+                    final Integer userId = ((Integer) event.getProperty(FolderEventConstants.PROPERTY_USER));
+                    final String folderId = (String) event.getProperty(FolderEventConstants.PROPERTY_FOLDER);
+                    final Boolean contentRelated = (Boolean) event.getProperty(FolderEventConstants.PROPERTY_CONTENT_RELATED);
+                    try {
+                        if (null == session) {
+                            tmp.removeSingleFromCache(sanitizeFolderId(folderId), FolderStorage.REAL_TREE_ID, null == userId ? -1 : userId.intValue(), contextId.intValue(), true, session);
+                        } else {
+                            tmp.removeFromCache(sanitizeFolderId(folderId), FolderStorage.REAL_TREE_ID, null != contentRelated && contentRelated.booleanValue(), session);
+                        }
+                    } catch (final FolderException e) {
+                        LOG.error(e.getMessage(), e);
+                    }
+                }
+            };
+            final Dictionary<String, Object> dict = new Hashtable<String, Object>(1);
+            dict.put(EventConstants.EVENT_TOPIC, FolderEventConstants.getAllTopics());
+            registrations.add(context.registerService(EventHandler.class.getName(), eventHandler, dict));
+        }
+        {
+            final EventHandler eventHandler = new EventHandler() {
+
+                public void handleEvent(final Event event) {
+                    final String topic = event.getTopic();
+                    if (SessiondEventConstants.TOPIC_REMOVE_SESSION.equals(topic)) {
+                        handleDroppedSession((Session) event.getProperty(SessiondEventConstants.PROP_SESSION));
+                    } else if (SessiondEventConstants.TOPIC_REMOVE_CONTAINER.equals(topic) || SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic)) {
+                        @SuppressWarnings("unchecked")
+                        final Map<String, Session> map = (Map<String, Session>) event.getProperty(SessiondEventConstants.PROP_CONTAINER);
+                        for (final Session session : map.values()) {
+                            handleDroppedSession(session);
+                        }
+                    }
+                }
+
+                private void handleDroppedSession(final Session session) {
+                    if (null == getService(SessiondService.class).getAnyActiveSessionForUser(session.getUserId(), session.getContextId())) {
+                        FolderMapManagement.getInstance().dropFor(session);
+                        TreeLockManagement.getInstance().dropFor(session);
+                        UserLockManagement.getInstance().dropFor(session);
+                    }
+                }
+            };
+            final Dictionary<String, Object> dict = new Hashtable<String, Object>(1);
+            dict.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
+            registrations.add(context.registerService(EventHandler.class.getName(), eventHandler, dict));
+        }
+    }
+
+    private static final String DEFAULT = MailFolder.DEFAULT_FOLDER_ID;
+
+    private static final Pattern PAT_FIX = Pattern.compile(Pattern.quote(DEFAULT) + "([0-9]+)" + Pattern.quote(DEFAULT));
+
+    protected static String sanitizeFolderId(final String id) {
+        String fid = id;
+        if (fid.startsWith(DEFAULT)) {
+            try {
+                final Matcher matcher = PAT_FIX.matcher(fid);
+                if (matcher.matches()) {
+                    fid = DEFAULT + matcher.group(1);
+                }
+            } catch (final Exception e) {
+                LOG.warn("Couldn't sanitize folder identifier: " + id + ". Returning unchanged.", e);
+                return id;
             }
-        };
-        final Dictionary<String, Object> dict = new Hashtable<String, Object>();
-        dict.put(EventConstants.EVENT_TOPIC, PushEventConstants.TOPIC_ATTR);
-        eventHandlerRegistration = context.registerService(EventHandler.class.getName(), eventHandler, dict);
+        }
+        return fid;
     }
 
     private void unregisterCacheFolderStorage() {
-        // Unregister event handler
-        if (null != eventHandlerRegistration) {
-            eventHandlerRegistration.unregister();
-            eventHandlerRegistration = null;
-        }
-        // Unregister folder storage
-        if (null != folderStorageRegistration) {
-            folderStorageRegistration.unregister();
-            folderStorageRegistration = null;
+        // Unregister
+        if (null != registrations) {
+            while (!registrations.isEmpty()) {
+                registrations.remove(0).unregister();
+            }
+            registrations = null;
         }
     }
 
