@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,13 +57,13 @@ import com.openexchange.folderstorage.cache.CacheFolderStorageRegistry;
 
 /**
  * {@link CacheFolderStorageServiceTracker} - A {@link ServiceTrackerCustomizer customizer} for cache folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CacheFolderStorageServiceTracker implements ServiceTrackerCustomizer {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(CacheFolderStorageServiceTracker.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CacheFolderStorageServiceTracker.class));
 
     private final BundleContext context;
 
