@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,12 +68,12 @@ import com.openexchange.server.impl.OCLPermission;
 
 /**
  * {@link DatabaseFolder} - A database folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class DatabaseFolder extends AbstractFolder {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DatabaseFolder.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DatabaseFolder.class));
 
     private static final long serialVersionUID = -4035221612481906228L;
 
@@ -83,14 +83,14 @@ public class DatabaseFolder extends AbstractFolder {
 
     /**
      * Initializes an empty {@link DatabaseFolder}.
-     * 
+     *
      * @param cacheable <code>true</code> if this database folder is cacheable; otherwise <code>false</code>
      */
     public DatabaseFolder(final boolean cacheable) {
         super();
         this.cacheable = cacheable;
         global = true;
-        this.subscribed = true;
+        subscribed = true;
     }
 
     /**
@@ -98,7 +98,7 @@ public class DatabaseFolder extends AbstractFolder {
      * <p>
      * Subfolder identifiers and tree identifier are not set within this constructor. Moreover passed database folder is considered to be
      * subscribed.
-     * 
+     *
      * @param folderObject The underlying database folder
      */
     public DatabaseFolder(final FolderObject folderObject) {
@@ -110,7 +110,7 @@ public class DatabaseFolder extends AbstractFolder {
      * <p>
      * Subfolder identifiers and tree identifier are not set within this constructor. Moreover passed database folder is considered to be
      * subscribed.
-     * 
+     *
      * @param folderObject The underlying database folder
      * @param cacheable <code>true</code> if this database folder is cacheable; otherwise <code>false</code>
      */
@@ -118,27 +118,27 @@ public class DatabaseFolder extends AbstractFolder {
         super();
         this.cacheable = cacheable;
         global = true;
-        this.id = String.valueOf(folderObject.getObjectID());
-        this.name = folderObject.getFolderName();
-        this.parent = String.valueOf(folderObject.getParentFolderID());
-        this.type = getType(folderObject.getType());
-        this.contentType = getContentType(folderObject.getModule());
+        id = String.valueOf(folderObject.getObjectID());
+        name = folderObject.getFolderName();
+        parent = String.valueOf(folderObject.getParentFolderID());
+        type = getType(folderObject.getType());
+        contentType = getContentType(folderObject.getModule());
         final OCLPermission[] oclPermissions = folderObject.getPermissionsAsArray();
-        this.permissions = new Permission[oclPermissions.length];
+        permissions = new Permission[oclPermissions.length];
         for (int i = 0; i < oclPermissions.length; i++) {
-            this.permissions[i] = new DatabasePermission(oclPermissions[i]);
+            permissions[i] = new DatabasePermission(oclPermissions[i]);
         }
-        this.createdBy = folderObject.getCreatedBy();
-        this.modifiedBy = folderObject.getModifiedBy();
+        createdBy = folderObject.getCreatedBy();
+        modifiedBy = folderObject.getModifiedBy();
         {
             final Date d = folderObject.getCreationDate();
-            this.creationDate = null == d ? null : new Date(d.getTime());
+            creationDate = null == d ? null : new Date(d.getTime());
         }
         {
             final Date d = folderObject.getLastModified();
-            this.lastModified = null == d ? null : new Date(d.getTime());
+            lastModified = null == d ? null : new Date(d.getTime());
         }
-        this.subscribed = true;
+        subscribed = true;
         deefault = folderObject.isDefaultFolder();
         defaultType = deefault ? contentType.getModule() : 0;
     }
@@ -153,10 +153,10 @@ public class DatabaseFolder extends AbstractFolder {
 
     /**
      * Sets the cachable flag.
-     * 
+     *
      * @param cacheable The cachable flag.
      */
-    public void setCacheable(boolean cacheable) {
+    public void setCacheable(final boolean cacheable) {
         this.cacheable = cacheable;
     }
 
@@ -212,7 +212,7 @@ public class DatabaseFolder extends AbstractFolder {
 
     /**
      * Sets whether this database folder is globally valid or per-user valid.
-     * 
+     *
      * @param global <code>true</code> if this database folder is globally valid; otherwise <code>false</code> if per-user valid
      */
     public void setGlobal(final boolean global) {
