@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,16 +54,18 @@ import com.openexchange.folderstorage.FolderType;
 
 /**
  * {@link DatabaseFolderType} - The database folder type.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DatabaseFolderType implements FolderType {
 
+    private static final String STRING = "DB";
+
     private static final DatabaseFolderType instance = new DatabaseFolderType();
 
     /**
      * Gets the {@link DatabaseFolderType} instance.
-     * 
+     *
      * @return The {@link DatabaseFolderType} instance
      */
     public static DatabaseFolderType getInstance() {
@@ -89,4 +91,9 @@ public final class DatabaseFolderType implements FolderType {
         return servesFolderId(parentId);
     }
 
+    @Override
+    public String toString() {
+        return STRING;
+    }
+
 }
