@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.folderstorage.SortableId;
 
 /**
  * {@link DatabaseId}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DatabaseId implements SortableId {
@@ -62,28 +62,38 @@ public final class DatabaseId implements SortableId {
 
     private final int ordinal;
 
+    private final String name;
+
     /**
      * Initializes a new {@link DatabaseId}.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ordinal The ordinal
+     * @param name The name
      */
-    public DatabaseId(final int folderId, final int ordinal) {
+    public DatabaseId(final int folderId, final int ordinal, final String name) {
         super();
         this.folderId = String.valueOf(folderId);
         this.ordinal = ordinal;
+        this.name = name;
     }
 
     /**
      * Initializes a new {@link DatabaseId}.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ordinal The ordinal
+     * @param name The name
      */
-    public DatabaseId(final String folderId, final int ordinal) {
+    public DatabaseId(final String folderId, final int ordinal, final String name) {
         super();
         this.folderId = folderId;
         this.ordinal = ordinal;
+        this.name = name;
+    }
+
+    public String getName() {
+        return name;
     }
 
     public String getId() {
@@ -99,7 +109,7 @@ public final class DatabaseId implements SortableId {
 
     public int compareTo(final SortableId o) {
         if (o instanceof DatabaseId) {
-            final int thisVal = this.ordinal;
+            final int thisVal = ordinal;
             final int anotherVal = ((DatabaseId) o).ordinal;
             return (thisVal < anotherVal ? -1 : (thisVal == anotherVal ? 0 : 1));
         }
