@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,13 @@
 
 package com.openexchange.folderstorage.database;
 
+import com.openexchange.folderstorage.FolderException;
+import com.openexchange.server.ServiceException;
 import com.openexchange.server.osgiservice.ServiceRegistry;
 
 /**
  * {@link DatabaseServiceRegistry} - The service registry for database folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DatabaseServiceRegistry {
@@ -62,13 +64,30 @@ public final class DatabaseServiceRegistry {
 
     /**
      * Gets the service registry
-     * 
+     *
      * @return The service registry
      */
     public static ServiceRegistry getServiceRegistry() {
         return REGISTRY;
     }
 
+    /**
+     * Gets the service defined by given class
+     * 
+     * @param <S> The type of service's class
+     * @param clazz The service's class
+     * @param errorOnAbsence <code>true</code> to throw an error on service absence; otherwise <code>false</code>
+     * @return The service if found; otherwise <code>null</code> if <code>errorOnAbsence</code> is <code>false</code>
+     * @throws FolderException If <code>errorOnAbsence</code> is <code>true</code> and service could not be found
+     */
+    public static <S extends Object> S getService(final Class<? extends S> clazz, final boolean errorOnAbsence) throws FolderException {
+        try {
+            return REGISTRY.getService(clazz, errorOnAbsence);
+        } catch (final ServiceException e) {
+            throw new FolderException(e);
+        }
+    }
+
     /**
      * Initializes a new {@link IMAPServiceRegistry}
      */
