@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,18 +58,19 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.FutureTask;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.i18n.LocaleTools;
 import com.openexchange.i18n.tools.StringHelper;
 
 /**
  * {@link LocalizedDatabaseFolder} - A locale-sensitive database folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class LocalizedDatabaseFolder extends DatabaseFolder {
 
     private static final long serialVersionUID = 3830248343115931304L;
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(LocalizedDatabaseFolder.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(LocalizedDatabaseFolder.class));
 
     private ConcurrentMap<Locale, Future<String>> localizedNames;
 
@@ -78,7 +79,7 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
      * <p>
      * Subfolder identifiers and tree identifier are not set within this constructor. Moreover passed database folder is considered to be
      * subscribed.
-     * 
+     *
      * @param folderObject The underlying database folder
      */
     public LocalizedDatabaseFolder(final FolderObject folderObject) {
@@ -90,7 +91,7 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
      * <p>
      * Subfolder identifiers and tree identifier are not set within this constructor. Moreover passed database folder is considered to be
      * subscribed.
-     * 
+     *
      * @param folderObject The underlying database folder
      * @param cacheable <code>true</code> if this database folder is cacheable; otherwise <code>false</code>
      */
@@ -103,7 +104,7 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
     public Object clone() {
         final LocalizedDatabaseFolder clone = (LocalizedDatabaseFolder) super.clone();
         // Locale-sensitive names
-        final ConcurrentMap<Locale, Future<String>> thisMap = this.localizedNames;
+        final ConcurrentMap<Locale, Future<String>> thisMap = localizedNames;
         if (null == localizedNames) {
             clone.localizedNames = null;
         } else {
@@ -119,7 +120,8 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
 
     @Override
     public String getLocalizedName(final Locale locale) {
-        Future<String> future = localizedNames.get(locale);
+        final Locale loc = null == locale ? LocaleTools.DEFAULT_LOCALE : locale;
+        Future<String> future = localizedNames.get(loc);
         if (null == future) {
             final String fname = getName();
             if (null == fname) {
@@ -128,10 +130,10 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
             final FutureTask<String> ft = new FutureTask<String>(new Callable<String>() {
 
                 public String call() throws Exception {
-                    return new StringHelper(locale).getString(fname);
+                    return StringHelper.valueOf(loc).getString(fname);
                 }
             });
-            future = localizedNames.putIfAbsent(locale, ft);
+            future = localizedNames.putIfAbsent(loc, ft);
             if (null == future) {
                 future = ft;
                 ft.run();
@@ -142,11 +144,11 @@ public class LocalizedDatabaseFolder extends DatabaseFolder {
         } catch (final InterruptedException e) {
             // Keep interrupted status
             Thread.currentThread().interrupt();
-            LOG.error(e.getMessage(), e);
+            LOG.warn(e.getMessage(), e);
             return getName();
         } catch (final ExecutionException e) {
             final Throwable t = e.getCause();
-            LOG.error(t.getMessage(), t);
+            LOG.warn(t.getMessage(), t);
             return getName();
         }
     }
