@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,37 +49,77 @@
 
 package com.openexchange.folderstorage.database.getfolder;
 
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.map.hash.TIntObjectHashMap;
+import gnu.trove.procedure.TIntProcedure;
+import gnu.trove.procedure.TObjectProcedure;
 import java.sql.Connection;
 import java.util.ArrayList;
-import java.util.Iterator;
+import java.util.Collections;
 import java.util.List;
 import java.util.Queue;
 import com.openexchange.api2.OXException;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.database.DatabaseFolder;
+import com.openexchange.folderstorage.database.FolderIdNamePair;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.Groups;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.server.impl.OCLPermission;
-import com.openexchange.tools.iterator.FolderObjectIterator;
-import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 
 /**
  * {@link SharedPrefixFolder} - Gets the folder whose identifier starts with shared prefix.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class SharedPrefixFolder {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(SharedPrefixFolder.class);
+    private static final class RemovingProcedure implements TIntProcedure {
+
+        private final TIntObjectHashMap<FolderObject> map;
+
+        public RemovingProcedure(final TIntObjectHashMap<FolderObject> map) {
+            this.map = map;
+        }
+
+        public boolean execute(final int folderId) {
+            map.remove(folderId);
+            return true;
+        }
+    }
+
+    private static final class DetectDirectSubfoldersProcedure implements TObjectProcedure<FolderObject> {
+
+        private final TIntObjectHashMap<FolderObject> map;
+
+        private final TIntList toRemove;
+
+        public DetectDirectSubfoldersProcedure(final TIntObjectHashMap<FolderObject> map, final TIntList toRemove) {
+            this.map = map;
+            this.toRemove = toRemove;
+        }
+
+        public boolean execute(final FolderObject folder) {
+            /*
+             * Check if current folder's parent is contained in map.
+             */
+            final int parent = folder.getParentFolderID();
+            if (map.containsKey(parent)) {
+                toRemove.add(folder.getObjectID());
+            }
+            return true;
+        }
+    }
 
     /**
      * Initializes a new {@link SharedPrefixFolder}.
@@ -91,7 +131,7 @@ public final class SharedPrefixFolder {
     /**
      * Checks existence of specified folder identifier starting with shared prefix; meaning folder's owner shared at least one folder to
      * given user.
-     * 
+     *
      * @param folderIdentifier The folder identifier starting with shared prefix
      * @param user The user
      * @param userConfiguration The user configuration
@@ -107,45 +147,30 @@ public final class SharedPrefixFolder {
         } catch (final NumberFormatException exc) {
             throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(exc, exc.getMessage());
         }
-        final SearchIterator<FolderObject> searchIterator;
         try {
-            searchIterator =
-                OXFolderIteratorSQL.getVisibleSharedFolders(
-                    user.getId(),
-                    user.getGroups(),
-                    userConfiguration.getAccessibleModules(),
-                    sharedOwner,
-                    ctx,
-                    null,
-                    con);
+            return OXFolderIteratorSQL.hasVisibleSharedFolders(
+                user.getId(),
+                user.getGroups(),
+                userConfiguration.getAccessibleModules(),
+                sharedOwner,
+                ctx,
+                null,
+                con);
         } catch (final OXException e) {
             throw new FolderException(e);
-        } catch (final SearchIteratorException e) {
-            throw new FolderException(e);
-        }
-        try {
-            return searchIterator.hasNext();
-        } finally {
-            try {
-                searchIterator.close();
-            } catch (final SearchIteratorException e) {
-                LOG.error("Failed closing search iterator.", e);
-            }
         }
     }
 
     /**
      * Gets the folder whose identifier starts with shared prefix.
-     * 
+     *
      * @param folderIdentifier The folder identifier starting with shared prefix
      * @param user The user
-     * @param userConfiguration The user configuration
      * @param ctx The context
-     * @param con The connection
      * @return The corresponding database folder with subfolders set
      * @throws FolderException If returning corresponding database folder fails
      */
-    public static DatabaseFolder getSharedPrefixFolder(final String folderIdentifier, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws FolderException {
+    public static DatabaseFolder getSharedPrefixFolder(final String folderIdentifier, final User user, final Context ctx) throws FolderException {
         final int sharedOwner;
         try {
             sharedOwner = Integer.parseInt(folderIdentifier.substring(2));
@@ -159,9 +184,8 @@ public final class SharedPrefixFolder {
             if (sharedOwner != OCLPermission.ALL_GROUPS_AND_USERS) {
                 throw new FolderException(e);
             }
-            creatorDisplayName = new StringHelper(user.getLocale()).getString(Groups.ALL_USERS);
+            creatorDisplayName = StringHelper.valueOf(user.getLocale()).getString(Groups.ALL_USERS);
         }
-
         final FolderObject virtualOwnerFolder = FolderObject.createVirtualSharedFolderObject(sharedOwner, creatorDisplayName);
         /*
          * This highly user-specific folder is NOT cacheable
@@ -170,7 +194,29 @@ public final class SharedPrefixFolder {
         retval.setID(folderIdentifier);
         retval.setParentID(String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID));
         retval.setGlobal(false);
+        retval.setSubfolderIDs(null);
+        retval.setSubscribedSubfolders(true);
+        return retval;
+    }
 
+    /**
+     * Gets the folder whose identifier starts with shared prefix.
+     *
+     * @param folderIdentifier The folder identifier starting with shared prefix
+     * @param user The user
+     * @param userConfiguration The user configuration
+     * @param ctx The context
+     * @param con The connection
+     * @return The corresponding database folder with subfolders set
+     * @throws FolderException If returning corresponding database folder fails
+     */
+    public static int[] getSharedPrefixFolderSubfoldersAsInt(final String folderIdentifier, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws FolderException {
+        final int sharedOwner;
+        try {
+            sharedOwner = Integer.parseInt(folderIdentifier.substring(2));
+        } catch (final NumberFormatException exc) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(exc, exc.getMessage());
+        }
         final Queue<FolderObject> q;
         try {
             q =
@@ -187,15 +233,102 @@ public final class SharedPrefixFolder {
         } catch (final OXException e) {
             throw new FolderException(e);
         }
-        final int size = q.size();
-        final Iterator<FolderObject> iter = q.iterator();
-        final List<String> subfolderIds = new ArrayList<String>(size);
-        for (int i = 0; i < size; i++) {
-            subfolderIds.add(String.valueOf(iter.next().getObjectID()));
+        if (q.isEmpty()) {
+            return new int[0];
         }
-        retval.setSubfolderIDs(subfolderIds.toArray(new String[subfolderIds.size()]));
-        retval.setSubscribedSubfolders(!subfolderIds.isEmpty());
-        return retval;
+        /*
+         * Get first level shared folders
+         */
+        final int size = q.size();
+        final TIntObjectHashMap<FolderObject> set = getFirstLevelSharedFolders(q, size);
+        /*
+         * Return filtered list
+         */
+        final TIntList ret = new TIntArrayList(q.size());
+        for (final FolderObject fo : q) {
+            final int folderId = fo.getObjectID();
+            if (set.containsKey(folderId)) {
+                ret.add(folderId);
+            }
+        }
+        return ret.toArray();
+    }
+
+    /**
+     * Gets the folder whose identifier starts with shared prefix.
+     *
+     * @param folderIdentifier The folder identifier starting with shared prefix
+     * @param user The user
+     * @param userConfiguration The user configuration
+     * @param ctx The context
+     * @param con The connection
+     * @return The corresponding database folder with subfolders set
+     * @throws FolderException If returning corresponding database folder fails
+     */
+    public static List<FolderIdNamePair> getSharedPrefixFolderSubfolders(final String folderIdentifier, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws FolderException {
+        final int sharedOwner;
+        try {
+            sharedOwner = Integer.parseInt(folderIdentifier.substring(2));
+        } catch (final NumberFormatException exc) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(exc, exc.getMessage());
+        }
+        final Queue<FolderObject> q;
+        try {
+            q =
+                ((FolderObjectIterator) OXFolderIteratorSQL.getVisibleSharedFolders(
+                    user.getId(),
+                    user.getGroups(),
+                    userConfiguration.getAccessibleModules(),
+                    sharedOwner,
+                    ctx,
+                    null,
+                    con)).asQueue();
+        } catch (final SearchIteratorException e) {
+            throw new FolderException(e);
+        } catch (final OXException e) {
+            throw new FolderException(e);
+        }
+        if (q.isEmpty()) {
+            return Collections.<FolderIdNamePair> emptyList();
+        }
+        /*
+         * Get first level shared folders
+         */
+        final int size = q.size();
+        final TIntObjectHashMap<FolderObject> set = getFirstLevelSharedFolders(q, size);
+        /*
+         * Return filtered list
+         */
+        final List<FolderIdNamePair> ret = new ArrayList<FolderIdNamePair>(size);
+        for (final FolderObject fo : q) {
+            final int folderId = fo.getObjectID();
+            if (set.containsKey(folderId)) {
+                ret.add(new FolderIdNamePair(folderId, fo.getFolderName()));
+            }
+        }
+        return ret;
+    }
+
+    private static TIntObjectHashMap<FolderObject> getFirstLevelSharedFolders(final Queue<FolderObject> q, final int size) {
+        /*
+         * Generate mapping
+         */
+        final TIntObjectHashMap<FolderObject> map = new TIntObjectHashMap<FolderObject>(size);
+        for (final FolderObject fo : q) {
+            map.put(fo.getObjectID(), fo);
+        }
+        /*
+         * Strip direct subfolders
+         */
+        {
+            final TIntList toRemove = new TIntArrayList(size >> 1);
+            map.forEachValue(new DetectDirectSubfoldersProcedure(map, toRemove));
+            toRemove.forEach(new RemovingProcedure(map));
+        }
+        /*
+         * Return set view
+         */
+        return map;
     }
 
 }
