@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,6 +67,7 @@ import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.database.DatabaseFolder;
 import com.openexchange.folderstorage.database.LocalizedDatabaseFolder;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.FolderStrings;
@@ -74,22 +75,25 @@ import com.openexchange.groupware.i18n.Groups;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.server.impl.OCLPermission;
-import com.openexchange.tools.iterator.FolderObjectIterator;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
+import com.openexchange.tools.oxfolder.OXFolderException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMap;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 
 /**
  * {@link SystemSharedFolder} - Gets the system shared folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class SystemSharedFolder {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(SystemSharedFolder.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(SystemSharedFolder.class));
 
     /**
      * Initializes a new {@link SystemSharedFolder}.
@@ -100,7 +104,7 @@ public final class SystemSharedFolder {
 
     /**
      * Gets the database folder representing system shared folder for given user.
-     * 
+     *
      * @param fo The folder object fetched from database
      * @param user The user
      * @param userConfiguration The user configuration
@@ -116,6 +120,24 @@ public final class SystemSharedFolder {
         final DatabaseFolder retval = new LocalizedDatabaseFolder(fo, false);
         retval.setName(FolderStrings.SYSTEM_SHARED_FOLDER_NAME);
         // Enforce getSubfolders() from storage if at least one shared folder is accessible for user
+        ConditionTreeMap treeMap;
+        try {
+            treeMap = ConditionTreeMapManagement.getInstance().optMapFor(ctx.getContextId());
+        } catch (final OXFolderException e) {
+            treeMap = null;
+        }
+        if (null != treeMap) {
+            /*
+             * Set to null if a shared folder exists otherwise to empty array to indicate no subfolders
+             */
+            final boolean hasNext = treeMap.hasSharedFolder(user.getId(), user.getGroups(), userConfiguration.getAccessibleModules());
+            retval.setSubfolderIDs(hasNext ? null : new String[0]);
+            retval.setSubscribedSubfolders(hasNext);
+            return retval;
+        }
+        /*
+         * Query database
+         */
         final SearchIterator<FolderObject> searchIterator;
         try {
             searchIterator =
@@ -143,10 +165,12 @@ public final class SystemSharedFolder {
             final boolean hasNext = searchIterator.hasNext();
             retval.setSubfolderIDs(hasNext ? null : new String[0]);
             retval.setSubscribedSubfolders(hasNext);
+        } catch (final AbstractOXException e) {
+            throw new FolderException(e);
         } finally {
             try {
                 searchIterator.close();
-            } catch (final SearchIteratorException e) {
+            } catch (final AbstractOXException e) {
                 LOG.error("Failed closing search iterator.", e);
             }
         }
@@ -155,7 +179,7 @@ public final class SystemSharedFolder {
 
     /**
      * Gets the subfolder identifiers of database folder representing system shared folder for given user.
-     * 
+     *
      * @param user The user
      * @param userConfiguration The user configuration
      * @param ctx The context
@@ -163,7 +187,7 @@ public final class SystemSharedFolder {
      * @return The subfolder identifiers of database folder representing system shared folder for given user
      * @throws FolderException If the database folder cannot be returned
      */
-    public static String[] getSystemSharedFolderSubfolder(final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws FolderException {
+    public static List<String[]> getSystemSharedFolderSubfolder(final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws FolderException {
         /*
          * The system shared folder
          */
@@ -192,7 +216,7 @@ public final class SystemSharedFolder {
             /*
              * Gather all display names
              */
-            final StringHelper strHelper = new StringHelper(user.getLocale());
+            final StringHelper strHelper = StringHelper.valueOf(user.getLocale());
             final int size = q.size();
             displayNames = new HashMap<String, Integer>(size);
             final UserStorage us = UserStorage.getInstance();
@@ -220,17 +244,18 @@ public final class SystemSharedFolder {
         final List<String> sortedDisplayNames = new ArrayList<String>(displayNames.keySet());
         Collections.sort(sortedDisplayNames, new DisplayNameComparator(user.getLocale()));
         final StringBuilder sb = new StringBuilder(8);
-        final List<String> subfolderIds = new ArrayList<String>(displayNames.size());
+        final List<String[]> subfolderIds = new ArrayList<String[]>(displayNames.size());
         for (final String displayName : sortedDisplayNames) {
             sb.setLength(0);
-            subfolderIds.add(sb.append(FolderObject.SHARED_PREFIX).append(displayNames.get(displayName).intValue()).toString());
+            final int createdBy = displayNames.get(displayName).intValue();
+            subfolderIds.add(new String[] {sb.append(FolderObject.SHARED_PREFIX).append(createdBy).toString(), displayName});
         }
-        return subfolderIds.toArray(new String[subfolderIds.size()]);
+        return subfolderIds;
     }
 
     /**
      * {@link DisplayNameComparator} - Sorts display names with respect to a certain locale.
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     private static final class DisplayNameComparator implements Comparator<String> {
