@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,16 +49,26 @@
 
 package com.openexchange.folderstorage.internal;
 
+import gnu.trove.map.hash.TIntIntHashMap;
+import gnu.trove.set.TIntSet;
+import gnu.trove.set.hash.TIntHashSet;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Type;
+import com.openexchange.folderstorage.internal.performers.AbstractPerformer;
+import com.openexchange.folderstorage.type.PrivateType;
+import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
+import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
@@ -66,7 +76,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link CalculatePermission} - Utility class to obtain an effective permission.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CalculatePermission {
@@ -80,53 +90,100 @@ public final class CalculatePermission {
 
     /**
      * Calculates the effective user permissions for given folder.
-     * 
+     *
      * @param folder The folder whose effective user permissions shall be calculated
      * @param context The context
-     * @throws FolderException If calculating effective user permissions fails
      */
-    public static void calculateUserPermissions(final Folder folder, final Context context) throws FolderException {
+    public static void calculateUserPermissions(final Folder folder, final Context context) {
         final Permission[] staticPermissions = folder.getPermissions();
         if (null == staticPermissions || 0 == staticPermissions.length) {
             return;
         }
-        try {
-            final UserConfigurationStorage userConfStorage = UserConfigurationStorage.getInstance();
-            final String id = folder.getID();
-            final Type type = folder.getType();
-            final ContentType contentType = folder.getContentType();
+        final UserConfigurationStorage userConfStorage = UserConfigurationStorage.getInstance();
+        final String id = folder.getID();
+        final Type type = folder.getType();
+        final ContentType contentType = folder.getContentType();
 
-            final java.util.List<Permission> userizedPermissions = new ArrayList<Permission>(staticPermissions.length);
-            for (int i = 0; i < staticPermissions.length; i++) {
-                final Permission staticPermission = staticPermissions[i];
-                if (0 == staticPermission.getSystem()) {
-                    // A non-system permission
-                    final Permission userizedPermission;
-                    if (staticPermission.isGroup()) {
-                        userizedPermission = staticPermission;
-                    } else {
-                        final UserConfiguration userConfig = userConfStorage.getUserConfiguration(staticPermission.getEntity(), context);
-                        userizedPermission =
-                            new EffectivePermission(
-                                staticPermission,
-                                id,
-                                type,
-                                contentType,
-                                userConfig,
-                                Collections.<ContentType> emptyList());
-                    }
-                    userizedPermissions.add(userizedPermission);
+        final Permission[] userizedPermissions = new Permission[staticPermissions.length];
+        final TIntIntHashMap toLoad = new TIntIntHashMap(staticPermissions.length);
+        for (int index = 0; index < staticPermissions.length; index++) {
+            final Permission staticPermission = staticPermissions[index];
+            if (0 == staticPermission.getSystem()) {
+                // A non-system permission
+                if (staticPermission.isGroup()) {
+                    userizedPermissions[index] = staticPermission;
+                } else {
+                    // Load appropriate user configuration
+                    toLoad.put(staticPermission.getEntity(), index);
                 }
             }
-            folder.setPermissions(userizedPermissions.toArray(new Permission[userizedPermissions.size()]));
-        } catch (final UserConfigurationException e) {
-            throw new FolderException(e);
         }
+        /*
+         * Batch-load user configurations
+         */
+        if (!toLoad.isEmpty()) {
+            final int[] userIds = toLoad.keys();
+            try {
+                final UserConfiguration[] configurations =
+                    userConfStorage.getUserConfiguration(context, UserStorage.getInstance().getUser(context, userIds));
+                for (int i = 0; i < configurations.length; i++) {
+                    final int userId = userIds[i];
+                    if (toLoad.containsKey(userId)) {
+                        final int index = toLoad.get(userId);
+                        UserConfiguration userConfig = configurations[i];
+                        if (null == userConfig) {
+                            userConfig = userConfStorage.getUserConfiguration(userId, context);
+                        }
+                        userizedPermissions[index] = new EffectivePermission(
+                            staticPermissions[index],
+                            id,
+                            type,
+                            contentType,
+                            userConfig,
+                            Collections.<ContentType> emptyList()).setEntityInfo(userId, context);
+                    }
+                }
+            } catch (final UserConfigurationException e) {
+                final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(CalculatePermission.class));
+                logger.warn("User configuration could not be loaded. Ignoring user permissions.", e);
+            } catch (final UserException e) {
+                final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(CalculatePermission.class));
+                logger.warn("User configuration could not be loaded. Ignoring user permissions.", e);
+            }
+        }
+        /*
+         * Remove possible null values & apply to folder
+         */
+        final java.util.List<Permission> tmp = new ArrayList<Permission>(userizedPermissions.length);
+        for (int i = 0; i < userizedPermissions.length; i++) {
+            final Permission p = userizedPermissions[i];
+            if (null != p) {
+                tmp.add(p);
+            }
+        }
+        folder.setPermissions(tmp.toArray(new Permission[tmp.size()]));
     }
 
     /**
      * Calculates the effective permission for given user in given folder.
-     * 
+     *
+     * @param folder The folder
+     * @param performer The performer to calculate for
+     * @param allowedContentTypes The allowed content types; an empty list indicates all are allowed
+     * @return The effective permission for given user in given folder
+     * @throws FolderException If calculating the effective permission fails
+     */
+    public static Permission calculate(final Folder folder, final AbstractPerformer performer, final java.util.List<ContentType> allowedContentTypes) throws FolderException {
+        final ServerSession session = performer.getSession();
+        if (null == session) {
+            return calculate(folder, performer.getUser(), performer.getContext(), allowedContentTypes);
+        }
+        return calculate(folder, session, allowedContentTypes);
+    }
+
+    /**
+     * Calculates the effective permission for given user in given folder.
+     *
      * @param folder The folder
      * @param user The user
      * @param context The context
@@ -141,18 +198,128 @@ public final class CalculatePermission {
         } catch (final UserConfigurationException e) {
             throw new FolderException(e);
         }
+        final Permission underlyingPermission;
+        {
+            final int bits = -1; // folder.getBits();
+            if (bits >= 0) {
+                /*
+                 * Get permission from bits
+                 */
+                final DummyPermission p = new DummyPermission();
+                p.setNoPermissions();
+                final int[] permissionBits = parsePermissionBits(bits);
+                p.setFolderPermission(permissionBits[0]);
+                p.setReadPermission(permissionBits[1]);
+                p.setWritePermission(permissionBits[2]);
+                p.setDeletePermission(permissionBits[3]);
+                p.setAdmin(permissionBits[4] > 0 ? true : false);
+                underlyingPermission = p;
+            } else {
+                /*
+                 * Compute permission from all folder permissions
+                 */
+                underlyingPermission = getMaxPermission(folder.getPermissions(), userConfiguration);
+            }
+        }
         return new EffectivePermission(
-            getMaxPermission(folder.getPermissions(), userConfiguration),
+            underlyingPermission,
             folder.getID(),
             folder.getType(),
             folder.getContentType(),
             userConfiguration,
-            allowedContentTypes);
+            allowedContentTypes).setEntityInfo(user.getId(), context);
+    }
+
+    public static boolean isVisible(final Folder folder, final User user, final Context context, final java.util.List<ContentType> allowedContentTypes) throws FolderException {
+        final UserConfiguration userConfiguration;
+        try {
+            userConfiguration = UserConfigurationStorage.getInstance().getUserConfiguration(user.getId(), context);
+        } catch (final UserConfigurationException e) {
+            throw new FolderException(e);
+        }
+        final Permission underlyingPermission;
+        final Type type = folder.getType();
+        final ContentType contentType = folder.getContentType();
+        {
+            final int bits = -1; // folder.getBits();
+            if (bits >= 0) {
+                /*
+                 * Get permission from bits
+                 */
+                final DummyPermission p = new DummyPermission();
+                p.setNoPermissions();
+                final int[] permissionBits = parsePermissionBits(bits);
+                p.setFolderPermission(permissionBits[0]);
+                p.setReadPermission(permissionBits[1]);
+                p.setWritePermission(permissionBits[2]);
+                p.setDeletePermission(permissionBits[3]);
+                p.setAdmin(permissionBits[4] > 0 ? true : false);
+                underlyingPermission = p;
+            } else {
+                /*
+                 * Check visibility by folder
+                 */
+                if (PrivateType.getInstance().equals(type)) {
+                    final int createdBy = folder.getCreatedBy();
+                    if (createdBy <= 0 || createdBy == user.getId()) {
+                        return hasAccess(contentType, userConfiguration, allowedContentTypes);
+                    }
+                }
+                /*
+                 * Check visibility by effective permission
+                 */
+                underlyingPermission = getMaxPermission(folder.getPermissions(), userConfiguration);
+            }
+        }
+        return new EffectivePermission(underlyingPermission, folder.getID(), type, contentType, userConfiguration, allowedContentTypes).isVisible();
+    }
+
+    private static boolean hasAccess(final ContentType contentType, final UserConfiguration userConfig, final java.util.List<ContentType> allowedContentTypes) {
+        final int module = contentType.getModule();
+        if (!userConfig.hasModuleAccess(module)) {
+            return false;
+        }
+        if (null == allowedContentTypes || allowedContentTypes.isEmpty()) {
+            return true;
+        }
+        final TIntSet set = new TIntHashSet(allowedContentTypes.size() + 2);
+        for (final ContentType allowedContentType : allowedContentTypes) {
+            set.add(allowedContentType.getModule());
+        }
+        // Module SYSTEM is allowed in any case
+        set.add(FolderObject.SYSTEM_MODULE);
+        set.add(FolderObject.UNBOUND);
+        return set.isEmpty() ? true : set.contains(module);
+    }
+
+    private static final int[] mapping = { 0, 2, 4, -1, 8 };
+
+    /**
+     * The actual max permission that can be transfered in field 'bits' or JSON's permission object
+     */
+    private static final int MAX_PERMISSION = 64;
+
+    private static final int[] parsePermissionBits(final int bitsArg) {
+        int bits = bitsArg;
+        final int[] retval = new int[5];
+        for (int i = retval.length - 1; i >= 0; i--) {
+            final int shiftVal = (i * 7); // Number of bits to be shifted
+            retval[i] = bits >> shiftVal;
+            bits -= (retval[i] << shiftVal);
+            if (retval[i] == MAX_PERMISSION) {
+                retval[i] = Permission.MAX_PERMISSION;
+            } else if (i < (retval.length - 1)) {
+                retval[i] = mapping[retval[i]];
+            } else {
+                retval[i] = retval[i];
+            }
+        }
+        return retval;
     }
 
     /**
      * Calculates the effective permission for given session's user in given folder.
-     * 
+     *
      * @param folder The folder
      * @param session The session
      * @param allowedContentTypes The allowed content types; an empty list indicates all are allowed
@@ -160,8 +327,31 @@ public final class CalculatePermission {
      */
     public static Permission calculate(final Folder folder, final ServerSession session, final java.util.List<ContentType> allowedContentTypes) {
         final UserConfiguration userConfiguration = session.getUserConfiguration();
+        final Permission underlyingPermission;
+        {
+            final int bits = -1;// folder.getBits();
+            if (bits >= 0) {
+                /*
+                 * Get permission from bits
+                 */
+                final DummyPermission p = new DummyPermission();
+                p.setNoPermissions();
+                final int[] permissionBits = parsePermissionBits(bits);
+                p.setFolderPermission(permissionBits[0]);
+                p.setReadPermission(permissionBits[1]);
+                p.setWritePermission(permissionBits[2]);
+                p.setDeletePermission(permissionBits[3]);
+                p.setAdmin(permissionBits[4] > 0 ? true : false);
+                underlyingPermission = p;
+            } else {
+                /*
+                 * Compute permission from all folder permissions
+                 */
+                underlyingPermission = getMaxPermission(folder.getPermissions(), userConfiguration);
+            }
+        }
         return new EffectivePermission(
-            getMaxPermission(folder.getPermissions(), userConfiguration),
+            underlyingPermission,
             folder.getID(),
             folder.getType(),
             folder.getContentType(),
@@ -172,6 +362,7 @@ public final class CalculatePermission {
     private static Permission getMaxPermission(final Permission[] permissions, final UserConfiguration userConfig) {
         final DummyPermission p = new DummyPermission();
         p.setNoPermissions();
+        p.setEntity(userConfig.getUserId());
 
         final int[] idArr;
         {
@@ -182,26 +373,39 @@ public final class CalculatePermission {
             Arrays.sort(idArr);
         }
 
-        for (int i = 0; i < permissions.length; i++) {
-            final Permission cur = permissions[i];
+        int fp = 0;
+        int rp = 0;
+        int wp = 0;
+        int dp = 0;
+        boolean admin = false;
+        for (final Permission cur : permissions) {
             if (Arrays.binarySearch(idArr, cur.getEntity()) >= 0) {
-                if (cur.getFolderPermission() > p.getFolderPermission()) {
-                    p.setFolderPermission(cur.getFolderPermission());
+                // Folder permission
+                int tmp = cur.getFolderPermission();
+                if (tmp > fp) {
+                    fp = tmp;
                 }
-                if (cur.getReadPermission() > p.getReadPermission()) {
-                    p.setReadPermission(cur.getReadPermission());
+                // Read permission
+                tmp = cur.getReadPermission();
+                if (tmp > rp) {
+                    rp = tmp;
                 }
-                if (cur.getWritePermission() > p.getWritePermission()) {
-                    p.setWritePermission(cur.getWritePermission());
+                // Write permission
+                tmp = cur.getWritePermission();
+                if (tmp > wp) {
+                    wp = tmp;
                 }
-                if (cur.getDeletePermission() > p.getDeletePermission()) {
-                    p.setDeletePermission(cur.getDeletePermission());
-                }
-                if (!p.isAdmin() && cur.isAdmin()) {
-                    p.setAdmin(true);
+                // Delete permission
+                tmp = cur.getDeletePermission();
+                if (tmp > dp) {
+                    dp = tmp;
                 }
+                // Admin flag
+                admin |= cur.isAdmin();
             }
         }
+        p.setAllPermissions(fp, rp, wp, dp);
+        p.setAdmin(admin);
 
         return p;
     }
@@ -333,7 +537,7 @@ public final class CalculatePermission {
         }
 
         public void setDeletePermission(final int permission) {
-            this.deletePermission = permission;
+            deletePermission = permission;
         }
 
         public void setEntity(final int entity) {
@@ -341,7 +545,7 @@ public final class CalculatePermission {
         }
 
         public void setFolderPermission(final int permission) {
-            this.folderPermission = permission;
+            folderPermission = permission;
         }
 
         public void setGroup(final boolean group) {
@@ -349,23 +553,23 @@ public final class CalculatePermission {
         }
 
         public void setMaxPermissions() {
-            this.folderPermission = Permission.MAX_PERMISSION;
-            this.readPermission = Permission.MAX_PERMISSION;
-            this.deletePermission = Permission.MAX_PERMISSION;
-            this.writePermission = Permission.MAX_PERMISSION;
-            this.admin = true;
+            folderPermission = Permission.MAX_PERMISSION;
+            readPermission = Permission.MAX_PERMISSION;
+            deletePermission = Permission.MAX_PERMISSION;
+            writePermission = Permission.MAX_PERMISSION;
+            admin = true;
         }
 
         public void setNoPermissions() {
-            this.folderPermission = Permission.NO_PERMISSIONS;
-            this.readPermission = Permission.NO_PERMISSIONS;
-            this.deletePermission = Permission.NO_PERMISSIONS;
-            this.writePermission = Permission.NO_PERMISSIONS;
-            this.admin = false;
+            folderPermission = Permission.NO_PERMISSIONS;
+            readPermission = Permission.NO_PERMISSIONS;
+            deletePermission = Permission.NO_PERMISSIONS;
+            writePermission = Permission.NO_PERMISSIONS;
+            admin = false;
         }
 
         public void setReadPermission(final int permission) {
-            this.readPermission = permission;
+            readPermission = permission;
         }
 
         public void setSystem(final int system) {
@@ -373,7 +577,7 @@ public final class CalculatePermission {
         }
 
         public void setWritePermission(final int permission) {
-            this.writePermission = permission;
+            writePermission = permission;
         }
 
         @Override
