@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,33 +52,35 @@ package com.openexchange.folderstorage.internal;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
+import java.util.Queue;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.CopyOnWriteArrayList;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.ContentTypeDiscoveryService;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageComparator;
+import com.openexchange.folderstorage.virtual.VirtualFolderStorage;
+import com.openexchange.folderstorage.virtual.VirtualFolderType;
 
 /**
  * {@link ContentTypeRegistry} - A registry for a tree's content types.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ContentTypeRegistry.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ContentTypeRegistry.class));
 
     private static final ContentTypeRegistry instance = new ContentTypeRegistry();
 
     /**
      * Gets the {@link ContentTypeRegistry} instance.
-     * 
+     *
      * @return The {@link ContentTypeRegistry} instance
      */
     public static ContentTypeRegistry getInstance() {
@@ -89,29 +91,29 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
         private final ConcurrentMap<ContentType, FolderStorage> concreteStorages;
 
-        private volatile List<FolderStorage> generalStorages;
+        private volatile Queue<FolderStorage> generalStorages;
 
         public Element() {
             super();
             concreteStorages = new ConcurrentHashMap<ContentType, FolderStorage>();
-            generalStorages = new CopyOnWriteArrayList<FolderStorage>();
+            generalStorages = new ConcurrentLinkedQueue<FolderStorage>();
         }
 
         public ConcurrentMap<ContentType, FolderStorage> getConcreteStorages() {
             return concreteStorages;
         }
 
-        public List<FolderStorage> getGeneralStorages() {
+        public Queue<FolderStorage> getGeneralStorages() {
             return generalStorages;
         }
 
         /**
          * Performs an atomic clear&addAll by reassigning volatile variable.
-         * 
+         *
          * @param replacement The replacement
          */
         public void replaceGeneralStorages(final List<FolderStorage> replacement) {
-            generalStorages = new CopyOnWriteArrayList<FolderStorage>(replacement);
+            generalStorages = new ConcurrentLinkedQueue<FolderStorage>(replacement);
         }
 
     }
@@ -148,7 +150,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Associates specified folder storage to given content type.
-     * 
+     *
      * @param treeId The folder storage's tree identifier
      * @param contentType The content type to register
      * @param folderStorage The content type's folder storage
@@ -169,7 +171,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Adds a general-purpose folder storage (capable to serve every content type) to this registry.
-     * 
+     *
      * @param treeId The folder storage's tree identifier
      * @param folderStorage The general-purpose folder storage
      * @return <code>true</code> if folder storage was successfully registered; otherwise <code>false</code>
@@ -186,7 +188,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Gets the available content types.
-     * 
+     *
      * @return The available content types
      */
     public Map<Integer, ContentType> getAvailableContentTypes() {
@@ -204,7 +206,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Gets the specified content type's storage.
-     * 
+     *
      * @param treeId The tree identifier
      * @param contentType The content type
      * @return The content type's storage or <code>null</code>
@@ -212,12 +214,15 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
     public FolderStorage getFolderStorageByContentType(final String treeId, final ContentType contentType) {
         final Element element = getElementForTreeId(treeId, false);
         if (null == element) {
+            if (VirtualFolderType.getInstance().servesTreeId(treeId)) {
+                return VirtualFolderStorage.getInstance();
+            }
             return null;
         }
         // Look-up in general-purpose folder storages
-        final List<FolderStorage> generalStorages = element.getGeneralStorages();
+        final Queue<FolderStorage> generalStorages = element.getGeneralStorages();
         if (!generalStorages.isEmpty()) {
-            return generalStorages.get(0);
+            return generalStorages.peek();
         }
         final ConcurrentMap<ContentType, FolderStorage> types = element.getConcreteStorages();
         if (null == types) {
@@ -227,9 +232,8 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
     }
 
     public ContentType getByString(final String contentTypeString) {
-        for (final Iterator<Entry<String, Element>> iterator = registry.entrySet().iterator(); iterator.hasNext();) {
-            final Entry<String, Element> entry = iterator.next();
-            final List<FolderStorage> generalStorages = entry.getValue().getGeneralStorages();
+        for (final Entry<String, Element> entry : registry.entrySet()) {
+            final Queue<FolderStorage> generalStorages = entry.getValue().getGeneralStorages();
             /*
              * Iterate general storages' content types
              */
@@ -237,8 +241,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
             for (final FolderStorage genStorage : generalStorages) {
                 final FolderStorage folderStorage = genStorage;
                 final ContentType[] supportedContentTypes = folderStorage.getSupportedContentTypes();
-                for (int i = 0; i < supportedContentTypes.length; i++) {
-                    final ContentType supportedContentType = supportedContentTypes[i];
+                for (final ContentType supportedContentType : supportedContentTypes) {
                     if (supportedContentType.toString().equals(contentTypeString) && (null == candidate || candidate.getPriority() > supportedContentType.getPriority())) {
                         candidate = supportedContentType;
                     }
@@ -265,7 +268,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Removes specified content type.
-     * 
+     *
      * @param treeId The tree identifier
      * @param contentType The content type
      */
@@ -280,7 +283,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Removes specified general-purpose folder storage.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The general-purpose folder storage
      */
@@ -298,7 +301,7 @@ public final class ContentTypeRegistry implements ContentTypeDiscoveryService {
 
     /**
      * Removes tree's content types.
-     * 
+     *
      * @param treeId The tree identifier
      */
     public void removeTreeContentTypes(final String treeId) {
