@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,15 +49,22 @@
 
 package com.openexchange.folderstorage.internal;
 
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
+import java.util.HashSet;
 import java.util.Map;
+import java.util.Set;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
+import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderFilter;
 import com.openexchange.folderstorage.FolderResponse;
 import com.openexchange.folderstorage.FolderService;
 import com.openexchange.folderstorage.FolderServiceDecorator;
+import com.openexchange.folderstorage.FolderStorage;
+import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.internal.performers.AllVisibleFoldersPerformer;
 import com.openexchange.folderstorage.internal.performers.ClearPerformer;
@@ -67,17 +74,23 @@ import com.openexchange.folderstorage.internal.performers.DeletePerformer;
 import com.openexchange.folderstorage.internal.performers.GetPerformer;
 import com.openexchange.folderstorage.internal.performers.ListPerformer;
 import com.openexchange.folderstorage.internal.performers.PathPerformer;
+import com.openexchange.folderstorage.internal.performers.SubscribePerformer;
+import com.openexchange.folderstorage.internal.performers.UnsubscribePerformer;
 import com.openexchange.folderstorage.internal.performers.UpdatePerformer;
 import com.openexchange.folderstorage.internal.performers.UpdatesPerformer;
+import com.openexchange.folderstorage.internal.performers.VisibleFoldersPerformer;
+import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
+import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.session.Session;
+import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * {@link FolderServiceImpl} - The {@link FolderService} implementation.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FolderServiceImpl implements FolderService {
@@ -92,10 +105,10 @@ public final class FolderServiceImpl implements FolderService {
     public void checkConsistency(final String treeId, final User user, final Context context) throws FolderException {
         new ConsistencyPerformer(user, context).doConsistencyCheck(treeId);
     }
-    
+
     public void checkConsistency(final String treeId, final Session session) throws FolderException {
         try {
-            new ConsistencyPerformer(new ServerSessionAdapter(session)).doConsistencyCheck(treeId);
+            new ConsistencyPerformer(ServerSessionAdapter.valueOf(session)).doConsistencyCheck(treeId);
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
@@ -107,19 +120,21 @@ public final class FolderServiceImpl implements FolderService {
 
     public void clearFolder(final String treeId, final String folderId, final Session session) throws FolderException {
         try {
-            new ClearPerformer(new ServerSessionAdapter(session)).doClear(treeId, folderId);
+            new ClearPerformer(ServerSessionAdapter.valueOf(session)).doClear(treeId, folderId);
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
     }
 
-    public String createFolder(final Folder folder, final User user, final Context context) throws FolderException {
-        return new CreatePerformer(user, context).doCreate(folder);
+    public FolderResponse<String> createFolder(final Folder folder, final User user, final Context context) throws FolderException {
+        final CreatePerformer createPerformer = new CreatePerformer(user, context);
+        return FolderResponseImpl.newFolderResponse(createPerformer.doCreate(folder), createPerformer.getStorageParameters().getWarnings());
     }
 
-    public String createFolder(final Folder folder, final Session session) throws FolderException {
+    public FolderResponse<String> createFolder(final Folder folder, final Session session) throws FolderException {
         try {
-            return new CreatePerformer(new ServerSessionAdapter(session)).doCreate(folder);
+            final CreatePerformer createPerformer = new CreatePerformer(ServerSessionAdapter.valueOf(session));
+            return FolderResponseImpl.newFolderResponse(createPerformer.doCreate(folder), createPerformer.getStorageParameters().getWarnings());
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
@@ -132,20 +147,37 @@ public final class FolderServiceImpl implements FolderService {
 
     public void deleteFolder(final String treeId, final String folderId, final Date timeStamp, final Session session) throws FolderException {
         try {
-            new DeletePerformer(new ServerSessionAdapter(session)).doDelete(treeId, folderId, timeStamp);
+            new DeletePerformer(ServerSessionAdapter.valueOf(session)).doDelete(treeId, folderId, timeStamp);
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
     }
 
     public UserizedFolder getDefaultFolder(final User user, final String treeId, final ContentType contentType, final User ruser, final Context context, final FolderServiceDecorator decorator) throws FolderException {
-        // TODO Auto-generated method stub
-        return null;
+        final String folderId =
+            FolderStorageRegistry.getInstance().getFolderStorageByContentType(treeId, contentType).getDefaultFolderID(
+                user,
+                treeId,
+                contentType,
+                PrivateType.getInstance(),
+                new StorageParametersImpl(user, context));
+        return new GetPerformer(user, context, decorator).doGet(treeId, folderId);
     }
 
     public UserizedFolder getDefaultFolder(final User user, final String treeId, final ContentType contentType, final Session session, final FolderServiceDecorator decorator) throws FolderException {
-        // TODO Auto-generated method stub
-        return null;
+        try {
+            final ServerSession serverSession = ServerSessionAdapter.valueOf(session);
+            final String folderId =
+                FolderStorageRegistry.getInstance().getFolderStorageByContentType(treeId, contentType).getDefaultFolderID(
+                    serverSession.getUser(),
+                    treeId,
+                    contentType,
+                    PrivateType.getInstance(),
+                    new StorageParametersImpl(serverSession));
+            return new GetPerformer(serverSession, decorator).doGet(treeId, folderId);
+        } catch (final ContextException e) {
+            throw new FolderException(e);
+        }
     }
 
     public UserizedFolder getFolder(final String treeId, final String folderId, final User user, final Context context, final FolderServiceDecorator decorator) throws FolderException {
@@ -154,7 +186,7 @@ public final class FolderServiceImpl implements FolderService {
 
     public UserizedFolder getFolder(final String treeId, final String folderId, final Session session, final FolderServiceDecorator decorator) throws FolderException {
         try {
-            return new GetPerformer(new ServerSessionAdapter(session), decorator).doGet(treeId, folderId);
+            return new GetPerformer(ServerSessionAdapter.valueOf(session), decorator).doGet(treeId, folderId);
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
@@ -167,7 +199,7 @@ public final class FolderServiceImpl implements FolderService {
 
     public FolderResponse<UserizedFolder[]> getAllVisibleFolders(final String treeId, final FolderFilter filter, final Session session, final FolderServiceDecorator decorator) throws FolderException {
         try {
-            final AllVisibleFoldersPerformer performer = new AllVisibleFoldersPerformer(new ServerSessionAdapter(session), decorator);
+            final AllVisibleFoldersPerformer performer = new AllVisibleFoldersPerformer(ServerSessionAdapter.valueOf(session), decorator);
             return FolderResponseImpl.newFolderResponse(performer.doAllVisibleFolders(treeId, filter), performer.getWarnings());
         } catch (final ContextException e) {
             throw new FolderException(e);
@@ -181,13 +213,27 @@ public final class FolderServiceImpl implements FolderService {
 
     public FolderResponse<UserizedFolder[]> getPath(final String treeId, final String folderId, final Session session, final FolderServiceDecorator decorator) throws FolderException {
         try {
-            final PathPerformer performer = new PathPerformer(new ServerSessionAdapter(session), decorator);
+            final PathPerformer performer = new PathPerformer(ServerSessionAdapter.valueOf(session), decorator);
             return FolderResponseImpl.newFolderResponse(performer.doPath(treeId, folderId, true), performer.getWarnings());
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
     }
 
+    public FolderResponse<UserizedFolder[]> getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final boolean all, final User user, final Context context, final FolderServiceDecorator decorator) throws FolderException {
+        final VisibleFoldersPerformer performer = new VisibleFoldersPerformer(user, context, decorator);
+        return FolderResponseImpl.newFolderResponse(performer.doVisibleFolders(treeId, contentType, type, all), performer.getWarnings());
+    }
+
+    public FolderResponse<UserizedFolder[]> getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final boolean all, final Session session, final FolderServiceDecorator decorator) throws FolderException {
+        try {
+            final VisibleFoldersPerformer performer = new VisibleFoldersPerformer(ServerSessionAdapter.valueOf(session), decorator);
+            return FolderResponseImpl.newFolderResponse(performer.doVisibleFolders(treeId, contentType, type, all), performer.getWarnings());
+        } catch (final ContextException e) {
+            throw new FolderException(e);
+        }
+    }
+
     public FolderResponse<UserizedFolder[]> getSubfolders(final String treeId, final String parentId, final boolean all, final User user, final Context context, final FolderServiceDecorator decorator) throws FolderException {
         final ListPerformer listPerformer = new ListPerformer(user, context, decorator);
         return FolderResponseImpl.newFolderResponse(listPerformer.doList(treeId, parentId, all), listPerformer.getWarnings());
@@ -195,7 +241,7 @@ public final class FolderServiceImpl implements FolderService {
 
     public FolderResponse<UserizedFolder[]> getSubfolders(final String treeId, final String parentId, final boolean all, final Session session, final FolderServiceDecorator decorator) throws FolderException {
         try {
-            final ListPerformer listPerformer = new ListPerformer(new ServerSessionAdapter(session), decorator);
+            final ListPerformer listPerformer = new ListPerformer(ServerSessionAdapter.valueOf(session), decorator);
             return FolderResponseImpl.newFolderResponse(listPerformer.doList(treeId, parentId, all), listPerformer.getWarnings());
         } catch (final ContextException e) {
             throw new FolderException(e);
@@ -211,7 +257,7 @@ public final class FolderServiceImpl implements FolderService {
 
     public FolderResponse<UserizedFolder[][]> getUpdates(final String treeId, final Date timeStamp, final boolean ignoreDeleted, final ContentType[] includeContentTypes, final Session session, final FolderServiceDecorator decorator) throws FolderException {
         try {
-            final UpdatesPerformer performer = new UpdatesPerformer(new ServerSessionAdapter(session), decorator);
+            final UpdatesPerformer performer = new UpdatesPerformer(ServerSessionAdapter.valueOf(session), decorator);
             return FolderResponseImpl.newFolderResponse(
                 performer.doUpdates(treeId, timeStamp, ignoreDeleted, includeContentTypes),
                 performer.getWarnings());
@@ -220,24 +266,48 @@ public final class FolderServiceImpl implements FolderService {
         }
     }
 
-    public void subscribeFolder(final String sourceTreeId, final String folderId, final String targetTreeId, final String targetParentId, final User user, final Context context) throws FolderException {
-        // TODO Auto-generated method stub
-
+    public void subscribeFolder(final String sourceTreeId, final String folderId, final String targetTreeId, final String optTargetParentId, final User user, final Context context) throws FolderException {
+        if (!FolderStorage.REAL_TREE_ID.equals(sourceTreeId)) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Subscribe only supported for real tree as source tree.");
+        }
+        if (KNOWN_TREES.contains(optTargetParentId)) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Subscribe not supported for known trees.");
+        }
+        new SubscribePerformer(user, context).doSubscribe(sourceTreeId, folderId, targetTreeId, optTargetParentId);
     }
 
-    public void subscribeFolder(final String sourceTreeId, final String folderId, final String targetTreeId, final String targetParentId, final Session session) throws FolderException {
-        // TODO Auto-generated method stub
+    private static final Set<String> KNOWN_TREES = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList(FolderStorage.REAL_TREE_ID, OutlookFolderStorage.OUTLOOK_TREE_ID)));
 
+    public void subscribeFolder(final String sourceTreeId, final String folderId, final String targetTreeId, final String optTargetParentId, final Session session) throws FolderException {
+        try {
+            if (!FolderStorage.REAL_TREE_ID.equals(sourceTreeId)) {
+                throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Subscribe only supported for real tree as source tree.");
+            }
+            if (KNOWN_TREES.contains(targetTreeId)) {
+                throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Subscribe not supported for known trees.");
+            }
+            new SubscribePerformer(ServerSessionAdapter.valueOf(session)).doSubscribe(sourceTreeId, folderId, targetTreeId, optTargetParentId);
+        } catch (final ContextException e) {
+            throw new FolderException(e);
+        }
     }
 
     public void unsubscribeFolder(final String treeId, final String folderId, final User user, final Context context) throws FolderException {
-        // TODO Auto-generated method stub
-
+        if (KNOWN_TREES.contains(treeId)) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Unsubscribe not supported for known trees.");
+        }
+        new UnsubscribePerformer(user, context).doUnsubscribe(treeId, folderId);
     }
 
     public void unsubscribeFolder(final String treeId, final String folderId, final Session session) throws FolderException {
-        // TODO Auto-generated method stub
-
+        try {
+            if (KNOWN_TREES.contains(treeId)) {
+                throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Unsubscribe not supported for known trees.");
+            }
+            new UnsubscribePerformer(ServerSessionAdapter.valueOf(session)).doUnsubscribe(treeId, folderId);
+        } catch (final ContextException e) {
+            throw new FolderException(e);
+        }
     }
 
     public void updateFolder(final Folder folder, final Date timeStamp, final User user, final Context context) throws FolderException {
@@ -246,7 +316,7 @@ public final class FolderServiceImpl implements FolderService {
 
     public void updateFolder(final Folder folder, final Date timeStamp, final Session session) throws FolderException {
         try {
-            new UpdatePerformer(new ServerSessionAdapter(session)).doUpdate(folder, timeStamp);
+            new UpdatePerformer(ServerSessionAdapter.valueOf(session)).doUpdate(folder, timeStamp);
         } catch (final ContextException e) {
             throw new FolderException(e);
         }
