@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,7 @@
 
 package com.openexchange.folderstorage.internal;
 
-import gnu.trove.TIntIntHashMap;
+import gnu.trove.map.hash.TIntIntHashMap;
 import java.util.TimeZone;
 import java.util.concurrent.Callable;
 import java.util.concurrent.CancellationException;
@@ -62,7 +62,7 @@ import com.openexchange.folderstorage.Permission;
 
 /**
  * {@link Tools} - A utility class for folder storage processing.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Tools {
@@ -78,7 +78,7 @@ public final class Tools {
 
     /**
      * Gets the <code>TimeZone</code> for the given ID.
-     * 
+     *
      * @param timeZoneID The ID for a <code>TimeZone</code>, either an abbreviation such as "PST", a full name such as
      *            "America/Los_Angeles", or a custom ID such as "GMT-8:00".
      * @return The specified <code>TimeZone</code>, or the GMT zone if the given ID cannot be understood.
@@ -131,7 +131,7 @@ public final class Tools {
 
     /**
      * Parses a positive <code>int</code> value from passed {@link String} instance.
-     * 
+     *
      * @param s The string to parse
      * @return The parsed positive <code>int</code> value or <code>-1</code> if parsing failed
      */
@@ -185,7 +185,7 @@ public final class Tools {
 
     /**
      * Calculates the bits from given permission.
-     * 
+     *
      * @param perm The permission
      * @return The bits calculated from given permission
      */
@@ -216,7 +216,7 @@ public final class Tools {
 
     /**
      * Calculates the bits from given permissions.
-     * 
+     *
      * @param fp The folder permission
      * @param rp The read permission
      * @param wp The write permission
