@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,24 @@
 
 package com.openexchange.folderstorage.internal;
 
+import java.util.Collections;
 import java.util.Date;
 import java.util.Locale;
+import java.util.Map;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
+import com.openexchange.folderstorage.FolderExtension;
+import com.openexchange.folderstorage.FolderField;
+import com.openexchange.folderstorage.FolderProperty;
+import com.openexchange.folderstorage.ParameterizedFolder;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
+import com.openexchange.i18n.LocaleTools;
 
 /**
  * {@link UserizedFolderImpl} - The {@link UserizedFolder} implementation.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UserizedFolderImpl implements UserizedFolder {
@@ -78,9 +85,25 @@ public final class UserizedFolderImpl implements UserizedFolder {
 
     private Integer defaultType;
 
+    private Type type;
+
+    private Permission[] permissions;
+
+    private String[] subfolderIds;
+
+    private String parentId;
+
+    private Date creationDate;
+
+    private Date lastModified;
+
+    private volatile Map<FolderField, FolderProperty> properties;
+
+    private int[] totalAndUnread;
+
     /**
      * Initializes a new {@link UserizedFolderImpl} from specified folder.
-     * 
+     *
      * @param folder The underlying folder
      * @throws IllegalArgumentException If folder is <code>null</code>
      */
@@ -103,7 +126,7 @@ public final class UserizedFolderImpl implements UserizedFolder {
         try {
             final UserizedFolderImpl clone = (UserizedFolderImpl) super.clone();
             clone.folder = (Folder) clone.folder.clone();
-            clone.ownPermission = (Permission) clone.ownPermission.clone();
+            clone.ownPermission = ownPermission == null ? null : (Permission) ownPermission.clone();
             clone.lastModifiedUTC = null == lastModifiedUTC ? null : new Date(lastModifiedUTC.getTime());
             clone.locale = (Locale) (null == locale ? null : locale.clone());
             return clone;
@@ -125,11 +148,11 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public Date getCreationDate() {
-        return folder.getCreationDate();
+        return creationDate == null ? folder.getCreationDate() : creationDate;
     }
 
     public Date getLastModified() {
-        return folder.getLastModified();
+        return lastModified == null ? folder.getLastModified() : lastModified;
     }
 
     public int getModifiedBy() {
@@ -141,11 +164,11 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public void setCreationDate(final Date creationDate) {
-        folder.setCreationDate(creationDate);
+        this.creationDate = creationDate == null ? null : new Date(creationDate.getTime());
     }
 
     public void setLastModified(final Date lastModified) {
-        folder.setLastModified(lastModified);
+        this.lastModified = lastModified == null ? null : new Date(lastModified.getTime());
     }
 
     public void setModifiedBy(final int modifiedBy) {
@@ -161,7 +184,7 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public String getLocalizedName(final Locale locale) {
-        return folder.getLocalizedName(locale);
+        return folder.getLocalizedName(null == locale ? LocaleTools.DEFAULT_LOCALE : locale);
     }
 
     public String getName() {
@@ -169,15 +192,15 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public String getParentID() {
-        return folder.getParentID();
+        return null == parentId ? folder.getParentID() : parentId;
     }
 
     public Permission[] getPermissions() {
-        return folder.getPermissions();
+        return null == permissions ? folder.getPermissions() : permissions;
     }
 
     public String[] getSubfolderIDs() {
-        return folder.getSubfolderIDs();
+        return subfolderIds == null ? folder.getSubfolderIDs() : subfolderIds;
     }
 
     public String getTreeID() {
@@ -185,7 +208,7 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public Type getType() {
-        return folder.getType();
+        return null == type ? folder.getType() : type;
     }
 
     public boolean isCacheable() {
@@ -221,15 +244,15 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public void setParentID(final String parentId) {
-        folder.setParentID(parentId);
+        this.parentId = parentId;
     }
 
     public void setPermissions(final Permission[] permissions) {
-        folder.setPermissions(permissions);
+        this.permissions = permissions;
     }
 
     public void setSubfolderIDs(final String[] subfolderIds) {
-        folder.setSubfolderIDs(subfolderIds);
+        this.subfolderIds = subfolderIds;
     }
 
     public void setSubscribed(final boolean subscribed) {
@@ -245,7 +268,7 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public void setType(final Type type) {
-        folder.setType(type);
+        this.type = type;
     }
 
     public Permission getOwnPermission() {
@@ -281,10 +304,30 @@ public final class UserizedFolderImpl implements UserizedFolder {
     }
 
     public int getTotal() {
+        if (null == totalAndUnread) {
+            if (folder instanceof FolderExtension) {
+                totalAndUnread = ((FolderExtension) folder).getTotalAndUnread();
+                if (null != totalAndUnread) {
+                    return totalAndUnread[0];
+                }
+            }
+        } else {
+            return totalAndUnread[0];
+        }
         return folder.getTotal();
     }
 
     public int getUnread() {
+        if (null == totalAndUnread) {
+            if (folder instanceof FolderExtension) {
+                totalAndUnread = ((FolderExtension) folder).getTotalAndUnread();
+                if (null != totalAndUnread) {
+                    return totalAndUnread[1];
+                }
+            }
+        } else {
+            return totalAndUnread[1];
+        }
         return folder.getUnread();
     }
 
@@ -344,4 +387,27 @@ public final class UserizedFolderImpl implements UserizedFolder {
         throw new UnsupportedOperationException("UserizedFolderImpl.setNewID()");
     }
 
+    public void setProperty(final FolderField name, final Object value) {
+        // Nope...
+    }
+
+    public Map<FolderField, FolderProperty> getProperties() {
+        Map<FolderField, FolderProperty> map = this.properties;
+        if (null == map) {
+            synchronized (this) {
+                map = this.properties;
+                if (null == map) {
+                    if (folder instanceof ParameterizedFolder) {
+                        final ParameterizedFolder parameterizedFolder = (ParameterizedFolder) folder;
+                        map = parameterizedFolder.getProperties();
+                    } else {
+                        map = Collections.emptyMap();
+                    }
+                    this.properties = map;
+                }
+            }
+        }
+        return map;
+    }
+
 }
