@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,6 @@
 
 package com.openexchange.folderstorage.internal.performers;
 
-import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.Locale;
@@ -66,23 +65,25 @@ import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.internal.CalculatePermission;
-import com.openexchange.folderstorage.internal.Tools;
 import com.openexchange.folderstorage.internal.UserizedFolderImpl;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link AbstractUserizedFolderPerformer} - Abstract super class for actions which return one or multiple instances of
  * {@link UserizedFolder}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer {
 
+    private static final String DUMMY_ID = "dummyId";
+
     private final FolderServiceDecorator decorator;
 
     private volatile TimeZone timeZone;
@@ -93,7 +94,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Initializes a new {@link AbstractUserizedFolderPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      */
@@ -105,7 +106,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Initializes a new {@link AbstractUserizedFolderPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -118,7 +119,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Initializes a new {@link AbstractUserizedFolderPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -131,7 +132,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Initializes a new {@link AbstractUserizedFolderPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -145,7 +146,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Gets the optional folder service decorator.
-     * 
+     *
      * @return The folder service decorator or <code>null</code>
      */
     protected FolderServiceDecorator getDecorator() {
@@ -157,7 +158,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
      * <p>
      * If a {@link FolderServiceDecorator decorator} was set and its {@link FolderServiceDecorator#getTimeZone() getTimeZone()} method
      * returns a non-<code>null</code> value, then decorator's time zone is returned; otherwise user's time zone is returned.
-     * 
+     *
      * @return The time zone
      */
     protected TimeZone getTimeZone() {
@@ -167,7 +168,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
                 tmp = timeZone;
                 if (null == tmp) {
                     final TimeZone tz = null == decorator ? null : decorator.getTimeZone();
-                    timeZone = tmp = (tz == null ? Tools.getTimeZone(getUser().getTimeZone()) : tz);
+                    timeZone = tmp = (tz == null ? TimeZoneUtils.getTimeZone(getUser().getTimeZone()) : tz);
                 }
             }
         }
@@ -179,7 +180,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
      * <p>
      * If a {@link FolderServiceDecorator decorator} was set and its {@link FolderServiceDecorator#getLocale() getLocale()} method returns a
      * non-<code>null</code> value, then decorator's locale is returned; otherwise user's locale is returned.
-     * 
+     *
      * @return The locale
      */
     protected Locale getLocale() {
@@ -198,7 +199,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Gets the allowed content types.
-     * 
+     *
      * @return The allowed content types
      */
     protected java.util.List<ContentType> getAllowedContentTypes() {
@@ -216,7 +217,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
 
     /**
      * Gets the user-sensitive folder for given folder.
-     * 
+     *
      * @param folder The folder
      * @param ownPermission The user's permission on given folder
      * @param treeId The tree identifier
@@ -229,24 +230,66 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
      * @throws FolderException If a folder error occurs
      */
     protected UserizedFolder getUserizedFolder(final Folder folder, final Permission ownPermission, final String treeId, final boolean all, final boolean nullIsPublicAccess, final StorageParameters storageParameters, final java.util.Collection<FolderStorage> openedStorages) throws FolderException {
-        final UserizedFolder userizedFolder = new UserizedFolderImpl(folder);
+        return getUserizedFolder(folder, ownPermission, treeId, all, nullIsPublicAccess, storageParameters, openedStorages, false);
+    }
+
+    /**
+     * Gets the user-sensitive folder for given folder.
+     *
+     * @param folder The folder
+     * @param ownPermission The user's permission on given folder
+     * @param treeId The tree identifier
+     * @param all <code>true</code> to add all subfolders; otherwise <code>false</code> to only add subscribed ones
+     * @param nullIsPublicAccess <code>true</code> if a <code>null</code> value obtained from {@link Folder#getSubfolderIDs()} hints to
+     *            publicly accessible folder; otherwise <code>false</code>
+     * @param storageParameters The storage parameters to use
+     * @param openedStorages The list of opened storages
+     * @return The user-sensitive folder for given folder
+     * @throws FolderException If a folder error occurs
+     */
+    protected UserizedFolder getUserizedFolder(final Folder folder, final Permission ownPermission, final String treeId, final boolean all, final boolean nullIsPublicAccess, final StorageParameters storageParameters, final java.util.Collection<FolderStorage> openedStorages, final boolean checkOnly) throws FolderException {
+        Folder f = folder;
+        final UserizedFolder userizedFolder;
         /*-
-         * 
-        if (folder.isGlobalID()) {
-            // Set default folder flag
-            final String id = folder.getID();
-            final FolderStorage folderStorage = getOpenedStorage(id, treeId, storageParameters, openedStorages);
-            final ContentType contentType = folder.getContentType();
-            if (id.equals(folderStorage.getDefaultFolderID(getUser(), treeId, contentType, storageParameters))) {
-                // Default folder of current user
-                userizedFolder.setDefault(true);
-                userizedFolder.setDefaultType(contentType.getModule());
-            } else {
-                // Not a default folder
+         * Type
+         *
+         * Create user-sensitive folder dependent on shared flag
+         */
+        final boolean isShared;
+        {
+            final int createdBy = f.getCreatedBy();
+            final Type type = f.getType();
+            if (SharedType.getInstance().equals(type)) {
+                userizedFolder = new UserizedFolderImpl(f);
                 userizedFolder.setDefault(false);
-                userizedFolder.setDefaultType(0);
+                isShared = true;
+            } else if ((createdBy >= 0) && (createdBy != getUserId()) && PrivateType.getInstance().equals(type)) {
+                /*
+                 * Prepare
+                 */
+                final FolderStorage curStorage = folderStorageDiscoverer.getFolderStorage(treeId, f.getID());
+                boolean alreadyOpened = false;
+                final Iterator<FolderStorage> it = openedStorages.iterator();
+                for (int j = 0; !alreadyOpened && j < openedStorages.size(); j++) {
+                    if (it.next().equals(curStorage)) {
+                        alreadyOpened = true;
+                    }
+                }
+                if (!alreadyOpened && curStorage.startTransaction(storageParameters, false)) {
+                    openedStorages.add(curStorage);
+                }
+                f = curStorage.prepareFolder(treeId, f, storageParameters);
+                userizedFolder = new UserizedFolderImpl(f);
+                userizedFolder.setDefault(false);
+                userizedFolder.setType(SharedType.getInstance());
+                isShared = true;
+            } else {
+                userizedFolder = new UserizedFolderImpl(f);
+                isShared = false;
             }
         }
+        /*
+         * Set locale
          */
         userizedFolder.setLocale(getLocale());
         /*
@@ -255,53 +298,45 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
         userizedFolder.setOwnPermission(ownPermission);
         CalculatePermission.calculateUserPermissions(userizedFolder, getContext());
         /*
-         * Type
+         * Check parent
          */
-        final boolean isShared;
-        {
-            final Type type = userizedFolder.getType();
-            if (SharedType.getInstance().equals(type) || userizedFolder.getCreatedBy() != getUserId() && PrivateType.getInstance().equals(
-                type)) {
-                userizedFolder.setType(SharedType.getInstance());
-                userizedFolder.setSubfolderIDs(new String[0]);
-                isShared = true;
-            } else {
-                isShared = false;
-            }
-        }
-        // Modify parent
-        if (isShared) {
-            // Remain tree if parent is viewable, too.
-            final FolderStorage parentStorage = getOpenedStorage(treeId, folder.getParentID(), storageParameters, openedStorages);
-            final Folder parent = parentStorage.getFolder(treeId, folder.getParentID(), storageParameters);
-            final Permission permission = CalculatePermission.calculate(parent, session, getAllowedContentTypes());
-            if (!permission.isVisible()) {
-                userizedFolder.setParentID(FolderObject.SHARED_PREFIX + FolderObject.SYSTEM_SHARED_FOLDER_ID);
-            }
-            userizedFolder.setDefault(false);
+        if (userizedFolder.getID().startsWith(FolderObject.SHARED_PREFIX)) {
+            userizedFolder.setParentID(FolderStorage.SHARED_ID);
         }
         /*
          * Time zone offset and last-modified in UTC
          */
         {
-            final Date cd = folder.getCreationDate();
+            final Date cd = f.getCreationDate();
             if (null != cd) {
                 userizedFolder.setCreationDate(new Date(addTimeZoneOffset(cd.getTime(), getTimeZone())));
             }
         }
         {
-            final Date lm = folder.getLastModified();
+            final Date lm = f.getLastModified();
             if (null != lm) {
                 final long time = lm.getTime();
                 userizedFolder.setLastModified(new Date(addTimeZoneOffset(time, getTimeZone())));
                 userizedFolder.setLastModifiedUTC(new Date(time));
             }
         }
-        if (!isShared) {
-            /*
-             * Compute user-sensitive subfolders
-             */
-            hasVisibleSubfolderIDs(folder, treeId, all, userizedFolder, nullIsPublicAccess, storageParameters, openedStorages);
+        if (!checkOnly) {
+            if (isShared) {
+                /*
+                 * Subfolders already calculated for user
+                 */
+                final String[] visibleSubfolders = f.getSubfolderIDs();
+                if (null == visibleSubfolders) {
+                    userizedFolder.setSubfolderIDs(nullIsPublicAccess ? new String[] { DUMMY_ID } : new String[0]);
+                } else {
+                    userizedFolder.setSubfolderIDs(visibleSubfolders);
+                }
+            } else {
+                /*
+                 * Compute user-visible subfolders
+                 */
+                hasVisibleSubfolderIDs(f, treeId, all, userizedFolder, nullIsPublicAccess, storageParameters, openedStorages);
+            }
         }
         return userizedFolder;
     }
@@ -311,20 +346,20 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
          * Subfolders
          */
         final String[] subfolders = folder.getSubfolderIDs();
-        final java.util.List<String> visibleSubfolderIds = new ArrayList<String>(1);
+        String dummyId = null;
         if (null == subfolders) {
             if (nullIsPublicAccess) {
                 /*
                  * A null value hints to a special folder; e.g. a system folder which contains subfolder for all users
                  */
-                visibleSubfolderIds.add("dummyId");
+                dummyId = DUMMY_ID;
             } else {
                 /*
                  * Get appropriate storages and start transaction
                  */
                 final String folderId = folder.getID();
                 final FolderStorage[] ss = folderStorageDiscoverer.getFolderStoragesForParent(treeId, folderId);
-                for (int i = 0; visibleSubfolderIds.isEmpty() && i < ss.length; i++) {
+                for (int i = 0; (null == dummyId) && i < ss.length; i++) {
                     final FolderStorage curStorage = ss[i];
                     boolean alreadyOpened = false;
                     final Iterator<FolderStorage> it = openedStorages.iterator();
@@ -333,8 +368,7 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
                             alreadyOpened = true;
                         }
                     }
-                    if (!alreadyOpened) {
-                        curStorage.startTransaction(storageParameters, false);
+                    if (!alreadyOpened && curStorage.startTransaction(storageParameters, false)) {
                         openedStorages.add(curStorage);
                     }
                     final SortableId[] visibleIds = curStorage.getSubfolders(treeId, folderId, storageParameters);
@@ -342,13 +376,13 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
                         /*
                          * Found a storage which offers visible subfolder(s)
                          */
-                        for (int j = 0; visibleSubfolderIds.isEmpty() && j < visibleIds.length; j++) {
+                        for (int j = 0; (null == dummyId) && j < visibleIds.length; j++) {
                             final String id = visibleIds[0].getId();
                             final Folder subfolder = curStorage.getFolder(treeId, id, storageParameters);
                             if (all || (subfolder.isSubscribed() || subfolder.hasSubscribedSubfolders())) {
                                 final Permission p = CalculatePermission.calculate(subfolder, session, getAllowedContentTypes());
                                 if (p.isVisible()) {
-                                    visibleSubfolderIds.add(id);
+                                    dummyId = id;
                                 }
                             }
                         }
@@ -359,31 +393,26 @@ public abstract class AbstractUserizedFolderPerformer extends AbstractPerformer
             final int length = subfolders.length;
             if (length > 0) {
                 /*
-                 * Check until first visible subfolder found
+                 * Check until a visible subfolder is found in case of a global folder
                  */
-                for (int i = 0; visibleSubfolderIds.isEmpty() && i < length; i++) {
-                    final String id = subfolders[i];
-                    final FolderStorage tmp = getOpenedStorage(id, treeId, storageParameters, openedStorages);
-                    /*
-                     * Get subfolder from appropriate storage
-                     */
-                    final Folder subfolder = tmp.getFolder(treeId, id, storageParameters);
-                    /*
-                     * Check for access rights and subscribed status dependent on parameter "all"
-                     */
-                    final Permission subfolderPermission;
-                    if (null == getSession()) {
-                        subfolderPermission = CalculatePermission.calculate(subfolder, getUser(), getContext(), getAllowedContentTypes());
-                    } else {
-                        subfolderPermission = CalculatePermission.calculate(subfolder, getSession(), getAllowedContentTypes());
-                    }
-                    if (subfolderPermission.isVisible() && (all || (subfolder.isSubscribed() || subfolder.hasSubscribedSubfolders()))) {
-                        visibleSubfolderIds.add(id);
+                if (folder.isGlobalID()) {
+                    for (int i = 0; (null == dummyId) && i < length; i++) {
+                        final String id = subfolders[i];
+                        final FolderStorage tmp = getOpenedStorage(id, treeId, storageParameters, openedStorages);
+                        /*
+                         * Get subfolder from appropriate storage
+                         */
+                        final Folder subfolder = tmp.getFolder(treeId, id, storageParameters);
+                        if ((all || (subfolder.isSubscribed() || subfolder.hasSubscribedSubfolders())) && CalculatePermission.isVisible(subfolder, getUser(), getContext(), getAllowedContentTypes())) {
+                            dummyId = id;
+                        }
                     }
+                } else if (all || folder.hasSubscribedSubfolders()) { // User-only folder
+                    dummyId = DUMMY_ID;
                 }
             }
         }
-        userizedFolder.setSubfolderIDs(visibleSubfolderIds.isEmpty() ? new String[0] : new String[] { visibleSubfolderIds.get(0) });
+        userizedFolder.setSubfolderIDs((null == dummyId) ? new String[0] : new String[] { dummyId });
     }
 
     private static long addTimeZoneOffset(final long date, final TimeZone timeZone) {
