@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,8 @@
 package com.openexchange.folderstorage.internal.performers;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
-import java.util.Locale;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
@@ -60,24 +60,38 @@ import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.SortableId;
+import com.openexchange.folderstorage.database.contentType.InfostoreContentType;
 import com.openexchange.folderstorage.internal.CalculatePermission;
+import com.openexchange.folderstorage.mail.contentType.MailContentType;
+import com.openexchange.folderstorage.outlook.DuplicateCleaner;
+import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
 import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.utils.MailFolderUtility;
+import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link CreatePerformer} - Serves the <code>CREATE</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CreatePerformer extends AbstractPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CreatePerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CreatePerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
+
+    private static final String CONTENT_TYPE_MAIL = MailContentType.getInstance().toString();
+
+    private static final String CONTENT_TYPE_INFOSTORE = InfostoreContentType.getInstance().toString();
 
     /**
      * Initializes a new {@link CreatePerformer}.
-     * 
+     *
      * @param session The session
      */
     public CreatePerformer(final ServerSession session) {
@@ -86,7 +100,7 @@ public final class CreatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link CreatePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      */
@@ -96,7 +110,7 @@ public final class CreatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link CreatePerformer}.
-     * 
+     *
      * @param session The session
      * @param folderStorageDiscoverer The folder storage discoverer
      */
@@ -106,7 +120,7 @@ public final class CreatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link CreatePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -117,7 +131,7 @@ public final class CreatePerformer extends AbstractPerformer {
 
     /**
      * Performs the <code>CREATE</code> request.
-     * 
+     *
      * @param toCreate The object describing the folder to create
      * @throws FolderException If creation fails
      */
@@ -126,18 +140,20 @@ public final class CreatePerformer extends AbstractPerformer {
         if (null == parentId) {
             throw FolderExceptionErrorMessage.MISSING_PARENT_ID.create(new Object[0]);
         }
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         final String treeId = toCreate.getTreeID();
         if (null == treeId) {
             throw FolderExceptionErrorMessage.MISSING_TREE_ID.create(new Object[0]);
         }
+        if (!KNOWN_TREES.contains(treeId)) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Create not supported by tree " + treeId);
+        }
         final FolderStorage parentStorage = folderStorageDiscoverer.getFolderStorage(treeId, parentId);
         if (null == parentStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, parentId);
         }
-        parentStorage.startTransaction(storageParameters, true);
         final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(parentStorage);
+        checkOpenedStorage(parentStorage, openedStorages);
         try {
             final Folder parent = parentStorage.getFolder(treeId, parentId, storageParameters);
             /*
@@ -151,13 +167,29 @@ public final class CreatePerformer extends AbstractPerformer {
             }
             if (!parentPermission.isVisible()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                    parentId,
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(parent),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
-            if ((FolderStorage.PUBLIC_ID.equals(parent.getID()) || PublicType.getInstance().equals(parent.getType())) && "mail".equals(toCreate.getContentType().toString())) {
+            final String cts = toCreate.getContentType().toString();
+            if ((FolderStorage.PUBLIC_ID.equals(parent.getID()) || PublicType.getInstance().equals(parent.getType())) && CONTENT_TYPE_MAIL.equals(
+                cts)) {
                 throw FolderExceptionErrorMessage.NO_PUBLIC_MAIL_FOLDER.create();
             }
+            /*
+             * Check for duplicates for OLOX-covered folders
+             */
+            if (!CONTENT_TYPE_INFOSTORE.equals(cts)) {
+                final Session session = storageParameters.getSession();
+                if (null == session) {
+                    checkForDuplicate(toCreate.getName(), treeId, parentId, openedStorages);
+                } else {
+                    final CheckForDuplicateResult result = getCheckForDuplicateResult(toCreate.getName(), treeId, parentId, openedStorages);
+                    if (null != result && null != result.optFolderId && "USM-JSON".equals(session.getClient())) {
+                        return result.optFolderId;
+                    }
+                }
+            }
             /*
              * Create folder dependent on folder is virtual or not
              */
@@ -170,7 +202,20 @@ public final class CreatePerformer extends AbstractPerformer {
             for (final FolderStorage folderStorage : openedStorages) {
                 folderStorage.commitTransaction(storageParameters);
             }
-            if (LOG.isDebugEnabled()) {
+            /*
+             * Sanity check
+             */
+            if (!FolderStorage.REAL_TREE_ID.equals(toCreate.getTreeID())) {
+                final String duplicateId = DuplicateCleaner.cleanDuplicates(treeId, storageParameters, newId);
+                if (null != duplicateId) {
+                    throw FolderExceptionErrorMessage.EQUAL_NAME.create(toCreate.getName(), parent.getLocalizedName(storageParameters.getUser().getLocale()), treeId);
+                    // return duplicateId;
+                }
+            }
+            /*
+             * Debug out
+             */
+            if (DEBUG_ENABLED) {
                 final long duration = System.currentTimeMillis() - start;
                 LOG.debug(new StringBuilder().append("Create.doCreate() took ").append(duration).append("msec for folder: ").append(newId).toString());
             }
@@ -193,8 +238,9 @@ public final class CreatePerformer extends AbstractPerformer {
         boolean supported = false;
         final ContentType folderContentType = toCreate.getContentType();
         if (0 < contentTypes.length) {
+            final String cts = folderContentType.toString();
             for (final ContentType contentType : contentTypes) {
-                if (contentType.equals(folderContentType)) {
+                if (contentType.toString().equals(cts)) {
                     supported = true;
                     break;
                 }
@@ -241,24 +287,6 @@ public final class CreatePerformer extends AbstractPerformer {
                 // TODO: Pass this one? final Folder created = realStorage.getFolder(treeId, toCreate.getID(), storageParameters);
                 virtualStorage.createFolder(toCreate, storageParameters);
             } else {
-                /*
-                 * Check for possible duplicate folder name
-                 */
-                {
-                    final SortableId[] checkMe = virtualStorage.getSubfolders(treeId, toCreate.getParentID(), storageParameters);
-                    final Locale locale = storageParameters.getUser().getLocale();
-                    for (final SortableId sortableId : checkMe) {
-                        final String localizedName =
-                            virtualStorage.getFolder(treeId, sortableId.getId(), storageParameters).getLocalizedName(locale);
-                        if (localizedName.equals(toCreate.getName())) {
-                            checkOpenedStorage(realStorage, openedStorages);
-                            throw FolderExceptionErrorMessage.EQUAL_NAME.create(toCreate.getName(), realStorage.getFolder(
-                                FolderStorage.REAL_TREE_ID,
-                                parentId,
-                                storageParameters).getLocalizedName(locale), treeId);
-                        }
-                    }
-                }
                 /*
                  * Find the real storage which is capable to create the folder
                  */
@@ -268,15 +296,66 @@ public final class CreatePerformer extends AbstractPerformer {
                     throw FolderExceptionErrorMessage.NO_STORAGE_FOR_CT.create(FolderStorage.REAL_TREE_ID, folderContentType.toString());
                 }
                 checkOpenedStorage(capStorage, openedStorages);
+                /*
+                 * Special handling for mail folders on root level
+                 */
+                if (FolderStorage.PRIVATE_ID.equals(parentId) && CONTENT_TYPE_MAIL.equals(folderContentType.toString())) {
+                    final String rootId = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
+                    /*
+                     * Check if create is allowed
+                     */
+                    final Permission rootPermission;
+                    {
+                        final Folder rootFolder = capStorage.getFolder(treeId, rootId, storageParameters);
+                        final List<ContentType> contentTypes = Collections.<ContentType> emptyList();
+                        if (null == getSession()) {
+                            rootPermission = CalculatePermission.calculate(rootFolder, getUser(), getContext(), contentTypes);
+                        } else {
+                            rootPermission = CalculatePermission.calculate(rootFolder, getSession(), contentTypes);
+                        }
+                    }
+                    if (rootPermission.getFolderPermission() >= Permission.CREATE_SUB_FOLDERS) {
+                        /*
+                         * Creation of subfolders is allowed
+                         */
+                        final Folder clone4Real = (Folder) toCreate.clone();
+                        clone4Real.setParentID(rootId);
+                        capStorage.createFolder(clone4Real, storageParameters);
+                        toCreate.setID(clone4Real.getID());
+                        /*
+                         * Update parent's last-modified time stamp
+                         */
+                        final boolean started = realStorage.startTransaction(storageParameters, true);
+                        try {
+                            realStorage.updateLastModified(System.currentTimeMillis(), FolderStorage.REAL_TREE_ID, parentId, storageParameters);
+                            if (started) {
+                                realStorage.commitTransaction(storageParameters);
+                            }
+                        } catch (final FolderException e) {
+                            if (started) {
+                                realStorage.rollback(storageParameters);
+                            }
+                            throw e;
+                        } catch (final Exception e) {
+                            if (started) {
+                                realStorage.rollback(storageParameters);
+                            }
+                            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+                        }
+                        OutlookFolderStorage.clearTCM();
+                        return toCreate.getID();
+                    }
+                }
                 /*
                  * 1. Create at default location in capable real storage
                  */
                 {
                     final String realParentId =
-                        capStorage.getDefaultFolderID(
+                        virtualStorage.getDefaultFolderID(
                             user,
-                            FolderStorage.REAL_TREE_ID,
+                            treeId,
                             null == folderContentType ? capStorage.getDefaultContentType() : folderContentType,
+                            virtualStorage.getTypeByParent(user, treeId, parentId, storageParameters),
                             storageParameters);
                     if (null == realParentId) {
                         /*
@@ -351,8 +430,9 @@ public final class CreatePerformer extends AbstractPerformer {
                 return;
             }
         }
-        storage.startTransaction(storageParameters, true);
-        openedStorages.add(storage);
+        if (storage.startTransaction(storageParameters, true)) {
+            openedStorages.add(storage);
+        }
     }
 
     private static boolean supportsContentType(final ContentType folderContentType, final FolderStorage folderStorage) {
@@ -363,8 +443,9 @@ public final class CreatePerformer extends AbstractPerformer {
         if (0 == supportedContentTypes.length) {
             return true;
         }
+        final String cts = folderContentType.toString();
         for (final ContentType supportedContentType : supportedContentTypes) {
-            if (supportedContentType.equals(folderContentType)) {
+            if (supportedContentType.toString().equals(cts)) {
                 return true;
             }
         }
