@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,6 +57,7 @@ import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
+import com.openexchange.folderstorage.FolderType;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.internal.CalculatePermission;
@@ -66,16 +67,18 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link DeletePerformer} - Serves the <code>DELETE</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DeletePerformer extends AbstractPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DeletePerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DeletePerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
 
     /**
      * Initializes a new {@link DeletePerformer}.
-     * 
+     *
      * @param session The session
      */
     public DeletePerformer(final ServerSession session) {
@@ -84,7 +87,7 @@ public final class DeletePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link DeletePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      */
@@ -94,7 +97,7 @@ public final class DeletePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link DeletePerformer}.
-     * 
+     *
      * @param session The session
      * @param folderStorageDiscoverer The folder storage discoverer
      */
@@ -104,7 +107,7 @@ public final class DeletePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link DeletePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -115,21 +118,23 @@ public final class DeletePerformer extends AbstractPerformer {
 
     /**
      * Performs the <code>DELETE</code> request.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param timeStamp The requestor's last-modified time stamp
      * @throws FolderException If an error occurs during deletion
      */
     public void doDelete(final String treeId, final String folderId, final Date timeStamp) throws FolderException {
+        if (!KNOWN_TREES.contains(treeId)) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create("Create not supported by tree " + treeId);
+        }
         final FolderStorage folderStorage = folderStorageDiscoverer.getFolderStorage(treeId, folderId);
         if (null == folderStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
         }
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
-        folderStorage.startTransaction(storageParameters, true);
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(folderStorage);
+        checkOpenedStorage(folderStorage, openedStorages);
         if (null != timeStamp) {
             storageParameters.setTimeStamp(timeStamp);
         }
@@ -142,7 +147,7 @@ public final class DeletePerformer extends AbstractPerformer {
             } else {
                 /*-
                  * Virtual delete:
-                 * 
+                 *
                  * 1. Delete from virtual storage
                  * 2. Delete from real storage
                  */
@@ -159,7 +164,7 @@ public final class DeletePerformer extends AbstractPerformer {
                     deleteVirtualFolder(folderId, treeId, folderStorage, openedStorages);
                 }
             }
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG_ENABLED) {
                 final long duration = System.currentTimeMillis() - start;
                 LOG.debug(new StringBuilder().append("Delete.doDelete() took ").append(duration).append("msec for folder: ").append(
                     folderId).toString());
@@ -185,6 +190,7 @@ public final class DeletePerformer extends AbstractPerformer {
 
     private void deleteVirtualFolder(final String folderId, final String treeId, final FolderStorage folderStorage, final List<FolderStorage> openedStorages) throws FolderException {
         final Folder folder = folderStorage.getFolder(treeId, folderId, storageParameters);
+        storageParameters.putParameter(FolderType.GLOBAL, "global", Boolean.valueOf(folder.isGlobalID()));
         {
             final Permission permission;
             if (null == getSession()) {
@@ -194,29 +200,29 @@ public final class DeletePerformer extends AbstractPerformer {
             }
             if (!permission.isVisible()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                    folder.getLocalizedName(session.getUser().getLocale()),
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(folder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
             if (!permission.isAdmin()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_DELETEABLE.create(
-                    folder.getLocalizedName(session.getUser().getLocale()),
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(folder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
             /*
              * Delete permissions
              */
             if (!canDeleteAllObjects(permission, folderId, treeId, folderStorage)) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_DELETEABLE.create(
-                    folderId,
-                    Integer.valueOf(user.getId()),
-                    Integer.valueOf(context.getContextId()));
+                    getFolderInfo4Error(folder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
         }
         final SortableId[] subfolders = folderStorage.getSubfolders(treeId, folderId, storageParameters);
-        for (int i = 0; i < subfolders.length; i++) {
-            final String id = subfolders[i].getId();
+        for (final SortableId subfolder : subfolders) {
+            final String id = subfolder.getId();
             final FolderStorage subfolderStorage;
             if (folderStorage.getFolderType().servesFolderId(id)) {
                 subfolderStorage = folderStorage;
@@ -273,8 +279,9 @@ public final class DeletePerformer extends AbstractPerformer {
                 return;
             }
         }
-        storage.startTransaction(storageParameters, true);
-        openedStorages.add(storage);
+        if (storage.startTransaction(storageParameters, true)) {
+            openedStorages.add(storage);
+        }
     }
 
 }
