@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,16 +65,18 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link GetPerformer} - Serves the <code>GET</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class GetPerformer extends AbstractUserizedFolderPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(GetPerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(GetPerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
 
     /**
      * Initializes a new {@link GetPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      */
@@ -84,7 +86,7 @@ public final class GetPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link GetPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -95,7 +97,7 @@ public final class GetPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link GetPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -106,7 +108,7 @@ public final class GetPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link GetPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -121,10 +123,11 @@ public final class GetPerformer extends AbstractUserizedFolderPerformer {
         if (null == folderStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
         }
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
-        folderStorage.startTransaction(storageParameters, false);
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         final java.util.List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(folderStorage);
+        if (folderStorage.startTransaction(storageParameters, false)) {
+            openedStorages.add(folderStorage);
+        }
         try {
             final Folder folder = folderStorage.getFolder(treeId, folderId, storageParameters);
             /*
@@ -138,14 +141,14 @@ public final class GetPerformer extends AbstractUserizedFolderPerformer {
             }
             if (!ownPermission.isVisible()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                    folderId,
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(folder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
             // TODO: All or only subscribed subfolders?
             final UserizedFolder userizedFolder =
                 getUserizedFolder(folder, ownPermission, treeId, true, true, storageParameters, openedStorages);
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG_ENABLED) {
                 final long duration = System.currentTimeMillis() - start;
                 LOG.debug(new StringBuilder().append("Get.doGet() took ").append(duration).append("msec for folder: ").append(folderId).toString());
             }
