@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,12 +51,14 @@ package com.openexchange.folderstorage.internal.performers;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import com.openexchange.folderstorage.AbstractFolder;
+import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
@@ -67,17 +69,25 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.internal.CalculatePermission;
+import com.openexchange.folderstorage.mail.contentType.MailContentType;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.utils.MailFolderUtility;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link MovePerformer} - Serves the <code>UPDATE</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class MovePerformer extends AbstractPerformer {
 
+    private static final String MAIL_DEFAULT_ID = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
+
+    private static final String MAIL = MailContentType.getInstance().toString();
+
     private static final class FolderInfo {
 
         final String id;
@@ -92,7 +102,7 @@ final class MovePerformer extends AbstractPerformer {
             super();
             this.id = id;
             this.name = name;
-            this.subfolders = new ArrayList<FolderInfo>();
+            subfolders = new ArrayList<FolderInfo>();
             subfoldersMap = new HashMap<String, FolderInfo>();
         }
 
@@ -131,9 +141,11 @@ final class MovePerformer extends AbstractPerformer {
         }
     }
 
+    private final String realTreeId = FolderStorage.REAL_TREE_ID;
+
     /**
      * Initializes a new {@link MovePerformer} from given session.
-     * 
+     *
      * @param session The session
      */
     MovePerformer(final ServerSession session) {
@@ -142,7 +154,7 @@ final class MovePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link MovePerformer} from given user-context-pair.
-     * 
+     *
      * @param user The user
      * @param context The context
      */
@@ -152,7 +164,7 @@ final class MovePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link MovePerformer}.
-     * 
+     *
      * @param session The session
      * @param folderStorageDiscoverer The folder storage discoverer
      */
@@ -162,7 +174,7 @@ final class MovePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link MovePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -186,11 +198,81 @@ final class MovePerformer extends AbstractPerformer {
             final Permission permission = effectivePermission(storageFolder);
             if (!permission.isAdmin()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_MOVEABLE.create(
-                    storageFolder.getLocalizedName(session.getUser().getLocale()),
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(storageFolder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
         }
+        /*
+         * Get subfolders
+         */
+        final FolderStorage realStorage = folderStorageDiscoverer.getFolderStorage(realTreeId, folder.getID());
+        if (null == realStorage) {
+            throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(realTreeId, folder.getID());
+        }
+        checkOpenedStorage(realStorage, openedStorages);
+        /*
+         * Special handling for mail folders on root level
+         */
+        boolean flag = true;
+        if (FolderStorage.PRIVATE_ID.equals(folder.getParentID()) && MAIL.equals(storageFolder.getContentType().toString())) {
+            /*
+             * Perform the move in real storage
+             */
+            final String rootId = MAIL_DEFAULT_ID;
+            /*
+             * Check if create is allowed
+             */
+            final Permission rootPermission;
+            {
+                final Folder rootFolder = realStorage.getFolder(realTreeId, rootId, storageParameters);
+                final List<ContentType> contentTypes = Collections.<ContentType> emptyList();
+                if (null == getSession()) {
+                    rootPermission = CalculatePermission.calculate(rootFolder, getUser(), getContext(), contentTypes);
+                } else {
+                    rootPermission = CalculatePermission.calculate(rootFolder, getSession(), contentTypes);
+                }
+            }
+            if (rootPermission.getFolderPermission() >= Permission.CREATE_SUB_FOLDERS) {
+                /*
+                 * Creation of subfolders is allowed
+                 */
+                final Folder clone4Real = (Folder) folder.clone();
+                clone4Real.setParentID(rootId);
+                clone4Real.setTreeID(realTreeId);
+                realStorage.updateFolder(clone4Real, storageParameters);
+                virtualStorage.deleteFolder(folder.getTreeID(), folder.getID(), storageParameters);
+                folder.setID(clone4Real.getID());
+                /*
+                 * Update parent's last-modified time stamp
+                 */
+                final boolean started = realStorage.startTransaction(storageParameters, true);
+                try {
+                    realStorage.updateLastModified(
+                        System.currentTimeMillis(),
+                        realTreeId,
+                        folder.getParentID(),
+                        storageParameters);
+                    if (started) {
+                        realStorage.commitTransaction(storageParameters);
+                    }
+                } catch (final FolderException e) {
+                    if (started) {
+                        realStorage.rollback(storageParameters);
+                    }
+                    throw e;
+                } catch (final Exception e) {
+                    if (started) {
+                        realStorage.rollback(storageParameters);
+                    }
+                    throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+                }
+                flag = false;
+            }
+        }
+        if (!flag) {
+            return;
+        }
         /*
          * Check permission on destination folder
          */
@@ -199,18 +281,14 @@ final class MovePerformer extends AbstractPerformer {
             final Permission permission = effectivePermission(destFolder);
             if (permission.getFolderPermission() < Permission.CREATE_SUB_FOLDERS) {
                 throw FolderExceptionErrorMessage.NO_CREATE_SUBFOLDERS.create(
-                    getUser().getDisplayName(),
-                    destFolder.getLocalizedName(session.getUser().getLocale()),
-                    Integer.valueOf(getContextId()));
+                    getUserInfo4Error(),
+                    getFolderInfo4Error(destFolder),
+                    getContextInfo4Error());
             }
         }
         /*
          * Get subfolders
          */
-        final FolderStorage realStorage = folderStorageDiscoverer.getFolderStorage(FolderStorage.REAL_TREE_ID, folder.getID());
-        if (null == realStorage) {
-            throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(FolderStorage.REAL_TREE_ID, folder.getID());
-        }
         final String oldParent = storageFolder.getParentID();
         if (virtualStorage.equals(realStorage)) {
             virtualStorage.updateFolder(folder, storageParameters);
@@ -223,45 +301,55 @@ final class MovePerformer extends AbstractPerformer {
             final boolean parentEquality = newRealParentStorage.equals(realParentStorage);
             if (destEquality) {
                 /*
-                 * Perform the move in virtual storage
+                 * Check presence in virtual tree
                  */
-                virtualStorage.updateFolder(folder, storageParameters);
-                /*
-                 * Remember previous virtual entries
-                 */
-                final String oldId = folder.getID();
-                final FolderInfo oldFolderInfo = new FolderInfo(oldId, storageFolder.getName());
+                final FolderInfo oldFolderInfo = new FolderInfo(folder.getID(), storageFolder.getName());
                 gatherSubfolders(treeId, oldFolderInfo, storageParameters, virtualStorage, true);
-                /*
-                 * Destination folder is compatible: Perform real move
-                 */
-                checkOpenedStorage(realStorage, openedStorages);
-                realStorage.updateFolder(folder, storageParameters);
-                final String newId = folder.getID();
-                if (!parentEquality) {
+                if (containsAny(folder.getTreeID(), oldFolderInfo, virtualStorage, storageParameters)) {
                     /*
-                     * Delete in virtual storage
+                     * Perform the move in virtual storage
                      */
-                    virtualStorage.deleteFolder(treeId, oldId, storageParameters);
-                }
-                /*
-                 * Generate map
-                 */
-                final FolderInfo newFolderInfo = new FolderInfo(newId, folder.getName());
-                gatherSubfolders(treeId, newFolderInfo, storageParameters, realStorage, false);
-                final Map<String, String> parentIDMap = generateParentIDMap(oldFolderInfo, newFolderInfo);
-                final Map<String, String> idMap = generateIDMap(oldFolderInfo, newFolderInfo);
-                for (final Entry<String, String> entry : parentIDMap.entrySet()) {
-                    final Folder up = new UpdateFolder();
-                    final String id = entry.getKey();
-                    up.setID(id);
-                    up.setParentID(entry.getValue());
-                    up.setTreeID(treeId);
-                    final String newIdent = idMap.get(id);
-                    if (null != newIdent) {
-                        up.setNewID(newIdent);
+                    virtualStorage.updateFolder(folder, storageParameters);
+                    /*
+                     * Remember previous virtual entries
+                     */
+                    final String oldId = folder.getID();
+                    /*
+                     * Destination folder is compatible: Perform real move
+                     */
+                    checkOpenedStorage(realStorage, openedStorages);
+                    realStorage.updateFolder(folder, storageParameters);
+                    final String newId = folder.getID();
+                    if (!parentEquality) {
+                        /*
+                         * Delete in virtual storage
+                         */
+                        virtualStorage.deleteFolder(treeId, oldId, storageParameters);
                     }
-                    virtualStorage.updateFolder(up, storageParameters);
+                    /*
+                     * Generate map
+                     */
+                    final FolderInfo newFolderInfo = new FolderInfo(newId, folder.getName());
+                    gatherSubfolders(treeId, newFolderInfo, storageParameters, realStorage, false);
+                    final Map<String, String> parentIDMap = generateParentIDMap(oldFolderInfo, newFolderInfo);
+                    final Map<String, String> idMap = generateIDMap(oldFolderInfo, newFolderInfo);
+                    for (final Entry<String, String> entry : parentIDMap.entrySet()) {
+                        final Folder up = new UpdateFolder();
+                        final String id = entry.getKey();
+                        up.setID(id);
+                        up.setParentID(entry.getValue());
+                        up.setTreeID(treeId);
+                        final String newIdent = idMap.get(id);
+                        if (null != newIdent) {
+                            up.setNewID(newIdent);
+                        }
+                        virtualStorage.updateFolder(up, storageParameters);
+                    }
+                } else {
+                    /*
+                     * There is nothing to change in virtual tree. Just delegate to to real folder storage
+                     */
+                    realStorage.updateFolder(folder, storageParameters);
                 }
                 /*
                  * Leave method
@@ -280,7 +368,7 @@ final class MovePerformer extends AbstractPerformer {
                 final Folder clone4Real = (Folder) folder.clone();
                 clone4Real.setName(nonExistingName(
                     clone4Real.getName(),
-                    FolderStorage.REAL_TREE_ID,
+                    realTreeId,
                     clone4Real.getParentID(),
                     openedStorages));
                 realStorage.updateFolder(clone4Real, storageParameters);
@@ -304,29 +392,53 @@ final class MovePerformer extends AbstractPerformer {
                  * Move to default location in real storage
                  */
                 checkOpenedStorage(realStorage, openedStorages);
-                final String defaultParentId =
-                    realStorage.getDefaultFolderID(user, FolderStorage.REAL_TREE_ID, realStorage.getDefaultContentType(), storageParameters);
-                if (null == defaultParentId) {
+                /*
+                 * Perform the move in virtual storage
+                 */
+                {
+                    final String defaultParentId =
+                        virtualStorage.getDefaultFolderID(
+                            user,
+                            treeId,
+                            realStorage.getDefaultContentType(),
+                            virtualStorage.getTypeByParent(user, treeId, folder.getParentID(), storageParameters),
+                            storageParameters);
+                    if (null == defaultParentId) {
+                        /*
+                         * No default folder found
+                         */
+                        throw FolderExceptionErrorMessage.NO_DEFAULT_FOLDER.create(
+                            realStorage.getDefaultContentType(),
+                            realTreeId);
+                    }
+                    // TODO: Check permission for obtained default folder ID?
                     /*
-                     * No default folder found
+                     * Is real folder already located below default folder localtion?
                      */
-                    throw FolderExceptionErrorMessage.NO_DEFAULT_FOLDER.create(
-                        realStorage.getDefaultContentType(),
-                        FolderStorage.REAL_TREE_ID);
-                }
-                // TODO: Check permission for obtained default folder ID?
-                final Folder clone4Real = (Folder) folder.clone();
-                clone4Real.setParentID(defaultParentId);
-                clone4Real.setName(nonExistingName(clone4Real.getName(), FolderStorage.REAL_TREE_ID, defaultParentId, openedStorages));
-                realStorage.updateFolder(clone4Real, storageParameters);
-                final String newId = clone4Real.getID();
-                if (null != newId) {
+                    final String realParentID =
+                        realStorage.getFolder(realTreeId, folder.getID(), storageParameters).getParentID();
+                    if (!defaultParentId.equals(realParentID)) {
+                        final Folder clone4Real = (Folder) folder.clone();
+                        clone4Real.setParentID(defaultParentId);
+                        clone4Real.setName(nonExistingName(
+                            clone4Real.getName(),
+                            realTreeId,
+                            defaultParentId,
+                            openedStorages));
+                        realStorage.updateFolder(clone4Real, storageParameters);
+                        final String newId = clone4Real.getID();
+                        if (null != newId) {
+                            /*
+                             * Perform the "move" in virtual storage
+                             */
+                            folder.setID(newId);
+                        }
+                    }
                     /*
                      * Perform the "move" in virtual storage
                      */
-                    folder.setID(newId);
+                    virtualStorage.createFolder(folder, storageParameters);
                 }
-                virtualStorage.createFolder(folder, storageParameters);
             } else {
                 /*
                  * (!parentChildEquality && !parentEquality) ?
@@ -352,9 +464,9 @@ final class MovePerformer extends AbstractPerformer {
                 final Permission permission = effectivePermission(f);
                 if (!permission.isAdmin()) {
                     throw FolderExceptionErrorMessage.FOLDER_NOT_MOVEABLE.create(
-                        f.getLocalizedName(session.getUser().getLocale()),
-                        getUser().getDisplayName(),
-                        Integer.valueOf(getContextId()));
+                        getFolderInfo4Error(f),
+                        getUserInfo4Error(),
+                        getContextInfo4Error());
                 }
                 subfolder = new FolderInfo(subfolderId, f.getName());
             } else {
@@ -375,6 +487,18 @@ final class MovePerformer extends AbstractPerformer {
         return permission;
     }
 
+    private static boolean containsAny(final String treeId, final FolderInfo folderInfo, final FolderStorage folderStorage, final StorageParameters storageParameters) throws FolderException {
+        if (folderStorage.containsFolder(treeId, folderInfo.id, storageParameters)) {
+            return true;
+        }
+        for (final FolderInfo subfolder : folderInfo.subfolders) {
+            if (containsAny(treeId, subfolder, folderStorage, storageParameters)) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     private static Map<String, String> generateIDMap(final FolderInfo oldFolder, final FolderInfo newFolder) {
         final Map<String, String> map = new HashMap<String, String>();
         fillIDMap(oldFolder, newFolder, map);
@@ -413,8 +537,9 @@ final class MovePerformer extends AbstractPerformer {
                 return;
             }
         }
-        storage.startTransaction(storageParameters, true);
-        openedStorages.add(storage);
+        if (storage.startTransaction(storageParameters, true)) {
+            openedStorages.add(storage);
+        }
     }
 
     private boolean equallyNamedSibling(final String name, final String treeId, final String parentId, final Collection<FolderStorage> openedStorages) throws FolderException {
@@ -425,7 +550,7 @@ final class MovePerformer extends AbstractPerformer {
             listPerformer = new ListPerformer(session, null);
         }
         listPerformer.setStorageParameters(storageParameters);
-        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages);
+        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages, false);
         for (final UserizedFolder userizedFolder : subfolders) {
             if (name.equals(userizedFolder.getName())) {
                 return true;
@@ -442,7 +567,7 @@ final class MovePerformer extends AbstractPerformer {
             listPerformer = new ListPerformer(session, null);
         }
         listPerformer.setStorageParameters(storageParameters);
-        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages);
+        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages, false);
         final StringBuilder sb = new StringBuilder();
         String nonExistingName = name;
         int i = 0;
