@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,16 +67,18 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link PathPerformer} - Serves the <code>PATH</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PathPerformer extends AbstractUserizedFolderPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PathPerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PathPerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
 
     /**
      * Initializes a new {@link PathPerformer} from given session.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      */
@@ -86,7 +88,7 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link PathPerformer} from given user-context-pair.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -97,7 +99,7 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link PathPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -108,7 +110,7 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link PathPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decoratorde
@@ -164,7 +166,7 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Performs the <code>PATH</code> request.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @param all <code>true</code> to get all subfolders regardless of their subscription status; otherwise <code>false</code> to only get
@@ -180,10 +182,11 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
         if (null == folderStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
         }
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
-        folderStorage.startTransaction(storageParameters, false);
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         final java.util.List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(folderStorage);
+        if (folderStorage.startTransaction(storageParameters, false)) {
+            openedStorages.add(folderStorage);
+        }
         final UserizedFolder[] ret;
         try {
             Folder folder = folderStorage.getFolder(treeId, folderId, storageParameters);
@@ -200,23 +203,25 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
             Permission ownPermission = permissionProvider.getOwnPermission(folder);
             if (!ownPermission.isVisible()) {
                 throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                    folderId,
-                    getUser().getDisplayName(),
-                    Integer.valueOf(getContextId()));
+                    getFolderInfo4Error(folder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
             final List<UserizedFolder> path = new ArrayList<UserizedFolder>(8);
-            path.add(getUserizedFolder(folder, ownPermission, treeId, all, true, storageParameters, openedStorages));
-            while (!FolderStorage.ROOT_ID.equals(folder.getParentID())) {
-                final FolderStorage fs = getOpenedStorage(folder.getParentID(), treeId, storageParameters, openedStorages);
-                folder = fs.getFolder(treeId, folder.getParentID(), storageParameters);
+            UserizedFolder userizedFolder = getUserizedFolder(folder, ownPermission, treeId, all, true, storageParameters, openedStorages);
+            path.add(userizedFolder);
+            while (!FolderStorage.ROOT_ID.equals(userizedFolder.getParentID())) {
+                final FolderStorage fs = getOpenedStorage(userizedFolder.getParentID(), treeId, storageParameters, openedStorages);
+                folder = fs.getFolder(treeId, userizedFolder.getParentID(), storageParameters);
                 ownPermission = permissionProvider.getOwnPermission(folder);
                 if (!ownPermission.isVisible()) {
                     throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                        folderId,
-                        getUser().getDisplayName(),
-                        Integer.valueOf(getContextId()));
+                        getFolderInfo4Error(folder),
+                        getUserInfo4Error(),
+                        getContextInfo4Error());
                 }
-                path.add(getUserizedFolder(folder, ownPermission, treeId, all, true, storageParameters, openedStorages));
+                userizedFolder = getUserizedFolder(folder, ownPermission, treeId, all, true, storageParameters, openedStorages);
+                path.add(userizedFolder);
             }
 
             ret = path.toArray(new UserizedFolder[path.size()]);
@@ -235,12 +240,65 @@ public final class PathPerformer extends AbstractUserizedFolderPerformer {
             }
             throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG_ENABLED) {
             final long duration = System.currentTimeMillis() - start;
-            LOG.debug(new StringBuilder().append("List.doList() with single storage took ").append(duration).append(
+            LOG.debug(new StringBuilder().append("Path.doPath() took ").append(duration).append(
                 "msec for parent folder: ").append(folderId).toString());
         }
         return ret;
     }
 
+    /**
+     * Performs the <code>PATH</code> request.
+     *
+     * @param treeId The tree identifier
+     * @param folderId The folder identifier
+     * @param all <code>true</code> to get all subfolders regardless of their subscription status; otherwise <code>false</code> to only get
+     *            subscribed ones
+     * @return The user-sensitive folders describing the path to root folder
+     * @throws FolderException If a folder error occurs
+     */
+    public String[] doForcePath(final String treeId, final String folderId, final boolean all) throws FolderException {
+        if (FolderStorage.ROOT_ID.equals(folderId)) {
+            return new String[0];
+        }
+        final FolderStorage folderStorage = folderStorageDiscoverer.getFolderStorage(treeId, folderId);
+        if (null == folderStorage) {
+            throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
+        }
+        final java.util.List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
+        if (folderStorage.startTransaction(storageParameters, false)) {
+            openedStorages.add(folderStorage);
+        }
+        final String[] ret;
+        try {
+            Folder folder = folderStorage.getFolder(treeId, folderId, storageParameters);
+
+            final List<String> path = new ArrayList<String>(8);
+            path.add(folderId);
+            while (!FolderStorage.ROOT_ID.equals(folder.getParentID())) {
+                final FolderStorage fs = getOpenedStorage(folder.getParentID(), treeId, storageParameters, openedStorages);
+                folder = fs.getFolder(treeId, folder.getParentID(), storageParameters);
+                path.add(folder.getID());
+            }
+
+            ret = path.toArray(new String[path.size()]);
+
+            for (final FolderStorage fs : openedStorages) {
+                fs.commitTransaction(storageParameters);
+            }
+        } catch (final FolderException e) {
+            for (final FolderStorage fs : openedStorages) {
+                fs.rollback(storageParameters);
+            }
+            throw e;
+        } catch (final Exception e) {
+            for (final FolderStorage fs : openedStorages) {
+                fs.rollback(storageParameters);
+            }
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+        return ret;
+    }
+
 }
