@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,7 +50,12 @@
 package com.openexchange.folderstorage.internal.performers;
 
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.LinkedList;
 import java.util.List;
+import java.util.Set;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
@@ -59,20 +64,24 @@ import com.openexchange.folderstorage.FolderStorageDiscoverer;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.internal.CalculatePermission;
+import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.utils.MailFolderUtility;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link SubscribePerformer} - Serves the <code>SUBSCRIBE</code> action.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class SubscribePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link SubscribePerformer}.
-     * 
+     *
      * @param session
      */
     public SubscribePerformer(final ServerSession session) {
@@ -81,7 +90,7 @@ public final class SubscribePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link SubscribePerformer}.
-     * 
+     *
      * @param user
      * @param context
      */
@@ -91,7 +100,7 @@ public final class SubscribePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link SubscribePerformer}.
-     * 
+     *
      * @param session The session
      * @param folderStorageDiscoverer The folder storage discoverer
      */
@@ -101,7 +110,7 @@ public final class SubscribePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link SubscribePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -110,67 +119,115 @@ public final class SubscribePerformer extends AbstractPerformer {
         super(user, context, folderStorageDiscoverer);
     }
 
+    private static final Set<String> SYSTEM_FOLDERS = Collections.<String> unmodifiableSet(new HashSet<String>(Arrays.asList(
+        FolderStorage.ROOT_ID,
+        FolderStorage.PRIVATE_ID,
+        FolderStorage.PUBLIC_ID,
+        FolderStorage.SHARED_ID)));
+    
+    private static final Set<String> VIRTUAL_IDS =  Collections.<String> unmodifiableSet(new HashSet<String>(Arrays.asList(
+        Integer.toString(FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID), Integer.toString(FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID),
+            Integer.toString(FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID), Integer.toString(FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID))));
+
+    /**
+     * The prepared fullname.
+     */
+    private static final String PREPARED_FULLNAME_DEFAULT = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
+
+    private static boolean isSystemFolder(final String folderId) {
+        if (null == folderId) {
+            return false;
+        }
+        if (SYSTEM_FOLDERS.contains(folderId)) {
+            return true;
+        }
+        if (folderId.startsWith(FolderObject.SHARED_PREFIX)) {
+            return true;
+        }
+        if (VIRTUAL_IDS.contains(folderId)) {
+            return true;
+        }
+        if (PREPARED_FULLNAME_DEFAULT.equals(folderId)) {
+            return true;
+        }
+        return false;
+    }
+
     /**
      * Performs the <code>SUBSCRIBE</code> action.
-     * 
+     *
      * @param sourceTreeId The source tree identifier
      * @param folderId The folder identifier
      * @param targetTreeId The target tree identifier
      * @param targetParentId The target parent identifier
      * @throws FolderException If a folder error occurs
      */
-    public void doSubscribe(final String sourceTreeId, final String folderId, final String targetTreeId, final String targetParentId) throws FolderException {
-        if (FolderStorage.REAL_TREE_ID.equals(targetTreeId)) {
+    public void doSubscribe(final String sourceTreeId, final String folderId, final String targetTreeId, final String optTargetParentId) throws FolderException {
+        if (KNOWN_TREES.contains(targetTreeId)) {
             throw FolderExceptionErrorMessage.NO_REAL_SUBSCRIBE.create(targetTreeId);
         }
         final FolderStorage sourceStorage = folderStorageDiscoverer.getFolderStorage(sourceTreeId, folderId);
         if (null == sourceStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(sourceTreeId, folderId);
         }
-        sourceStorage.startTransaction(storageParameters, false);
         final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(sourceStorage);
+        if (sourceStorage.startTransaction(storageParameters, false)) {
+            openedStorages.add(sourceStorage);
+        }
         try {
-            final Folder sourceFolder = sourceStorage.getFolder(sourceTreeId, folderId, storageParameters);
-            {
-                /*
-                 * Check folder permission for parent folder
-                 */
-                final Permission parentPermission;
-                if (null == getSession()) {
-                    parentPermission = CalculatePermission.calculate(sourceFolder, getUser(), getContext(), ALL_ALLOWED);
-                } else {
-                    parentPermission = CalculatePermission.calculate(sourceFolder, getSession(), ALL_ALLOWED);
-                }
-                if (!parentPermission.isVisible()) {
-                    throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                        folderId,
-                        getUser().getDisplayName(),
-                        Integer.valueOf(getContextId()));
-                }
+            Folder sourceFolder = sourceStorage.getFolder(sourceTreeId, folderId, storageParameters);
+            /*
+             * Check folder permission
+             */
+            if (!CalculatePermission.calculate(sourceFolder, this, ALL_ALLOWED).isVisible()) {
+                throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
+                    getFolderInfo4Error(sourceFolder),
+                    getUserInfo4Error(),
+                    getContextInfo4Error());
             }
+            /*
+             * Determine parent in target tree
+             */
+            final String targetParentId = optTargetParentId == null ? sourceFolder.getParentID() : optTargetParentId;
             final FolderStorage targetStorage = getOpenedStorage(targetParentId, targetTreeId, storageParameters, openedStorages);
-            {
-                /*
-                 * Check for equally named folder
-                 */
-                final UserizedFolder[] subfolders =
-                    (session == null ? new ListPerformer(user, context, null) : new ListPerformer(session, null)).doList(
-                        targetTreeId,
-                        targetParentId,
-                        true,
-                        openedStorages);
-                for (final UserizedFolder userizedFolder : subfolders) {
-                    if (userizedFolder.getName().equals(sourceFolder.getName())) {
-                        throw FolderExceptionErrorMessage.EQUAL_NAME.create(sourceFolder.getName(), targetParentId, targetTreeId);
-                    }
-                }
+            /*
+             * Check for equally named folder
+             */
+            if (targetStorage.containsFolder(targetTreeId, targetParentId, storageParameters)) {
+                checkForSimilarNamed(sourceFolder, targetTreeId, targetParentId, openedStorages);
             }
-            final Folder virtualFolder = (Folder) sourceFolder.clone();
+            /*
+             * List of folders
+             */
+            final LinkedList<Folder> folders = new LinkedList<Folder>();
+
+            Folder virtualFolder = (Folder) sourceFolder.clone();
             virtualFolder.setParentID(targetParentId);
             virtualFolder.setTreeID(targetTreeId);
             virtualFolder.setSubfolderIDs(null);
-            targetStorage.createFolder(virtualFolder, storageParameters);
+            folders.add(virtualFolder);
+
+            while (!isSystemFolder(virtualFolder.getParentID()) && !targetStorage.containsFolder(targetTreeId, virtualFolder.getParentID(), storageParameters)) {
+                sourceFolder = sourceStorage.getFolder(sourceTreeId, virtualFolder.getParentID(), storageParameters);
+                /*
+                 * Check folder permission for parent folder
+                 */
+                final Permission parentPermission = CalculatePermission.calculate(sourceFolder, this, ALL_ALLOWED);
+                if (parentPermission.isVisible()) {
+                    virtualFolder = (Folder) sourceFolder.clone();
+                    final String parentId = sourceFolder.getParentID();
+                    virtualFolder.setParentID(isSystemFolder(parentId) ? FolderStorage.ROOT_ID : parentId);
+                    virtualFolder.setTreeID(targetTreeId);
+                    virtualFolder.setSubfolderIDs(null);
+                    folders.addFirst(virtualFolder);
+                } else {
+                    virtualFolder.setParentID(FolderStorage.ROOT_ID);
+                }
+            }
+
+            for (final Folder folder : folders) {
+                targetStorage.createFolder(folder, storageParameters);
+            }
 
             for (final FolderStorage fs : openedStorages) {
                 fs.commitTransaction(storageParameters);
@@ -186,7 +243,26 @@ public final class SubscribePerformer extends AbstractPerformer {
             }
             throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
+    }
 
+    private void checkForSimilarNamed(final Folder sourceFolder, final String targetTreeId, final String targetParentId, final List<FolderStorage> openedStorages) throws FolderException {
+        /*
+         * Check for equally named folder
+         */
+        final UserizedFolder[] subfolders =
+            (session == null ? new ListPerformer(user, context, null) : new ListPerformer(session, null)).doList(
+                targetTreeId,
+                targetParentId,
+                true,
+                openedStorages,
+                false);
+        final String sourceId = sourceFolder.getID();
+        final String sourceName = sourceFolder.getName();
+        for (final UserizedFolder userizedFolder : subfolders) {
+            if (!userizedFolder.getID().equals(sourceId) && userizedFolder.getName().equals(sourceName)) {
+                throw FolderExceptionErrorMessage.EQUAL_NAME.create(sourceName, targetParentId, targetTreeId);
+            }
+        }
     }
 
 }
