@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -117,54 +117,19 @@ public final class UnsubscribePerformer extends AbstractPerformer {
      * @throws FolderException If a folder error occurs
      */
     public void doUnsubscribe(final String treeId, final String folderId) throws FolderException {
-        if (FolderStorage.REAL_TREE_ID.equals(treeId)) {
+        if (KNOWN_TREES.contains(treeId)) {
             throw FolderExceptionErrorMessage.NO_REAL_UNSUBSCRIBE.create(treeId);
         }
         final FolderStorage virtualStorage = folderStorageDiscoverer.getFolderStorage(treeId, folderId);
         if (null == virtualStorage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
         }
-        virtualStorage.startTransaction(storageParameters, false);
         final java.util.List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(virtualStorage);
+        if (virtualStorage.startTransaction(storageParameters, false)) {
+            openedStorages.add(virtualStorage);
+        }
         try {
-            final Folder folder = virtualStorage.getFolder(treeId, folderId, storageParameters);
-            {
-                /*
-                 * Check folder permission for parent folder
-                 */
-                final Permission parentPermission;
-                if (null == getSession()) {
-                    parentPermission = CalculatePermission.calculate(folder, getUser(), getContext(), ALL_ALLOWED);
-                } else {
-                    parentPermission = CalculatePermission.calculate(folder, getSession(), ALL_ALLOWED);
-                }
-                if (!parentPermission.isVisible()) {
-                    throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
-                        folderId,
-                        getUser().getDisplayName(),
-                        Integer.valueOf(getContextId()));
-                }
-            }
-            {
-                /*
-                 * No unsubscribe on a folder which has subfolders
-                 */
-                final String[] ids = folder.getSubfolderIDs();
-                if (null == ids) {
-                    final SortableId[] tmp = virtualStorage.getSubfolders(treeId, folderId, storageParameters);
-                    if (tmp.length > 0) {
-                        throw FolderExceptionErrorMessage.NO_UNSUBSCRIBE.create(folderId, treeId);
-                    }
-                } else {
-                    if (ids.length > 0) {
-                        throw FolderExceptionErrorMessage.NO_UNSUBSCRIBE.create(folderId, treeId);
-                    }
-                }
-            }
-
-            virtualStorage.deleteFolder(treeId, folderId, storageParameters);
-
+            unsubscribeFolder(treeId, folderId, virtualStorage, true);
             for (final FolderStorage fs : openedStorages) {
                 fs.commitTransaction(storageParameters);
             }
@@ -182,4 +147,54 @@ public final class UnsubscribePerformer extends AbstractPerformer {
 
     }
 
+    private void unsubscribeFolder(final String treeId, final String folderId, final FolderStorage virtualStorage, final boolean allowSubfolderUnsubscribe) throws FolderException {
+        if (!virtualStorage.containsFolder(treeId, folderId, storageParameters)) {
+            return;
+        }
+        /*
+         * Unsubscribe contained folder
+         */
+        final Folder folder = virtualStorage.getFolder(treeId, folderId, storageParameters);
+        /*
+         * Check folder permission
+         */
+        final Permission permission = CalculatePermission.calculate(folder, this, ALL_ALLOWED);
+        if (!permission.isVisible()) {
+            throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
+                getFolderInfo4Error(folder),
+                getUserInfo4Error(),
+                getContextInfo4Error());
+        }
+        /*
+         * Check subfolders
+         */
+        {
+            /*
+             * No unsubscribe on a folder which has subfolders
+             */
+            final String[] ids = folder.getSubfolderIDs();
+            if (null == ids) {
+                final SortableId[] sortableIds = virtualStorage.getSubfolders(treeId, folderId, storageParameters);
+                if (sortableIds.length > 0) {
+                    if (!allowSubfolderUnsubscribe) {
+                        throw FolderExceptionErrorMessage.NO_UNSUBSCRIBE.create(folderId, treeId);
+                    }
+                    for (final SortableId sortableId : sortableIds) {
+                        unsubscribeFolder(treeId, sortableId.getId(), virtualStorage, allowSubfolderUnsubscribe);
+                    }
+                }
+            } else {
+                if (ids.length > 0) {
+                    if (!allowSubfolderUnsubscribe) {
+                        throw FolderExceptionErrorMessage.NO_UNSUBSCRIBE.create(folderId, treeId);
+                    }
+                    for (final String id : ids) {
+                        unsubscribeFolder(treeId, id, virtualStorage, allowSubfolderUnsubscribe);
+                    }
+                }
+            }
+        }
+        virtualStorage.deleteFolder(treeId, folderId, storageParameters);
+    }
+
 }
