@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,16 +67,18 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link UpdatePerformer} - Serves the <code>UPDATE</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UpdatePerformer extends AbstractPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UpdatePerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UpdatePerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
 
     /**
      * Initializes a new {@link UpdatePerformer} from given session.
-     * 
+     *
      * @param session The session
      */
     public UpdatePerformer(final ServerSession session) {
@@ -85,7 +87,7 @@ public final class UpdatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link UpdatePerformer} from given user-context-pair.
-     * 
+     *
      * @param user The user
      * @param context The context
      */
@@ -95,7 +97,7 @@ public final class UpdatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link UpdatePerformer}.
-     * 
+     *
      * @param session The session
      * @param folderStorageDiscoverer The folder storage discoverer
      */
@@ -105,7 +107,7 @@ public final class UpdatePerformer extends AbstractPerformer {
 
     /**
      * Initializes a new {@link UpdatePerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -116,7 +118,7 @@ public final class UpdatePerformer extends AbstractPerformer {
 
     /**
      * Performs the <code>UPDATE</code> request.
-     * 
+     *
      * @param folder The object which denotes the folder to update and provides the changes to perform
      * @param timeStamp The requestor's last-modified time stamp
      * @throws FolderException If update fails
@@ -134,13 +136,12 @@ public final class UpdatePerformer extends AbstractPerformer {
         if (null == storage) {
             throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
         }
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
-        storage.startTransaction(storageParameters, true);
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         if (null != timeStamp) {
             storageParameters.setTimeStamp(timeStamp);
         }
         final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(4);
-        openedStorages.add(storage);
+        checkOpenedStorage(storage, openedStorages);
 
         try {
             /*
@@ -152,11 +153,24 @@ public final class UpdatePerformer extends AbstractPerformer {
             {
                 final String newParentId = folder.getParentID();
                 move = (null != newParentId && !newParentId.equals(oldParentId));
+                if (move && !"infostore".equals(storageFolder.getContentType().toString())) {
+                    /*
+                     * Check for duplicate
+                     */
+                    final String folderName = (folder.getName() != null) ? folder.getName() : storageFolder.getName();
+                    checkForDuplicate(folderName, treeId, newParentId, openedStorages);
+                }
             }
             final boolean rename;
             {
                 final String newName = folder.getName();
                 rename = (null != newName && !newName.equals(storageFolder.getName()));
+                if (rename && !"infostore".equals(storageFolder.getContentType().toString())) {
+                    /*
+                     * Check for duplicate
+                     */
+                    checkForDuplicate(newName, treeId, storageFolder.getParentID(), openedStorages);
+                }
             }
             final boolean changePermissions;
             {
@@ -224,22 +238,22 @@ public final class UpdatePerformer extends AbstractPerformer {
                  * Check for forbidden public mail folder
                  */
                 {
-                    final boolean started = newRealParentStorage.startTransaction(storageParameters, false);
+                    final boolean started2 = newRealParentStorage.startTransaction(storageParameters, true);
                     try {
                         final Folder newParent = newRealParentStorage.getFolder(FolderStorage.REAL_TREE_ID, newParentId, storageParameters);
                         if ((FolderStorage.PUBLIC_ID.equals(newParent.getID()) || PublicType.getInstance().equals(newParent.getType())) && "mail".equals(storageFolder.getContentType().toString())) {
                             throw FolderExceptionErrorMessage.NO_PUBLIC_MAIL_FOLDER.create();
                         }
-                        if (started) {
+                        if (started2) {
                             newRealParentStorage.commitTransaction(storageParameters);
                         }
                     } catch (final FolderException e) {
-                        if (started) {
+                        if (started2) {
                             newRealParentStorage.rollback(storageParameters);
                         }
                         throw e;
                     } catch (final Exception e) {
-                        if (started) {
+                        if (started2) {
                             newRealParentStorage.rollback(storageParameters);
                         }
                         throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
@@ -316,9 +330,9 @@ public final class UpdatePerformer extends AbstractPerformer {
                 fs.commitTransaction(storageParameters);
             }
 
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG_ENABLED) {
                 final long duration = System.currentTimeMillis() - start;
-                LOG.debug(new StringBuilder().append("Update.doUpdate() took ").append(duration).append("msec for folder: ").append(
+                LOG.debug(new StringBuilder().append("UpdatePerformer.doUpdate() took ").append(duration).append("msec for folder: ").append(
                     folderId).toString());
             }
         } catch (final FolderException e) {
@@ -374,8 +388,9 @@ public final class UpdatePerformer extends AbstractPerformer {
                 return;
             }
         }
-        storage.startTransaction(storageParameters, true);
-        openedStorages.add(storage);
+        if (storage.startTransaction(storageParameters, true)) {
+            openedStorages.add(storage);
+        }
     }
 
     private boolean equallyNamedSibling(final String name, final String treeId, final String parentId, final Collection<FolderStorage> openedStorages) throws FolderException {
@@ -386,7 +401,7 @@ public final class UpdatePerformer extends AbstractPerformer {
             listPerformer = new ListPerformer(session, null);
         }
         listPerformer.setStorageParameters(storageParameters);
-        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages);
+        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages, false);
         for (final UserizedFolder userizedFolder : subfolders) {
             if (name.equals(userizedFolder.getName())) {
                 return true;
@@ -402,8 +417,8 @@ public final class UpdatePerformer extends AbstractPerformer {
         } else {
             listPerformer = new ListPerformer(session, null);
         }
-        // listPerformer.setStorageParameters(storageParameters);
-        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages);
+        listPerformer.setStorageParameters(storageParameters);
+        final UserizedFolder[] subfolders = listPerformer.doList(treeId, parentId, true, openedStorages, false);
         final StringBuilder sb = new StringBuilder();
         String nonExistingName = name;
         int i = 0;
