@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,16 +85,18 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link UpdatesPerformer} - Serves the <code>UPDATES</code> request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UpdatesPerformer.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UpdatesPerformer.class));
+
+    private static final boolean DEBUG_ENABLED = LOG.isDebugEnabled();
 
     /**
      * Initializes a new {@link UpdatesPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      */
@@ -104,7 +106,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link UpdatesPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -115,7 +117,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link UpdatesPerformer}.
-     * 
+     *
      * @param session The session
      * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
@@ -126,7 +128,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Initializes a new {@link UpdatesPerformer}.
-     * 
+     *
      * @param user The user
      * @param context The context
      * @param decorator The optional folder service decorator
@@ -138,7 +140,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
 
     /**
      * Performs the <code>UPDATES</code> request.
-     * 
+     *
      * @param treeId The tree identifier
      * @param since The time stamp
      * @param ignoreDeleted <code>true</code> to ignore delete operations performed since given time stamp; otherwise <code>false</code> to
@@ -150,12 +152,11 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
     public UserizedFolder[][] doUpdates(final String treeId, final Date since, final boolean ignoreDeleted, final ContentType[] includeContentTypes) throws FolderException {
         final List<FolderStorage> realFolderStorages =
             new ArrayList<FolderStorage>(Arrays.asList(folderStorageDiscoverer.getTreeFolderStorages(FolderStorage.REAL_TREE_ID)));
-        for (final FolderStorage folderStorage : realFolderStorages) {
-            folderStorage.startTransaction(storageParameters, false);
-        }
         final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(realFolderStorages.size() + 1);
-        openedStorages.addAll(realFolderStorages);
-        final long start = LOG.isDebugEnabled() ? System.currentTimeMillis() : 0L;
+        for (final FolderStorage folderStorage : realFolderStorages) {
+            checkOpenedStorage(folderStorage, false, openedStorages);
+        }
+        final long start = DEBUG_ENABLED ? System.currentTimeMillis() : 0L;
         try {
             final UserConfiguration userConfiguration;
             {
@@ -203,15 +204,27 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
                 for (final FolderStorage folderStorage : realFolderStorages) {
                     final String[] modifiedFolderIDs =
                         folderStorage.getModifiedFolderIDs(treeId, since, includeContentTypes, storageParameters);
-                    for (int i = 0; i < modifiedFolderIDs.length; i++) {
+                    if (modifiedFolderIDs.length > 0) {
                         try {
-                            modifiedFolders.add(folderStorage.getFolder(FolderStorage.REAL_TREE_ID, modifiedFolderIDs[i], storageParameters));
+                            modifiedFolders.addAll(folderStorage.getFolders(
+                                FolderStorage.REAL_TREE_ID,
+                                Arrays.asList(modifiedFolderIDs),
+                                storageParameters));
                         } catch (final FolderException e) {
-                            LOG.error(
-                                new StringBuilder(128).append("Updated folder \"").append(modifiedFolderIDs[i]).append(
-                                    "\" could not be fetched from storage \"").append(folderStorage.getClass().getName()).append("\":\n").append(
-                                    e.getMessage()).toString(),
-                                e);
+                            for (final String modifiedFolderID : modifiedFolderIDs) {
+                                try {
+                                    modifiedFolders.add(folderStorage.getFolder(
+                                        FolderStorage.REAL_TREE_ID,
+                                        modifiedFolderID,
+                                        storageParameters));
+                                } catch (final FolderException ee) {
+                                    LOG.error(
+                                        new StringBuilder(128).append("Updated folder \"").append(modifiedFolderID).append(
+                                            "\" could not be fetched from storage \"").append(folderStorage.getClass().getName()).append(
+                                            "\":\n").append(ee.getMessage()).toString(),
+                                        ee);
+                                }
+                            }
                         }
                     }
                 }
@@ -222,18 +235,27 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
                         try {
                             final String[] modifiedFolderIDs =
                                 storage.getModifiedFolderIDs(treeId, since, includeContentTypes, storageParameters);
-                            for (int i = 0; i < modifiedFolderIDs.length; i++) {
+                            if (modifiedFolderIDs.length > 0) {
                                 try {
-                                    modifiedFolders.add(storage.getFolder(
+                                    modifiedFolders.addAll(storage.getFolders(
                                         FolderStorage.REAL_TREE_ID,
-                                        modifiedFolderIDs[i],
+                                        Arrays.asList(modifiedFolderIDs),
                                         storageParameters));
                                 } catch (final FolderException e) {
-                                    LOG.error(
-                                        new StringBuilder(128).append("Updated folder \"").append(modifiedFolderIDs[i]).append(
-                                            "\" could not be fetched from storage \"").append(storage.getClass().getName()).append("\":\n").append(
-                                            e.getMessage()).toString(),
-                                        e);
+                                    for (final String modifiedFolderID : modifiedFolderIDs) {
+                                        try {
+                                            modifiedFolders.add(storage.getFolder(
+                                                FolderStorage.REAL_TREE_ID,
+                                                modifiedFolderID,
+                                                storageParameters));
+                                        } catch (final FolderException ee) {
+                                            LOG.error(
+                                                new StringBuilder(128).append("Updated folder \"").append(modifiedFolderID).append(
+                                                    "\" could not be fetched from storage \"").append(storage.getClass().getName()).append(
+                                                    "\":\n").append(ee.getMessage()).toString(),
+                                                ee);
+                                        }
+                                    }
                                 }
                             }
                             if (started) {
@@ -244,7 +266,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
                                 storage.rollback(storageParameters);
                             }
                             throw e;
-                        } catch (Exception e) {
+                        } catch (final Exception e) {
                             if (started) {
                                 storage.rollback(storageParameters);
                             }
@@ -382,9 +404,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
                 final List<Folder> deletedFolders = new ArrayList<Folder>();
                 for (final FolderStorage folderStorage : realFolderStorages) {
                     final String[] deletedFolderIDs = folderStorage.getDeletedFolderIDs(treeId, since, storageParameters);
-                    for (int i = 0; i < deletedFolderIDs.length; i++) {
-                        // Pass storage type to fetch folder from backup tables
-                        final String folderId = deletedFolderIDs[i];
+                    for (final String folderId : deletedFolderIDs) {
                         if (treeChecker.containsVirtualFolder(folderId, treeId, StorageType.BACKUP)) {
                             deletedFolders.add(folderStorage.getFolder(
                                 FolderStorage.REAL_TREE_ID,
@@ -428,7 +448,7 @@ public final class UpdatesPerformer extends AbstractUserizedFolderPerformer {
             for (final FolderStorage folderStorage : openedStorages) {
                 folderStorage.commitTransaction(storageParameters);
             }
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG_ENABLED) {
                 final long duration = System.currentTimeMillis() - start;
                 LOG.debug(new StringBuilder().append("Updates.doUpdates() took ").append(duration).append("msec.").toString());
             }
