@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,12 +56,12 @@ import com.openexchange.mail.dataobjects.MailFolder;
 
 /**
  * {@link MailFolderType} - The folder type for mail.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailFolderType implements FolderType {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailFolderType.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailFolderType.class));
 
     private static final int LEN = MailFolder.DEFAULT_FOLDER_ID.length();
 
@@ -69,7 +69,7 @@ public final class MailFolderType implements FolderType {
 
     /**
      * Gets the {@link MailFolderType} instance.
-     * 
+     *
      * @return The {@link MailFolderType} instance
      */
     public static MailFolderType getInstance() {
