@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.folderstorage.SortableId;
 
 /**
  * {@link MailId} - A mail ID.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailId implements SortableId {
@@ -62,9 +62,11 @@ public final class MailId implements SortableId {
 
     private final int ordinal;
 
+    private String name;
+
     /**
      * Initializes a new {@link MailId}.
-     * 
+     *
      * @param fullname The fullname
      * @param ordinal The ordinal
      */
@@ -74,6 +76,21 @@ public final class MailId implements SortableId {
         this.ordinal = ordinal;
     }
 
+    /**
+     * Applies specified name.
+     *
+     * @param name The name
+     * @return This {@link MailId} instance with new name applied
+     */
+    public MailId setName(final String name) {
+        this.name = name;
+        return this;
+    }
+
+    public String getName() {
+        return name;
+    }
+
     public String getId() {
         return fullname;
     }
@@ -87,7 +104,7 @@ public final class MailId implements SortableId {
 
     public int compareTo(final SortableId o) {
         if (o instanceof MailId) {
-            final int thisVal = this.ordinal;
+            final int thisVal = ordinal;
             final int anotherVal = ((MailId) o).ordinal;
             return (thisVal < anotherVal ? -1 : (thisVal == anotherVal ? 0 : 1));
         }
