@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,6 @@ import java.util.Set;
 import com.openexchange.folderstorage.AbstractFolder;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Permission;
-import com.openexchange.folderstorage.SystemContentType;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.messaging.contentType.DraftsContentType;
 import com.openexchange.folderstorage.messaging.contentType.MessagingContentType;
@@ -69,14 +68,17 @@ import com.openexchange.folderstorage.messaging.contentType.TrashContentType;
 import com.openexchange.folderstorage.type.MailType;
 import com.openexchange.folderstorage.type.SystemType;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.i18n.MailStrings;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.messaging.MessagingException;
 import com.openexchange.messaging.MessagingFolder;
-import com.openexchange.messaging.MessagingPermission;
 import com.openexchange.messaging.MessagingFolder.DefaultFolderType;
+import com.openexchange.messaging.MessagingPermission;
 
 /**
  * {@link MessagingFolderImpl} - A messaging folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessagingFolderImpl extends AbstractFolder {
@@ -88,7 +90,7 @@ public final class MessagingFolderImpl extends AbstractFolder {
      */
     public static enum MessagingFolderType {
         NONE(MessagingContentType.getInstance(), 0),
-        ROOT(SystemContentType.getInstance(), 0),
+        ROOT(MessagingContentType.getInstance(), 0),
         INBOX(MessagingContentType.getInstance(), 13), // FolderObject.MESSAGING
         DRAFTS(DraftsContentType.getInstance(), 14),
         SENT(SentContentType.getInstance(), 15),
@@ -107,7 +109,7 @@ public final class MessagingFolderImpl extends AbstractFolder {
 
         /**
          * Gets the content type associated with this mail folder type.
-         * 
+         *
          * @return The content type
          */
         public ContentType getContentType() {
@@ -116,7 +118,7 @@ public final class MessagingFolderImpl extends AbstractFolder {
 
         /**
          * Gets the type.
-         * 
+         *
          * @return The type
          */
         public int getType() {
@@ -145,76 +147,96 @@ public final class MessagingFolderImpl extends AbstractFolder {
      * Initializes a new {@link MessagingFolderImpl} from given messaging folder.
      * <p>
      * Subfolder identifiers and tree identifier are not set within this constructor.
-     * 
+     *
      * @param messagingFolder The underlying messaging folder
      * @param accountId The account identifier
      * @param serviceId The service identifier
      * @param fullnameProvider The (optional) fullname provider
      */
-    public MessagingFolderImpl(final MessagingFolder messagingFolder, final int accountId, final String serviceId, final DefaultFolderFullnameProvider fullnameProvider) {
+    public MessagingFolderImpl(final MessagingFolder messagingFolder, final int accountId, final String serviceId, final User user, final DefaultFolderFullnameProvider fullnameProvider) {
         super();
         final String fullname = messagingFolder.getId();
-        this.id = serviceId + "://" + accountId;
-        this.name = messagingFolder.getName();
+        id = MessagingFolderIdentifier.getFQN(serviceId, accountId, fullname);
+        name = messagingFolder.getName();
         final boolean isRootFolder = messagingFolder.isRootFolder();
         if (isRootFolder) { // Root folder
-            this.parent = PRIVATE_FOLDER_ID;
+            parent = PRIVATE_FOLDER_ID;
         } else {
-            this.parent = MessagingFolderIdentifier.getFQN(serviceId, accountId, messagingFolder.getParentId());
+            parent = MessagingFolderIdentifier.getFQN(serviceId, accountId, messagingFolder.getParentId());
         }
         {
             final List<MessagingPermission> messagingPermissions = messagingFolder.getPermissions();
             final int size = messagingPermissions.size();
-            this.permissions = new Permission[size];
+            permissions = new Permission[size];
             for (int i = 0; i < size; i++) {
-                this.permissions[i] = new MessagingPermissionImpl(messagingPermissions.get(i));
+                permissions[i] = new MessagingPermissionImpl(messagingPermissions.get(i));
             }
         }
         type = SystemType.getInstance();
-        this.subscribed = messagingFolder.isSubscribed();
-        this.subscribedSubfolders = messagingFolder.hasSubscribedSubfolders();
-        this.capabilities = parseCaps(messagingFolder.getCapabilities());
+        subscribed = messagingFolder.isSubscribed();
+        subscribedSubfolders = messagingFolder.hasSubscribedSubfolders();
+        capabilities = parseCaps(messagingFolder.getCapabilities());
         {
             final String value =
                 isRootFolder ? "" : new StringBuilder(16).append('(').append(messagingFolder.getMessageCount()).append('/').append(
                     messagingFolder.getUnreadMessageCount()).append(')').toString();
-            this.summary = value;
+            summary = value;
         }
-        this.deefault = /* messagingFolder.isDefaultFolder(); */0 == accountId && messagingFolder.isDefaultFolder();
-        this.total = messagingFolder.getMessageCount();
-        this.nu = messagingFolder.getNewMessageCount();
-        this.unread = messagingFolder.getUnreadMessageCount();
-        this.deleted = messagingFolder.getDeletedMessageCount();
+        deefault = /* messagingFolder.isDefaultFolder(); */0 == accountId && messagingFolder.isDefaultFolder();
+        total = messagingFolder.getMessageCount();
+        nu = messagingFolder.getNewMessageCount();
+        unread = messagingFolder.getUnreadMessageCount();
+        deleted = messagingFolder.getDeletedMessageCount();
         if (messagingFolder.containsDefaultFolderType()) {
             messagingFolderType = TYPES.get(messagingFolder.getDefaultFolderType());
+            switch (messagingFolderType) {
+            case DRAFTS:
+                name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS);
+                break;
+            case SENT:
+                name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT);
+                break;
+            case SPAM:
+                name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM);
+                break;
+            case TRASH:
+                name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH);
+                break;
+            default:
+                break;
+            }
+        } else if (messagingFolder.isRootFolder()) {
+            messagingFolderType = MessagingFolderType.ROOT;
         } else if (null != fullname) {
             try {
                 if (fullname.equals(fullnameProvider.getDraftsFolder())) {
                     messagingFolderType = MessagingFolderType.DRAFTS;
+                    name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS);
                 } else if (fullname.equals(fullnameProvider.getINBOXFolder())) {
                     messagingFolderType = MessagingFolderType.INBOX;
                 } else if (fullname.equals(fullnameProvider.getSentFolder())) {
+                    name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT);
                     messagingFolderType = MessagingFolderType.SENT;
                 } else if (fullname.equals(fullnameProvider.getSpamFolder())) {
+                    name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM);
                     messagingFolderType = MessagingFolderType.SPAM;
                 } else if (fullname.equals(fullnameProvider.getTrashFolder())) {
+                    name = StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH);
                     messagingFolderType = MessagingFolderType.TRASH;
                 } else {
                     messagingFolderType = MessagingFolderType.NONE;
                 }
             } catch (final MessagingException e) {
-                org.apache.commons.logging.LogFactory.getLog(MessagingFolderImpl.class).error(e.getMessage(), e);
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MessagingFolderImpl.class)).error(e.getMessage(), e);
                 messagingFolderType = MessagingFolderType.NONE;
             }
-        } else if (messagingFolder.isRootFolder()) {
-            messagingFolderType = MessagingFolderType.ROOT;
         } else {
             messagingFolderType = MessagingFolderType.NONE;
         }
         /*
          * Trash folder must not be cacheable
          */
-        this.cacheable = !messagingFolder.isDefaultFolder() || !messagingFolderType.equals(MessagingFolderType.TRASH);
+        cacheable = !messagingFolder.isDefaultFolder() || !messagingFolderType.equals(MessagingFolderType.TRASH);
     }
 
     @Override
@@ -316,7 +338,7 @@ public final class MessagingFolderImpl extends AbstractFolder {
 
     /**
      * Parses given capabilities to an <code>int</code> value.
-     * 
+     *
      * @param caps The capabilities to parse
      * @return The resulting <code>int</code> value
      */
@@ -337,7 +359,7 @@ public final class MessagingFolderImpl extends AbstractFolder {
          * Initializes a new header name from specified character sequence.
          * <p>
          * Yields significantly better space and time performance by caching frequently requested headers.
-         * 
+         *
          * @param s The character sequence
          * @return The new header name.
          */
