@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -77,16 +77,15 @@ import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
 import com.openexchange.folderstorage.Type;
-import com.openexchange.folderstorage.mail.MailParameterConstants;
 import com.openexchange.folderstorage.messaging.contentType.DraftsContentType;
 import com.openexchange.folderstorage.messaging.contentType.MessagingContentType;
 import com.openexchange.folderstorage.messaging.contentType.SentContentType;
 import com.openexchange.folderstorage.messaging.contentType.SpamContentType;
 import com.openexchange.folderstorage.messaging.contentType.TrashContentType;
+import com.openexchange.folderstorage.type.MessagingType;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.MailSessionParameterNames;
 import com.openexchange.mail.messaging.MailMessagingService;
@@ -114,16 +113,18 @@ import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * {@link MessagingFolderStorage} - The messaging folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessagingFolderStorage implements FolderStorage {
 
+    private static final String PARAM = MessagingParameterConstants.PARAM_MESSAGING_ACCESS;
+
     private static volatile boolean mailFolderStorageAvailable;
 
     /**
      * Sets whether mail folder storage is available.
-     * 
+     *
      * @param mailFolderStorageAvailable <code>true</code> if mail folder storage is available; otherwise <code>false</code>
      */
     public static void setMailFolderStorageAvailable(final boolean mailFolderStorageAvailable) {
@@ -192,15 +193,25 @@ public final class MessagingFolderStorage implements FolderStorage {
         super();
     }
 
-    public void restore(String treeId, String folderId, StorageParameters storageParameters) throws FolderException {
+    public void clearCache(final int userId, final int contextId) {
+        /*
+         * Nothing to do...
+         */
+    }
+
+    public void restore(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         // TODO:
     }
 
-    public void checkConsistency(String treeId, StorageParameters storageParameters) throws FolderException {
+    public Folder prepareFolder(final String treeId, final Folder folder, final StorageParameters storageParameters) throws FolderException {
+        return folder;
+    }
+
+    public void checkConsistency(final String treeId, final StorageParameters storageParameters) throws FolderException {
         // Nothing to do
     }
 
-    public SortableId[] getVisibleFolders(String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws FolderException {
+    public SortableId[] getVisibleFolders(final String treeId, final ContentType contentType, final Type type, final StorageParameters storageParameters) throws FolderException {
         throw new UnsupportedOperationException("VirtualFolderStorage.getVisibleSubfolders()");
     }
 
@@ -210,7 +221,7 @@ public final class MessagingFolderStorage implements FolderStorage {
         if (null == accountAccess) {
             try {
                 accountAccess =
-                    getServiceRegistry().getService(MessagingServiceRegistry.class, true).getMessagingService(serviceId).getAccountAccess(
+                    getServiceRegistry().getService(MessagingServiceRegistry.class, true).getMessagingService(serviceId, session.getUserId(), session.getContextId()).getAccountAccess(
                         accountId,
                         session);
             } catch (final MessagingException e) {
@@ -228,9 +239,6 @@ public final class MessagingFolderStorage implements FolderStorage {
 
     private void openMessagingAccess(final MessagingAccountAccess accountAccess) throws MessagingException {
         if (!accountAccess.isConnected()) {
-            /*
-             * Get new mail configuration
-             */
             try {
                 accountAccess.connect();
             } catch (final MessagingException e) {
@@ -253,7 +261,7 @@ public final class MessagingFolderStorage implements FolderStorage {
         @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
             (ConcurrentMap<Key, MessagingAccountAccess>) params.getParameter(
                 MessagingFolderType.getInstance(),
-                MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                PARAM);
         if (null != accesses) {
             try {
                 final Collection<MessagingAccountAccess> values = accesses.values();
@@ -261,7 +269,7 @@ public final class MessagingFolderStorage implements FolderStorage {
                     messagingAccess.close();
                 }
             } finally {
-                params.putParameter(MessagingFolderType.getInstance(), MessagingParameterConstants.PARAM_MESSAGING_ACCESS, null);
+                params.putParameter(MessagingFolderType.getInstance(), PARAM, null);
             }
         }
     }
@@ -271,11 +279,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folder.getParentID());
@@ -327,11 +333,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
@@ -356,11 +360,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
@@ -380,7 +382,7 @@ public final class MessagingFolderStorage implements FolderStorage {
         }
     }
 
-    public String getDefaultFolderID(final User user, final String treeId, final ContentType contentType, final StorageParameters storageParameters) throws FolderException {
+    public String getDefaultFolderID(final User user, final String treeId, final ContentType contentType, final Type type, final StorageParameters storageParameters) throws FolderException {
         if (!(contentType instanceof MessagingContentType)) {
             throw FolderExceptionErrorMessage.UNKNOWN_CONTENT_TYPE.create(contentType.toString());
         }
@@ -395,11 +397,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
             /*
              * Open account access
@@ -426,16 +426,18 @@ public final class MessagingFolderStorage implements FolderStorage {
         }
     }
 
+    public Type getTypeByParent(final User user, final String treeId, final String parentId, final StorageParameters storageParameters) throws FolderException {
+        return MessagingType.getInstance();
+    }
+
     public boolean containsForeignObjects(final User user, final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         try {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
@@ -468,11 +470,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
@@ -500,6 +500,18 @@ public final class MessagingFolderStorage implements FolderStorage {
         // Nothing to do
     }
 
+    public List<Folder> getFolders(final String treeId, final List<String> folderIds, final StorageParameters storageParameters) throws FolderException {
+        return getFolders(treeId, folderIds, StorageType.WORKING, storageParameters);
+    }
+
+    public List<Folder> getFolders(final String treeId, final List<String> folderIds, final StorageType storageType, final StorageParameters storageParameters) throws FolderException {
+        final List<Folder> ret = new ArrayList<Folder>(folderIds.size());
+        for (final String folderId : folderIds) {
+            ret.add(getFolder(treeId, folderId, storageType, storageParameters));
+        }
+        return ret;
+    }
+
     public Folder getFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         return getFolder(treeId, folderId, StorageType.WORKING, storageParameters);
     }
@@ -512,112 +524,80 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
             final String serviceId = mfi.getServiceId();
             final int accountId = mfi.getAccountId();
-            final MessagingAccountAccess accountAccess =
-                getMessagingAccessForAccount(serviceId, accountId, storageParameters.getSession(), accesses);
-            openMessagingAccess(accountAccess);
 
             final String fullname = mfi.getFullname();
+            final Session session = storageParameters.getSession();
 
-            final MessagingFolderImpl retval;
+            final Folder retval;
             final boolean hasSubfolders;
             if ("".equals(fullname)) {
-                final MessagingFolder rootFolder = accountAccess.getFolderAccess().getRootFolder();
-                retval = new MessagingFolderImpl(rootFolder, accountId, serviceId, null);
-                /*
-                 * Set proper name
-                 */
-                try {
-                    final MessagingServiceRegistry msr =
-                        MessagingFolderStorageServiceRegistry.getServiceRegistry().getService(MessagingServiceRegistry.class, true);
-                    final MessagingService messagingService = msr.getMessagingService(serviceId);
-                    final MessagingAccount messagingAccount =
-                        messagingService.getAccountManager().getAccount(accountId, storageParameters.getSession());
+                final MessagingServiceRegistry msr =
+                    MessagingFolderStorageServiceRegistry.getServiceRegistry().getService(MessagingServiceRegistry.class, true);
+                final MessagingService messagingService = msr.getMessagingService(serviceId, session.getUserId(), session.getContextId());
+                final MessagingAccount messagingAccount =
+                    messagingService.getAccountManager().getAccount(accountId, session);
+
+                if ("com.openexchange.messaging.rss".equals(serviceId)) {
+                    retval = new ExternalMessagingAccountRootFolder(messagingAccount, serviceId, session, messagingService.getStaticRootPermissions());
+                    hasSubfolders = false;
+                } else if ("com.openexchange.messaging.facebook".equals(serviceId)) {
+                    retval = new ExternalMessagingAccountRootFolder(messagingAccount, serviceId, session, messagingService.getStaticRootPermissions());
+                    hasSubfolders = true;
+                } else if ("com.openexchange.messaging.twitter".equals(serviceId)) {
+                    retval = new ExternalMessagingAccountRootFolder(messagingAccount, serviceId, session, messagingService.getStaticRootPermissions());
+                    hasSubfolders = false;
+                } else {
+                    final MessagingAccountAccess accountAccess =
+                        getMessagingAccessForAccount(serviceId, accountId, session, accesses);
+                    openMessagingAccess(accountAccess);
+
+                    final MessagingFolder rootFolder = accountAccess.getFolderAccess().getRootFolder();
+                    retval = new MessagingFolderImpl(rootFolder, accountId, serviceId, storageParameters.getUser(), null);
+                    /*
+                     * Set proper name
+                     */
                     retval.setName(messagingAccount.getDisplayName());
-                } catch (final ServiceException e) {
-                    throw new FolderException(e);
+                    hasSubfolders = rootFolder.hasSubfolders();
                 }
-                hasSubfolders = rootFolder.hasSubfolders();
+                /*
+                 * This one needs sorting. Just pass null or an empty array.
+                 */
+                retval.setSubfolderIDs(hasSubfolders ? null : new String[0]);
             } else {
+                final MessagingAccountAccess accountAccess =
+                    getMessagingAccessForAccount(serviceId, accountId, session, accesses);
+                openMessagingAccess(accountAccess);
                 final MessagingFolder messagingFolder = accountAccess.getFolderAccess().getFolder(fullname);
                 retval =
                     new MessagingFolderImpl(
                         messagingFolder,
                         accountId,
                         serviceId,
+                        storageParameters.getUser(),
                         new MessagingAccountAccessFullnameProvider(accountAccess));
                 hasSubfolders = messagingFolder.hasSubfolders();
-            }
-            retval.setTreeID(treeId);
-            /*
-             * Check if denoted parent can hold default folders like Trash, Sent, etc.
-             */
-            if (!"".equals(fullname) && !"INBOX".equals(fullname)) {
                 /*
-                 * Denoted parent is not capable to hold default folders. Therefore output as it is.
+                 * Check if denoted parent can hold default folders like Trash, Sent, etc.
                  */
-                final List<MessagingFolder> children = Arrays.asList(accountAccess.getFolderAccess().getSubfolders(fullname, true));
-                Collections.sort(children, new SimpleMessagingFolderComparator(storageParameters.getUser().getLocale()));
-                final String[] subfolderIds = new String[children.size()];
-                int i = 0;
-                for (final MessagingFolder child : children) {
-                    subfolderIds[i++] = MessagingFolderIdentifier.getFQN(serviceId, accountId, child.getId());
-                }
-                retval.setSubfolderIDs(subfolderIds);
-            } else {
-                /*
-                 * This one needs sorting. Just pass null or an empty array.
-                 */
-                retval.setSubfolderIDs(hasSubfolders ? null : new String[0]);
-
-                if (false) {
+                if ("INBOX".equals(fullname)) {
                     /*
-                     * Ensure default folders are at first positions
+                     * This one needs sorting. Just pass null or an empty array.
+                     */
+                    retval.setSubfolderIDs(hasSubfolders ? null : new String[0]);
+                } else {
+                    /*
+                     * Denoted parent is not capable to hold default folders. Therefore output as it is.
                      */
                     final List<MessagingFolder> children = Arrays.asList(accountAccess.getFolderAccess().getSubfolders(fullname, true));
-                    final String[] names;
-                    if (isDefaultFoldersChecked(accountId, storageParameters.getSession())) {
-                        names = getSortedDefaultMessagingFolders(accountId, storageParameters.getSession());
-                    } else {
-                        final List<String> tmp = new ArrayList<String>();
-                        tmp.add("INBOX");
-
-                        final MessagingFolderAccess folderStorage = accountAccess.getFolderAccess();
-                        String fn = folderStorage.getDraftsFolder();
-                        if (null != fn) {
-                            tmp.add(fn);
-                        }
-
-                        fn = folderStorage.getSentFolder();
-                        if (null != fn) {
-                            tmp.add(fn);
-                        }
-
-                        fn = folderStorage.getSpamFolder();
-                        if (null != fn) {
-                            tmp.add(fn);
-                        }
-
-                        fn = folderStorage.getTrashFolder();
-                        if (null != fn) {
-                            tmp.add(fn);
-                        }
-
-                        names = tmp.toArray(new String[tmp.size()]);
-                    }
-                    /*
-                     * Sort them
-                     */
-                    Collections.sort(children, new MessagingFolderComparator(names, storageParameters.getUser().getLocale()));
+                    Collections.sort(children, new SimpleMessagingFolderComparator(storageParameters.getUser().getLocale()));
                     final String[] subfolderIds = new String[children.size()];
                     int i = 0;
                     for (final MessagingFolder child : children) {
@@ -626,10 +606,13 @@ public final class MessagingFolderStorage implements FolderStorage {
                     retval.setSubfolderIDs(subfolderIds);
                 }
             }
+            retval.setTreeID(treeId);
 
             return retval;
         } catch (final MessagingException e) {
             throw new FolderException(e);
+        } catch (final ServiceException e) {
+            throw new FolderException(e);
         }
     }
 
@@ -676,7 +659,7 @@ public final class MessagingFolderStorage implements FolderStorage {
                 final List<MessagingAccount> accounts = new ArrayList<MessagingAccount>(8);
                 {
                     final MessagingServiceRegistry registry = getServiceRegistry().getService(MessagingServiceRegistry.class, true);
-                    final List<MessagingService> allServices = registry.getAllServices();
+                    final List<MessagingService> allServices = registry.getAllServices(session.getUserId(), session.getContextId());
                     final boolean available = mailFolderStorageAvailable;
                     final String mailMessagingServiceId = MailMessagingService.ID;
                     for (final MessagingService messagingService : allServices) {
@@ -710,7 +693,7 @@ public final class MessagingFolderStorage implements FolderStorage {
                 final List<SortableId> list = new ArrayList<SortableId>(size);
                 for (int j = 0; j < size; j++) {
                     final MessagingAccount acc = accounts.get(j);
-                    list.add(new MessagingId(MessagingFolderIdentifier.getFQN(acc.getMessagingService().getId(), acc.getId(), ""), j));
+                    list.add(new MessagingId(MessagingFolderIdentifier.getFQN(acc.getMessagingService().getId(), acc.getId(), ""), j, null));
                 }
                 return list.toArray(new SortableId[list.size()]);
             }
@@ -719,11 +702,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(parentId);
@@ -787,7 +768,8 @@ public final class MessagingFolderStorage implements FolderStorage {
             final List<SortableId> list = new ArrayList<SortableId>(children.size());
             final int size = children.size();
             for (int j = 0; j < size; j++) {
-                list.add(new MessagingId(MessagingFolderIdentifier.getFQN(serviceId, accountId, children.get(j).getId()), j));
+                final MessagingFolder cur = children.get(j);
+                list.add(new MessagingId(MessagingFolderIdentifier.getFQN(serviceId, accountId, cur.getId()), j, cur.getName()));
             }
             return list.toArray(new SortableId[list.size()]);
         } catch (final MessagingException e) {
@@ -803,7 +785,7 @@ public final class MessagingFolderStorage implements FolderStorage {
         @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
             (ConcurrentMap<Key, MessagingAccountAccess>) params.getParameter(
                 MessagingFolderType.getInstance(),
-                MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                PARAM);
         if (null != accesses) {
             try {
                 final Collection<MessagingAccountAccess> values = accesses.values();
@@ -811,7 +793,7 @@ public final class MessagingFolderStorage implements FolderStorage {
                     access.close();
                 }
             } finally {
-                params.putParameter(MessagingFolderType.getInstance(), MailParameterConstants.PARAM_MAIL_ACCESS, null);
+                params.putParameter(MessagingFolderType.getInstance(), PARAM, null);
             }
         }
     }
@@ -828,7 +810,7 @@ public final class MessagingFolderStorage implements FolderStorage {
          */
         return parameters.putParameterIfAbsent(
             MessagingFolderType.getInstance(),
-            MessagingParameterConstants.PARAM_MESSAGING_ACCESS,
+            PARAM,
             new ConcurrentHashMap<Key, MessagingAccountAccess>());
     }
 
@@ -848,11 +830,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folderId);
@@ -894,11 +874,9 @@ public final class MessagingFolderStorage implements FolderStorage {
             @SuppressWarnings("unchecked") final ConcurrentMap<Key, MessagingAccountAccess> accesses =
                 (ConcurrentMap<Key, MessagingAccountAccess>) storageParameters.getParameter(
                     MessagingFolderType.getInstance(),
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS);
+                    PARAM);
             if (null == accesses) {
-                throw new FolderException(new MailException(
-                    MailException.Code.MISSING_PARAM,
-                    MessagingParameterConstants.PARAM_MESSAGING_ACCESS));
+                throw FolderExceptionErrorMessage.MISSING_PARAMETER.create(PARAM);
             }
 
             final MessagingFolderIdentifier mfi = new MessagingFolderIdentifier(folder.getID());
@@ -1056,8 +1034,7 @@ public final class MessagingFolderStorage implements FolderStorage {
 
     private void check4DuplicateFolder(final MessagingAccountAccess accountAccess, final String parentId, final String name2check) throws MessagingException {
         final MessagingFolder[] subfolders = accountAccess.getFolderAccess().getSubfolders(parentId, true);
-        for (int j = 0; j < subfolders.length; j++) {
-            final MessagingFolder subfolder = subfolders[j];
+        for (final MessagingFolder subfolder : subfolders) {
             if (name2check.equals(subfolder.getName())) {
                 throw MessagingExceptionCodes.DUPLICATE_FOLDER.create(name2check, parentId);
             }
@@ -1092,7 +1069,7 @@ public final class MessagingFolderStorage implements FolderStorage {
         // Append messages to destination account
         /* final String[] mailIds = */destMessageStorage.appendMessages(destFullname, msgs.toArray(new MessagingMessage[msgs.size()]));
         /*-
-         * 
+         *
         // Ensure flags
         final String[] arr = new String[1];
         for (int i = 0; i < msgs.length; i++) {
@@ -1111,8 +1088,8 @@ public final class MessagingFolderStorage implements FolderStorage {
          */
         // Iterate subfolders
         final MessagingFolder[] tmp = srcAccess.getFolderAccess().getSubfolders(srcFullname, true);
-        for (int i = 0; i < tmp.length; i++) {
-            fullCopy(srcAccess, tmp[i].getId(), destAccess, destFullname, destSeparator, user, hasPermissions);
+        for (final MessagingFolder element : tmp) {
+            fullCopy(srcAccess, element.getId(), destAccess, destFullname, destSeparator, user, hasPermissions);
         }
         return destFullname;
     }
@@ -1129,7 +1106,7 @@ public final class MessagingFolderStorage implements FolderStorage {
 
         public int compare(final MessagingAccount o1, final MessagingAccount o2) {
             /*-
-             * 
+             *
             if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(o1.getMailProtocol())) {
                 if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(o2.getMailProtocol())) {
                     return 0;
