@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.messaging.registry.MessagingServiceRegistry;
 
 /**
  * {@link MessagingFolderType} - The folder type for messaging.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessagingFolderType implements FolderType {
@@ -66,7 +66,7 @@ public final class MessagingFolderType implements FolderType {
 
     /**
      * Gets the {@link MessagingFolderType} instance.
-     * 
+     *
      * @return The {@link MessagingFolderType} instance
      */
     public static MessagingFolderType getInstance() {
@@ -100,7 +100,7 @@ public final class MessagingFolderType implements FolderType {
         try {
             pfi = new MessagingFolderIdentifier(folderId);
         } catch (final FolderException e) {
-            // org.apache.commons.logging.LogFactory.getLog(MessagingFolderType.class).warn(e.getMessage(), e);
+            // com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MessagingFolderType.class)).warn(e.getMessage(), e);
             return false;
         }
         /*
@@ -111,7 +111,7 @@ public final class MessagingFolderType implements FolderType {
         if (null == registry) {
             return false;
         }
-        if (!registry.containsMessagingService(pfi.getServiceId())) {
+        if (!registry.containsMessagingService(pfi.getServiceId(), -1, -1)) { // FIXME: Please pass user and context
             return false;
         }
         return true;
