@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.folderstorage.SortableId;
 
 /**
  * {@link MessagingId} - A messaging ID.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessagingId implements SortableId {
@@ -62,16 +62,24 @@ public final class MessagingId implements SortableId {
 
     private final int ordinal;
 
+    private final String name;
+
     /**
      * Initializes a new {@link MessagingId}.
-     * 
+     *
      * @param fullname The fullname
      * @param ordinal The ordinal
+     * @param name The name
      */
-    public MessagingId(final String fullname, final int ordinal) {
+    public MessagingId(final String fullname, final int ordinal, final String name) {
         super();
         this.fullname = fullname;
         this.ordinal = ordinal;
+        this.name = name;
+    }
+
+    public String getName() {
+        return name;
     }
 
     public String getId() {
@@ -87,7 +95,7 @@ public final class MessagingId implements SortableId {
 
     public int compareTo(final SortableId o) {
         if (o instanceof MessagingId) {
-            final int thisVal = this.ordinal;
+            final int thisVal = ordinal;
             final int anotherVal = ((MessagingId) o).ordinal;
             return (thisVal < anotherVal ? -1 : (thisVal == anotherVal ? 0 : 1));
         }
