@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,11 +52,17 @@ package com.openexchange.folderstorage.osgi;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.locks.Lock;
+import java.util.concurrent.locks.ReentrantLock;
+import org.json.JSONObject;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTracker;
+import com.openexchange.ajax.customizer.folder.AdditionalFieldsUtils;
+import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.folderstorage.ContentTypeDiscoveryService;
 import com.openexchange.folderstorage.FolderExceptionFactory;
@@ -64,21 +70,113 @@ import com.openexchange.folderstorage.FolderService;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.cache.osgi.CacheFolderStorageActivator;
 import com.openexchange.folderstorage.database.osgi.DatabaseFolderStorageActivator;
+import com.openexchange.folderstorage.filestorage.osgi.FileStorageFolderStorageActivator;
 import com.openexchange.folderstorage.internal.ContentTypeRegistry;
 import com.openexchange.folderstorage.internal.FolderServiceImpl;
 import com.openexchange.folderstorage.mail.osgi.MailFolderStorageActivator;
 import com.openexchange.folderstorage.messaging.osgi.MessagingFolderStorageActivator;
 import com.openexchange.folderstorage.outlook.osgi.OutlookFolderStorageActivator;
+import com.openexchange.folderstorage.virtual.osgi.VirtualFolderStorageActivator;
 import com.openexchange.groupware.EnumComponent;
+import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link FolderStorageActivator} - {@link BundleActivator Activator} for folder storage framework.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FolderStorageActivator implements BundleActivator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(FolderStorageActivator.class);
+    private static final class Key {
+
+        public static Key valueOf(final int userId, final int cid) {
+            return new Key(userId, cid);
+        }
+
+        private final int userId;
+
+        private final int cid;
+
+        private final int hash;
+
+        public Key(final int userId, final int cid) {
+            super();
+            this.userId = userId;
+            this.cid = cid;
+            final int prime = 31;
+            int result = 1;
+            result = prime * result + cid;
+            result = prime * result + userId;
+            hash = result;
+        }
+
+        @Override
+        public int hashCode() {
+            return hash;
+        }
+
+        @Override
+        public boolean equals(final Object obj) {
+            if (this == obj) {
+                return true;
+            }
+            if (!(obj instanceof Key)) {
+                return false;
+            }
+            final Key other = (Key) obj;
+            if (cid != other.cid) {
+                return false;
+            }
+            if (userId != other.userId) {
+                return false;
+            }
+            return true;
+        }
+
+    }
+
+    private static final class DisplayNameFolderField implements AdditionalFolderField {
+
+        private final ConcurrentMap<Key, String> cache;
+
+        protected DisplayNameFolderField() {
+            super();
+            final Lock lock = new ReentrantLock();
+            cache = new LockBasedConcurrentMap<Key, String>(lock, lock, new MaxCapacityLinkedHashMap<Key, String>(1000));
+        }
+
+        public Object renderJSON(final Object value) {
+            return value == null ? JSONObject.NULL : value;
+        }
+
+        public Object getValue(final FolderObject folder, final ServerSession session) {
+            final int createdBy = folder.getCreatedBy();
+            if (createdBy <= 0) {
+                return JSONObject.NULL;
+            }
+            final Context context = session.getContext();
+            final String displayName = cache.get(Key.valueOf(createdBy, context.getContextId()));
+            return null == displayName ? UserStorage.getStorageUser(createdBy, context).getDisplayName() : displayName;
+        }
+
+        public String getColumnName() {
+            return "com.openexchange.folderstorage.displayName";
+        }
+
+        public int getColumnID() {
+            return 3030;
+        }
+
+        public List<Object> getValues(final List<FolderObject> folder, final ServerSession session) {
+            return AdditionalFieldsUtils.bulk(this, folder, session);
+        }
+
+    }
+
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FolderStorageActivator.class));
 
     private ComponentRegistration componentRegistration;
 
@@ -112,6 +210,7 @@ public final class FolderStorageActivator implements BundleActivator {
                 ContentTypeDiscoveryService.class.getName(),
                 ContentTypeRegistry.getInstance(),
                 null));
+            serviceRegistrations.add(context.registerService(AdditionalFolderField.class.getName(), new DisplayNameFolderField(), null));
             // Register service trackers
             serviceTrackers = new ArrayList<ServiceTracker>(4);
             serviceTrackers.add(new ServiceTracker(context, FolderStorage.class.getName(), new FolderStorageTracker(context)));
@@ -120,13 +219,14 @@ public final class FolderStorageActivator implements BundleActivator {
             }
 
             // Start other activators
-            activators = new ArrayList<BundleActivator>(4);
+            activators = new ArrayList<BundleActivator>(8);
             activators.add(new DatabaseFolderStorageActivator()); // Database impl
             activators.add(new MailFolderStorageActivator()); // Mail impl
             activators.add(new MessagingFolderStorageActivator()); // Messaging impl
+            activators.add(new FileStorageFolderStorageActivator()); // File storage impl
             activators.add(new CacheFolderStorageActivator()); // Cache impl
             activators.add(new OutlookFolderStorageActivator()); // MS Outlook storage activator
-            // activators.add(new VirtualFolderStorageActivator()); // Virtual storage activator
+            activators.add(new VirtualFolderStorageActivator()); // Virtual storage activator
             BundleActivator activator = null;
             for (final Iterator<BundleActivator> iter = activators.iterator(); iter.hasNext();) {
                 try {
@@ -149,7 +249,7 @@ public final class FolderStorageActivator implements BundleActivator {
             if (LOG.isInfoEnabled()) {
                 final StringBuilder sb = new StringBuilder(32);
                 sb.append("Bundle \"");
-                sb.append(FolderStorageActivator.class.getName());
+                sb.append("com.openexchange.folderstorage");
                 sb.append("\" successfully started!");
                 LOG.info(sb.toString());
             }
@@ -206,7 +306,7 @@ public final class FolderStorageActivator implements BundleActivator {
             if (LOG.isInfoEnabled()) {
                 final StringBuilder sb = new StringBuilder(32);
                 sb.append("Bundle \"");
-                sb.append(FolderStorageActivator.class.getName());
+                sb.append("com.openexchange.folderstorage");
                 sb.append("\" successfully stopped!");
                 LOG.info(sb.toString());
             }
