@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,12 +51,12 @@ package com.openexchange.folderstorage.outlook;
 
 import java.util.ArrayList;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
+import java.util.Queue;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.CopyOnWriteArrayList;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
@@ -65,7 +65,7 @@ import com.openexchange.folderstorage.StoragePriority;
 
 /**
  * {@link OutlookFolderStorageRegistry} - MS Outlook storage's registry for real folder storages.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OutlookFolderStorageRegistry implements FolderStorageDiscoverer {
@@ -74,7 +74,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Gets the {@link OutlookFolderStorageRegistry} instance.
-     * 
+     *
      * @return The {@link OutlookFolderStorageRegistry} instance
      */
     public static OutlookFolderStorageRegistry getInstance() {
@@ -85,9 +85,9 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
      * Member section
      */
 
-    private final ConcurrentMap<String, List<FolderStorage>> registry;
+    private final ConcurrentMap<String, Queue<FolderStorage>> registry;
 
-    private final List<FolderStorage> genStorages;
+    private final Queue<FolderStorage> genStorages;
 
     private final ConcurrentMap<ContentType, FolderStorage> contentTypes;
 
@@ -96,14 +96,14 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
      */
     private OutlookFolderStorageRegistry() {
         super();
-        registry = new ConcurrentHashMap<String, List<FolderStorage>>();
-        genStorages = new CopyOnWriteArrayList<FolderStorage>();
+        registry = new ConcurrentHashMap<String, Queue<FolderStorage>>();
+        genStorages = new ConcurrentLinkedQueue<FolderStorage>();
         contentTypes = new ConcurrentHashMap<ContentType, FolderStorage>();
     }
 
     /**
      * Associates specified folder storage to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to add
      * @return <code>true</code> If registration was successful; otherwise <code>false</code>
@@ -124,7 +124,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
                 } else {
                     // No, already present
                     final org.apache.commons.logging.Log log =
-                        org.apache.commons.logging.LogFactory.getLog(OutlookFolderStorageRegistry.class);
+                        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OutlookFolderStorageRegistry.class));
                     if (log.isErrorEnabled()) {
                         log.error("Duplicate folder storage for content type \"" + contentTypes[j].toString() + "\"", new Throwable());
                     }
@@ -142,9 +142,9 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         if (FolderStorage.ALL_TREE_ID.equals(treeId)) {
             genStorages.add(folderStorage);
         } else {
-            List<FolderStorage> storages = registry.get(treeId);
+            Queue<FolderStorage> storages = registry.get(treeId);
             if (null == storages) {
-                final List<FolderStorage> tmp = new CopyOnWriteArrayList<FolderStorage>();
+                final Queue<FolderStorage> tmp = new ConcurrentLinkedQueue<FolderStorage>();
                 storages = registry.putIfAbsent(treeId, tmp);
                 if (null == storages) {
                     storages = tmp;
@@ -160,8 +160,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (folderStorage.getFolderType().servesTreeId(treeId)) {
                     return folderStorage;
                 }
@@ -170,7 +169,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return null;
         }
@@ -184,7 +183,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Gets the dedicated folder storage for specified tree-folder-pair.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderId The folder identifier
      * @return The dedicated folder storage for specified tree-folder-pair or <code>null</code>
@@ -193,7 +192,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return null;
         }
@@ -210,8 +209,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId) && folderType.servesParentId(parentId)) {
                     return new FolderStorage[] { folderStorage };
@@ -221,7 +219,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -239,8 +237,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -250,7 +247,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -262,8 +259,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (!StoragePriority.HIGHEST.equals(folderStorage.getStoragePriority()) && folderStorage.getFolderType().servesTreeId(
                     treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -273,7 +269,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         /*
          * Obtain candidates by tree identifier
          */
-        final List<FolderStorage> storages = registry.get(treeId);
+        final Queue<FolderStorage> storages = registry.get(treeId);
         if (null == storages) {
             return new FolderStorage[0];
         }
@@ -293,7 +289,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Removes specified folder storage bound to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to remove
      */
@@ -305,7 +301,7 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         if (FolderStorage.ALL_TREE_ID.equals(treeId)) {
             genStorages.remove(folderStorage);
         } else {
-            final List<FolderStorage> storages = registry.get(treeId);
+            final Queue<FolderStorage> storages = registry.get(treeId);
             if (null == storages) {
                 return;
             }
@@ -314,8 +310,8 @@ public final class OutlookFolderStorageRegistry implements FolderStorageDiscover
         // Unregister storage's content types
         final ContentType[] contentTypes = folderStorage.getSupportedContentTypes();
         if (null != contentTypes && contentTypes.length > 0) {
-            for (int j = 0; j < contentTypes.length; j++) {
-                this.contentTypes.remove(contentTypes[j]);
+            for (final ContentType contentType : contentTypes) {
+                this.contentTypes.remove(contentType);
             }
         }
     }
