@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,7 @@ import com.openexchange.folderstorage.database.DatabaseId;
 
 /**
  * {@link OutlookId} - A MS Outlook ID which orders subfolder by name in a locale-sensitive way.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OutlookId implements SortableId {
@@ -63,16 +63,24 @@ public final class OutlookId implements SortableId {
 
     private final int ordinal;
 
+    private final String name;
+
     /**
      * Initializes a new {@link DatabaseId}.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ordinal The ordinal
+     * @param name The name
      */
-    public OutlookId(final String folderId, final int ordinal) {
+    public OutlookId(final String folderId, final int ordinal, final String name) {
         super();
         this.folderId = folderId;
         this.ordinal = ordinal;
+        this.name = name;
+    }
+
+    public String getName() {
+        return name;
     }
 
     public String getId() {
@@ -86,7 +94,7 @@ public final class OutlookId implements SortableId {
     public int compareTo(final SortableId o) {
         // Compare by ordinal
         if (o instanceof OutlookId) {
-            final int thisVal = this.ordinal;
+            final int thisVal = ordinal;
             final int anotherVal = ((OutlookId) o).ordinal;
             return (thisVal < anotherVal ? -1 : (thisVal == anotherVal ? 0 : 1));
         }
