@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,7 +62,7 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Delete} - SQL for deleting a virtual folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Delete {
@@ -77,30 +77,47 @@ public final class Delete {
     private static final String SQL_DELETE_SUBS =
         "DELETE FROM virtualSubscription WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE_SUBS =
+        "DELETE FROM virtualSubscription WHERE cid = ? AND tree = ? AND folderId = ?";
+
     private static final String SQL_DELETE_INSERT_SUBS =
         "INSERT INTO virtualBackupSubscription SELECT * FROM virtualSubscription WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE_INSERT_SUBS =
+        "INSERT INTO virtualBackupSubscription SELECT * FROM virtualSubscription WHERE cid = ? AND tree = ? AND folderId = ?";
+
     private static final String SQL_DELETE_PERMS = "DELETE FROM virtualPermission WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE_PERMS = "DELETE FROM virtualPermission WHERE cid = ? AND tree = ? AND folderId = ?";
+
     private static final String SQL_DELETE_INSERT_PERMS =
         "INSERT INTO virtualBackupPermission SELECT * FROM virtualPermission WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE_INSERT_PERMS =
+        "INSERT INTO virtualBackupPermission SELECT * FROM virtualPermission WHERE cid = ? AND tree = ? AND folderId = ?";
+
     private static final String SQL_DELETE = "DELETE FROM virtualTree WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE = "DELETE FROM virtualTree WHERE cid = ? AND tree = ? AND folderId = ?";
+
     private static final String SQL_DELETE_INSERT =
         "INSERT INTO virtualBackupTree SELECT * FROM virtualTree WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?";
 
+    private static final String SQL_GLOBAL_DELETE_INSERT =
+        "INSERT INTO virtualBackupTree SELECT * FROM virtualTree WHERE cid = ? AND tree = ? AND folderId = ?";
+
     /**
      * Deletes specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
      * @param folderId The folder identifier
+     * @param global <code>true</code> for global folder; otherwise <code>false</code>
      * @param backup <code>true</code> to backup folder data prior to deletion; otherwise <code>false</code>
      * @throws FolderException If delete fails
      */
-    public static void deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup) throws FolderException {
+    public static boolean deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean global, final boolean backup) throws FolderException {
         final DatabaseService databaseService = getDatabaseService();
         // Get a connection
         final Connection con;
@@ -111,8 +128,9 @@ public final class Delete {
         }
         try {
             con.setAutoCommit(false); // BEGIN
-            deleteFolder(cid, tree, user, folderId, backup, con);
+            final boolean ret = deleteFolder(cid, tree, user, folderId, global, backup, con);
             con.commit(); // COMMIT
+            return ret;
         } catch (final SQLException e) {
             DBUtils.rollback(con); // ROLLBACK
             throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
@@ -130,29 +148,34 @@ public final class Delete {
 
     /**
      * Deletes specified folder with specified connection.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
      * @param folderId The folder identifier
+     * @param global <code>true</code> for global folder; otherwise <code>false</code>
      * @param backup <code>true</code> to backup folder data prior to deletion; otherwise <code>false</code>
      * @param con The connection to use
      * @return <code>true</code> if a folder denoted by given identifier was deleted; otherwise <code>false</code>
      * @throws FolderException If delete fails
      */
-    public static boolean deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup, final Connection con) throws FolderException {
+    public static boolean deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean global, final boolean backup, final Connection con) throws FolderException {
+        if (null == con) {
+            return deleteFolder(cid, tree, user, folderId, global, backup);
+        }
         PreparedStatement stmt = null;
-
         if (backup) {
             /*
              * Backup folder data
              */
             try {
-                stmt = con.prepareStatement(SQL_DELETE_INSERT);
+                stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE_INSERT : SQL_DELETE_INSERT);
                 int pos = 1;
                 stmt.setInt(pos++, cid);
                 stmt.setInt(pos++, tree);
-                stmt.setInt(pos++, user);
+                if (!global) {
+                    stmt.setInt(pos++, user);
+                }
                 stmt.setString(pos, folderId);
                 stmt.executeUpdate();
             } catch (final SQLException e) {
@@ -160,7 +183,7 @@ public final class Delete {
                  * Backup failed
                  */
                 debugSQL(stmt);
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Delete.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Delete.class));
                 if (LOG.isDebugEnabled()) {
                     LOG.debug("Backup failed.", e);
                 }
@@ -171,16 +194,18 @@ public final class Delete {
              * Backup permission data
              */
             try {
-                stmt = con.prepareStatement(SQL_DELETE_INSERT_PERMS);
+                stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE_INSERT_PERMS : SQL_DELETE_INSERT_PERMS);
                 int pos = 1;
                 stmt.setInt(pos++, cid);
                 stmt.setInt(pos++, tree);
-                stmt.setInt(pos++, user);
+                if (!global) {
+                    stmt.setInt(pos++, user);
+                }
                 stmt.setString(pos, folderId);
                 stmt.executeUpdate();
             } catch (final SQLException e) {
                 debugSQL(stmt);
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Delete.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Delete.class));
                 if (LOG.isDebugEnabled()) {
                     LOG.debug("Backup failed.", e);
                 }
@@ -191,16 +216,18 @@ public final class Delete {
              * Backup subscribe data
              */
             try {
-                stmt = con.prepareStatement(SQL_DELETE_INSERT_SUBS);
+                stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE_INSERT_SUBS : SQL_DELETE_INSERT_SUBS);
                 int pos = 1;
                 stmt.setInt(pos++, cid);
                 stmt.setInt(pos++, tree);
-                stmt.setInt(pos++, user);
+                if (!global) {
+                    stmt.setInt(pos++, user);
+                }
                 stmt.setString(pos, folderId);
                 stmt.executeUpdate();
             } catch (final SQLException e) {
                 debugSQL(stmt);
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Delete.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Delete.class));
                 if (LOG.isDebugEnabled()) {
                     LOG.debug("Backup failed.", e);
                 }
@@ -212,11 +239,13 @@ public final class Delete {
          * Delete subscribe data
          */
         try {
-            stmt = con.prepareStatement(SQL_DELETE_SUBS);
+            stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE_SUBS : SQL_DELETE_SUBS);
             int pos = 1;
             stmt.setInt(pos++, cid);
             stmt.setInt(pos++, tree);
-            stmt.setInt(pos++, user);
+            if (!global) {
+                stmt.setInt(pos++, user);
+            }
             stmt.setString(pos, folderId);
             stmt.executeUpdate();
         } catch (final SQLException e) {
@@ -229,11 +258,13 @@ public final class Delete {
          * Delete permission data
          */
         try {
-            stmt = con.prepareStatement(SQL_DELETE_PERMS);
+            stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE_PERMS : SQL_DELETE_PERMS);
             int pos = 1;
             stmt.setInt(pos++, cid);
             stmt.setInt(pos++, tree);
-            stmt.setInt(pos++, user);
+            if (!global) {
+                stmt.setInt(pos++, user);
+            }
             stmt.setString(pos, folderId);
             stmt.executeUpdate();
         } catch (final SQLException e) {
@@ -246,11 +277,13 @@ public final class Delete {
          * Delete folder data
          */
         try {
-            stmt = con.prepareStatement(SQL_DELETE);
+            stmt = con.prepareStatement(global ? SQL_GLOBAL_DELETE : SQL_DELETE);
             int pos = 1;
             stmt.setInt(pos++, cid);
             stmt.setInt(pos++, tree);
-            stmt.setInt(pos++, user);
+            if (!global) {
+                stmt.setInt(pos++, user);
+            }
             stmt.setString(pos, folderId);
             return stmt.executeUpdate() > 0;
         } catch (final SQLException e) {
