@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -77,7 +77,7 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Select} - SQL to load a virtual folder or its subfolder identifiers.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Select {
@@ -168,7 +168,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains a parent denoted by given parent identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -196,7 +196,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains a parent denoted by given parent identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -207,6 +207,9 @@ public final class Select {
      * @throws FolderException If checking folder's presence fails
      */
     public static boolean containsParent(final int cid, final int tree, final int user, final String parentId, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return containsParent(cid, tree, user, parentId, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -229,7 +232,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains a folder denoted by given folder identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -257,7 +260,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains a folder denoted by given folder identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -268,6 +271,9 @@ public final class Select {
      * @throws FolderException If checking folder's presence fails
      */
     public static boolean containsFolder(final int cid, final int tree, final int user, final String folderId, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return containsFolder(cid, tree, user, folderId, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -290,7 +296,7 @@ public final class Select {
 
     /**
      * Gets the name of the folder held in virtual tree for the folder denoted by given folder identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -317,7 +323,7 @@ public final class Select {
 
     /**
      * Gets the name of the folder held in virtual tree for the folder denoted by given folder identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -327,6 +333,9 @@ public final class Select {
      * @throws FolderException If returning folder's name fails
      */
     public static String getFolderName(final int cid, final int tree, final int user, final String folderId, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return getFolderName(cid, tree, user, folderId, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -349,7 +358,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains any of the folders denoted by given folder identifiers.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -376,7 +385,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains any of the folders denoted by given folder identifiers.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -386,6 +395,9 @@ public final class Select {
      * @throws FolderException If checking folder's presence fails
      */
     public static boolean[] containsFolders(final int cid, final int tree, final int user, final String[] folderIds, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return containsFolders(cid, tree, user, folderIds, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -416,7 +428,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains any of the folders denoted by given folder identifiers.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -443,7 +455,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains any of the folders denoted by given folder identifiers.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -453,6 +465,9 @@ public final class Select {
      * @throws FolderException If checking folder's presence fails
      */
     public static boolean[] containsFolders(final int cid, final int tree, final int user, final SortableId[] folderIds, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return containsFolders(cid, tree, user, folderIds, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -483,7 +498,7 @@ public final class Select {
 
     /**
      * Fills specified folder, does nothing if folder does not exist in tables.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -515,7 +530,7 @@ public final class Select {
 
     /**
      * Fills specified folder, does nothing if folder does not exist in tables.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -526,6 +541,9 @@ public final class Select {
      * @throws FolderException If filling the folder fails
      */
     public static boolean fillFolder(final int cid, final int tree, final int user, final Locale locale, final OutlookFolder outlookFolder, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return fillFolder(cid, tree, user, locale, outlookFolder, storageType);
+        }
         final String folderId = outlookFolder.getID();
         // Select folder data
         PreparedStatement stmt = null;
@@ -572,7 +590,7 @@ public final class Select {
             }
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -615,7 +633,7 @@ public final class Select {
             }
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -643,7 +661,7 @@ public final class Select {
             outlookFolder.setSubscribed(subscribed);
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -679,7 +697,7 @@ public final class Select {
             }
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -694,7 +712,7 @@ public final class Select {
 
     /**
      * Gets the sorted identifiers of the subfolders located below specified parent.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -723,7 +741,7 @@ public final class Select {
 
     /**
      * Gets the sorted identifiers of the subfolders located below specified parent.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -736,6 +754,9 @@ public final class Select {
      * @throws FolderException If subfolders cannot be detected
      */
     public static String[] getSubfolderIds(final int cid, final int tree, final int user, final Locale locale, final String parentId, final List<String[]> realSubfolderIds, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return getSubfolderIds(cid, tree, user, locale, parentId, realSubfolderIds, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -767,7 +788,7 @@ public final class Select {
                 }
             } else {
                 final TreeMap<String, List<String>> treeMap = new TreeMap<String, List<String>>(new FolderNameComparator(locale));
-                final StringHelper stringHelper = new StringHelper(locale);
+                final StringHelper stringHelper = StringHelper.valueOf(locale);
                 for (final String[] realSubfolderId : realSubfolderIds) {
                     final String localizedName = stringHelper.getString(realSubfolderId[1]);
                     List<String> list = treeMap.get(localizedName);
@@ -800,7 +821,7 @@ public final class Select {
             return subfolderIds.toArray(new String[subfolderIds.size()]);
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -831,6 +852,9 @@ public final class Select {
     private static final String SQL_SELECT_ALL = "SELECT folderId FROM virtualTree WHERE cid = ? AND tree = ? AND user = ?";
 
     public static List<String> getFolders(final int cid, final int tree, final int user, final Connection con) throws FolderException {
+        if (null == con) {
+            return getFolders(cid, tree, user);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -851,7 +875,7 @@ public final class Select {
             return l;
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -882,6 +906,9 @@ public final class Select {
     }
 
     public static List<String[]> getSubfolderIds(final int cid, final int tree, final int user, final String parentId, final StorageType storageType, final Connection con) throws FolderException {
+        if (null == con) {
+            return getSubfolderIds(cid, tree, user, parentId, storageType);
+        }
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -905,7 +932,7 @@ public final class Select {
             return l;
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
