@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,17 +52,25 @@ package com.openexchange.folderstorage.outlook.sql;
 import static com.openexchange.folderstorage.outlook.sql.Utility.debugSQL;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
+import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Map.Entry;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventAdmin;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.folderstorage.Folder;
+import com.openexchange.folderstorage.FolderEventConstants;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
+import com.openexchange.folderstorage.mail.MailServiceRegistry;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Update} - SQL for updating a MS outlook folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Update {
@@ -75,11 +83,119 @@ public final class Update {
     }
 
     /**
-     * Updates specified folder.
+     * Updates identifiers.
      * 
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
+     * @param newId The new identifier
+     * @param oldId The old identifier
+     * @param delim The delimiter
+     * @throws FolderException If an error occurs
+     */
+    public static void updateIds(final int cid, final int tree, final int user, final String newId, final String oldId, final String delim) throws FolderException {
+        final DatabaseService databaseService = Utility.getDatabaseService();
+        // Get a connection
+        final Connection con;
+        try {
+            con = databaseService.getWritable(cid);
+            con.setAutoCommit(false); // BEGIN
+        } catch (final SQLException e) {
+            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+        } catch (final DBPoolingException e) {
+            throw new FolderException(e);
+        }
+        try {
+            updateIds(cid, tree, user, newId, oldId, delim, con);
+            con.commit(); // COMMIT
+        } catch (final SQLException e) {
+            DBUtils.rollback(con); // ROLLBACK
+            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+        } catch (final FolderException e) {
+            DBUtils.rollback(con); // ROLLBACK
+            throw e;
+        } catch (final Exception e) {
+            DBUtils.rollback(con); // ROLLBACK
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.autocommit(con);
+            databaseService.backWritable(cid, con);
+        }
+    }
+
+    /**
+     * Updates identifiers.
+     * 
+     * @param cid The context identifier
+     * @param tree The tree identifier
+     * @param user The user identifier
+     * @param newId The new identifier
+     * @param oldId The old identifier
+     * @param delim The delimiter
+     * @param con The connection to use
+     * @throws FolderException If an error occurs
+     */
+    public static void updateIds(final int cid, final int tree, final int user, final String newId, final String oldId, final String delim, final Connection con) throws FolderException {
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        try {
+            stmt = con.prepareStatement("UPDATE virtualTree SET parentId = ? WHERE cid = ? AND tree = ? AND user = ? AND parentId = ?");
+            stmt.setString(1, newId);
+            stmt.setInt(2, cid);
+            stmt.setInt(3, tree);
+            stmt.setInt(4, user);
+            stmt.setString(5, oldId);
+            stmt.executeUpdate();
+            DBUtils.closeSQLStuff(stmt);
+
+            final StringBuilder tmp = new StringBuilder();
+            final String prefix = tmp.append(oldId).append(delim).toString();
+            stmt = con.prepareStatement("SELECT parentId FROM virtualTree WHERE cid = ? AND tree = ? AND user = ? AND SUBSTRING(parentId,1,"+prefix.length()+") = ?");
+            stmt.setInt(1, cid);
+            stmt.setInt(2, tree);
+            stmt.setInt(3, user);
+            stmt.setString(4, prefix);
+            rs = stmt.executeQuery();
+            if (rs.next()) {
+                final Map<String, String> parentIds = new HashMap<String, String>();
+                do {
+                    final String oldS = rs.getString(1);
+                    final String tail = oldS.substring(prefix.length() + 1);
+                    tmp.setLength(0);
+                    final String newS = tmp.append(newId).append(delim).append(tail).toString();
+
+                    parentIds.put(newS, oldS);
+                } while (rs.next());
+                DBUtils.closeSQLStuff(rs, stmt);
+
+                stmt = con.prepareStatement("UPDATE virtualTree SET parentId = ? WHERE cid = ? AND tree = ? AND user = ? AND parentId = ?");
+                for (final Entry<String, String> entry : parentIds.entrySet()) {
+                    stmt.setString(1, entry.getKey());
+                    stmt.setInt(2, cid);
+                    stmt.setInt(3, tree);
+                    stmt.setInt(4, user);
+                    stmt.setString(5, entry.getValue());
+                    stmt.addBatch();
+
+                    // Post event
+                    postChangedId(entry.getValue(), user, cid);
+                }
+                stmt.executeBatch();
+            }
+        } catch (final SQLException e) {
+            debugSQL(stmt);
+            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(rs, stmt);
+        }
+    }
+
+    /**
+     * Updates specified folder.
+     *
+     * @param cid The context identifier
+     * @param tree The tree identifier
+     * @param user The user identifier
      * @param folder The folder
      * @throws FolderException If update fails
      */
@@ -96,7 +212,7 @@ public final class Update {
             throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
         }
         try {
-            if (Delete.deleteFolder(cid, tree, user, folder.getID(), false, con)) {
+            if (Delete.deleteFolder(cid, tree, user, folder.getID(), false, false, con)) {
                 Insert.insertFolder(cid, tree, user, folder, con);
             }
             con.commit(); // COMMIT
@@ -120,7 +236,7 @@ public final class Update {
 
     /**
      * Updates last-modified time stamp of specified folder in virtual table.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -162,7 +278,7 @@ public final class Update {
 
     /**
      * Updates last-modified time stamp of specified folder in virtual table.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -196,7 +312,7 @@ public final class Update {
 
     /**
      * Updates last-modified time stamp of specified folder in virtual table.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -229,7 +345,7 @@ public final class Update {
 
     /**
      * Updates last-modified time stamp of specified folder in virtual table.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -262,7 +378,7 @@ public final class Update {
 
     /**
      * Updates last-modified time stamp of specified folder in virtual table.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -290,4 +406,18 @@ public final class Update {
         }
     }
 
+    private static void postChangedId(final String folderId, final int userId, final int contextId) {
+        final EventAdmin eventAdmin = MailServiceRegistry.getServiceRegistry().getService(EventAdmin.class);
+        if (null != eventAdmin) {
+            final Map<String, Object> properties = new HashMap<String, Object>(6);
+            properties.put(FolderEventConstants.PROPERTY_CONTEXT, Integer.valueOf(contextId));
+            properties.put(FolderEventConstants.PROPERTY_USER, Integer.valueOf(userId));
+            properties.put(FolderEventConstants.PROPERTY_CONTENT_RELATED, Boolean.FALSE);
+            properties.put(FolderEventConstants.PROPERTY_FOLDER, folderId);
+            properties.put(FolderEventConstants.PROPERTY_IMMEDIATELY, Boolean.TRUE);
+            final Event event = new Event(FolderEventConstants.TOPIC, properties);
+            eventAdmin.postEvent(event);
+        }
+    }
+
 }
