@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.server.ServiceException;
 
 /**
  * {@link Utility}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Utility {
@@ -71,7 +71,7 @@ public final class Utility {
 
     /**
      * Gets the {@link DatabaseService} from service registry.
-     * 
+     *
      * @return The {@link DatabaseService} from service registry
      * @throws FolderException If {@link DatabaseService} is not contained in service registry
      */
@@ -87,12 +87,12 @@ public final class Utility {
 
     /**
      * Debugs given statement's SQL string.
-     * 
+     *
      * @param stmt The statement
      */
     public static void debugSQL(final PreparedStatement stmt) {
         if (null != stmt) {
-            final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Utility.class);
+            final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Utility.class));
             if (LOG.isDebugEnabled()) {
                 final String sql = getSQLString(stmt);
                 LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -102,7 +102,7 @@ public final class Utility {
 
     /**
      * Extracts SQL string from passed statement.
-     * 
+     *
      * @param stmt The statement
      * @return The extracted SQL string
      */
