@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,22 +49,29 @@
 
 package com.openexchange.folderstorage.virtual;
 
+import java.util.Collections;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.Locale;
+import java.util.Map;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
+import com.openexchange.folderstorage.FolderField;
+import com.openexchange.folderstorage.FolderProperty;
+import com.openexchange.folderstorage.ParameterizedFolder;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Type;
+import com.openexchange.i18n.LocaleTools;
 import com.openexchange.i18n.tools.StringHelper;
 
 /**
  * {@link VirtualFolder} - A virtual folder backed by a real folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class VirtualFolder implements Folder {
+public final class VirtualFolder implements ParameterizedFolder {
 
-    private static final long serialVersionUID = 1076412172524386127L;
+    private static final long serialVersionUID = -7353105231203614064L;
 
     private Folder realFolder;
 
@@ -83,20 +90,31 @@ public final class VirtualFolder implements Folder {
     private Permission[] permissions;
 
     private String[] subfolders;
+    private boolean b_subfolders;
 
-    private boolean subscribed;
+    private Boolean subscribed;
+
+    private Boolean subscribedSubfolders;
 
     private String newId;
 
+    private Map<FolderField, FolderProperty> properties;
+
     /**
      * Initializes a {@link VirtualFolder} with specified real folder.
-     * 
+     *
      * @param source The real folder which is mapped by this virtual folder
      */
     public VirtualFolder(final Folder source) {
         super();
-        this.realFolder = source;
+        realFolder = source;
         modifiedBy = -1;
+        properties = new HashMap<FolderField, FolderProperty>(4);
+    }
+
+    @Override
+    public String toString() {
+        return new StringBuilder(32).append("{ name=").append(getName()).append(", id=").append(getID()).append('}').toString();
     }
 
     @Override
@@ -106,7 +124,7 @@ public final class VirtualFolder implements Folder {
             clone.realFolder = (Folder) (realFolder == null ? null : realFolder.clone());
             clone.lastModified = cloneDate(lastModified);
             if (permissions != null) {
-                final Permission[] thisPermissions = this.permissions;
+                final Permission[] thisPermissions = permissions;
                 final Permission[] clonePermissions = new Permission[thisPermissions.length];
                 for (int i = 0; i < thisPermissions.length; i++) {
                     clonePermissions[i] = (Permission) thisPermissions[i].clone();
@@ -121,6 +139,10 @@ public final class VirtualFolder implements Folder {
                 }
                 clone.subfolders = cloneSub;
             }
+            if (properties != null) {
+                final Map<FolderField, FolderProperty> cloneProps = new HashMap<FolderField, FolderProperty>(properties);
+                clone.properties = cloneProps;
+            }
             return clone;
         } catch (final CloneNotSupportedException e) {
             throw new InternalError(e.getMessage());
@@ -136,19 +158,19 @@ public final class VirtualFolder implements Folder {
     }
 
     public int getCreatedBy() {
-        return realFolder.getCreatedBy();
+        return null == realFolder ? -1 : realFolder.getCreatedBy();
     }
 
     public Date getCreationDate() {
-        return realFolder.getCreationDate();
+        return null == realFolder ? null : realFolder.getCreationDate();
     }
 
     public Date getLastModified() {
-        return lastModified == null ? realFolder.getLastModified() : cloneDate(lastModified);
+        return lastModified == null ? (null == realFolder ? null : realFolder.getLastModified()) : cloneDate(lastModified);
     }
 
     public int getModifiedBy() {
-        return -1 == modifiedBy ? realFolder.getModifiedBy() : modifiedBy;
+        return -1 == modifiedBy ? (null == realFolder ? -1 : realFolder.getModifiedBy()) : modifiedBy;
     }
 
     public void setCreatedBy(final int createdBy) {
@@ -176,8 +198,12 @@ public final class VirtualFolder implements Folder {
     }
 
     public String getLocalizedName(final Locale locale) {
+        final Locale loc = null == locale ? LocaleTools.DEFAULT_LOCALE : locale;
+        if (null == name) {
+            return realFolder.getLocalizedName(loc);
+        }
         if (null == localizedName) {
-            localizedName = new StringHelper(locale).getString(getName());
+            localizedName = StringHelper.valueOf(loc).getString(name);
         }
         return localizedName;
     }
@@ -187,27 +213,27 @@ public final class VirtualFolder implements Folder {
     }
 
     public String getParentID() {
-        return parent;
+        return null == parent ? realFolder.getParentID() : parent;
     }
 
     /**
      * Gets either real folder's permissions or virtual folder's individual permissions (if set)
-     * 
+     *
      * <pre>
      * return permissions == null ? realFolder.getPermissions() : permissions;
      * </pre>
-     * 
+     *
      * @return The permissions for this virtual folder
      */
     public Permission[] getPermissions() {
         /*
          * If no permissions applied return real folder's permissions
          */
-        return permissions == null ? realFolder.getPermissions() : permissions;
+        return null == permissions ? realFolder.getPermissions() : permissions;
     }
 
     public String[] getSubfolderIDs() {
-        return subfolders;
+        return b_subfolders ? subfolders : realFolder.getSubfolderIDs();
     }
 
     public String getTreeID() {
@@ -228,11 +254,11 @@ public final class VirtualFolder implements Folder {
 
     public void setName(final String name) {
         this.name = name;
-        this.localizedName = null;
+        localizedName = null;
     }
 
     public void setParentID(final String parentId) {
-        this.parent = parentId;
+        parent = parentId;
     }
 
     public void setPermissions(final Permission[] permissions) {
@@ -240,11 +266,12 @@ public final class VirtualFolder implements Folder {
     }
 
     public void setSubfolderIDs(final String[] subfolderIds) {
-        this.subfolders = subfolderIds;
+        subfolders = subfolderIds;
+        b_subfolders = true;
     }
 
     public void setTreeID(final String id) {
-        this.treeId = id;
+        treeId = id;
     }
 
     public void setType(final Type type) {
@@ -252,19 +279,26 @@ public final class VirtualFolder implements Folder {
     }
 
     public boolean isSubscribed() {
-        return subscribed;
+        return null == subscribed ? realFolder.isSubscribed() : subscribed.booleanValue();
     }
 
     public void setSubscribed(final boolean subscribed) {
-        this.subscribed = subscribed;
+        this.subscribed = Boolean.valueOf(subscribed);
     }
 
     public boolean hasSubscribedSubfolders() {
-        throw new UnsupportedOperationException();
+        return null == subscribedSubfolders ? realFolder.hasSubscribedSubfolders() : subscribedSubfolders.booleanValue();
+        /*-
+         *
+        if (null == subscribedSubfolders) {
+            return null == subfolders || subfolders.length > 0;
+        }
+        return subscribedSubfolders.booleanValue();
+        */
     }
 
     public void setSubscribedSubfolders(final boolean subscribedSubfolders) {
-        throw new UnsupportedOperationException();
+        this.subscribedSubfolders = Boolean.valueOf(subscribedSubfolders);
     }
 
     public boolean isVirtual() {
@@ -272,11 +306,11 @@ public final class VirtualFolder implements Folder {
     }
 
     public boolean isGlobalID() {
-        return false;
+        return realFolder.isGlobalID();
     }
 
     public boolean isCacheable() {
-        return true;
+        return false;
     }
 
     public int getCapabilities() {
@@ -358,4 +392,16 @@ public final class VirtualFolder implements Folder {
         return new Date(d.getTime());
     }
 
+    public void setProperty(final FolderField name, final Object value) {
+        if (null == value) {
+            properties.remove(name);
+        } else {
+            properties.put(name, new FolderProperty(name.getName(), value));
+        }
+    }
+
+    public Map<FolderField, FolderProperty> getProperties() {
+        return Collections.unmodifiableMap(properties);
+    }
+
 }
