@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,6 @@ package com.openexchange.folderstorage.virtual;
 
 import java.util.ArrayList;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
@@ -65,7 +64,7 @@ import com.openexchange.folderstorage.StoragePriority;
 
 /**
  * {@link VirtualFolderStorageRegistry} - Virtual storage's registry for real folder storages.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class VirtualFolderStorageRegistry implements FolderStorageDiscoverer {
@@ -74,7 +73,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Gets the {@link VirtualFolderStorageRegistry} instance.
-     * 
+     *
      * @return The {@link VirtualFolderStorageRegistry} instance
      */
     public static VirtualFolderStorageRegistry getInstance() {
@@ -103,7 +102,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Associates specified folder storage to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to add
      * @return <code>true</code> If registration was successful; otherwise <code>false</code>
@@ -124,7 +123,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
                 } else {
                     // No, already present
                     final org.apache.commons.logging.Log log =
-                        org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageRegistry.class);
+                        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageRegistry.class));
                     if (log.isErrorEnabled()) {
                         log.error("Duplicate folder storage for content type \"" + contentTypes[j].toString() + "\"", new Throwable());
                     }
@@ -160,8 +159,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (folderStorage.getFolderType().servesTreeId(treeId)) {
                     return folderStorage;
                 }
@@ -187,8 +185,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId) && folderType.servesParentId(parentId)) {
                     return new FolderStorage[] { folderStorage };
@@ -216,8 +213,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 final FolderType folderType = folderStorage.getFolderType();
                 if (folderType.servesTreeId(treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -239,8 +235,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
             /*
              * Check general storages first
              */
-            for (final Iterator<FolderStorage> iterator = genStorages.iterator(); iterator.hasNext();) {
-                final FolderStorage folderStorage = iterator.next();
+            for (final FolderStorage folderStorage : genStorages) {
                 if (!StoragePriority.HIGHEST.equals(folderStorage.getStoragePriority()) && folderStorage.getFolderType().servesTreeId(
                     treeId)) {
                     return new FolderStorage[] { folderStorage };
@@ -270,7 +265,7 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
 
     /**
      * Removes specified folder storage bound to given tree identifier.
-     * 
+     *
      * @param treeId The tree identifier
      * @param folderStorage The folder storage to remove
      */
@@ -291,8 +286,8 @@ public final class VirtualFolderStorageRegistry implements FolderStorageDiscover
         // Unregister storage's content types
         final ContentType[] contentTypes = folderStorage.getSupportedContentTypes();
         if (null != contentTypes && contentTypes.length > 0) {
-            for (int j = 0; j < contentTypes.length; j++) {
-                this.contentTypes.remove(contentTypes[j]);
+            for (final ContentType contentType : contentTypes) {
+                this.contentTypes.remove(contentType);
             }
         }
     }
