@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,7 +65,7 @@ import com.openexchange.groupware.update.UpdateTask;
 
 /**
  * {@link VirtualTreeCreateTableTask} - Inserts necessary tables to support virtual folder trees.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class VirtualTreeCreateTableTask implements UpdateTask {
@@ -118,7 +118,7 @@ public class VirtualTreeCreateTableTask implements UpdateTask {
         createTable("virtualBackupPermission", getDelTable2(), contextId);
         createTable("virtualBackupSubscription", getDelTable3(), contextId);
 
-        final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(VirtualTreeCreateTableTask.class);
+        final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(VirtualTreeCreateTableTask.class));
         if (LOG.isInfoEnabled()) {
             LOG.info("UpdateTask 'VirtualTreeCreateTableTask' successfully performed!");
         }
@@ -148,7 +148,7 @@ public class VirtualTreeCreateTableTask implements UpdateTask {
 
     /**
      * Check a table's existence
-     * 
+     *
      * @param tableName The table name to check
      * @param dbmd The database's meta data
      * @return <code>true</code> if table exists; otherwise <code>false</code>
