@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,8 +69,8 @@ import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.virtual.sql.Insert;
 import com.openexchange.groupware.contexts.impl.ContextException;
-import com.openexchange.login.LoginResult;
 import com.openexchange.login.LoginHandlerService;
+import com.openexchange.login.LoginResult;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.dataobjects.MailFolder;
@@ -88,7 +88,7 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link VirtualTreeMigrationLoginHandler} - Migration for virtual tree structure.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class VirtualTreeMigrationLoginHandler implements LoginHandlerService {
@@ -167,7 +167,7 @@ public class VirtualTreeMigrationLoginHandler implements LoginHandlerService {
                                 mailFolder.setTreeID("1");
                                 mailFolder.setParentID(FolderStorage.ROOT_ID);
                                 mailFolder.setSubscribed(true);
-                                Insert.insertFolder(s.getContextId(), 1, s.getUserId(), mailFolder);
+                                Insert.insertFolder(s.getContextId(), 1, s.getUserId(), mailFolder, null, s);
                             }
                         }
                     }
@@ -215,7 +215,7 @@ public class VirtualTreeMigrationLoginHandler implements LoginHandlerService {
         mailFolder.setTreeID("1");
         mailFolder.setParentID("1");
         mailFolder.setSubscribed(true);
-        Insert.insertFolder(s.getContextId(), 1, s.getUserId(), mailFolder);
+        Insert.insertFolder(s.getContextId(), 1, s.getUserId(), mailFolder, null, s);
     }
 
     public void handleLogout(final LoginResult logout) throws LoginException {
