@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,9 +57,9 @@ import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
@@ -76,11 +76,14 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
+import com.openexchange.groupware.i18n.MailStrings;
+import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
 import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTaskAdapter;
+import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.server.impl.OCLPermission;
@@ -88,22 +91,20 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
 
 /**
  * {@link VirtualTreeMigrationTask} - Migrates folder data to new outlook-like tree structure.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
 
-    private static final Log LOG = LogFactory.getLog(VirtualTreeMigrationTask.class);
-
-    private static final String[] DEPENDENCIES = { VirtualTreeCreateTableTask.class.getName() };
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(VirtualTreeMigrationTask.class));
 
     public String[] getDependencies() {
-        return DEPENDENCIES;
+        return new String[] { VirtualTreeCreateTableTask.class.getName() };
     }
 
-    public void perform(PerformParameters params) throws AbstractOXException {
-        int contextId = params.getContextId();
-        Schema schema = params.getSchema();
+    public void perform(final PerformParameters params) throws AbstractOXException {
+        final int contextId = params.getContextId();
+        final Schema schema = params.getSchema();
         final Map<Integer, List<Integer>> m = getAllUsers(contextId);
 
         final int size = m.size();
@@ -114,8 +115,7 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
         }
 
         int processed = 0;
-        for (final Iterator<Map.Entry<Integer, List<Integer>>> it = m.entrySet().iterator(); it.hasNext();) {
-            final Map.Entry<Integer, List<Integer>> me = it.next();
+        for (final Entry<Integer, List<Integer>> me : m.entrySet()) {
             final int currentContextId = me.getKey().intValue();
             try {
                 iterateUsersPerContext(me.getValue(), currentContextId);
@@ -236,7 +236,7 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
             folder.setTreeID("1");
             folder.setParentID("");
             folder.setSubscribed(true);
-            Insert.insertFolder(ctx.getContextId(), 1, user, folder);
+            Insert.insertFolder(ctx.getContextId(), 1, user, folder, null, null);
         } catch (final FolderException e) {
             throw new UpdateException(e);
         }
@@ -256,18 +256,18 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
                 folder.setTreeID("1");
                 folder.setParentID(String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID));
                 folder.setSubscribed(true);
-                Insert.insertFolder(ctx.getContextId(), 1, user, folder);
+                Insert.insertFolder(ctx.getContextId(), 1, user, folder, null, null);
             }
             /*
              * Insert default primary mail account folder (INBOX)
              */
             final DummyFolder folder = new DummyFolder();
-            folder.setName("Inbox");
+            folder.setName(StringHelper.valueOf(UserStorage.getStorageUser(user, ctx).getLocale()).getString(MailStrings.INBOX));
             folder.setID(MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, "INBOX"));
-            folder.setTreeID("1");
+            folder.setTreeID(FolderStorage.PRIVATE_ID);
             folder.setParentID(String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID));
             folder.setSubscribed(true);
-            Insert.insertFolder(ctx.getContextId(), 1, user, folder);
+            Insert.insertFolder(ctx.getContextId(), 1, user, folder, null, null);
             /*
              * Insert other mail default folders: Drafts, Sent, Spam, and Trash
              */
@@ -311,7 +311,7 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
                 systemFolder.setLastModified(/* new Date(creatingTime) */null); // TODO: Ignore?
                 systemFolder.setSubscribed(true);
                 systemFolder.setTreeID(treeIdentifier);
-                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, con);
+                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, null, null, con);
                 /*
                  * Insert system public folder
                  */
@@ -324,7 +324,7 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
                 systemFolder.setID(String.valueOf(FolderObject.SYSTEM_PUBLIC_FOLDER_ID));
                 systemFolder.setName(FolderObject.SYSTEM_PUBLIC_FOLDER_NAME); // TODO: Empty string?
                 systemFolder.setPermissions(/* new Permission[] { systemPermission } */null); // TODO: Ignore?
-                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, con);
+                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, null, null, con);
                 /*
                  * Insert system shared folder
                  */
@@ -337,7 +337,7 @@ public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
                 systemFolder.setID(String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID));
                 systemFolder.setName(FolderObject.SYSTEM_SHARED_FOLDER_NAME); // TODO: Empty string?
                 systemFolder.setPermissions(/* new Permission[] { systemPermission } */null); // TODO: Ignore?
-                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, con);
+                Insert.insertFolder(ctx.getContextId(), treeId, user, systemFolder, null, null, con);
             } catch (final FolderException e) {
                 throw new UpdateException(e);
             } finally {
