@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,36 +50,27 @@
 package com.openexchange.folderstorage.virtual.osgi;
 
 import static com.openexchange.folderstorage.virtual.VirtualServiceRegistry.getServiceRegistry;
-import java.util.ArrayList;
 import java.util.Dictionary;
 import java.util.Hashtable;
-import java.util.List;
 import org.osgi.framework.BundleActivator;
-import org.osgi.framework.ServiceRegistration;
-import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.folderstorage.FolderField;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.virtual.VirtualFolderDeleteListener;
 import com.openexchange.folderstorage.virtual.VirtualFolderStorage;
-import com.openexchange.folderstorage.virtual.VirtualTreeCreateTableTask;
 import com.openexchange.groupware.delete.DeleteListener;
-import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.server.osgiservice.DeferredActivator;
+import com.openexchange.server.osgiservice.HousekeepingActivator;
 import com.openexchange.server.osgiservice.ServiceRegistry;
 
 /**
  * {@link VirtualFolderStorageActivator} - {@link BundleActivator Activator} for virtual folder storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public class VirtualFolderStorageActivator extends DeferredActivator {
+public class VirtualFolderStorageActivator extends HousekeepingActivator {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageActivator.class);
-
-    private List<ServiceRegistration> serviceRegistrations;
-
-    private List<ServiceTracker> serviceTrackers;
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageActivator.class));
 
     /**
      * Initializes a new {@link VirtualFolderStorageActivator}.
@@ -120,28 +111,26 @@ public class VirtualFolderStorageActivator extends DeferredActivator {
                 final ServiceRegistry registry = getServiceRegistry();
                 registry.clearRegistry();
                 final Class<?>[] classes = getNeededServices();
-                for (int i = 0; i < classes.length; i++) {
-                    final Object service = getService(classes[i]);
+                for (final Class<?> classe : classes) {
+                    final Object service = getService(classe);
                     if (null != service) {
-                        registry.addService(classes[i], service);
+                        registry.addService(classe, service);
                     }
                 }
             }
             // Trackers
-            serviceTrackers = new ArrayList<ServiceTracker>(1);
-            serviceTrackers.add(new ServiceTracker(context, FolderStorage.class.getName(), new VirtualFolderStorageServiceTracker(context)));
-            for (final ServiceTracker serviceTracker : serviceTrackers) {
-                serviceTracker.open();
-            }
+            track(FolderStorage.class, new VirtualFolderStorageServiceTracker(context));
+            openTrackers();
 
             // Register services
-            serviceRegistrations = new ArrayList<ServiceRegistration>(4);
-            serviceRegistrations.add(context.registerService(DeleteListener.class.getName(), new VirtualFolderDeleteListener(), null));
-            serviceRegistrations.add(context.registerService(UpdateTask.class.getName(), new VirtualTreeCreateTableTask(), null));
+            registerService(DeleteListener.class, new VirtualFolderDeleteListener(), null);
+
+            // Register folder properties
+            registerService(FolderField.class, VirtualFolderStorage.FIELD_NAME_PAIR_PREDEFINED);
 
             final Dictionary<String, String> dictionary = new Hashtable<String, String>();
             dictionary.put("tree", FolderStorage.ALL_TREE_ID);
-            serviceRegistrations.add(context.registerService(FolderStorage.class.getName(), new VirtualFolderStorage(), dictionary));
+            registerService(FolderStorage.class, VirtualFolderStorage.getInstance(), dictionary);
         } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             throw e;
@@ -151,26 +140,7 @@ public class VirtualFolderStorageActivator extends DeferredActivator {
     @Override
     protected void stopBundle() throws Exception {
         try {
-            /*
-             * Drop service registrations
-             */
-            if (null != serviceRegistrations) {
-                for (final ServiceRegistration serviceRegistration : serviceRegistrations) {
-                    serviceRegistration.unregister();
-                }
-                serviceRegistrations.clear();
-                serviceRegistrations = null;
-            }
-            /*
-             * Drop/close service trackers
-             */
-            if (null != serviceTrackers) {
-                for (final ServiceTracker serviceTracker : serviceTrackers) {
-                    serviceTracker.close();
-                }
-                serviceTrackers.clear();
-                serviceTrackers = null;
-            }
+            cleanUp();
             /*
              * Clear service registry
              */
