@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,13 +58,13 @@ import com.openexchange.folderstorage.virtual.VirtualFolderStorageRegistry;
 /**
  * {@link VirtualFolderStorageServiceTracker} - A {@link ServiceTrackerCustomizer customizer} for virtual folder storage which tracks real
  * folder storages; meaning those storages which indicate to handle the {@link FolderStorage#REAL_TREE_ID} tree identifier.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class VirtualFolderStorageServiceTracker implements ServiceTrackerCustomizer {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageServiceTracker.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(VirtualFolderStorageServiceTracker.class));
 
     private final BundleContext context;
 
