@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,20 +49,38 @@
 
 package com.openexchange.folderstorage.virtual.sql;
 
+import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
+import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
+import java.sql.ResultSet;
 import java.sql.SQLException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.event.impl.EventClient;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
+import com.openexchange.folderstorage.internal.Tools;
+import com.openexchange.folderstorage.mail.MailFolderType;
 import com.openexchange.folderstorage.virtual.VirtualServiceRegistry;
+import com.openexchange.mail.FullnameArgument;
+import com.openexchange.mail.event.EventPool;
+import com.openexchange.mail.event.PooledEvent;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.server.ServiceException;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
+import com.openexchange.tools.oxfolder.OXFolderAccess;
+import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.ServerSessionAdapter;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Delete} - SQL for deleting a virtual folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Delete {
@@ -92,7 +110,7 @@ public final class Delete {
 
     /**
      * Deletes specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -100,15 +118,15 @@ public final class Delete {
      * @param backup <code>true</code> to backup folder data prior to deletion; otherwise <code>false</code>
      * @throws FolderException If delete fails
      */
-    public static void deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup) throws FolderException {
-        final DatabaseService databaseService;
+    public static void deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup, final Session session) throws FolderException {
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getWritable(cid);
         } catch (final DBPoolingException e) {
@@ -116,7 +134,7 @@ public final class Delete {
         }
         try {
             con.setAutoCommit(false); // BEGIN
-            deleteFolder(cid, tree, user, folderId, backup, con);
+            deleteFolder(cid, tree, user, folderId, backup, session, con);
             con.commit(); // COMMIT
         } catch (final SQLException e) {
             DBUtils.rollback(con); // ROLLBACK
@@ -135,7 +153,7 @@ public final class Delete {
 
     /**
      * Deletes specified folder with specified connection.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -144,9 +162,34 @@ public final class Delete {
      * @param con The connection to use
      * @throws FolderException If delete fails
      */
-    public static void deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup, final Connection con) throws FolderException {
+    public static void deleteFolder(final int cid, final int tree, final int user, final String folderId, final boolean backup, final Session session, final Connection con) throws FolderException {
+        if (null == con) {
+            deleteFolder(cid, tree, user, folderId, backup, session);
+            return;
+        }
         PreparedStatement stmt = null;
-
+        ResultSet rs = null;
+        try {
+            stmt = con.prepareStatement("SELECT shadow FROM virtualTree WHERE cid = ? AND tree = ? AND user = ? AND folderId = ?");
+            int pos = 1;
+            stmt.setInt(pos++, cid);
+            stmt.setInt(pos++, tree);
+            stmt.setInt(pos++, user);
+            stmt.setString(pos, folderId);
+            rs = stmt.executeQuery();
+            if (!rs.next()) {
+                return;
+            }
+            final String shadow = rs.getString(1);
+            if ("default".equals(shadow)) {
+                throw FolderExceptionErrorMessage.FOLDER_NOT_DELETEABLE.create(folderId, Integer.valueOf(user), Integer.valueOf(cid));
+            }
+        } catch (final SQLException e) {
+            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(rs, stmt);
+            rs = null;
+        }
         if (backup) {
             /*
              * Backup folder data
@@ -245,6 +288,43 @@ public final class Delete {
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
+        /*
+         * Post event
+         */
+        if (null != session) {
+            final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+            final boolean postEvent = null == service ? true : service.getBoolProperty("com.openexchange.folderstorage.postEASFolderEvents", true);
+            if (postEvent) {
+                try {
+                    if (MailFolderType.getInstance().servesFolderId(folderId)) {
+                        final FullnameArgument argument = prepareMailFolderParam(folderId);
+                        postEvent(argument.getAccountId(), argument.getFullname(), false, true, false, session);
+                    } else {
+                        final ServerSession serverSession = ServerSessionAdapter.valueOf(session);
+                        new EventClient(serverSession).delete(new OXFolderAccess(con, serverSession.getContext()).getFolderObject(unsignedInt(folderId)));
+                    }
+                } catch (final Exception e) {
+                    // Ignore
+                    final Log log = com.openexchange.log.Log.valueOf(LogFactory.getLog(Delete.class));
+                    log.error(e.getMessage(), e);
+                }
+            }
+        }
+    }
+
+    private static void postEvent(final int accountId, final String fullname, final boolean contentRelated, final boolean immediateDelivery, final boolean async, final Session session) {
+        if (MailAccount.DEFAULT_ID != accountId) {
+            /*
+             * TODO: No event for non-primary account?
+             */
+            return;
+        }
+        EventPool.getInstance().put(
+            new PooledEvent(session.getContextId(), session.getUserId(), accountId, prepareFullname(accountId, fullname), contentRelated, immediateDelivery, session).setAsync(async));
+    }
+
+    private static int unsignedInt(final String sInteger) {
+        return Tools.getUnsignedInteger(sInteger);
     }
 
 }
