@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,24 +49,41 @@
 
 package com.openexchange.folderstorage.virtual.sql;
 
+import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
+import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.sql.Types;
 import java.util.Date;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.event.impl.EventClient;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.Permission;
+import com.openexchange.folderstorage.internal.Tools;
+import com.openexchange.folderstorage.mail.MailFolderType;
 import com.openexchange.folderstorage.virtual.VirtualServiceRegistry;
+import com.openexchange.mail.FullnameArgument;
+import com.openexchange.mail.event.EventPool;
+import com.openexchange.mail.event.PooledEvent;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.server.ServiceException;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
+import com.openexchange.tools.oxfolder.OXFolderAccess;
+import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.ServerSessionAdapter;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Insert} - SQL for inserting a virtual folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Insert {
@@ -89,22 +106,23 @@ public final class Insert {
 
     /**
      * Inserts specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
      * @param folder The folder
+     * @param shadow The optional shadow string
      * @throws FolderException If insertion fails
      */
-    public static void insertFolder(final int cid, final int tree, final int user, final Folder folder) throws FolderException {
-        final DatabaseService databaseService;
+    public static void insertFolder(final int cid, final int tree, final int user, final Folder folder, final String shadow, final Session session) throws FolderException {
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getWritable(cid);
         } catch (final DBPoolingException e) {
@@ -112,7 +130,7 @@ public final class Insert {
         }
         try {
             con.setAutoCommit(false); // BEGIN
-            insertFolder(cid, tree, user, folder, con);
+            insertFolder(cid, tree, user, folder, shadow, session, con);
             con.commit(); // COMMIT
         } catch (final SQLException e) {
             DBUtils.rollback(con); // ROLLBACK
@@ -131,15 +149,20 @@ public final class Insert {
 
     /**
      * Inserts specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
      * @param folder The folder
+     * @param shadow The optional shadow string
      * @param con The connection
      * @throws FolderException If insertion fails
      */
-    public static void insertFolder(final int cid, final int tree, final int user, final Folder folder, final Connection con) throws FolderException {
+    public static void insertFolder(final int cid, final int tree, final int user, final Folder folder, final String shadow, final Session session, final Connection con) throws FolderException {
+        if (null == con) {
+            insertFolder(cid, tree, user, folder, shadow, session);
+            return;
+        }
         final String folderId = folder.getID();
         // Insert folder data
         PreparedStatement stmt = null;
@@ -164,57 +187,98 @@ public final class Insert {
             } else {
                 stmt.setLong(pos++, lastModified.getTime());
             }
-            stmt.setString(pos, ""); // TODO: Shadow
+            stmt.setString(pos, null == shadow ? "" : shadow);
             stmt.executeUpdate();
         } catch (final SQLException e) {
             throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
-        // Insert permission data if non-null and not empty
-        final Permission[] permissions = folder.getPermissions();
-        if (null != permissions && permissions.length > 0) {
-            try {
-                stmt = con.prepareStatement(SQL_INSERT_PERM);
-                for (int i = 0; i < permissions.length; i++) {
-                    final Permission p = permissions[i];
-                    int pos = 1;
-                    stmt.setInt(pos++, cid);
-                    stmt.setInt(pos++, tree);
-                    stmt.setInt(pos++, user);
-                    stmt.setString(pos++, folderId);
-                    stmt.setInt(pos++, p.getEntity());
-                    stmt.setInt(pos++, p.isGroup() ? 1 : 0);
-                    stmt.setInt(pos++, p.getFolderPermission());
-                    stmt.setInt(pos++, p.getReadPermission());
-                    stmt.setInt(pos++, p.getWritePermission());
-                    stmt.setInt(pos++, p.getDeletePermission());
-                    stmt.setInt(pos++, p.isAdmin() ? 1 : 0);
-                    stmt.setInt(pos++, p.getSystem());
-                    stmt.addBatch();
+        if (false) {
+            // Insert permission data if non-null and not empty
+            final Permission[] permissions = folder.getPermissions();
+            if (null != permissions && permissions.length > 0) {
+                try {
+                    stmt = con.prepareStatement(SQL_INSERT_PERM);
+                    for (final Permission p : permissions) {
+                        int pos = 1;
+                        stmt.setInt(pos++, cid);
+                        stmt.setInt(pos++, tree);
+                        stmt.setInt(pos++, user);
+                        stmt.setString(pos++, folderId);
+                        stmt.setInt(pos++, p.getEntity());
+                        stmt.setInt(pos++, p.isGroup() ? 1 : 0);
+                        stmt.setInt(pos++, p.getFolderPermission());
+                        stmt.setInt(pos++, p.getReadPermission());
+                        stmt.setInt(pos++, p.getWritePermission());
+                        stmt.setInt(pos++, p.getDeletePermission());
+                        stmt.setInt(pos++, p.isAdmin() ? 1 : 0);
+                        stmt.setInt(pos++, p.getSystem());
+                        stmt.addBatch();
+                    }
+                    stmt.executeBatch();
+                } catch (final SQLException e) {
+                    throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+                } finally {
+                    DBUtils.closeSQLStuff(stmt);
                 }
-                stmt.executeBatch();
+            }
+        }
+        if (false) {
+            // Insert subscription data
+            try {
+                stmt = con.prepareStatement(SQL_INSERT_SUBS);
+                int pos = 1;
+                stmt.setInt(pos++, cid);
+                stmt.setInt(pos++, tree);
+                stmt.setInt(pos++, user);
+                stmt.setString(pos++, folderId);
+                stmt.setInt(pos, folder.isSubscribed() ? 1 : 0);
+                stmt.executeUpdate();
             } catch (final SQLException e) {
                 throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
             } finally {
                 DBUtils.closeSQLStuff(stmt);
             }
         }
-        // Insert subscription data
-        try {
-            stmt = con.prepareStatement(SQL_INSERT_SUBS);
-            int pos = 1;
-            stmt.setInt(pos++, cid);
-            stmt.setInt(pos++, tree);
-            stmt.setInt(pos++, user);
-            stmt.setString(pos++, folderId);
-            stmt.setInt(pos, folder.isSubscribed() ? 1 : 0);
-            stmt.executeUpdate();
-        } catch (final SQLException e) {
-            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
-        } finally {
-            DBUtils.closeSQLStuff(stmt);
+        /*
+         * Post event
+         */
+        if (null != session) {
+            final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+            final boolean postEvent =
+                null == service ? true : service.getBoolProperty("com.openexchange.folderstorage.postEASFolderEvents", true);
+            if (postEvent) {
+                try {
+                    if (MailFolderType.getInstance().servesFolderId(folderId)) {
+                        final FullnameArgument argument = prepareMailFolderParam(folder.getParentID());
+                        postEvent(argument.getAccountId(), argument.getFullname(), false, false, session);
+                    } else {
+                        final ServerSession serverSession = ServerSessionAdapter.valueOf(session);
+                        new EventClient(serverSession).create(new OXFolderAccess(con, serverSession.getContext()).getFolderObject(unsignedInt(folderId)));
+                    }
+                } catch (final Exception e) {
+                    // Ignore
+                    final Log log = com.openexchange.log.Log.valueOf(LogFactory.getLog(Delete.class));
+                    log.error(e.getMessage(), e);
+                }
+            }
         }
     }
 
+    private static void postEvent(final int accountId, final String fullname, final boolean contentRelated, final boolean immediateDelivery, final Session session) {
+        if (MailAccount.DEFAULT_ID != accountId) {
+            /*
+             * TODO: No event for non-primary account?
+             */
+            return;
+        }
+        EventPool.getInstance().put(
+            new PooledEvent(session.getContextId(), session.getUserId(), accountId, prepareFullname(accountId, fullname), contentRelated, immediateDelivery, session));
+    }
+
+    private static int unsignedInt(final String sInteger) {
+        return Tools.getUnsignedInteger(sInteger);
+    }
+
 }
