@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,9 +60,9 @@ import java.util.Comparator;
 import java.util.Date;
 import java.util.List;
 import java.util.Locale;
+import java.util.Map.Entry;
 import java.util.Set;
 import java.util.TreeMap;
-import java.util.Map.Entry;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.folderstorage.FolderException;
@@ -79,7 +79,7 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Select} - SQL to load a virtual folder or its subfolder identifiers.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Select {
@@ -128,7 +128,7 @@ public final class Select {
 
     /**
      * Checks if the specified virtual tree contains a folder denoted by given folder identifier.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -139,14 +139,14 @@ public final class Select {
      * @throws FolderException If checking folder's presence fails
      */
     public static boolean containsFolder(final int cid, final int tree, final int user, final String folderId, final StorageType storageType) throws FolderException {
-        final DatabaseService databaseService;
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getReadOnly(cid);
         } catch (final DBPoolingException e) {
@@ -176,7 +176,7 @@ public final class Select {
 
     /**
      * Fills specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -186,14 +186,14 @@ public final class Select {
      * @throws FolderException If filling the folder fails
      */
     public static void fillFolder(final int cid, final int tree, final int user, final Locale locale, final VirtualFolder virtualFolder, final StorageType storageType) throws FolderException {
-        final DatabaseService databaseService;
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getReadOnly(cid);
         } catch (final DBPoolingException e) {
@@ -239,7 +239,7 @@ public final class Select {
                 }
             } catch (final SQLException e) {
                 if (null != stmt) {
-                    final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                    final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                     if (LOG.isDebugEnabled()) {
                         final String sql = getSQLString(stmt);
                         LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -251,7 +251,11 @@ public final class Select {
             }
             stmt = null;
             // Select subfolders
-            virtualFolder.setSubfolderIDs(getSubfolderIds(cid, tree, user, locale, folderId, storageType, con));
+            {
+                final String[] subfolderIds = getSubfolderIds(cid, tree, user, locale, folderId, storageType, con);
+                virtualFolder.setSubfolderIDs(subfolderIds);
+                virtualFolder.setSubscribedSubfolders(subfolderIds != null && subfolderIds.length > 0);
+            }
             // Select permissions
             try {
                 stmt = con.prepareStatement(working ? SQL_SELECT_PERMS : SQL_SELECT_PERMS_BCK);
@@ -282,7 +286,7 @@ public final class Select {
                 }
             } catch (final SQLException e) {
                 if (null != stmt) {
-                    final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                    final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                     if (LOG.isDebugEnabled()) {
                         final String sql = getSQLString(stmt);
                         LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -310,7 +314,7 @@ public final class Select {
                 virtualFolder.setSubscribed(subscribed);
             } catch (final SQLException e) {
                 if (null != stmt) {
-                    final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                    final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                     if (LOG.isDebugEnabled()) {
                         final String sql = getSQLString(stmt);
                         LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
@@ -327,7 +331,7 @@ public final class Select {
 
     /**
      * Gets the sorted identifiers of the subfolders located below specified parent.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -338,14 +342,14 @@ public final class Select {
      * @throws FolderException If subfolders cannot be detected
      */
     public static String[] getSubfolderIds(final int cid, final int tree, final int user, final Locale locale, final String parentId, final StorageType storageType) throws FolderException {
-        final DatabaseService databaseService;
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getReadOnly(cid);
         } catch (final DBPoolingException e) {
@@ -360,7 +364,7 @@ public final class Select {
 
     /**
      * Gets the sorted identifiers of the subfolders located below specified parent.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
@@ -403,7 +407,7 @@ public final class Select {
                 }
             } else {
                 final TreeMap<String, String> treeMap = new TreeMap<String, String>(new FolderNameComparator(locale));
-                final StringHelper stringHelper = new StringHelper(locale);
+                final StringHelper stringHelper = StringHelper.valueOf(locale);
                 while (rs.next()) {
                     treeMap.put(stringHelper.getString(rs.getString(2)), rs.getString(pos));
                 }
@@ -416,7 +420,7 @@ public final class Select {
             return subfolderIds.toArray(new String[subfolderIds.size()]);
         } catch (final SQLException e) {
             if (null != stmt) {
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Select.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Select.class));
                 if (LOG.isDebugEnabled()) {
                     final String sql = getSQLString(stmt);
                     LOG.debug(new StringBuilder(sql.length() + 16).append("Failed SQL:\n\t").append(sql).toString());
