@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,11 +58,12 @@ import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.virtual.VirtualServiceRegistry;
 import com.openexchange.server.ServiceException;
+import com.openexchange.session.Session;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link Update} - SQL for updating a virtual folder.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Update {
@@ -76,22 +77,22 @@ public final class Update {
 
     /**
      * Updates specified folder.
-     * 
+     *
      * @param cid The context identifier
      * @param tree The tree identifier
      * @param user The user identifier
      * @param folder The folder
      * @throws FolderException If update fails
      */
-    public static void updateFolder(final int cid, final int tree, final int user, final Folder folder) throws FolderException {
-        final DatabaseService databaseService;
+    public static void updateFolder(final int cid, final int tree, final int user, final Folder folder, final Session session) throws FolderException {
+        DatabaseService databaseService;
         try {
             databaseService = VirtualServiceRegistry.getServiceRegistry().getService(DatabaseService.class, true);
         } catch (final ServiceException e) {
             throw new FolderException(e);
         }
         // Get a connection
-        final Connection con;
+        Connection con;
         try {
             con = databaseService.getWritable(cid);
         } catch (final DBPoolingException e) {
@@ -99,8 +100,8 @@ public final class Update {
         }
         try {
             con.setAutoCommit(false); // BEGIN
-            Delete.deleteFolder(cid, tree, user, folder.getID(), false, con);
-            Insert.insertFolder(cid, tree, user, folder, con);
+            Delete.deleteFolder(cid, tree, user, folder.getID(), false, session, con);
+            Insert.insertFolder(cid, tree, user, folder, null, session, con);
             con.commit(); // COMMIT
         } catch (final SQLException e) {
             DBUtils.rollback(con); // ROLLBACK
