@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.groupware.ldap.LdapException;
 /**
  * This class defines the storage API for groups. This is a low level API for reading and writing groups into some storage - normally
  * databases.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public abstract class GroupStorage {
@@ -75,7 +75,7 @@ public abstract class GroupStorage {
 
     /**
      * This method inserts a group without its members into the storage.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param group group to insert.
@@ -87,7 +87,7 @@ public abstract class GroupStorage {
 
     /**
      * This method inserts a group without its members into the storage.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param group group to insert.
@@ -98,7 +98,7 @@ public abstract class GroupStorage {
 
     /**
      * This method updates group field in the storage.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param group group with fields to update.
@@ -113,7 +113,7 @@ public abstract class GroupStorage {
 
     /**
      * This method deletes a group from the database. Before all its members must be removed.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param groupId unique identifier of the group to delete.
@@ -124,7 +124,7 @@ public abstract class GroupStorage {
 
     /**
      * Reads a group from the persistent storage.
-     * 
+     *
      * @param gid Unique identifier of the group.
      * @param The context.
      * @return The group data object.
@@ -137,17 +137,18 @@ public abstract class GroupStorage {
      * should be searched in. You can also name the attributes that values should be returned. Please insure that returned attributes are
      * strings and not any other data types. You will get a Set with string arrays. The string arrays contain the values auf the requested
      * attributes in the same order.
-     * 
+     *
      * @param pattern this pattern will be searched in the displayName of the group.
+     * @param loadMembers - switch whether members should be loaded, too (decreases performance, don't use if not needed)
      * @param The context.
      * @return an array of groups that match the search pattern.
      * @throws GroupException if searching has some storage related problem.
      */
-    public abstract Group[] searchGroups(String pattern, Context context) throws GroupException;
+    public abstract Group[] searchGroups(String pattern, boolean loadMembers, Context context) throws GroupException;
 
     /**
      * This method returns groups that have been modified since the given timestamp.
-     * 
+     *
      * @param modifiedSince timestamp after that the groups have been modified.
      * @param The context.
      * @return an array of groups.
@@ -156,17 +157,28 @@ public abstract class GroupStorage {
     public abstract Group[] listModifiedGroups(Date modifiedSince, Context context) throws LdapException;
 
     /**
-     * Returns the data objects of all groups.
-     * 
+     * This metods returns groups that have been deleted since the given timestamp
+     *
+     * @param modifiedSince timestamp after that the groups have been deleted.
      * @param The context.
+     * @return an array of groups.
+     * @throws LdapException if an error occurs.
+     */
+    public abstract Group[] listDeletedGroups(Date modifiedSince, Context context) throws LdapException;
+
+    /**
+     * Returns the data objects of all groups.
+     *
+     * @param context - the context.
+     * @param loadMembers - switch whether members should be loaded, too (decreases performance, don't use if not needed)
      * @return all groups.
      * @throws LdapException if an error occurs.
      */
-    public abstract Group[] getGroups(Context context) throws LdapException;
+    public abstract Group[] getGroups(boolean loadMembers, Context context) throws LdapException;
 
     /**
      * Creates a new instance implementing the group storage interface.
-     * 
+     *
      * @return an instance implementing the group storage interface.
      */
     public static GroupStorage getInstance() {
@@ -188,4 +200,6 @@ public abstract class GroupStorage {
          */
         DELETED
     }
+
+
 }
