@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,8 +56,8 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupException;
-import com.openexchange.group.GroupStorage;
 import com.openexchange.group.GroupException.Code;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
@@ -79,7 +79,7 @@ public final class Create {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(Create.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Create.class));
 
     /**
      * Context.
@@ -103,7 +103,7 @@ public final class Create {
 
     /**
      * Default constructor.
-     * @param user 
+     * @param user
      */
     public Create(final Context ctx, final User user, final Group group) {
         super();
@@ -198,12 +198,12 @@ public final class Create {
             storage.insertMember(ctx, con, group, group.getMember());
         } catch (final SQLException e) {
             throw new GroupException(Code.SQL_ERROR, e, e.getMessage());
-        }            
+        }
     }
 
     /**
      * Inform the rest of the system about the new group.
-     * @throws GroupException 
+     * @throws GroupException
      */
     private void propagate() throws GroupException {
         UserStorage storage = UserStorage.getInstance();
