@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,8 +58,8 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupException;
-import com.openexchange.group.GroupStorage;
 import com.openexchange.group.GroupException.Code;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.group.GroupStorage.StorageType;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.delete.DeleteEvent;
@@ -83,7 +83,7 @@ public final class Delete {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(Delete.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Delete.class));
 
     /**
      * Context.
