@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,7 +62,7 @@ import com.openexchange.server.Initialization;
  */
 public final class GroupInit implements Initialization {
 
-    private static final Log LOG = LogFactory.getLog(GroupInit.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GroupInit.class));
 
     /**
      * Singleton instance.
