@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -107,8 +107,8 @@ public final class GroupsWithGroupZero extends GroupStorage {
      * {@inheritDoc}
      */
     @Override
-    public Group[] getGroups(final Context ctx) throws LdapException {
-        final Group[] groups = delegate.getGroups(ctx);
+    public Group[] getGroups(boolean loadMembers, final Context ctx) throws LdapException {
+        final Group[] groups = delegate.getGroups(loadMembers, ctx);
         final Group[] retval = new Group[groups.length + 1];
         try {
             retval[0] = GroupTools.getGroupZero(ctx);
@@ -136,11 +136,24 @@ public final class GroupsWithGroupZero extends GroupStorage {
         return retval;
     }
 
+    @Override
+    public Group[] listDeletedGroups(Date modifiedSince, Context ctx) throws LdapException {
+        final Group[] groups = delegate.listDeletedGroups(modifiedSince, ctx);
+        final Group[] retval = new Group[groups.length + 1];
+        try {
+            retval[0] = GroupTools.getGroupZero(ctx);
+        } catch (final UserException e) {
+            throw new LdapException(e);
+        }
+        System.arraycopy(groups, 0, retval, 1, groups.length);
+        return retval;
+    }
+
     /**
      * {@inheritDoc}
      */
     @Override
-    public Group[] searchGroups(final String pattern, final Context ctx) throws GroupException {
+    public Group[] searchGroups(final String pattern, final boolean loadMembers, final Context ctx) throws GroupException {
         final Pattern pat = Pattern.compile(pattern.replace("*", ".*"), Pattern
             .CASE_INSENSITIVE);
         final Group zero;
@@ -153,7 +166,7 @@ public final class GroupsWithGroupZero extends GroupStorage {
         }
         final Matcher match = pat.matcher(zero.getDisplayName());
         final List<Group> groups = new ArrayList<Group>();
-        groups.addAll(Arrays.asList(delegate.searchGroups(pattern, ctx)));
+        groups.addAll(Arrays.asList(delegate.searchGroups(pattern, loadMembers, ctx)));
         if (match.find()) {
             groups.add(zero);
         }
@@ -192,4 +205,5 @@ public final class GroupsWithGroupZero extends GroupStorage {
         final int groupId, final Date lastRead) throws GroupException {
         delegate.deleteGroup(ctx, con, groupId, lastRead);
     }
+
 }
