@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,12 +49,13 @@
 
 package com.openexchange.group.internal;
 
-import gnu.trove.TIntHashSet;
+import gnu.trove.set.TIntSet;
+import gnu.trove.set.hash.TIntHashSet;
 import java.util.Date;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupException;
-import com.openexchange.group.GroupStorage;
 import com.openexchange.group.GroupException.Code;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.data.Check;
 import com.openexchange.groupware.ldap.UserException;
@@ -74,7 +75,7 @@ public final class Logic {
     }
 
     /**
-     * 
+     *
      * @param group
      * @throws GroupException
      */
@@ -104,7 +105,7 @@ public final class Logic {
     }
 
     /**
-     * 
+     *
      * @param group
      * @throws GroupException
      */
@@ -185,7 +186,7 @@ public final class Logic {
         if (!group.isSimpleNameSet()) {
             return;
         }
-        final Group[] others = storage.searchGroups(group.getSimpleName(), ctx);
+        final Group[] others = storage.searchGroups(group.getSimpleName(), true, ctx);
         for (final Group other : others) {
             if (group.getSimpleName().equals(other.getSimpleName())
                 && group.getIdentifier() != other.getIdentifier()) {
@@ -209,7 +210,7 @@ public final class Logic {
         }
         try {
             final UserStorage storage = UserStorage.getInstance();
-            final TIntHashSet set = new TIntHashSet();
+            final TIntSet set = new TIntHashSet();
             for (final int userId : storage.listAllUser(ctx)) {
                 set.add(userId);
             }
