@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,9 @@
 package com.openexchange.group.internal;
 
 import static com.openexchange.java.Autoboxing.I;
-import gnu.trove.TIntHashSet;
-import gnu.trove.TIntIterator;
+import gnu.trove.iterator.TIntIterator;
+import gnu.trove.set.TIntSet;
+import gnu.trove.set.hash.TIntHashSet;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Date;
@@ -60,8 +61,8 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupException;
-import com.openexchange.group.GroupStorage;
 import com.openexchange.group.GroupException.Code;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
@@ -82,18 +83,18 @@ final class Update {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(Update.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Update.class));
 
     /**
      * Context.
      */
     private final Context ctx;
-    
+
     /**
      * User.
      */
     private final User user;
-    
+
     /**
      * Group object with changed information.
      */
@@ -111,12 +112,12 @@ final class Update {
     /**
      * Added members.
      */
-    private final TIntHashSet addedMembers = new TIntHashSet();
+    private final TIntSet addedMembers = new TIntHashSet();
 
     /**
      * Removed members.
      */
-    private final TIntHashSet removedMembers = new TIntHashSet();
+    private final TIntSet removedMembers = new TIntHashSet();
 
     /**
      * Default constructor.
