@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,9 +53,9 @@ import java.util.concurrent.locks.ReentrantLock;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.configuration.ConfigurationException;
+import com.openexchange.configuration.ConfigurationException.Code;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.SystemConfig;
-import com.openexchange.configuration.ConfigurationException.Code;
 import com.openexchange.configuration.SystemConfig.Property;
 import com.openexchange.server.Initialization;
 import com.openexchange.tools.conf.AbstractConfig;
@@ -73,8 +73,8 @@ public class AttachmentConfig extends AbstractConfig implements Initialization {
 
     private static final Property KEY = Property.ATTACHMENT;
 
-	private static final Log LOG = LogFactory.getLog(AttachmentConfig.class);
-    
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AttachmentConfig.class));
+
     private static AttachmentConfig singleton;
 
     private static boolean loaded = false;
@@ -109,11 +109,11 @@ public class AttachmentConfig extends AbstractConfig implements Initialization {
 				LOG.error("Can't init config",e);
 			}
 		}
-			
+
         return singleton.getPropertyInternal(key);
     }
 
-      
+
     public static long getMaxUploadSize() {
 		final String sizeS = getProperty(AttachmentProperty.MAX_UPLOAD_SIZE.name());
 		if (null == sizeS) {
