@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,20 +50,19 @@
 package com.openexchange.groupware.attach;
 
 import com.openexchange.api2.OXException;
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 
 public class AttachmentException extends OXException {
 
-	private static final long serialVersionUID = -5210881621553596187L;
+    private static final long serialVersionUID = -5210881621553596187L;
 
-	public AttachmentException(final Category category, final int number, final String message, final Throwable cause, final Object[] msgArgs) {
-		super(EnumComponent.ATTACHMENT, category,number,message,cause);
-		setMessageArgs(msgArgs);
-	}
-
-	public AttachmentException(final AbstractOXException e) {
-		super(e);
-	}
+    public AttachmentException(final AbstractOXException e) {
+        super(e);
+    }
 
+    public AttachmentException(ErrorMessage message, Throwable cause, Object... args) {
+        super(message, cause);
+        setMessageArgs(args);
+    }
 }
