@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,9 @@
 
 package com.openexchange.groupware.attach;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
+import com.openexchange.database.provider.DBPoolProvider;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.attach.impl.AttachmentBaseImpl;
 import com.openexchange.groupware.attach.impl.OverridableAttachmentAuthorization;
@@ -58,8 +60,6 @@ import com.openexchange.groupware.calendar.CalendarAttachments;
 import com.openexchange.groupware.contact.ContactsAttachment;
 import com.openexchange.groupware.tasks.TaskAttachmentListener;
 import com.openexchange.groupware.tasks.TaskAuthorization;
-import com.openexchange.groupware.tx.DBPoolProvider;
-import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.tools.service.ServicePriorityConflictException;
 import com.openexchange.tools.service.SpecificServiceChooser;
 
@@ -69,32 +69,32 @@ public abstract class Attachments {
     private static final TIntObjectHashMap<SpecificServiceChooser<AttachmentListener>> listener = new TIntObjectHashMap<SpecificServiceChooser<AttachmentListener>>(3);
 
     private static final AttachmentBaseImpl impl = new AttachmentBaseImpl(new DBPoolProvider());
-    
+
     static {
         try {
             final SpecificServiceChooser<AttachmentAuthorization> taskAuth = new SpecificServiceChooser<AttachmentAuthorization>();
             taskAuth.registerForEverything(new TaskAuthorization(), 0);
-        
+
             final SpecificServiceChooser<AttachmentAuthorization> contactAuth = new SpecificServiceChooser<AttachmentAuthorization>();
             contactAuth.registerForEverything(new ContactsAttachment(), 0);
-            
+
             final SpecificServiceChooser<AttachmentAuthorization> appointmentAuth = new SpecificServiceChooser<AttachmentAuthorization>();
             appointmentAuth.registerForEverything(new CalendarAttachments(), 0);
-            
+
             authz.put(Types.TASK, taskAuth);
             authz.put(Types.CONTACT, contactAuth);
             authz.put(Types.APPOINTMENT, appointmentAuth);
-            
-            
+
+
             final SpecificServiceChooser<AttachmentListener> taskListener = new SpecificServiceChooser<AttachmentListener>();
             taskListener.registerForEverything(new TaskAttachmentListener(), 0);
-            
+
             final SpecificServiceChooser<AttachmentListener> contactListener = new SpecificServiceChooser<AttachmentListener>();
             contactListener.registerForEverything(new ContactsAttachment(), 0);
-            
+
             final SpecificServiceChooser<AttachmentListener> appointmentListener = new SpecificServiceChooser<AttachmentListener>();
             appointmentListener.registerForEverything(new CalendarAttachments(), 0);
-            
+
             listener.put(Types.TASK, taskListener);
             listener.put(Types.CONTACT, contactListener);
             listener.put(Types.APPOINTMENT, appointmentListener);
@@ -106,17 +106,17 @@ public abstract class Attachments {
             impl.addAuthorization(new OverridableAttachmentAuthorization(appointmentAuth), Types.APPOINTMENT);
             impl.registerAttachmentListener(new OverridableAttachmentListener(appointmentListener),Types.APPOINTMENT);
 
-            
+
         } catch (final ServicePriorityConflictException e) {
             // Doesn't happen
             e.printStackTrace();
         }
     }
-    
+
     public static SpecificServiceChooser<AttachmentAuthorization> getAuthorizationChooserForModule(final int module) {
         return authz.get(module);
     }
-    
+
     public static SpecificServiceChooser<AttachmentListener> getListenerChooserForModule(final int module) {
         return listener.get(module);
     }
