@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,10 +51,10 @@ package com.openexchange.groupware.attach.impl;
 
 import java.sql.Connection;
 import com.openexchange.api2.OXException;
+import com.openexchange.database.provider.SimpleDBProvider;
 import com.openexchange.groupware.delete.ContextDelete;
 import com.openexchange.groupware.delete.DeleteEvent;
 import com.openexchange.groupware.delete.DeleteFailedException;
-import com.openexchange.groupware.tx.SimpleDBProvider;
 
 public class AttachmentContextDelete extends ContextDelete {
 
