@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,20 +51,20 @@ package com.openexchange.groupware.attach.impl;
 
 import java.sql.SQLException;
 import java.util.List;
+import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.attach.AttachmentMetadata;
-import com.openexchange.groupware.tx.TransactionException;
 
 public abstract class AttachmentListQueryAction extends AbstractAttachmentAction {
 
 	private List<AttachmentMetadata> attachments;
-	
-	
-	protected void doUpdates(final String query, final List<AttachmentMetadata> attachments, final boolean addId) throws TransactionException, UpdateException {
+
+
+	protected void doUpdates(final String query, final List<AttachmentMetadata> attachments, final boolean addId) throws DBPoolingException, UpdateException {
 		final UpdateBlock[] updates = new UpdateBlock[attachments.size()];
 		int i = 0;
 		for(final AttachmentMetadata m : attachments) {
 			updates[i++] = new Update(query) {
-				
+
 				@Override
 				public void fillStatement() throws SQLException {
 					final int number = fillFields(m, stmt);
@@ -72,12 +72,12 @@ public abstract class AttachmentListQueryAction extends AbstractAttachmentAction
 						stmt.setInt(number,m.getId());
 					}
 				}
-				
+
 			};
 		}
 		doUpdates(updates);
 	}
-	
+
 	public List<AttachmentMetadata> getAttachments() {
 		return attachments;
 	}
