@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,11 @@
 package com.openexchange.groupware.calendar;
 
 import java.util.Date;
+import java.util.HashSet;
+import java.util.Set;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.container.Appointment;
+import com.openexchange.groupware.container.Differ;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.server.services.ServerServiceRegistry;
 
@@ -60,8 +63,6 @@ import com.openexchange.server.services.ServerServiceRegistry;
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  */
 public class CalendarDataObject extends Appointment {
-    
-    private static CalendarCollectionService calColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
 
     private String rec_string;
 
@@ -77,18 +78,25 @@ public class CalendarDataObject extends Appointment {
     private boolean folder_move;
     private boolean b_recurrencestring;
 
-    private boolean fill_participants;
+    private boolean fill_participants; 
     private boolean fill_user_participants;
     private boolean fill_folder_id;
     private boolean fillConfirmations;
     private boolean fillLastModifiedOfNewestAttachment;
+    
+    private boolean externalOrganizer;
+
+
+	private CalendarCollectionService getCalendarCollectionService(){
+    	return ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
+    }
 
     @Override
     public final void setUntil(final Date until) {
         if (until != null) {
             final long mod = until.getTime() % Constants.MILLI_DAY;
             if (mod != 0) {
-                if (calColl.exceedsHourOfDay(until.getTime(), getTimezoneFallbackUTC())) {
+                if (getCalendarCollectionService().exceedsHourOfDay(until.getTime(), getTimezoneFallbackUTC())) {
                     until.setTime((((until.getTime() - mod) + Constants.MILLI_DAY)));
                 } else {
                     until.setTime(until.getTime() - mod);
@@ -100,7 +108,7 @@ public class CalendarDataObject extends Appointment {
             super.setUntil(until);
         }
     }
-    
+
     @Override
     public void setOccurrence(final int occurrence) {
         if (occurrence == 0) {
@@ -133,20 +141,6 @@ public class CalendarDataObject extends Appointment {
         return action_folder;
     }
 
-    public final int getFulltime() {
-        if (!super.getFullTime()) {
-            return 0;
-        }
-        return 1;
-    }
-
-    public final int getPrivateflag() {
-        if (!super.getPrivateFlag()) {
-            return 0;
-        }
-        return 1;
-    }
-
     public final void setGlobalFolderID(final int fid) {
         super.setParentFolderID(fid);
     }
@@ -206,37 +200,37 @@ public class CalendarDataObject extends Appointment {
 
     public final void setDelExceptions(final String delete_execptions) {
         if (delete_execptions != null) {
-            super.setDeleteExceptions(calColl.convertString2Dates(delete_execptions));
+            super.setDeleteExceptions(getCalendarCollectionService().convertString2Dates(delete_execptions));
         } else {
-            setDeleteExceptions(null);
+            setDeleteExceptions((Date[])null);
         }
     }
 
     public final String getDelExceptions() {
         if (containsDeleteExceptions()) {
-            return calColl.convertDates2String(getDeleteException());
+            return getCalendarCollectionService().convertDates2String(getDeleteException());
         }
         return null;
     }
 
     public final void setExceptions(final String change_exceptions) {
         if (change_exceptions != null) {
-            super.setChangeExceptions(calColl.convertString2Dates(change_exceptions));
+            super.setChangeExceptions(getCalendarCollectionService().convertString2Dates(change_exceptions));
         } else {
-            setChangeExceptions(null);
+            setChangeExceptions((Date[])null);
         }
     }
 
     public final String getExceptions() {
         if (containsChangeExceptions()) {
-            return calColl.convertDates2String(getChangeException());
+            return getCalendarCollectionService().convertDates2String(getChangeException());
         }
         return null;
     }
 
     public final boolean calculateRecurrence() throws OXException {
         if (isSequence()) {
-            return calColl.fillDAO(this);
+            return getCalendarCollectionService().fillDAO(this);
         }
         return false;
     }
@@ -247,7 +241,7 @@ public class CalendarDataObject extends Appointment {
             /*
              * Determine max. end date
              */
-            return calColl.getMaxUntilDate(this);
+            return getCalendarCollectionService().getMaxUntilDate(this);
         }
         return super.getUntil();
     }
@@ -260,7 +254,7 @@ public class CalendarDataObject extends Appointment {
      */
     public final boolean isSequence(final boolean what) {
         if (what) {
-            return ((containsRecurrenceString() && getRecurrence() != null)|| (containsRecurrenceType() && getRecurrenceType() > 0 && getInterval() > 0));
+            return ((containsRecurrenceString() && getRecurrence() != null) || (containsRecurrenceType() && getRecurrenceType() > 0 && getInterval() > 0));
         }
         return (containsRecurrenceID() && containsRecurrenceType() && getRecurrenceType() > 0 && getInterval() > 0);
     }
@@ -432,8 +426,6 @@ public class CalendarDataObject extends Appointment {
             clone.setNotification(getNotification());
         }
         clone.setIgnoreConflicts(ignoreConflicts);
-        clone.setUsers(getUsers());
-        clone.setParticipants(getParticipants());
         clone.setRecurrenceCalculator(getRecurrenceCalculator());
         clone.setRecurrence(getRecurrence());
         clone.setFolderType(getFolderType());
@@ -449,10 +441,19 @@ public class CalendarDataObject extends Appointment {
         clone.setFolderMoveAction(getFolderMoveAction());
         clone.setFolderMove(getFolderMove());
         clone.setSharedFolderOwner(getSharedFolderOwner());
-
-
+        
+        
         return clone;
     }
+    
+    public boolean isExternalOrganizer() {
+		return externalOrganizer;
+	}
+
+	public void setExternalOrganizer(boolean externalOrganizer) {
+		this.externalOrganizer = externalOrganizer;
+	}
+
 
     private static final Date[] copy(final Date[] copyMe) {
         if (copyMe == null) {
@@ -516,4 +517,10 @@ public class CalendarDataObject extends Appointment {
         sb.append(getDayInMonth());
         return sb.toString();
     }
+
+    public static Set<Differ<? super CalendarDataObject>> differ = new HashSet<Differ<? super CalendarDataObject>>();
+    
+    static {
+        differ.addAll(Appointment.differ);
+    }
 }
