@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,14 +80,14 @@ public class OXCalendarException extends OXException {
     }
 
     public enum Code {
-        CFO_NOT_INITIALIZIED("FATAL: CalendarFolderObject not initialized!", 1, AbstractOXException.Category.CODE_ERROR),
+        CFO_NOT_INITIALIZIED("CalendarFolderObject not initialized!", 1, AbstractOXException.Category.CODE_ERROR),
         NOT_YET_SUPPORTED("Not yet supported!", 2, AbstractOXException.Category.CODE_ERROR),
         NO_SHARED_FOLDER_OWNER("Shared folder owner not given !", 3, AbstractOXException.Category.CODE_ERROR),
         FOLDER_TYPE_UNRESOLVEABLE("Folder type unresolvable !", 4, AbstractOXException.Category.CODE_ERROR),
         /**
          * Unexpected SQL Error!
          */
-        CALENDAR_SQL_ERROR("Unexpected SQL Error!", 5, AbstractOXException.Category.SUBSYSTEM_OR_SERVICE_DOWN),
+        CALENDAR_SQL_ERROR("Unexpected SQL Error!", 5, AbstractOXException.Category.CODE_ERROR),
         /**
          * TODO remove this exception. The AJAX interface should already check for a missing last modified.
          */
@@ -97,7 +97,7 @@ public class OXCalendarException extends OXException {
          */
         UNEXPECTED_EXCEPTION("Unexpected exception %d!", 7, AbstractOXException.Category.INTERNAL_ERROR),
         EXTERNAL_PARTICIPANTS_MANDATORY_FIELD("Mandatory field mail address for external participants", 8, AbstractOXException.Category.USER_INPUT),
-        UPDATE_WITHOUT_PARTICIPANTS("FATAL: Would create an object without participants", 9, AbstractOXException.Category.CODE_ERROR),
+        UPDATE_WITHOUT_PARTICIPANTS("Would create an object without participants", 9, AbstractOXException.Category.CODE_ERROR),
         UPDATE_USER_SHARED_MISMATCH("Folder type \"SHARED\" is not allowed in this situation.", 10, AbstractOXException.Category.USER_INPUT),
         RECURRING_UNEXPECTED_DELETE_STATE("Unexpected state for deleting a virtual appointment (exception). uid:oid:position %d:%d:%d", 11, AbstractOXException.Category.INTERNAL_ERROR),
         ERROR_SESSIONOBJECT_IS_NULL("SessionObject not initialized", 12, AbstractOXException.Category.CODE_ERROR),
@@ -109,44 +109,44 @@ public class OXCalendarException extends OXException {
         FOLDER_IS_EMPTY_INVALID_REQUEST("Invalid request. Folder is shared!", 18, AbstractOXException.Category.CODE_ERROR),
         FREE_BUSY_UNSUPPOTED_TYPE("Unsupported type detected : %d", 19, AbstractOXException.Category.CODE_ERROR),
         END_DATE_BEFORE_START_DATE("End date is before start date", 20, AbstractOXException.Category.USER_INPUT),
-        UNSUPPORTED_LABEL("ERROR: Unsupported label value %d", 21, AbstractOXException.Category.USER_INPUT),
-        PRIVATE_FLAG_IN_PRIVATE_FOLDER("ERROR: Private flag is only allowed inside of a private folder.", 22, AbstractOXException.Category.USER_INPUT),
-        PRIVATE_FLAG_AND_PARTICIPANTS("Error: Appointments marked as 'Private' can only be scheduled for the respective user (or owner of the calendar). Please remove additional participants or remove the \"Private\" mark.", 23, AbstractOXException.Category.USER_INPUT),
-        UNSUPPORTED_PRIVATE_FLAG("ERROR: Unsupported private flag value %d", 24, AbstractOXException.Category.USER_INPUT),
-        UNSUPPORTED_SHOWN_AS("ERROR:: Unsupported \"shown as\"  value %d", 25, AbstractOXException.Category.USER_INPUT),
+        UNSUPPORTED_LABEL("Unsupported label value %d", 21, AbstractOXException.Category.USER_INPUT),
+        PRIVATE_FLAG_IN_PRIVATE_FOLDER("Private flag is only allowed inside of a private folder.", 22, AbstractOXException.Category.USER_INPUT),
+        PRIVATE_FLAG_AND_PARTICIPANTS("Appointments marked as 'Private' can only be scheduled for the respective user (or owner of the calendar). Please remove additional participants or remove the \"Private\" mark.", 23, AbstractOXException.Category.USER_INPUT),
+        UNSUPPORTED_PRIVATE_FLAG("Unsupported private flag value %d", 24, AbstractOXException.Category.USER_INPUT),
+        UNSUPPORTED_SHOWN_AS("Unsupported \"shown as\"  value %d", 25, AbstractOXException.Category.USER_INPUT),
         MANDATORY_FIELD_START_DATE("Required  value \"Start Date\" was not supplied.", 26, AbstractOXException.Category.USER_INPUT),
         MANDATORY_FIELD_END_DATE("Required value \"End Date\" was not supplied.", 27, AbstractOXException.Category.USER_INPUT),
         MANDATORY_FIELD_TITLE("Required value \"Title\" was not supplied.", 28, AbstractOXException.Category.USER_INPUT),
         UNABLE_TO_CALCULATE_RECURRING_POSITION("Unable to create exception, recurring position can not be calculated !", 29, AbstractOXException.Category.USER_INPUT),
-        INTERNAL_USER_PARTICIPANT_CHECK_1("Error: Got an UserParticipant object with an identifier < 1 Identifier:Folder_Type = %d:%d", 30, AbstractOXException.Category.INTERNAL_ERROR),
-        INTERNAL_USER_PARTICIPANT_CHECK_2("Error: Got an UserParticipant object with a private folder id < 1 : Identifier = %d", 31, AbstractOXException.Category.USER_INPUT),
-        INTERNAL_USER_PARTICIPANT_CHECK_3("Error: Got an UserParticipant object with a private folder id in a public folder : Identifier = %d", 32, AbstractOXException.Category.USER_INPUT),
+        INTERNAL_USER_PARTICIPANT_CHECK_1("Got an UserParticipant object with an identifier < 1 Identifier:Folder_Type = %d:%d", 30, AbstractOXException.Category.INTERNAL_ERROR),
+        INTERNAL_USER_PARTICIPANT_CHECK_2("Got an UserParticipant object with a private folder id < 1 : Identifier = %d", 31, AbstractOXException.Category.USER_INPUT),
+        INTERNAL_USER_PARTICIPANT_CHECK_3("Got an UserParticipant object with a private folder id in a public folder : Identifier = %d", 32, AbstractOXException.Category.USER_INPUT),
         MOVE_NOT_SUPPORTED("Move not supported: Cannot move an appointment from folder %d to folder %d", 33, AbstractOXException.Category.CODE_ERROR),
         SHARED_FOLDER_MOVE_NOT_SUPPORTED("Move not allowed from shared folders", 34, AbstractOXException.Category.CODE_ERROR),
         CONTEXT_NOT_SET("Calendar operation: Context not set.", 35, AbstractOXException.Category.CODE_ERROR),
         NO_PERMISSIONS_TO_ATTACH_DETACH("Insufficient rights to attach/detach an attachment to this folder!", 36, AbstractOXException.Category.PERMISSION),
         NO_PERMISSIONS_TO_READ("Insufficient read rights for this folder!", 37, AbstractOXException.Category.PERMISSION),
         /**
-         * FATAL:: Can not resolve recurrence position because we got neither the recurring position nor a recurring date position
+         * Can not resolve recurrence position because we got neither the recurring position nor a recurring date position
          */
-        UNABLE_TO_CALCULATE_RECURRING_POSITION_NO_INPUT("FATAL:: Can not resolve recurrence position because we got neither the recurring position nor a recurring date position", 38, AbstractOXException.Category.INTERNAL_ERROR),
+        UNABLE_TO_CALCULATE_RECURRING_POSITION_NO_INPUT("Can not resolve recurrence position because we got neither the recurring position nor a recurring date position", 38, AbstractOXException.Category.INTERNAL_ERROR),
         RECURRING_MISSING_START_DATE("Missing start date, unable to calculate recurring!", 39, AbstractOXException.Category.CODE_ERROR),
-        RECURRING_MISSING_DAILY_INTERVAL("Fatal error. (DAILY) Missing or wrong Interval value: %d", 40, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_WEEKLY_INTERVAL("Fatal error. (WEEKLY) Missing or wrong Interval value: %d", 41, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_DAILY_INTERVAL("Missing or wrong interval value: %d", 40, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_WEEKLY_INTERVAL("Missing or wrong interval value: %d", 41, AbstractOXException.Category.USER_INPUT),
         /**
-         * Fatal error. (MONTHLY) Missing or wrong value DayInMonth : %d
+         * Missing or wrong value DayInMonth : %d
          */
-        RECURRING_MISSING_MONTLY_INTERVAL("Fatal error. (MONTHLY) Missing or wrong value DayInMonth : %d", 42, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_MONTLY_INTERVAL_2("Fatal error. (MONTHLY) Missing or wrong value Month : %d", 43, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_MONTLY_DAY("Fatal error. (MONTHLY2) Missing or wrong Day value: %d", 44, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_MONTLY_INTERVAL("Missing or wrong value DayInMonth : %d", 42, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_MONTLY_INTERVAL_2("Missing or wrong value Month : %d", 43, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_MONTLY_DAY("Missing or wrong Day value: %d", 44, AbstractOXException.Category.USER_INPUT),
         /**
-         * Fatal error. (MONTHLY2) Missing or wrong DayInMonth value: %d
+         * Missing or wrong DayInMonth value: %d
          */
-        RECURRING_MISSING_MONTLY_DAY_2("Fatal error. (MONTHLY2) Missing or wrong DayInMonth value: %d", 45, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_YEARLY_INTERVAL("Fatal error. (YEARLY) Missing or wrong value DayInMonth : %d", 46, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_YEARLY_DAY("Fatal error. (YEARLY2) Missing or wrong value day : %d", 47, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_YEARLY_TYPE("Fatal error. (YEARLY2) Missing or wrong day_or_type : %d", 48, AbstractOXException.Category.USER_INPUT),
-        RECURRING_MISSING_YEARLY_INTERVAL_2("Fatal error. (YEARLY2) Missing or wrong Interval value: %d", 49, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_MONTLY_DAY_2("Missing or wrong DayInMonth value: %d", 45, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_YEARLY_INTERVAL("Missing or wrong value DayInMonth : %d", 46, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_YEARLY_DAY("Missing or wrong value day : %d", 47, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_YEARLY_TYPE("Missing or wrong day_or_type : %d", 48, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_YEARLY_INTERVAL_2("Missing or wrong Interval value: %d", 49, AbstractOXException.Category.USER_INPUT),
         UNABLE_TO_REMOVE_PARTICIPANT("Unable to remove participant %d", 50, AbstractOXException.Category.CODE_ERROR),
         UNABLE_TO_REMOVE_PARTICIPANT_2("Unable to remove participant because this participant is the last one", 51, AbstractOXException.Category.USER_INPUT),
         UNSUPPORTED_ACTION_TYPE("Action type not supported : %d", 52,  AbstractOXException.Category.CODE_ERROR),
@@ -159,12 +159,12 @@ public class OXCalendarException extends OXException {
         LOAD_PERMISSION_EXCEPTION_2("Got the wrong folder identification. You do not have the appropriate permissions to modify this object.", 59, AbstractOXException.Category.PERMISSION),
         LOAD_PERMISSION_EXCEPTION_3("Got the wrong shared folder identification. You do not have the appropriate permissions to modify this object.", 60, AbstractOXException.Category.PERMISSION),
         LOAD_PERMISSION_EXCEPTION_4("You do not have the appropriate permissions to move this object.", 61, AbstractOXException.Category.PERMISSION),
-        LOAD_PERMISSION_EXCEPTION_5("You do not have the appropriate permissions to read this object", 62, AbstractOXException.Category.PERMISSION),
+        LOAD_PERMISSION_EXCEPTION_5("You do not have the appropriate permissions to read this object %1$d.", 62, AbstractOXException.Category.PERMISSION),
         LOAD_PERMISSION_EXCEPTION_6("You do not have the appropriate permissions to create an object", 63, AbstractOXException.Category.PERMISSION),
-        RECURRING_MISSING_YEARLY_MONTH("Fatal error. (YEARLY) Missing or wrong Month value: %d", 64, AbstractOXException.Category.USER_INPUT),
-        RECURRING_ALREADY_EXCEPTION("Fatal error. You are trying to create a new recurring from an exception!", 65, AbstractOXException.Category.USER_INPUT),
+        RECURRING_MISSING_YEARLY_MONTH("Missing or wrong Month value: %d", 64, AbstractOXException.Category.USER_INPUT),
+        RECURRING_ALREADY_EXCEPTION("You are trying to create a new recurring from an exception!", 65, AbstractOXException.Category.USER_INPUT),
         RECURRING_EXCEPTION_MOVE_EXCEPTION("You can not move one element of a recurring appointment into another folder.", 66, AbstractOXException.Category.USER_INPUT),
-        UPDATE_EXCEPTION("Fatal error. An database update exception occurred.", 67, AbstractOXException.Category.INTERNAL_ERROR),
+        UPDATE_EXCEPTION("An database update exception occurred.", 67, AbstractOXException.Category.INTERNAL_ERROR),
         MOVE_TO_SHARED_FOLDER_NOT_SUPPORTED("Move not allowed to a shared folder if the private flag is set", 68, AbstractOXException.Category.USER_INPUT),
         RECURRING_EXCEPTION_PRIVATE_FLAG("You can not use different private flags for one element of a recurring appointment", 69, AbstractOXException.Category.USER_INPUT),
         PIVATE_FLAG_ONLY_IN_PRIVATE_FOLDER("You can not use the private flags in a non private folder", 70, AbstractOXException.Category.USER_INPUT),
@@ -275,7 +275,7 @@ public class OXCalendarException extends OXException {
         UNNECESSARY_RECURRENCE_INFORMATION("Unnecessary recurrence information (%1$s) for type %2$s", 97, Category.USER_INPUT),
         UNABLE_TO_CALCULATE_POSITION("Unable to calculate given position. Seems to be a delete exception or outside range", 98, Category.USER_INPUT),
         CHANGE_EXCEPTION_TO_RECURRENCE("Changing an exception into a series is not supported.", 99, Category.USER_INPUT),
-        UID_ALREDY_EXISTS("Can not insert appointment with this uid. Uid already exists.", 100, Category.USER_INPUT),
+        UID_ALREDY_EXISTS("Cannot insert appointment (%1$s). An appointment with the unique identifier (%2$s) already exists.", 100, Category.USER_INPUT),
         /** SQL Problem. */
         SQL_ERROR("SQL Problem.", 101, Category.CODE_ERROR),
         /** Wrong number of rows changed. Expected %1$d but was %2$d. */
@@ -285,7 +285,21 @@ public class OXCalendarException extends OXException {
          */
         COULD_NOT_FIND_PARTICIPANT("Could not find participant for this object.", 103, Category.USER_INPUT),
         /** Was not able to calculate next upcoming reminder for series appointment %2$d in context %1$d. */
-        NEXT_REMINDER_FAILED("Was not able to calculate next upcoming reminder for series appointment %2$d in context %1$d.", 104, Category.CODE_ERROR);
+        NEXT_REMINDER_FAILED("Was not able to calculate next upcoming reminder for series appointment %2$d in context %1$d.", 104, Category.CODE_ERROR),
+        INVALID_SEQUENCE("Invalid Sequence value: %1$d", 105, Category.USER_INPUT),
+        /**
+         * An external participant with email address %1$s is already contained. Please remove duplicate participant and retry.
+         */
+        DUPLICATE_EXTERNAL_PARTICIPANT("An external participant with email address %1$s is already contained. Please remove duplicate participant and retry.", 106, Category.USER_INPUT),
+        /**
+         * Appointment is not a recurring appointment.
+         */
+        NO_RECCURENCE("Appointment is not a recurring appointment", 107, Category.USER_INPUT),
+        /**
+         * Unexpected SQL Error!
+         */
+        CALENDAR_SQL_ERROR_RETRY("Unexpected SQL Error!", 108, AbstractOXException.Category.TRY_AGAIN),
+        ;
 
         /**
          * Message of the exception.
