@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,12 +58,12 @@ import com.openexchange.search.SearchAttributeFetcher;
 
 /**
  * {@link ContactAttributeFetcher}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class ContactAttributeFetcher implements SearchAttributeFetcher<Contact> {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(AttributeGetter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(AttributeGetter.class));
 
     private static interface AttributeGetter {
 
@@ -662,7 +662,7 @@ public class ContactAttributeFetcher implements SearchAttributeFetcher<Contact>
 
     /**
      * Gets the contact attribute fetcher instance.
-     * 
+     *
      * @return The contact attribute fetcher instance.
      */
     public static ContactAttributeFetcher getInstance() {
