@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,11 +58,12 @@ import com.openexchange.contact.LdapServer;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.ContactSearchObject;
 import com.openexchange.groupware.search.Order;
+import com.openexchange.search.SearchTerm;
 import com.openexchange.tools.iterator.SearchIterator;
 
 /**
  * {@link ContactInterface} - The contact interface.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public interface ContactInterface {
@@ -77,15 +78,38 @@ public interface ContactInterface {
      */
     public static final String OVERRIDE_CONTEXT_ATTRIBUTE = "override_context";
 
+    /**
+     * Inserts specified contact.
+     * 
+     * @param co The contact
+     * @throws OXException If insertion fails
+     */
     public void insertContactObject(final Contact co) throws OXException;
 
-    public void updateContactObject(final Contact co, final int fid, final java.util.Date d) throws OXException, OXConcurrentModificationException, ContactException;
+    /**
+     * Updates specified contact.
+     * 
+     * @param co The contact providing contact identifier and changed values
+     * @param fid The folder identifier
+     * @param lastModified The client's last-modified time stamp to check for possible conflicts
+     * @throws OXException If a general exception occurs during update attempt
+     * @throws OXConcurrentModificationException If contact's last-modified time stamp is greater than client's last-modified time stamp
+     * @throws ContactException If a general exception occurs during update attempt
+     */
+    public void updateContactObject(final Contact co, final int fid, final java.util.Date lastModified) throws OXException, OXConcurrentModificationException, ContactException;
 
-    void updateUserContact(Contact contact, Date lastmodified) throws OXException;
+    /**
+     * Updates specified user contact.
+     * 
+     * @param co The user contact providing contact identifier and changed values
+     * @param lastModified The client's last-modified time stamp to check for possible conflicts
+     * @throws OXException If a general exception occurs during update attempt
+     */
+    public void updateUserContact(Contact contact, Date lastmodified) throws OXException;
 
     /**
      * Determines the number of contacts a certain private or public folder.
-     * 
+     *
      * @param folderId - The Folder ID
      * @param readCon - The Readable Connection To DB
      * @return Amount of contacts as an <code>int</code>
@@ -95,33 +119,46 @@ public interface ContactInterface {
 
     /**
      * List contacts in a folder
-     * 
+     *
      * @param folderId The Folder ID
      * @param from Start position in list
      * @param to End position in list
      * @param orderBy Column id to sort. 0 if no order by is used
      * @param order Order direction, may be null if no special ordering is requested
-     * @param cols The columns filled to the dataobject
+     * @param cols The columns filled to the data object
      * @param readcon The readable Database Connection
      * @return A SearchIterator contains Task objects
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    public SearchIterator<Contact> getContactsInFolder(int folderId, int from, int to, int orderBy, Order order, int[] cols) throws OXException;
+    public SearchIterator<Contact> getContactsInFolder(int folderId, int from, int to, int orderBy, Order order, String collation, int[] cols) throws OXException;
 
     /**
      * Lists all contacts that match the given search
-     * 
+     *
      * @param searchObject The SearchObject
      * @param cols fields that will be added to the data object
      * @return A SearchIterator contains ContactObject
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    public SearchIterator<Contact> getContactsByExtendedSearch(ContactSearchObject searchobject, int orderBy, Order order, int[] cols) throws OXException;
+    public SearchIterator<Contact> getContactsByExtendedSearch(ContactSearchObject searchobject, int orderBy, Order order, String collation, int[] cols) throws OXException;
 
     /**
-     * Lists all contacts where the firstname, lastname or the displayname match the given searchpattern
+     * Lists all contacts that match the given search
      * 
-     * @param searchpattern The searchpattern
+     * @param searchterm The search term
+     * @param orderBy The field to order by
+     * @param order The order direction
+     * @param collation The collation to use
+     * @param cols The columns the returned contacts shall provide
+     * @return The search results
+     * @throws OXException If search fails
+     */
+    public <T>SearchIterator<Contact> getContactsByExtendedSearch(SearchTerm<T> searchterm, int orderBy, Order order, String collation, int[] cols) throws OXException;
+
+    /**
+     * Lists all contacts where the first name, last name or the display name match the given search pattern
+     *
+     * @param searchpattern The search pattern
      * @param folderId folder id where to search
      * @param cols fields that will be added to the data object
      * @return A SearchIterator contains ContactObject
@@ -131,7 +168,7 @@ public interface ContactInterface {
 
     /**
      * Loads one contact by the given ID
-     * 
+     *
      * @param objectId The Object ID
      * @return return the ContactObject
      * @throws OXException, OXPermissionException
@@ -140,7 +177,7 @@ public interface ContactInterface {
 
     /**
      * Loads the contact of the given user id
-     * 
+     *
      * @param userId The User ID
      * @return User's contact
      * @throws OXException If loading the user fails
@@ -149,7 +186,7 @@ public interface ContactInterface {
 
     /**
      * Loads the contact of the given user id
-     * 
+     *
      * @param userId The User ID
      * @param performReadCheck <code>true</code> to perform read check; otherwise <code>false</code>
      * @return User's contact
@@ -157,9 +194,19 @@ public interface ContactInterface {
      */
     public Contact getUserById(int userId, boolean performReadCheck) throws OXException;
 
+    /**
+     * Loads the contacts of the given user identifier.
+     *
+     * @param userIds The user IDs
+     * @param performReadCheck <code>true</code> to perform read check; otherwise <code>false</code>
+     * @return User's contacts
+     * @throws OXException If loading the user fails
+     */
+    public Contact[] getUsersById(int[] userIds, boolean performReadCheck) throws OXException;
+
     /**
      * Lists all modified objects in a folder
-     * 
+     *
      * @param folderID The Folder ID
      * @param since all modification >= since
      * @return A SearchIterator containing ContactObjects
@@ -169,7 +216,7 @@ public interface ContactInterface {
 
     /**
      * Lists all deleted objects in a folder
-     * 
+     *
      * @param folderID The Folder ID
      * @param since all modification >= since
      * @return A SearchIterator containing ContactObjects
@@ -177,11 +224,21 @@ public interface ContactInterface {
      */
     public SearchIterator<Contact> getDeletedContactsInFolder(int folderId, int[] cols, Date since) throws OXException;
 
+    /**
+     * Deletes specified contact (and puts into backup/deleted tables)
+     * 
+     * @param oid The contact identifier
+     * @param fuid The folder identifier
+     * @param client_date The client's last-modified time stamp
+     * @throws OXObjectNotFoundException If such a contact does not exist
+     * @throws OXConflictException If object's last-modified time stamp is greater than passed client's last-modified time stamp
+     * @throws OXException A generell exception during deletion
+     */
     public void deleteContactObject(final int oid, final int fuid, final Date client_date) throws OXObjectNotFoundException, OXConflictException, OXException;
 
     /**
      * Loads a range of contacts by the given IDs
-     * 
+     *
      * @param objectIdAndInFolder[] array with two dimensions. First dimension contains a seond array with two values. 1. value is object_id
      *            2. value if folder_id
      * @param cols The columns filled to the dataobject
@@ -192,21 +249,21 @@ public interface ContactInterface {
 
     /**
      * Gets the folder ID.
-     * 
+     *
      * @return The folder ID
      */
     public int getFolderId();
 
     /**
-     * Gets the LDAP server.
-     * 
-     * @return The LDAP server
+     * Gets the LDAP server in case of a LDAP implementation; otherwise <code>null</code>.
+     *
+     * @return The LDAP server or <code>null</code>
      */
     public LdapServer getLdapServer();
 
     /**
      * Sets the session instance.
-     * 
+     *
      * @param s The session instance to set
      * @throws OXException If applying given session instance fails
      */
