@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,11 +51,10 @@ package com.openexchange.groupware.contact.datasource;
 
 import static com.openexchange.ajax.AJAXServlet.PARAMETER_FOLDERID;
 import static com.openexchange.ajax.AJAXServlet.PARAMETER_ID;
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.util.HashMap;
-import java.util.Map;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -70,6 +69,7 @@ import com.openexchange.conversion.SimpleData;
 import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
@@ -82,12 +82,12 @@ import com.openexchange.tools.versit.converter.OXContainerConverter;
 
 /**
  * {@link ContactDataSource} - A data source for contacts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ContactDataSource implements DataSource {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ContactDataSource.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ContactDataSource.class));
 
     private static final Class<?>[] TYPES = { InputStream.class, byte[].class };
 
@@ -109,11 +109,12 @@ public final class ContactDataSource implements DataSource {
          */
         final int[] folderIds;
         final int[] objectIds;
+        final int len;
         {
             final JSONArray pairsArray;
             try {
                 pairsArray = new JSONArray(dataArguments.get(ARGS[0]));
-                final int len = pairsArray.length();
+                len = pairsArray.length();
                 if (len == 0) {
                     throw DataExceptionCodes.MISSING_ARGUMENT.create(ARGS[0]);
                 }
@@ -124,38 +125,40 @@ public final class ContactDataSource implements DataSource {
                     folderIds[i] = pairObject.getInt(PARAMETER_FOLDERID);
                     objectIds[i] = pairObject.getInt(PARAMETER_ID);
                 }
-            } catch (final JSONException e1) {
-                throw DataExceptionCodes.INVALID_ARGUMENT.create(ARGS[0], dataArguments.get(ARGS[0]));
+            } catch (final JSONException e) {
+                throw DataExceptionCodes.INVALID_ARGUMENT.create(e, ARGS[0], dataArguments.get(ARGS[0]));
             }
         }
         /*
          * Get contact
          */
-        final Contact[] contacts = new Contact[folderIds.length];
+        final Contact[] contacts = new Contact[len];
         try {
-            final Map<Integer, ContactInterface> tmp = new HashMap<Integer, ContactInterface>(contacts.length);
-            for (int i = 0; i < contacts.length; i++) {
+            final ContactInterfaceDiscoveryService discoveryService = ServerServiceRegistry.getInstance().getService(
+                ContactInterfaceDiscoveryService.class,
+                true);
+            final TIntObjectHashMap<ContactInterface> tmp = new TIntObjectHashMap<ContactInterface>(len);
+            for (int i = 0; i < len; i++) {
                 final int folderId = folderIds[i];
-                final Integer key = Integer.valueOf(folderId);
-                ContactInterface contactInterface = tmp.get(key);
+                ContactInterface contactInterface = tmp.get(folderId);
                 if (null == contactInterface) {
-                    contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
-                        folderId,
-                        session);
-                    tmp.put(key, contactInterface);
+                    contactInterface = discoveryService.newContactInterface(folderId, session);
+                    tmp.put(folderId, contactInterface);
                 }
                 contacts[i] = contactInterface.getObjectById(objectIds[i], folderId);
             }
         } catch (final OXException e) {
             throw new DataException(e);
+        } catch (final ServiceException e) {
+            throw new DataException(e);
         }
         /*
          * Create necessary objects
          */
-        final ByteArrayOutputStream byteArrayOutputStream = new UnsynchronizedByteArrayOutputStream(folderIds.length << 12);
+        final ByteArrayOutputStream sink = new UnsynchronizedByteArrayOutputStream(len << 12);
         final VersitDefinition contactDef = Versit.getDefinition("text/vcard");
         for (final Contact contact : contacts) {
-            writeVCard2Stream(contact, byteArrayOutputStream, contactDef, session);
+            writeVCard2Stream(contact, sink, contactDef, session);
         }
         /*
          * Return data
@@ -167,17 +170,17 @@ public final class ContactDataSource implements DataSource {
         final String displayName = contacts.length == 1 ? contacts[0].getDisplayName() : null;
         properties.put(DataProperties.PROPERTY_NAME, displayName == null ? "vcard.vcf" : new StringBuilder(
             displayName.replaceAll(" +", "_")).append(".vcf").toString());
-        final byte[] vcardBytes = byteArrayOutputStream.toByteArray();
+        final byte[] vcardBytes = sink.toByteArray();
         properties.put(DataProperties.PROPERTY_SIZE, String.valueOf(vcardBytes.length));
         return new SimpleData<D>(
             (D) (InputStream.class.equals(type) ? new UnsynchronizedByteArrayInputStream(vcardBytes) : vcardBytes),
             properties);
     }
 
-    private static void writeVCard2Stream(final Contact contact, final ByteArrayOutputStream byteArrayOutputStream, final VersitDefinition contactDef, final Session session) throws DataException {
+    private static void writeVCard2Stream(final Contact contact, final ByteArrayOutputStream stream, final VersitDefinition contactDef, final Session session) throws DataException {
         final VersitDefinition.Writer versitWriter;
         try {
-            versitWriter = contactDef.getWriter(byteArrayOutputStream, "UTF-8");
+            versitWriter = contactDef.getWriter(stream, "UTF-8");
         } catch (final IOException e) {
             throw DataExceptionCodes.ERROR.create(e, e.getMessage());
         }
@@ -191,6 +194,7 @@ public final class ContactDataSource implements DataSource {
          * Convert
          */
         try {
+            oxContainerConverter.setAddDisplayName4DList(true);
             final VersitObject versitObject = oxContainerConverter.convertContact(contact, "3.0");
             contactDef.write(versitWriter, versitObject);
             versitWriter.flush();
