@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,28 +61,89 @@ import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.image.ImageDataSource;
+import com.openexchange.image.ImageLocation;
+import com.openexchange.image.ImageUtility;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 
 /**
  * {@link ContactImageDataSource} - A data source to obtains a contact's image data
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ContactImageDataSource implements ImageDataSource {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ContactImageDataSource.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ContactImageDataSource.class));
+
+    private static final ContactImageDataSource INSTANCE = new ContactImageDataSource();
+
+    /**
+     * Gets the instance
+     *
+     * @return The instance
+     */
+    public static ContactImageDataSource getInstance() {
+        return INSTANCE;
+    }
 
     private static final String[] ARGS = { "com.openexchange.groupware.contact.folder", "com.openexchange.groupware.contact.id" };
 
     /**
      * Initializes a new {@link ContactImageDataSource}
      */
-    public ContactImageDataSource() {
+    private ContactImageDataSource() {
         super();
     }
 
+    public String generateUrl(final ImageLocation imageLocation, final Session session) throws DataException {
+        try {
+            final StringBuilder sb = new StringBuilder(64);
+            ImageUtility.startImageUrl(imageLocation, session, this, true, sb);
+            final Contact contact = optContact(imageLocation, session);
+            if (null != contact) {
+                sb.append('&').append("timestamp=").append(contact.getLastModified().getTime());
+            }
+            return sb.toString();
+        } catch (final OXException e) {
+            throw new DataException(e);
+        }
+    }
+
+    public DataArguments generateDataArgumentsFrom(final ImageLocation imageLocation) {
+        final DataArguments dataArguments = new DataArguments(2);
+        dataArguments.put(ARGS[0], imageLocation.getFolder());
+        dataArguments.put(ARGS[1], imageLocation.getId());
+        return dataArguments;
+    }
+
+    public long getExpires() {
+        return -1L;
+    }
+
+    public ImageLocation parseUrl(final String url) {
+        return ImageUtility.parseImageLocationFrom(url);
+    }
+
+    public String getETag(final ImageLocation imageLocation, final Session session) throws DataException {
+        try {
+            final char delim = '#';
+            final StringBuilder builder = new StringBuilder(128);
+            builder.append(delim).append(imageLocation.getFolder());
+            // builder.append(delim).append(imageLocation.getId());
+            // builder.append(delim).append(session.getUserId());
+            // builder.append(delim).append(session.getContextId());
+            final Contact contact = optContact(imageLocation, session);
+            if (null != contact) {
+                builder.append(delim).append(contact.getLastModified().getTime());
+            }
+            builder.append(delim);
+            return ImageUtility.getMD5(builder.toString(), "hex");
+        } catch (final OXException e) {
+            throw new DataException(e);
+        }
+    }
+
     public <D> Data<D> getData(final Class<? extends D> type, final DataArguments dataArguments, final Session session) throws DataException {
         if (!InputStream.class.equals(type)) {
             throw DataExceptionCodes.TYPE_NOT_SUPPORTED.create(type.getName());
@@ -146,6 +207,23 @@ public final class ContactImageDataSource implements ImageDataSource {
         return new SimpleData<D>((D) (new UnsynchronizedByteArrayInputStream(imageBytes)), properties);
     }
 
+    private static Contact optContact(final ImageLocation imageLocation, final Session session) throws OXException {
+        return optContact(ImageUtility.getUnsignedInteger(imageLocation.getId()), ImageUtility.getUnsignedInteger(imageLocation.getFolder()), session);
+    }
+
+    private static Contact optContact(final int objectId, final int folder, final Session session) throws OXException {
+        try {
+            final ContactInterfaceDiscoveryService discoveryService = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class);
+            if (null == discoveryService) {
+                return null;
+            }
+            final ContactInterface contactInterface = discoveryService.newContactInterface(folder, session);
+            return contactInterface.getObjectById(objectId, folder);
+        } catch (final OXException e) {
+            throw new OXException(e);
+        }
+    }
+
     /**
      * <ul>
      * <li><code>&quot;com.openexchange.groupware.contact.folder&quot;</code></li>
@@ -168,4 +246,10 @@ public final class ContactImageDataSource implements ImageDataSource {
         return REGISTRATION_NAME;
     }
 
+    private static final String ALIAS = "/contact/picture";
+
+    public String getAlias() {
+        return ALIAS;
+    }
+
 }
