@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,11 +50,12 @@
 package com.openexchange.groupware.contact.helpers;
 
 import com.openexchange.groupware.contact.ContactException;
+import com.openexchange.groupware.container.Contact;
 
 public class AbstractContactSwitcherWithDelegate implements ContactSwitcher {
 
 	protected ContactSwitcher delegate;
-	
+
 //------//
 	public ContactSwitcher getDelegate() {
 		return delegate;
@@ -62,7 +63,7 @@ public class AbstractContactSwitcherWithDelegate implements ContactSwitcher {
 
 	public void setDelegate(final ContactSwitcher delegate) {
 		this.delegate = delegate;
-	}	
+	}
 
 //------//
 	public Object creationdate(final Object... objects) throws ContactException {
@@ -515,5 +516,56 @@ public class AbstractContactSwitcherWithDelegate implements ContactSwitcher {
 	public Object userfield20(final Object... objects) throws ContactException {
 		return delegate.userfield20(objects);
 	}
+	
+    public Object numberofimages(Object... objects) throws ContactException {
+        return delegate.numberofimages(objects);
+    }
 
+    public Object lastmodifiedofnewestattachment(Object... objects) throws ContactException {
+        return delegate.lastmodifiedofnewestattachment(objects);
+    }
+
+    public Object usecount(Object... objects) throws ContactException {
+        return delegate.usecount(objects);
+    }
+
+    public Object markasdistributionlist(Object[] objects) throws ContactException {
+        return delegate.markasdistributionlist(objects);
+    }
+
+    public Object yomifirstname(Object[] objects) throws ContactException {
+        return delegate.yomifirstname(objects);
+    }
+
+    public Object yomilastname(Object[] objects) throws ContactException {
+        return delegate.yomilastname(objects);
+    }
+
+    public Object yomicompanyname(Object[] objects) throws ContactException {
+        return delegate.yomicompanyname(objects);
+    }
+    
+    public Object image1contenttype(Object[] objects) throws ContactException {
+        return delegate.image1contenttype(objects);
+    }
+    
+    public Object homeaddress(Object[] objects) throws ContactException {
+        return delegate.homeaddress(objects);
+    }
+
+    public Object businessaddress(Object[] objects) throws ContactException {
+        return delegate.businessaddress(objects);
+    }
+
+    public Object otheraddress(Object[] objects) throws ContactException {
+        return delegate.otheraddress(objects);
+    }
+
+    public Object uid(Object[] objects) throws ContactException {
+        return delegate.uid(objects);
+    }
+
+    public boolean _unknownfield(Contact contact, String fieldname, Object value, Object... additionalObjects) throws ContactException {
+        return delegate._unknownfield(contact, fieldname, value, additionalObjects);
+    }
 }
