@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,9 @@
 
 package com.openexchange.groupware.contact.helpers;
 
+import gnu.trove.map.hash.TIntObjectHashMap;
 import java.util.Comparator;
-import java.util.HashMap;
-import java.util.Map;
+import java.util.Locale;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.Order;
 
@@ -64,39 +64,58 @@ import com.openexchange.groupware.search.Order;
  */
 public class DefaultContactComparator implements Comparator<Contact>{
 
-    private Map<Integer, Comparator<Contact>> SPECIAL_COMPARATORS = new HashMap<Integer, Comparator<Contact>>() {{
-        put(Contact.SPECIAL_SORTING, new ContactComparator());
-        put(Contact.USE_COUNT_GLOBAL_FIRST, new UseCountGlobalFirstComparator());
-    }};
-    
-    private int field;
-    private Order order;
+    private static interface ComparatorProvider {
+        
+        Comparator<Contact> getComparator(Locale locale);
+    }
 
-    public DefaultContactComparator(int field, Order order) {
+    private static final ComparatorProvider USE_COUNT_COMPARATOR_PROVIDER = new ComparatorProvider() {
+
+        private final UseCountGlobalFirstComparator comparator = new UseCountGlobalFirstComparator();
+        
+        public Comparator<Contact> getComparator(final Locale locale) {
+            return comparator;
+        }
+    };
+
+    private static final ComparatorProvider SPECIAL_COMPARATOR_PROVIDER = new ComparatorProvider() {
+        
+        public Comparator<Contact> getComparator(final Locale locale) {
+            return new SpecialAlphanumSortContactComparator(locale);
+        }
+    };
+
+    private static final TIntObjectHashMap<ComparatorProvider> SPECIAL_COMPARATORS = new TIntObjectHashMap<ComparatorProvider>() {{
+        put(Contact.SPECIAL_SORTING, SPECIAL_COMPARATOR_PROVIDER);
+        put(Contact.USE_COUNT_GLOBAL_FIRST, USE_COUNT_COMPARATOR_PROVIDER);
+    }};
+
+    private final int field;
+    private final Order order;
+    private final Locale locale;
+
+    public DefaultContactComparator(final int field, final Order order, final Locale locale) {
         super();
         this.field = field;
         this.order = order;
+        this.locale = locale;
     }
 
-    public int compare(Contact o1, Contact o2) {
-        if(field <= 0 || Order.NO_ORDER.equals(order)) {
+    public int compare(final Contact o1, final Contact o2) {
+        if (field <= 0 || Order.NO_ORDER.equals(order)) {
             return 0;
         }
-        int rating;
-        if(SPECIAL_COMPARATORS.containsKey(field)) {
-            rating = SPECIAL_COMPARATORS.get(field).compare(o1, o2);
-        } else {
-            Object v1 = o1.get(field);
-            Object v2 = o2.get(field);
-            rating = internalCompare(v1, v2);
+        final ComparatorProvider provider = SPECIAL_COMPARATORS.get(field);
+        if (null != provider) {
+            final Comparator<Contact> specialComparator = provider.getComparator(locale);
+            return Order.DESCENDING.equals(order) ? -1 * specialComparator.compare(o1, o2) : specialComparator.compare(o1, o2);
         }
-        if(Order.DESCENDING.equals(order)) {
-            rating = -rating;
-        }
-        return  rating;
+        final Object v1 = o1.get(field);
+        final Object v2 = o2.get(field);
+        return Order.DESCENDING.equals(order) ? -1 * internalCompare(v1, v2) : internalCompare(v1, v2);
     }
-    
-    private int internalCompare(Object v1, Object v2) {
+
+    private int internalCompare(final Object v1, final Object v2) {
         if(v1 == v2) {
             return 0;
         }
