@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.groupware.contact.helpers;
 
 import java.util.Comparator;
+import java.util.Locale;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
 
@@ -58,23 +59,27 @@ import com.openexchange.groupware.container.FolderObject;
  */
 public class UseCountComparator implements Comparator<Contact> {
 
-    private ContactComparator contactComparator;
+    private Comparator<Contact> contactComparator;
 
-    private boolean specialSort;
+    private final boolean specialSort;
 
-    public UseCountComparator(boolean specialSort) {
+    public UseCountComparator(final boolean specialSort, final Locale locale) {
         super();
         this.specialSort = specialSort;
-        this.contactComparator = new ContactComparator();
+        this.contactComparator = new SpecialAlphanumSortContactComparator(locale);
     }
 
-    public int compare(Contact o1, Contact o2) {
+    public UseCountComparator(final boolean specialSort, final Comparator<Contact> comp) {
+        this(specialSort, Locale.US);
+        this.contactComparator = comp;
+    }
+
+    public int compare(final Contact o1, final Contact o2) {
         if (o1.getParentFolderID() == FolderObject.SYSTEM_LDAP_FOLDER_ID && o2.getParentFolderID() == FolderObject.SYSTEM_LDAP_FOLDER_ID) {
             if (specialSort) {
                 return contactComparator.compare(o1, o2);
-            } else {
-                return 0;
             }
+            return 0;
         } else if (o1.getParentFolderID() != FolderObject.SYSTEM_LDAP_FOLDER_ID && o2.getParentFolderID() != FolderObject.SYSTEM_LDAP_FOLDER_ID) {
             return o2.getUseCount() - o1.getUseCount();
         } else if (o1.getParentFolderID() == FolderObject.SYSTEM_LDAP_FOLDER_ID) {
