@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,13 +49,14 @@
 
 package com.openexchange.groupware.container;
 
+import java.util.HashSet;
 import java.util.Set;
 import com.openexchange.groupware.calendar.Constants;
 
 /**
  * The appointment object.
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class Appointment extends CalendarObject implements Cloneable {
 
@@ -77,7 +78,7 @@ public class Appointment extends CalendarObject implements Cloneable {
         // From CalendarObject
         TITLE, START_DATE, END_DATE, NOTE, ALARM, RECURRENCE_ID, RECURRENCE_POSITION, RECURRENCE_DATE_POSITION, RECURRENCE_TYPE,
         CHANGE_EXCEPTIONS, DELETE_EXCEPTIONS, DAYS, DAY_IN_MONTH, MONTH, INTERVAL, UNTIL, NOTIFICATION, RECURRENCE_CALCULATOR,
-        PARTICIPANTS, USERS, RECURRENCE_COUNT, UID, ORGANIZER, SEQUENCE,
+        PARTICIPANTS, USERS, CONFIRMATIONS, RECURRENCE_COUNT, UID, ORGANIZER, SEQUENCE, ORGANIZER_ID, PRINCIPAL, PRINCIPAL_ID,
         // From CommonObject
         CATEGORIES, PRIVATE_FLAG,
         COLOR_LABEL, NUMBER_OF_LINKS, NUMBER_OF_ATTACHMENTS,
@@ -116,7 +117,7 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     protected boolean b_shown_as;
 
-    protected boolean bAlarm;
+    protected boolean b_Alarm;
 
     protected boolean b_timezone;
 
@@ -156,7 +157,7 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     /**
      * Returns the time zone essential for recurring appointments.
-     * 
+     *
      * @return the time zone if it has been set otherwise <code>null</code>.
      */
     public String getTimezone() {
@@ -165,7 +166,7 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     /**
      * Returns the time zone essential for recurring appointments.
-     * 
+     *
      * @return the time zone if it has been set otherwise UTC.
      * @deprecated use {@link #getTimezone()} and handle fallback to UTC yourself.
      */
@@ -203,7 +204,7 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     public void setAlarm(final int alarm) {
         this.alarm = alarm;
-        bAlarm = true;
+        b_Alarm = true;
     }
 
     public void setIgnoreConflicts(final boolean ignoreConflicts) {
@@ -233,7 +234,7 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     public void removeAlarm() {
         alarm = 0;
-        bAlarm = false;
+        b_Alarm = false;
     }
 
     public void removeTimezone() {
@@ -265,7 +266,7 @@ public class Appointment extends CalendarObject implements Cloneable {
     }
 
     public boolean containsAlarm() {
-        return bAlarm;
+        return b_Alarm;
     }
 
     public boolean containsTimezone() {
@@ -285,7 +286,7 @@ public class Appointment extends CalendarObject implements Cloneable {
         b_location = false;
         b_fulltime = false;
         b_shown_as = false;
-        bAlarm = false;
+        b_Alarm = false;
         b_timezone = false;
     }
 
@@ -307,44 +308,46 @@ public class Appointment extends CalendarObject implements Cloneable {
 
     @Override
     public Appointment clone() {
-        try {
-            final Appointment appointmentobject = (Appointment) super.clone();/* new AppointmentObject(); */
+        final Appointment appointmentobject = (Appointment) super.clone();
 
-            for(int field: ALL_COLUMNS)
-                if(contains(field))
-                    appointmentobject.set(field, get(field));
-            
-            if (containsLabel()) {
-                appointmentobject.setLabel(getLabel());
-            }
-            if (containsFullTime()) {
-                appointmentobject.setFullTime(getFullTime());
-            }
-            if (containsLocation()) {
-                appointmentobject.setLocation(getLocation());
-            }
-            if (containsShownAs()) {
-                appointmentobject.setShownAs(getShownAs());
-            }
-            if (containsOccurrence()) {
-                appointmentobject.setOccurrence(getOccurrence());
-            }
-            if (containsTimezone()) {
-                appointmentobject.setTimezone(getTimezoneFallbackUTC());
-            }
-            if (containsUid()) {
-                appointmentobject.setUid(getUid());
-            }
-            if (containsOrganizer()) {
-                appointmentobject.setOrganizer(getOrganizer());
-            }
-            return appointmentobject;
-        } catch (final CloneNotSupportedException e) {
-            /*
-             * Cannot occur since we are cloneable
-             */
-            throw new InternalError(e.getMessage());
+        for(int field: ALL_COLUMNS)
+            if(contains(field) && !appointmentobject.contains(field))
+                appointmentobject.set(field, get(field));
+
+        if (containsLabel()) {
+            appointmentobject.setLabel(getLabel());
         }
+        if (containsFullTime()) {
+            appointmentobject.setFullTime(getFullTime());
+        }
+        if (containsLocation()) {
+            appointmentobject.setLocation(getLocation());
+        }
+        if (containsShownAs()) {
+            appointmentobject.setShownAs(getShownAs());
+        }
+        if (containsOccurrence()) {
+            appointmentobject.setOccurrence(getOccurrence());
+        }
+        if (containsTimezone()) {
+            appointmentobject.setTimezone(getTimezoneFallbackUTC());
+        }
+        if (containsUid()) {
+            appointmentobject.setUid(getUid());
+        }
+        if (containsOrganizer()) {
+            appointmentobject.setOrganizer(getOrganizer());
+        }
+        if (containsPrincipal()) {
+            appointmentobject.setPrincipal(getPrincipal());
+        }
+        if (containsOrganizerId()) {
+            appointmentobject.setOrganizerId(getOrganizerId());
+        }
+        if (containsPrincipalId()) {
+            appointmentobject.setPrincipalId(getPrincipalId());
+        }
+        return appointmentobject;
     }
 
     @Override
@@ -477,4 +480,10 @@ public class Appointment extends CalendarObject implements Cloneable {
         }
     }
 
+    public static Set<Differ<? super Appointment>> differ = new HashSet<Differ<? super Appointment>>();
+    
+    static {
+        differ.addAll(CalendarObject.differ);
+    }
+
 }
