@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,16 +51,16 @@ package com.openexchange.groupware.container;
 
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contact.ContactConfig;
 import com.openexchange.groupware.contact.ContactException;
+import com.openexchange.groupware.contact.ContactExceptionCodes;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.tools.StringCollection;
 
 /**
  * DistributionListObject
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 
 public class DistributionListEntryObject {
@@ -116,7 +116,7 @@ public class DistributionListEntryObject {
 
     /**
      * Initializes a new {@link DistributionListEntryObject}
-     * 
+     *
      * @param displayname The display name
      * @param emailaddress The email address
      * @param emailfield The email field
@@ -186,7 +186,7 @@ public class DistributionListEntryObject {
 
     /**
      * Sets the distribution list entry's email address
-     * 
+     *
      * @param emailaddress The email address to set
      * @throws ContactException If specified email address is invalid
      */
@@ -197,7 +197,7 @@ public class DistributionListEntryObject {
         try {
             new QuotedInternetAddress(emailaddress);
         } catch (final AddressException e) {
-            throw new ContactException(Category.USER_INPUT, ContactException.INVALID_ADDRESS, 99, emailaddress);
+            throw ContactExceptionCodes.INVALID_EMAIL.create(e, emailaddress);
         }
         this.emailaddress = emailaddress;
         b_emailaddress = true;
