@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,11 @@
 package com.openexchange.groupware.container;
 
 import com.openexchange.groupware.container.participants.AbstractConfirmableParticipant;
+import com.openexchange.groupware.container.participants.ConfirmableParticipant;
 
 /**
  * {@link ExternalUserParticipant} - Represents an external user participant.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class ExternalUserParticipant extends AbstractConfirmableParticipant implements Comparable<Participant> {
@@ -62,13 +63,13 @@ public class ExternalUserParticipant extends AbstractConfirmableParticipant impl
 
     private String displayName;
 
-    private final String emailaddress;
+    private String emailaddress;
 
     private boolean ignoreNotification;
 
     /**
      * Default constructor.
-     * 
+     *
      * @param emailAddress The unique email address of the external participant.
      */
     public ExternalUserParticipant(final String emailAddress) {
@@ -166,12 +167,19 @@ public class ExternalUserParticipant extends AbstractConfirmableParticipant impl
     }
 
     @Override
-    public Object clone() throws CloneNotSupportedException {
-        return super.clone();
+    public ExternalUserParticipant clone() throws CloneNotSupportedException {
+        ExternalUserParticipant retval = (ExternalUserParticipant) super.clone();
+        
+        retval.setDisplayName(this.getDisplayName());
+        retval.emailaddress = this.emailaddress;
+        retval.setIdentifier(this.getIdentifier());
+        retval.setIgnoreNotification(this.isIgnoreNotification());
+
+        return retval;
     }
 
-    public Participant getClone() throws CloneNotSupportedException {
-        return (Participant) clone();
+    public ConfirmableParticipant getClone() throws CloneNotSupportedException {
+        return clone();
     }
 
     public boolean isIgnoreNotification() {
