@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,12 +49,13 @@
 
 package com.openexchange.groupware.container;
 
+import static com.openexchange.java.Autoboxing.i;
 import java.util.Set;
 
 /**
  * DataObject
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 
 public abstract class FolderChildObject extends DataObject {
@@ -94,6 +95,7 @@ public abstract class FolderChildObject extends DataObject {
         b_parent_folder_id = false;
     }
 
+    @Override
     public Set<Integer> findDifferingFields(DataObject otherDataObject) {
         Set<Integer> differingFields = super.findDifferingFields(otherDataObject);
 
@@ -115,7 +117,12 @@ public abstract class FolderChildObject extends DataObject {
     public void set(int field, Object value) {
         switch (field) {
         case FOLDER_ID:
-            setParentFolderID((Integer) value);
+            if (value instanceof Integer) {
+                setParentFolderID(i((Integer) value));
+            }
+            if (value instanceof String) {
+                setParentFolderID(Integer.parseInt((String) value));
+            }
             break;
         default:
             super.set(field, value);
