@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,20 +49,15 @@
 
 package com.openexchange.groupware.container;
 
-import static com.openexchange.tools.sql.DBUtils.closeResources;
 import java.io.Serializable;
 import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Set;
-import java.util.regex.Pattern;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.AbstractOXException;
@@ -71,7 +66,6 @@ import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.i18n.tools.StringHelper;
-import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.tools.OXCloneable;
@@ -79,14 +73,14 @@ import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderException;
-import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
-import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
-import com.openexchange.tools.oxfolder.OXFolderSQL;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
+import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
+import com.openexchange.tools.oxfolder.OXFolderLoader;
+import com.openexchange.tools.oxfolder.OXFolderSQL;
 
 /**
  * {@link FolderObject} - Represents a folder.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.org">Sebastian Kauss</a>
  * @author <a href="mailto:thorben.betten@open-xchange.org">Thorben Betten</a>
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a> - generic methods
@@ -96,17 +90,17 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     private static final long serialVersionUID = 1019652520335292041L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(FolderObject.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FolderObject.class));
 
     /**
      * Gets the locale-specific folder name
-     * 
+     *
      * @param id The folder ID
      * @param locale The locale
      * @return The locale-specific folder name or <code>null</code> if no locale-specific folder name is available
      */
     public static String getFolderString(final int id, final Locale locale) {
-        final StringHelper strHelper = new StringHelper(locale);
+        final StringHelper strHelper = StringHelper.valueOf(locale);
         switch (id) {
         case SYSTEM_PRIVATE_FOLDER_ID:
             return strHelper.getString(FolderStrings.SYSTEM_PRIVATE_FOLDER_NAME);
@@ -266,6 +260,8 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     public static final int MESSAGING = 13;
 
+    public static final int FILE = 14;
+
     // Types
     public static final int PRIVATE = 1;
 
@@ -279,7 +275,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Tests if specified type is valid; meaning either {@link #PRIVATE}, {@link #PUBLIC}, or {@link #SHARED}.
-     * 
+     *
      * @param type The folder type to test
      * @return <code>true</code> if specified type is valid; otherwise <code>false</code>
      */
@@ -350,7 +346,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Initializes a new {@link FolderObject}
-     * 
+     *
      * @param objectId The folder's object ID
      */
     public FolderObject(final int objectId) {
@@ -361,7 +357,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Initializes a new {@link FolderObject}
-     * 
+     *
      * @param folderName The folder name
      * @param objectId The object ID
      * @param module The module; {@link #TASK}, {@link #CALENDAR}, {@link #CONTACT} , {@link #UNBOUND}, {@link #SYSTEM_MODULE},
@@ -385,7 +381,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder denotes a user's default folder
-     * 
+     *
      * @return <code>true</code> if this folder denotes a user's default folder; otherwise <code>false</code>
      */
     public boolean isDefaultFolder() {
@@ -394,7 +390,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if default folder status has been set in this folder object
-     * 
+     *
      * @return <code>true</code> if default folder status has been set in this folder object; otherwise <code>false</code>
      */
     public boolean containsDefaultFolder() {
@@ -403,7 +399,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the default folder status for this folder object
-     * 
+     *
      * @param defaultFolder <code>true</code> if this folder denotes a user's default folder; otherwise <code>false</code>
      */
     public void setDefaultFolder(final boolean defaultFolder) {
@@ -421,7 +417,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets the folder name
-     * 
+     *
      * @return The folder name
      */
     public String getFolderName() {
@@ -430,7 +426,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if folder name has been set in this folder object
-     * 
+     *
      * @return <code>true</code> if folder name has been set in this folder object; otherwise <code>false</code>
      */
     public boolean containsFolderName() {
@@ -439,7 +435,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the folder name
-     * 
+     *
      * @param folderName The folder name to set
      */
     public void setFolderName(final String folderName) {
@@ -458,7 +454,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
     /**
      * Gets the module; either {@link #TASK}, {@link #CALENDAR}, {@link #CONTACT} , {@link #UNBOUND}, {@link #SYSTEM_MODULE},
      * {@link #PROJECT}, {@link #MAIL}, or {@link #INFOSTORE}
-     * 
+     *
      * @return The module; either {@link #TASK}, {@link #CALENDAR}, {@link #CONTACT} , {@link #UNBOUND}, {@link #SYSTEM_MODULE},
      *         {@link #PROJECT}, {@link #MAIL}, or {@link #INFOSTORE}
      */
@@ -468,7 +464,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if module has been set in this folder object
-     * 
+     *
      * @return <code>true</code> if module has been set in this folder object; otherwise <code>false</code>
      */
     public boolean containsModule() {
@@ -477,7 +473,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the module
-     * 
+     *
      * @param module The module to set; either {@link #TASK}, {@link #CALENDAR}, {@link #CONTACT} , {@link #UNBOUND}, {@link #SYSTEM_MODULE}
      *            , {@link #PROJECT}, {@link #MAIL}, or {@link #INFOSTORE}
      */
@@ -496,7 +492,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets the permission flag; either {@link #PRIVATE_PERMISSION}, {@link #PUBLIC_PERMISSION} or {@link #CUSTOM_PERMISSION}
-     * 
+     *
      * @return The permission flag; either {@link #PRIVATE_PERMISSION}, {@link #PUBLIC_PERMISSION} or {@link #CUSTOM_PERMISSION}
      */
     public int getPermissionFlag() {
@@ -505,7 +501,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if permission flag has been set in this folder object
-     * 
+     *
      * @return <code>true</code> if permission flag has been set in this folder object; otherwise <code>false</code>
      */
     public boolean containsPermissionFlag() {
@@ -514,7 +510,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the permission flag
-     * 
+     *
      * @param permissionFlag The permission flag to set; either {@link #PRIVATE_PERMISSION} , {@link #PUBLIC_PERMISSION} or
      *            {@link #CUSTOM_PERMISSION}
      */
@@ -533,7 +529,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets all permissions
-     * 
+     *
      * @return All permissions
      */
     public List<OCLPermission> getPermissions() {
@@ -542,7 +538,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets all permissions
-     * 
+     *
      * @return All permissions
      */
     public OCLPermission[] getPermissionsAsArray() {
@@ -553,7 +549,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets the non-system permissions
-     * 
+     *
      * @return The non-system permissions
      */
     public OCLPermission[] getNonSystemPermissionsAsArray() {
@@ -568,7 +564,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets the non-system permission this folder grants to specified entity
-     * 
+     *
      * @param entity The entity ID; either a group or user ID
      * @return The non-system permission or <code>null</code> if none granted
      */
@@ -583,7 +579,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder grants a non-system permission to specified entity which allows at least folder visibility
-     * 
+     *
      * @param entity The entity ID; either a group or user ID
      * @return <code>true</code> if this folder grants a non-system permission to specified entity which allows at least folder visibility;
      *         otherwise <code>false</code>
@@ -603,7 +599,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * <p>
      * <b>Note</b>: This method only checks <b><small>ALL</small></b> basic permissions and does not consider any configuration settings.
      * Use {@link #isVisible(int, UserConfiguration)} for a detailed check if this folder is visible to a certain user.
-     * 
+     *
      * @param entity The entity ID (either a user or a group ID)
      * @return <code>true</code> if this folder is visible to specified entity; otherwise <code>false</code>
      * @see #isVisible(int, UserConfiguration)
@@ -619,18 +615,28 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has permissions set
-     * 
+     *
      * @return <code>true</code> if this folder has permissions set; otherwise <code>false</code>
      */
     public boolean containsPermissions() {
         return b_permissions;
     }
 
+    /**
+     * Applies given permissions to this folder.
+     *
+     * @param permissions The permissions to set
+     */
+    public void setPermissionsNoClone(final List<OCLPermission> permissions) {
+        this.permissions = new ArrayList<OCLPermission>(permissions);
+        b_permissions = true;
+    }
+
     /**
      * Applies given permissions to this folder.
      * <p>
      * <b>NOTE</b>: A <b><small>DEEP</small></b> copy of specified permissions is passed to this folder not a reference.
-     * 
+     *
      * @param permissions The permissions to set
      */
     public void setPermissions(final List<OCLPermission> permissions) {
@@ -646,7 +652,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * Applies given permissions to this folder.
      * <p>
      * <b>NOTE</b>: A <b><small>DEEP</small></b> copy of specified permissions is passed to this folder not a reference.
-     * 
+     *
      * @param permissions The permissions to set
      */
     public void setPermissionsAsArray(final OCLPermission[] permissions) {
@@ -663,7 +669,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Adds given permission to this folder object.
-     * 
+     *
      * @param permission The permission to add
      */
     public void addPermission(final OCLPermission permission) {
@@ -689,7 +695,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * Gets this folder's type
      * <p>
      * <b>NOTE</b>: To check if this folder is shared call {@link #isShared(int)} or {@link #getType(int)}
-     * 
+     *
      * @return The type which is either {@link #PUBLIC} or {@link #PRIVATE}.
      */
     public int getType() {
@@ -701,7 +707,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * <p>
      * <b>NOTE</b>: This method does not check if specified used holds at least read-folder permission but only checks against its type and
      * owner values.
-     * 
+     *
      * @param userId The user ID
      * @return The type which is either {@link #PUBLIC}, {@link #PRIVATE} or {@link #SHARED}.
      */
@@ -711,7 +717,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has its type set
-     * 
+     *
      * @return <code>true</code> if this folder has its type set; otherwise <code>false</code>
      */
     public boolean containsType() {
@@ -720,7 +726,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets this folder's type
-     * 
+     *
      * @param type The type which is either {@link #PUBLIC} or {@link #PRIVATE}
      */
     public void setType(final int type) {
@@ -738,7 +744,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets the creator
-     * 
+     *
      * @return The creator
      */
     public int getCreator() {
@@ -747,7 +753,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if creator is set
-     * 
+     *
      * @return <code>true</code> if creator is set; otherwise <code>false</code>
      */
     public boolean containsCreator() {
@@ -756,7 +762,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the creator
-     * 
+     *
      * @param creator The creator
      */
     public void setCreator(final int creator) {
@@ -774,7 +780,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has subfolders
-     * 
+     *
      * @return <code>true</code> if this folder has subfolders; otherwise <code>false</code>
      */
     public boolean hasSubfolders() {
@@ -783,7 +789,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has subfolders visible to specified user
-     * 
+     *
      * @param user The user
      * @param userConfig The user's configuration
      * @param ctx The context
@@ -798,7 +804,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has subfolders visible to specified user
-     * 
+     *
      * @param userId The user ID
      * @param groups The user's group IDs
      * @param userConfig The user configuration
@@ -852,7 +858,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
             if (iter != null) {
                 try {
                     iter.close();
-                } catch (final SearchIteratorException e) {
+                } catch (final AbstractOXException e) {
                     LOG.error("SearchIterator cannot be closed", e);
                 }
             }
@@ -861,7 +867,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Checks if this folder has the sub-folder flag set
-     * 
+     *
      * @return <code>true</code> if this folder has the sub-folder flag set; otherwise <code>false</code>
      */
     public boolean containsSubfolderFlag() {
@@ -870,7 +876,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Sets the sub-folder flag
-     * 
+     *
      * @param subfolderFlag The sub-folder flag
      */
     public void setSubfolderFlag(final boolean subfolderFlag) {
@@ -888,7 +894,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Gets a list of user-visible subfolders
-     * 
+     *
      * @param userObj The user
      * @param userConfig The user configuration
      * @param ctx The context
@@ -898,14 +904,14 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws SQLException If a SQL error occurs
      * @throws SearchIteratorException If an iterator error occurs
      */
-    public final List<FolderObject> getVisibleSubfolders(final User userObj, final UserConfiguration userConfig, final Context ctx) throws DBPoolingException, OXException, SQLException, SearchIteratorException {
+    public final List<FolderObject> getVisibleSubfolders(final User userObj, final UserConfiguration userConfig, final Context ctx) throws SQLException, AbstractOXException {
         return getVisibleSubfolders(userObj.getId(), userObj.getGroups(), userConfig, ctx);
     }
 
     /**
      * Returns a <code>java.util.List</code> containing all user-visible subfolders
      */
-    public final List<FolderObject> getVisibleSubfolders(final int userId, final int[] groups, final UserConfiguration userConfig, final Context ctx) throws DBPoolingException, OXException, SQLException, SearchIteratorException {
+    public final List<FolderObject> getVisibleSubfolders(final int userId, final int[] groups, final UserConfiguration userConfig, final Context ctx) throws AbstractOXException, SQLException {
         if (b_subfolderFlag && !subfolderFlag) {
             return new ArrayList<FolderObject>(0);
         }
@@ -924,7 +930,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
             } else {
                 iter = OXFolderIteratorSQL.getVisibleSubfoldersIterator(objectId, userId, groups, ctx, userConfig, null);
             }
-            if (iter.hasSize()) {
+            if (iter.size() != -1) {
                 final int size = iter.size();
                 retval = new ArrayList<FolderObject>(size);
                 for (int i = 0; i < size; i++) {
@@ -984,9 +990,8 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
         return b_subfolderIds;
     }
 
-    @SuppressWarnings("unchecked")
     public void setSubfolderIds(final ArrayList<Integer> subfolderIds) {
-        this.subfolderIds = (ArrayList) subfolderIds.clone();
+        this.subfolderIds = new ArrayList<Integer>(subfolderIds);
         b_subfolderIds = true;
     }
 
@@ -1032,7 +1037,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Fills this folder with all availbable values from given folder and returns itself.
-     * 
+     *
      * @return filled folder
      */
     public final FolderObject fill(final FolderObject other) {
@@ -1041,7 +1046,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Fills this folder with all availbable values from given folder and returns itself.
-     * 
+     *
      * @param other The other instance of <code>{@link FolderObject}</code> serving as source
      * @param overwrite <code>true</code> to overwrite even if value is already present; <code>false</code> to only fill value if not
      *            present
@@ -1106,7 +1111,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
     /**
      * Checks if this folder exists in underlying storage by checking its object ID or (if object ID is not present) by its folder name,
      * parent and module. An <code>OXException</code> is thrown if folder does not hold sufficient information to verify existence.
-     * 
+     *
      * @return <code>true</code> if a corresponding folder can be detected, otherwise <code>false</code>
      */
     public final boolean exists(final Context ctx) throws OXException {
@@ -1138,7 +1143,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
     /**
      * <b>NOTE:</b> This method does not check user's permissions on this folder, but only checks if this folder is of type
      * <code>PRIVATE</code> and user is not folder's creator
-     * 
+     *
      * @return <code>true</code> if this folder is of type PRIVATE and user is not folder's creator, <code>false</code> otherwise
      */
     public final boolean isShared(final int userId) {
@@ -1165,12 +1170,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * user has on folder and applying the user configuration profile.
      */
     public final EffectivePermission getEffectiveUserPermission(final int userId, final UserConfiguration userConfig, final Connection readConArg) throws SQLException, DBPoolingException {
-        final EffectivePermission maxPerm = new EffectivePermission(userId, getObjectID(), getType(userId), getModule(), userConfig);
-        maxPerm.setAllPermission(
-            OCLPermission.NO_PERMISSIONS,
-            OCLPermission.NO_PERMISSIONS,
-            OCLPermission.NO_PERMISSIONS,
-            OCLPermission.NO_PERMISSIONS);
+        final EffectivePermission maxPerm = new EffectivePermission(userId, getObjectID(), getType(userId), getModule(), getCreatedBy(), userConfig);
         final int[] idArr;
         {
             final int[] groups = userConfig.getGroups();
@@ -1182,29 +1182,39 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
         if (!containsPermissions()) {
             setPermissionsAsArray(FolderObject.getFolderPermissions(getObjectID(), userConfig.getContext(), readConArg));
         }
-        final List<OCLPermission> list = getPermissions();
-        final int permissionsSize = list.size();
-        final Iterator<OCLPermission> iter = list.iterator();
-        for (int i = 0; i < permissionsSize; i++) {
-            final OCLPermission oclPerm = iter.next();
+        int fp = 0;
+        int orp = 0;
+        int owp = 0;
+        int odp = 0;
+        boolean admin = false;
+        for (final OCLPermission oclPerm : getPermissions()) {
             if (Arrays.binarySearch(idArr, oclPerm.getEntity()) >= 0) {
-                if (oclPerm.getFolderPermission() > maxPerm.getFolderPermission()) {
-                    maxPerm.setFolderPermission(oclPerm.getFolderPermission());
+                // Folder permission
+                int cur = oclPerm.getFolderPermission();
+                if (cur > fp) {
+                    fp = cur;
                 }
-                if (oclPerm.getReadPermission() > maxPerm.getReadPermission()) {
-                    maxPerm.setReadObjectPermission(oclPerm.getReadPermission());
+                // Read permission
+                cur = oclPerm.getReadPermission();
+                if (cur > orp) {
+                    orp = cur;
                 }
-                if (oclPerm.getWritePermission() > maxPerm.getWritePermission()) {
-                    maxPerm.setWriteObjectPermission(oclPerm.getWritePermission());
+                // Write permission
+                cur = oclPerm.getWritePermission();
+                if (cur > owp) {
+                    owp = cur;
                 }
-                if (oclPerm.getDeletePermission() > maxPerm.getDeletePermission()) {
-                    maxPerm.setDeleteObjectPermission(oclPerm.getDeletePermission());
-                }
-                if (!maxPerm.isFolderAdmin() && oclPerm.isFolderAdmin()) {
-                    maxPerm.setFolderAdmin(true);
+                // Delete permission
+                cur = oclPerm.getDeletePermission();
+                if (cur > odp) {
+                    odp = cur;
                 }
+                // Admin flag
+                admin |= oclPerm.isFolderAdmin();
             }
         }
+        maxPerm.setAllPermission(fp, orp, owp, odp);
+        maxPerm.setFolderAdmin(admin);
         return maxPerm;
     }
 
@@ -1470,20 +1480,16 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
     }
 
     public static FolderObject loadFolderObjectFromDB(final int folderId, final Context ctx) throws OXException {
-        return loadFolderObjectFromDB(folderId, ctx, null, true, false);
+        return OXFolderLoader.loadFolderObjectFromDB(folderId, ctx);
     }
 
     public static FolderObject loadFolderObjectFromDB(final int folderId, final Context ctx, final Connection readCon) throws OXException {
-        return loadFolderObjectFromDB(folderId, ctx, readCon, true, false);
+        return OXFolderLoader.loadFolderObjectFromDB(folderId, ctx, readCon);
     }
 
-    private static final String TABLE_OT = "oxfolder_tree";
-
-    private static final String TABLE_OP = "oxfolder_permissions";
-
     /**
      * Loads specified folder from database.
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @param readConArg A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1493,17 +1499,12 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws OXException If folder cannot be loaded
      */
     public static final FolderObject loadFolderObjectFromDB(final int folderId, final Context ctx, final Connection readConArg, final boolean loadPermissions, final boolean loadSubfolderList) throws OXException {
-        return loadFolderObjectFromDB(folderId, ctx, readConArg, loadPermissions, loadSubfolderList, TABLE_OT, TABLE_OP);
+        return OXFolderLoader.loadFolderObjectFromDB(folderId, ctx, readConArg, loadPermissions, loadSubfolderList);
     }
 
-    private static final String SQL_LOAD_F =
-        "SELECT parent, fname, module, type, creating_date, created_from, changing_date, changed_from, permission_flag, subfolder_flag, default_flag" + " FROM #TABLE# WHERE cid = ? AND fuid = ?";
-
-    private static final Pattern PAT_RPL_TABLE = Pattern.compile("#TABLE#");
-
     /**
      * Loads specified folder from database.
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @param readConArg A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1515,81 +1516,12 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws OXException If folder cannot be loaded
      */
     public static final FolderObject loadFolderObjectFromDB(final int folderId, final Context ctx, final Connection readConArg, final boolean loadPermissions, final boolean loadSubfolderList, final String table, final String permTable) throws OXException {
-        try {
-            Connection readCon = readConArg;
-            boolean closeCon = false;
-            PreparedStatement stmt = null;
-            ResultSet rs = null;
-            try {
-                if (readCon == null) {
-                    readCon = DBPool.pickup(ctx);
-                    closeCon = true;
-                }
-                stmt = readCon.prepareStatement(PAT_RPL_TABLE.matcher(SQL_LOAD_F).replaceFirst(table));
-                stmt.setInt(1, ctx.getContextId());
-                stmt.setInt(2, folderId);
-                rs = stmt.executeQuery();
-                if (!rs.next()) {
-                    throw new OXFolderNotFoundException(folderId, ctx);
-                }
-                final FolderObject folderObj = new FolderObject(rs.getString(2), folderId, rs.getInt(3), rs.getInt(4), rs.getInt(6));
-                folderObj.setParentFolderID(rs.getInt(1));
-                folderObj.setCreatedBy(parseStringValue(rs.getString(6), ctx));
-                folderObj.setCreationDate(new Date(rs.getLong(5)));
-                folderObj.setSubfolderFlag(rs.getInt(10) > 0 ? true : false);
-                folderObj.setLastModified(new Date(rs.getLong(7)));
-                folderObj.setModifiedBy(parseStringValue(rs.getString(8), ctx));
-                folderObj.setPermissionFlag(rs.getInt(9));
-                final int defaultFolder = rs.getInt(11);
-                if (rs.wasNull()) {
-                    folderObj.setDefaultFolder(false);
-                } else {
-                    folderObj.setDefaultFolder(defaultFolder > 0);
-                }
-                if (loadSubfolderList) {
-                    final ArrayList<Integer> subfolderList = getSubfolderIds(folderId, ctx, readCon, table);
-                    folderObj.setSubfolderIds(subfolderList);
-                }
-
-                if (loadPermissions) {
-                    folderObj.setPermissionsAsArray(getFolderPermissions(folderId, ctx, readCon, permTable));
-                }
-                return folderObj;
-            } finally {
-                closeResources(rs, stmt, closeCon ? readCon : null, true, ctx);
-            }
-        } catch (final SQLException e) {
-            throw new OXFolderException(
-                FolderCode.FOLDER_COULD_NOT_BE_LOADED,
-                e,
-                String.valueOf(folderId),
-                String.valueOf(ctx.getContextId()));
-        } catch (final DBPoolingException e) {
-            throw new OXFolderException(
-                FolderCode.FOLDER_COULD_NOT_BE_LOADED,
-                e,
-                String.valueOf(folderId),
-                String.valueOf(ctx.getContextId()));
-        }
-    }
-
-    private static final int parseStringValue(final String str, final Context ctx) {
-        if (null == str) {
-            return -1;
-        }
-        try {
-            return Integer.parseInt(str);
-        } catch (final NumberFormatException e) {
-            if (str.equalsIgnoreCase("system")) {
-                return ctx.getMailadmin();
-            }
-        }
-        return -1;
+        return OXFolderLoader.loadFolderObjectFromDB(folderId, ctx, readConArg, loadPermissions, loadSubfolderList, table, permTable);
     }
 
     /**
      * Loads folder permissions from database. Creates a new connection if <code>null</code> is given.
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @param readConArg A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1598,15 +1530,12 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws DBPoolingException If a pooling error occurs
      */
     public static final OCLPermission[] getFolderPermissions(final int folderId, final Context ctx, final Connection readConArg) throws SQLException, DBPoolingException {
-        return getFolderPermissions(folderId, ctx, readConArg, TABLE_OP);
+        return OXFolderLoader.getFolderPermissions(folderId, ctx, readConArg);
     }
 
-    private static final String SQL_LOAD_P =
-        "SELECT permission_id, fp, orp, owp, odp, admin_flag, group_flag, system" + " FROM #TABLE# WHERE cid = ? AND fuid = ?";
-
     /**
      * Loads folder permissions from database. Creates a new connection if <code>null</code> is given.
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @param readCon A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1616,41 +1545,12 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws DBPoolingException If a pooling error occurs
      */
     public static final OCLPermission[] getFolderPermissions(final int folderId, final Context ctx, final Connection readConArg, final String table) throws SQLException, DBPoolingException {
-        Connection readCon = readConArg;
-        boolean closeCon = false;
-        PreparedStatement stmt = null;
-        ResultSet rs = null;
-        try {
-            if (readCon == null) {
-                readCon = DBPool.pickup(ctx);
-                closeCon = true;
-            }
-            stmt = readCon.prepareStatement(PAT_RPL_TABLE.matcher(SQL_LOAD_P).replaceFirst(table));
-            stmt.setInt(1, ctx.getContextId());
-            stmt.setInt(2, folderId);
-            rs = stmt.executeQuery();
-            final ArrayList<OCLPermission> permList = new ArrayList<OCLPermission>();
-            while (rs.next()) {
-                final OCLPermission p = new OCLPermission();
-                p.setEntity(rs.getInt(1)); // Entity
-                p.setAllPermission(rs.getInt(2), rs.getInt(3), rs.getInt(4), rs.getInt(5)); // fp, orp, owp, and odp
-                p.setFolderAdmin(rs.getInt(6) > 0 ? true : false); // admin_flag
-                p.setGroupPermission(rs.getInt(7) > 0 ? true : false); // group_flag
-                p.setSystem(rs.getInt(8)); // system
-                permList.add(p);
-            }
-            stmt.close();
-            rs = null;
-            stmt = null;
-            return permList.toArray(new OCLPermission[permList.size()]);
-        } finally {
-            closeResources(rs, stmt, closeCon ? readCon : null, true, ctx);
-        }
+        return OXFolderLoader.getFolderPermissions(folderId, ctx, readConArg, table);
     }
 
     /**
      * Gets the subfolder IDs of specified folder.
-     * 
+     *
      * @param folderId The ID of the folder whose subfolders' IDs shall be returned
      * @param ctx The context
      * @param readConArg A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1659,14 +1559,12 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws DBPoolingException If a pooling error occurs
      */
     public static final ArrayList<Integer> getSubfolderIds(final int folderId, final Context ctx, final Connection readConArg) throws SQLException, DBPoolingException {
-        return getSubfolderIds(folderId, ctx, readConArg, TABLE_OT);
+        return OXFolderLoader.getSubfolderIds(folderId, ctx, readConArg);
     }
 
-    private static final String SQL_SEL = "SELECT fuid FROM #TABLE# WHERE cid = ? AND parent = ? ORDER BY default_flag DESC, fname";
-
     /**
      * Gets the subfolder IDs of specified folder.
-     * 
+     *
      * @param folderId The ID of the folder whose subfolders' IDs shall be returned
      * @param ctx The context
      * @param readConArg A connection with read capability; may be <code>null</code> to fetch from pool
@@ -1676,27 +1574,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @throws DBPoolingException If a pooling error occurs
      */
     public static final ArrayList<Integer> getSubfolderIds(final int folderId, final Context ctx, final Connection readConArg, final String table) throws SQLException, DBPoolingException {
-        Connection readCon = readConArg;
-        boolean closeCon = false;
-        PreparedStatement stmt = null;
-        ResultSet rs = null;
-        try {
-            if (readCon == null) {
-                readCon = DBPool.pickup(ctx);
-                closeCon = true;
-            }
-            stmt = readCon.prepareStatement(SQL_SEL.replaceFirst("#TABLE#", table));
-            stmt.setInt(1, ctx.getContextId());
-            stmt.setInt(2, folderId);
-            rs = stmt.executeQuery();
-            final ArrayList<Integer> retval = new ArrayList<Integer>();
-            while (rs.next()) {
-                retval.add(Integer.valueOf(rs.getInt(1)));
-            }
-            return retval;
-        } finally {
-            closeResources(rs, stmt, closeCon ? readCon : null, true, ctx);
-        }
+        return OXFolderLoader.getSubfolderIds(folderId, ctx, readConArg, table);
     }
 
     private static final OCLPermission VIRTUAL_FOLDER_PERMISSION = new OCLPermission();
@@ -1714,7 +1592,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Creates a folder instance representing a virtual folder.
-     * 
+     *
      * @param objectID The virtual object ID
      * @param name The name
      * @param module The module
@@ -1728,7 +1606,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Creates a folder instance representing a virtual folder.
-     * 
+     *
      * @param objectID The virtual object ID
      * @param name The name
      * @param module The module
@@ -1751,7 +1629,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Creates a folder instance representing a virtual folder.
-     * 
+     *
      * @param fullName The folder's fullname
      * @param name The name
      * @param module The module
@@ -1773,7 +1651,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
 
     /**
      * Creates a folder instance representing a shared folder.
-     * 
+     *
      * @param createdBy The user ID of shared folder's owner
      * @param creatorDisplayName The display name of shared folder's owner
      * @return A folder instance representing a shared folder.
