@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,7 +58,7 @@ import java.util.Set;
 
 /**
  * Participants
- * 
+ *
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  */
 public class Participants {
@@ -131,6 +131,24 @@ public class Participants {
             participants.add(p);
         }
     }
+    
+    /**
+     * This method adds the given UserParticipant or the corresponding UserParticipant of the given array if present.
+     * (This is needed to override the Confirmation Information of a User)
+     * @param p
+     * @param users
+     */
+    public void add(UserParticipant p, UserParticipant[] users) {
+        if (users != null) {
+            for (UserParticipant user : users) {
+                if (user.getIdentifier() == p.getIdentifier()) {
+                    add(user);
+                    return;
+                }
+            }
+        }
+        add(p);
+    }
 
     public boolean containsUserParticipant(final UserParticipant up) {
         if (participants != null) {
