@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,7 @@ package com.openexchange.groupware.container;
 
 /**
  * {@link ResourceGroupParticipant} - Represents a group of resources as participant.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class ResourceGroupParticipant implements Participant, Comparable<Participant> {
@@ -66,7 +66,7 @@ public class ResourceGroupParticipant implements Participant, Comparable<Partici
 
     /**
      * Default constructor.
-     * 
+     *
      * @param id unique identifier of the resource group.
      */
     public ResourceGroupParticipant(final int id) {
@@ -169,12 +169,19 @@ public class ResourceGroupParticipant implements Participant, Comparable<Partici
     }
 
     @Override
-    public Object clone() throws CloneNotSupportedException {
-        return super.clone();
+    public ResourceGroupParticipant clone() throws CloneNotSupportedException {
+        ResourceGroupParticipant retval = (ResourceGroupParticipant) super.clone();
+        
+        retval.setDisplayName(this.getDisplayName());
+        retval.setEmailAddress(this.getEmailAddress());
+        retval.setIdentifier(this.getIdentifier());
+        retval.setIgnoreNotification(this.isIgnoreNotification());
+        
+        return retval;
     }
 
     public Participant getClone() throws CloneNotSupportedException {
-        return (Participant) clone();
+        return clone();
     }
 
     public boolean isIgnoreNotification() {
