@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.resource.Resource;
 
 /**
  * {@link ResourceParticipant} - Represents a resource participant.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class ResourceParticipant implements Participant, Comparable<Participant> {
@@ -68,17 +68,17 @@ public class ResourceParticipant implements Participant, Comparable<Participant>
 
     /**
      * Default constructor.
-     * 
+     *
      * @param id unique identifier of the resource.
      */
     public ResourceParticipant(final int id) {
         super();
         this.id = id;
     }
-    
+
     /**
      * Constructor that takes values of from a given resource
-     * 
+     *
      * @param res - a resource to be used as base
      */
     public ResourceParticipant(Resource res){
@@ -182,12 +182,19 @@ public class ResourceParticipant implements Participant, Comparable<Participant>
     }
 
     @Override
-    public Object clone() throws CloneNotSupportedException {
-        return super.clone();
+    public ResourceParticipant clone() throws CloneNotSupportedException {
+        ResourceParticipant retval = (ResourceParticipant) super.clone();
+        
+        retval.setDisplayName(this.getDisplayName());
+        retval.setEmailAddress(this.getEmailAddress());
+        retval.setIdentifier(this.getIdentifier());
+        retval.setIgnoreNotification(this.isIgnoreNotification());
+        
+        return retval;
     }
 
     public Participant getClone() throws CloneNotSupportedException {
-        return (Participant) clone();
+        return clone();
     }
 
     public boolean isIgnoreNotification() {
