@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,10 +56,11 @@ import java.io.InputStream;
 import java.util.Arrays;
 import java.util.Date;
 import javax.activation.DataHandler;
+import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.Part;
-import javax.mail.Message.RecipientType;
+import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeBodyPart;
@@ -72,9 +73,7 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
-import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.mail.MailException;
-import com.openexchange.mail.MailSessionParameterNames;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
@@ -94,12 +93,14 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * MailObject
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class MailObject {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailObject.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailObject.class));
+
+    private static final boolean DEBUG = LOG.isDebugEnabled();
 
     public static final int DONT_SET = -2;
 
@@ -131,9 +132,15 @@ public class MailObject {
 
     private Multipart multipart;
 
+    private boolean internalRecipient;
+
+	private String uid;
+
+	private long recurrenceDatePosition;
+
     /**
      * Initializes a new {@link MailObject}
-     * 
+     *
      * @param session The session providing needed user data
      * @param objectId The object ID this message refers to
      * @param folderId The folder ID to which the referred object belongs
@@ -142,6 +149,7 @@ public class MailObject {
      */
     public MailObject(final Session session, final int objectId, final int folderId, final int module, final String type) {
         super();
+        internalRecipient = true;
         this.session = session;
         this.objectId = objectId;
         this.folderId = folderId;
@@ -150,11 +158,11 @@ public class MailObject {
     }
 
     private final void validateMailObject() throws MailException {
-        if (fromAddr == null || fromAddr.length() == 0) {
+        if (isEmpty(fromAddr)) {
             throw new MailException(MailException.Code.MISSING_FIELD, "From");
         } else if (toAddrs == null || toAddrs.length == 0) {
             throw new MailException(MailException.Code.MISSING_FIELD, "To");
-        } else if (contentType == null || contentType.length() == 0) {
+        } else if (isEmpty(contentType)) {
             throw new MailException(MailException.Code.MISSING_FIELD, "Content-Type");
         } else if (subject == null) {
             throw new MailException(MailException.Code.MISSING_FIELD, "Subject");
@@ -163,9 +171,30 @@ public class MailObject {
         }
     }
 
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
+    /**
+     * Sets whether this mail is transported to an internal recipient or not.
+     * 
+     * @param internalRecipient <code>true</code> for internal recipient; otherwise <code>false</code>
+     */
+    public void setInternalRecipient(final boolean internalRecipient) {
+        this.internalRecipient = internalRecipient;
+    }
+
     /**
      * Adds a file attachment to this mail object.
-     * 
+     *
      * @param contentType The content type (incl. charset parameter)
      * @param file The file to attach
      * @throws MailException If file attachment cannot be added
@@ -239,7 +268,7 @@ public class MailObject {
 
     /**
      * Adds a file attachment to this mail object.
-     * 
+     *
      * @param contentType The content type (incl. charset parameter)
      * @param fileName The attachment's file name
      * @param inputStream The attachment's data as an input stream
@@ -330,6 +359,10 @@ public class MailObject {
     private final static String HEADER_X_OX_TYPE = "X-Open-Xchange-Type";
 
     private final static String HEADER_X_OX_OBJECT = "X-Open-Xchange-Object";
+    
+    private final static String HEADER_X_OX_UID = "X-Open-Xchange-UID";
+
+    private final static String HEADER_X_OX_RECURRENCE_DATE = "X-Open-Xchange-RDATE";
 
     public final void send() throws MailException {
         try {
@@ -339,7 +372,11 @@ public class MailObject {
              * Set from
              */
             InternetAddress[] internetAddrs = parseAddressList(fromAddr, false);
+            if (null == internetAddrs || 0 == internetAddrs.length) {
+                throw MIMEMailException.handleMessagingException(new AddressException("\"From\" cannot be parsed: " + fromAddr));
+            }
             msg.setFrom(internetAddrs[0]);
+            msg.setReplyTo(internetAddrs);
             /*
              * Set to
              */
@@ -385,10 +422,11 @@ public class MailObject {
             /*
              * Set content and its type
              */
+            final String subType = ct.getSubType();
             if (multipart == null) {
-                if ("html".equalsIgnoreCase(ct.getSubType()) || "htm".equalsIgnoreCase(ct.getSubType())) {
+                if ("html".equalsIgnoreCase(subType) || "htm".equalsIgnoreCase(subType)) {
                     msg.setContent(text, ct.toString());
-                } else if ("plain".equalsIgnoreCase(ct.getSubType()) || "enriched".equalsIgnoreCase(ct.getSubType())) {
+                } else if ("plain".equalsIgnoreCase(subType) || "enriched".equalsIgnoreCase(subType)) {
                     if (!ct.containsCharsetParameter()) {
                         msg.setText((String) text);
                     } else {
@@ -401,9 +439,9 @@ public class MailObject {
                 }
             } else {
                 final MimeBodyPart textPart = new MimeBodyPart();
-                if ("html".equalsIgnoreCase(ct.getSubType()) || "htm".equalsIgnoreCase(ct.getSubType())) {
+                if ("html".equalsIgnoreCase(subType) || "htm".equalsIgnoreCase(subType)) {
                     textPart.setContent(text, ct.toString());
-                } else if ("plain".equalsIgnoreCase(ct.getSubType()) || "enriched".equalsIgnoreCase(ct.getSubType())) {
+                } else if ("plain".equalsIgnoreCase(subType) || "enriched".equalsIgnoreCase(subType)) {
                     if (!ct.containsCharsetParameter()) {
                         textPart.setText((String) text);
                     } else {
@@ -437,27 +475,12 @@ public class MailObject {
              * Set organization
              */
             try {
-                final Object org = session.getParameter(MailSessionParameterNames.PARAM_ORGANIZATION_HDR);
-                if (null == org) {
-                    /*
-                     * Get context's admin contact object
-                     */
-                    final Context ctx = ContextStorage.getStorageContext(session);
-                    final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
-                        ContactInterfaceDiscoveryService.class).newContactInterface(FolderObject.SYSTEM_LDAP_FOLDER_ID, session);
-                    final Contact c = contactInterface.getUserById(ctx.getMailadmin(),
-                        false);
-                    if (null != c && c.getCompany() != null && c.getCompany().length() > 0) {
-                        session.setParameter(MailSessionParameterNames.PARAM_ORGANIZATION_HDR, c.getCompany());
-                        msg.setHeader(HEADER_ORGANIZATION, c.getCompany());
-                    } else {
-                        session.setParameter(HEADER_ORGANIZATION, "null");
-                    }
-                } else if (!"null".equals(org.toString())) {
-                    /*
-                     * Apply value from session parameter
-                     */
-                    msg.setHeader(HEADER_ORGANIZATION, org.toString());
+                final Context ctx = ContextStorage.getStorageContext(session);
+                final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
+                    ContactInterfaceDiscoveryService.class).newContactInterface(FolderObject.SYSTEM_LDAP_FOLDER_ID, session);
+                final Contact c = contactInterface.getUserById(ctx.getMailadmin(), false);
+                if (null != c && c.getCompany() != null && c.getCompany().length() > 0) {
+                    msg.setHeader(HEADER_ORGANIZATION, c.getCompany());
                 }
             } catch (final Exception e) {
                 LOG.warn("Header \"Organization\" could not be set", e);
@@ -465,7 +488,7 @@ public class MailObject {
             /*
              * Set ox reference
              */
-            if (folderId != DONT_SET) {
+            if (internalRecipient && folderId != DONT_SET) {
                 msg.setHeader(HEADER_XOXREMINDER, new StringBuilder().append(objectId).append(',').append(folderId).append(',').append(
                     module).toString());
             }
@@ -481,17 +504,31 @@ public class MailObject {
             /*
              * X-Open-Xchange-Module
              */
-            msg.setHeader(HEADER_X_OX_MODULE, Types.APPOINTMENT == module ? "Appointments" : "Tasks");
+            if (internalRecipient) {
+                msg.setHeader(HEADER_X_OX_MODULE, Types.APPOINTMENT == module ? "Appointments" : "Tasks");
+            }
             /*
              * X-Open-Xchange-Type
              */
-            if (type != null) {
+            if (internalRecipient && type != null) {
                 msg.setHeader(HEADER_X_OX_TYPE, type);
             }
             /*
              * X-Open-Xchange-Object
              */
-            msg.setHeader(HEADER_X_OX_OBJECT, String.valueOf(objectId));
+            if (internalRecipient) {
+                msg.setHeader(HEADER_X_OX_OBJECT, String.valueOf(objectId));
+            }
+            
+            if (internalRecipient && uid != null) {
+            	msg.setHeader(HEADER_X_OX_UID, uid);
+            }
+            
+            if (internalRecipient && recurrenceDatePosition != 0) {
+            	msg.setHeader(HEADER_X_OX_RECURRENCE_DATE, String.valueOf(recurrenceDatePosition));
+            }
+            
+            msg.saveChanges();
             /*
              * Finally transport mail
              */
@@ -500,6 +537,9 @@ public class MailObject {
                 final UnsynchronizedByteArrayOutputStream bos = new UnsynchronizedByteArrayOutputStream();
                 msg.writeTo(bos);
                 transport.sendRawMessage(bos.toByteArray());
+                if (DEBUG) {
+                    LOG.debug("Sent mail:\n" + new String(bos.toByteArray()));
+                }
             } finally {
                 transport.close();
             }
@@ -585,6 +625,22 @@ public class MailObject {
     public void setSubject(final String subject) {
         this.subject = subject;
     }
+    
+    public void setUid(final String uid) {
+		this.uid = uid;
+	}
+    
+    public String getUid() {
+		return uid;
+	}
+
+    public void setRecurrenceDatePosition(final long time) {
+    	this.recurrenceDatePosition = time;
+	}
+    
+    public long getRecurrenceDatePosition() {
+		return recurrenceDatePosition;
+	}
 
     private static final String[] addAddr(final String addr, String[] arr) {
         if (arr == null) {
@@ -597,4 +653,5 @@ public class MailObject {
         return arr;
     }
 
+
 }
