@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.groupware.contexts.impl;
 
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 
@@ -88,10 +89,15 @@ public class ContextException extends AbstractOXException {
      * @param messageArgs arguments that will be formatted into the message.
      */
     public ContextException(final Code code, final Throwable cause, final Object... messageArgs) {
-        super(EnumComponent.CONTEXT, code.category, code.number, code.message, cause);
+        super(EnumComponent.CONTEXT, code.getCategory(), code.getNumber(), code.getMessage(), cause);
         setMessageArgs(messageArgs);
     }
 
+    public ContextException(ErrorMessage message, Throwable cause, Object... args) {
+        super(message, cause);
+        setMessageArgs(args);
+    }
+
     /**
      * Error codes for context exceptions.
      * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
