@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,24 +49,21 @@
 
 package com.openexchange.groupware.contexts.impl;
 
-import com.openexchange.cache.dynamic.impl.OXObjectFactory;
-import com.openexchange.cache.dynamic.impl.Refresher;
+import java.util.Map;
+import java.util.Set;
+import com.openexchange.caching.dynamic.OXObjectFactory;
+import com.openexchange.caching.dynamic.Refresher;
 import com.openexchange.groupware.AbstractOXException;
 
 /**
- * 
+ * Context object delegator that reloads the backed delegate newly into cache if it times out.
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 final class ContextReloader extends Refresher<ContextExtended> implements ContextExtended {
 
-    /**
-     * For serialization.
-     */
     private static final long serialVersionUID = -2022359916415524347L;
 
-    /**
-     * Cached delegate.
-     */
     private ContextExtended delegate;
 
     /**
@@ -74,123 +71,91 @@ final class ContextReloader extends Refresher<ContextExtended> implements Contex
      * @throws AbstractOXException if some problem occurs with refreshing.
      */
     public ContextReloader(OXObjectFactory<ContextExtended> factory, String regionName) throws AbstractOXException {
-        super(factory, regionName);
+        super(factory, regionName, false);
         this.delegate = refresh();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean equals(final Object obj) {
         updateDelegate();
         return delegate.equals(obj);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public int hashCode() {
         updateDelegate();
         return delegate.hashCode();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public String toString() {
         return "ContextReloader: " + delegate.toString();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public void setUpdating(final boolean updating) {
         updateDelegate();
         delegate.setUpdating(updating);
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    public void setReadOnly(boolean readOnly) {
+        updateDelegate();
+        delegate.setReadOnly(readOnly);
+    }
+
     public int getContextId() {
         return delegate.getContextId();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String getName() {
         updateDelegate();
         return delegate.getName();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String[] getFileStorageAuth() {
         updateDelegate();
         return delegate.getFileStorageAuth();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public long getFileStorageQuota() {
         updateDelegate();
         return delegate.getFileStorageQuota();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getFilestoreId() {
         updateDelegate();
         return delegate.getFilestoreId();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String getFilestoreName() {
         updateDelegate();
         return delegate.getFilestoreName();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String[] getLoginInfo() {
         updateDelegate();
         return delegate.getLoginInfo();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getMailadmin() {
         updateDelegate();
         return delegate.getMailadmin();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public boolean isEnabled() {
         updateDelegate();
         return delegate.isEnabled();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public boolean isUpdating() {
         updateDelegate();
         return delegate.isUpdating();
     }
 
+    public boolean isReadOnly() {
+        updateDelegate();
+        return delegate.isReadOnly();
+    }
+
     /**
      * @throws RuntimeException if refreshing fails.
      */
@@ -201,4 +166,9 @@ final class ContextReloader extends Refresher<ContextExtended> implements Contex
             throw new RuntimeException(e.getMessage(), e);
         }
     }
+
+    public Map<String, Set<String>> getAttributes() {
+        updateDelegate();
+        return delegate.getAttributes();
+    }
 }
