@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,6 +58,8 @@ import com.openexchange.session.Session;
 
 /**
  * This class defines the methods for accessing the storage of contexts.
+ * TODO We should introduce a logic layer above this context storage layer. That layer should then trigger the update tasks.
+ * Nearly all accesses to the ContextStorage need then to be replaced with an access to the ContextService.
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -66,7 +68,7 @@ public abstract class ContextStorage {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(ContextStorage.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContextStorage.class));
 
     /**
      * Singleton implementation.
@@ -80,6 +82,7 @@ public abstract class ContextStorage {
 
     /**
      * Creates an instance implementing the context storage.
+     *
      * @return an instance implementing the context storage.
      */
     public static ContextStorage getInstance() {
@@ -87,72 +90,72 @@ public abstract class ContextStorage {
     }
 
     /**
-     * Instantiates an implementation of the context interface and fill its
-     * attributes according to the needs to be able to separate contexts.
+     * Instantiates an implementation of the context interface and fill its attributes according to the needs to be able to separate
+     * contexts.
+     *
      * @param loginContextInfo the login info for the context.
-     * @return the unique identifier of the context or <code>-1</code> if no
-     * matching context exists.
+     * @return the unique identifier of the context or <code>-1</code> if no matching context exists.
      * @throws ContextException if an error occurs.
      */
     public abstract int getContextId(String loginContextInfo) throws ContextException;
 
-    public final Context getContext(final Session session)
-        throws ContextException {
+    public final Context getContext(final Session session) throws ContextException {
         return getContext(session.getContextId());
     }
 
     /**
      * Creates a context implementation for the given context unique identifier.
+     *
      * @param contextId unique identifier of the context.
-     * @return an implementation of the context or <code>null</code> if the
-     * context with the given identifier can't be found.
+     * @return an implementation of the context or <code>null</code> if the context with the given identifier can't be found.
      * @throws ContextException if an error occurs.
      */
     public Context getContext(final int contextId) throws ContextException {
         final Context retval = loadContext(contextId);
         if (retval.isUpdating()) {
-            throw new ContextException(Code.UPDATE);
+            final ContextException exception = new ContextException(Code.UPDATE);
+            LOG.info(exception.getMessage());
+            throw exception;
         }
         return retval;
     }
 
     /**
      * Loads the context object.
+     *
      * @param contextId unique identifier of the context to load.
      * @return the context object.
      * @throws ContextException if loading the context fails.
      */
-    public abstract ContextExtended loadContext(int contextId)
-        throws ContextException;
+    public abstract ContextExtended loadContext(int contextId) throws ContextException;
 
     /**
      * Invalidates the context object in cache(s).
+     *
      * @param contextId unique identifier of the context to invalidate
-     * @throws ContextException 
      * @throws ContextException if invalidating the context fails
      */
     public void invalidateContext(final int contextId) throws ContextException {
         if (LOG.isTraceEnabled()) {
-            LOG.trace("invalidateContext not implemented in " + this.getClass()
-                .getCanonicalName());
+            LOG.trace("invalidateContext not implemented in " + this.getClass().getCanonicalName());
         }
     }
 
     /**
      * Invalidates a login information in the cache.
+     *
      * @param loginContextInfo login information to invalidate.
-     * @throws ContextException 
      * @throws ContextException if invalidating the login information fails.
      */
     public void invalidateLoginInfo(final String loginContextInfo) throws ContextException {
         if (LOG.isTraceEnabled()) {
-            LOG.trace("invalidateLoginInfo not implemented in " + this
-                .getClass().getCanonicalName());
+            LOG.trace("invalidateLoginInfo not implemented in " + this.getClass().getCanonicalName());
         }
     }
 
     /**
      * Gives a list of all context ids which are stored in the config database.
+     *
      * @return the list of context ids
      * @throws ContextException if reading the contexts fails.
      */
@@ -160,20 +163,21 @@ public abstract class ContextStorage {
 
     /**
      * Internal start-up routine invoked in {@link #start()}
-     * 
+     *
      * @throws ContextException If an error occurs
      */
     protected abstract void startUp() throws ContextException;
 
     /**
      * Internal shut-down routine invoked in {@link #stop()}
-     * 
+     *
      * @throws ContextException If an error occurs
      */
     protected abstract void shutDown() throws ContextException;
 
     /**
      * Initialization.
+     *
      * @throws ContextException if initialization of contexts fails.
      */
     public static void start() throws ContextException {
@@ -199,23 +203,23 @@ public abstract class ContextStorage {
 
     /**
      * Convenience method for getting the context.
+     *
      * @param session The session providing the context ID
      * @return the context data object or null if the context with the given identifier can't be found.
      * @throws ContextException if getting the context fails.
      */
-    public static Context getStorageContext(final Session session)
-        throws ContextException {
+    public static Context getStorageContext(final Session session) throws ContextException {
         return getStorageContext(session.getContextId());
     }
 
     /**
      * Convenience method for getting the context.
+     *
      * @param contextId unique identifier of the context.
      * @return the context data object or null if the context with the given identifier can't be found.
      * @throws ContextException if getting the context fails.
      */
-    public static Context getStorageContext(final int contextId)
-        throws ContextException {
+    public static Context getStorageContext(final int contextId) throws ContextException {
         return getInstance().getContext(contextId);
     }
 }
