@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,10 +72,9 @@ public final class Check {
      * characters or a message what is wrong with the data.
      */
     public static String containsInvalidChars(final String check) {
-        String retval = null;
-        if (null != check) {
-            retval = Verifier.checkCharacterData(check);
+        if (null == check) {
+            return check;
         }
-        return retval;
+        return Verifier.checkCharacterData(check);
     }
 }
