@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.sql.SQLException;
+import java.util.Date;
 import java.util.List;
 import java.util.TimeZone;
 import org.json.JSONArray;
@@ -78,6 +79,7 @@ import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.ICalParser;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
+import com.openexchange.groupware.calendar.OXCalendarException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.container.Participant;
 import com.openexchange.groupware.container.UserParticipant;
@@ -92,12 +94,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link ICalDataHandler}
- * 
+ *
  * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
  */
 public abstract class ICalDataHandler implements DataHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ICalInsertDataHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ICalInsertDataHandler.class));
 
     private static final int LIMIT = 1048576;
 
@@ -110,7 +112,7 @@ public abstract class ICalDataHandler implements DataHandler {
         }
     }
 
-    protected void insertAppointments(final Session session, final int calendarFolder, final Context ctx, final List<CalendarDataObject> appointments, Confirm confirm, final JSONArray folderAndIdArray) throws OXException, JSONException, DataException {
+    protected void insertAppointments(final Session session, final int calendarFolder, final Context ctx, final List<CalendarDataObject> appointments, final Confirm confirm, final JSONArray folderAndIdArray) throws OXException, JSONException, DataException {
         final AppointmentSQLInterface appointmentSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(
             session);
         for (final CalendarDataObject appointment : appointments) {
@@ -120,15 +122,22 @@ public abstract class ICalDataHandler implements DataHandler {
             }
             String uid;
             int objectId = 0;
-            if (appointment.containsUid() && (uid = appointment.getUid()) != null)
+            if (appointment.containsUid() && (uid = appointment.getUid()) != null) {
                 objectId = appointmentSql.resolveUid(uid);
-                
-            if (objectId != 0 && confirm != null) {
-                try {
-                    updateOwnParticipantStatus(session, ctx, objectId, confirm, appointmentSql);
-                } catch (OXPermissionException e) {
-                    handleWithoutPermission(session, appointment, calendarFolder, confirm, appointmentSql);
+            }
+
+            if (objectId != 0) {
+                if (confirm != null) {
+                    try {
+                        updateOwnParticipantStatus(session, ctx, objectId, confirm, appointmentSql);
+                    } catch (final OXPermissionException e) {
+                        handleWithoutPermission(session, appointment, calendarFolder, confirm, appointmentSql);
+                    }
                 }
+                appointment.setObjectID(objectId);
+                appointment.setIgnoreConflicts(true);
+                updateAppointment(appointment, calendarFolder, appointmentSql);
+                folderAndIdArray.put(new JSONObject().put(CalendarFields.FOLDER_ID, calendarFolder).put(CalendarFields.ID, objectId));
             } else {
                 appointment.setParentFolderID(calendarFolder);
                 appointment.setIgnoreConflicts(true);
@@ -139,15 +148,28 @@ public abstract class ICalDataHandler implements DataHandler {
             }
         }
     }
-    
-    private void handleWithoutPermission(Session session, CalendarDataObject appointment, int calendarFolder, Confirm confirm, AppointmentSQLInterface appointmentSql) throws OXException {
+
+    private void updateAppointment(final CalendarDataObject appointment, final int calendarFolder, final AppointmentSQLInterface appointmentSql) throws OXException {
+        try {
+            final CalendarDataObject loadAppointment = appointmentSql.getObjectById(appointment.getObjectID(), calendarFolder);
+            if (loadAppointment.getSequence() >= appointment.getSequence()) {
+                return;
+            }
+        } catch (final SQLException e) {
+            throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, e);
+        }
+
+        appointmentSql.updateAppointmentObject(appointment, calendarFolder, new Date());
+    }
+
+    private void handleWithoutPermission(final Session session, final CalendarDataObject appointment, final int calendarFolder, final Confirm confirm, final AppointmentSQLInterface appointmentSql) throws OXException {
         appointment.removeUid();
         appointment.removeObjectID();
         appointment.removeUsers();
         appointment.removeParticipants();
         appointment.setParentFolderID(calendarFolder);
 
-        UserParticipant self = new UserParticipant(session.getUserId());
+        final UserParticipant self = new UserParticipant(session.getUserId());
         self.setConfirm(confirm.getConfirm());
         self.setConfirmMessage(confirm.getConfirmMessage());
         appointment.setUsers(new UserParticipant[] { self });
@@ -155,30 +177,30 @@ public abstract class ICalDataHandler implements DataHandler {
         appointmentSql.insertAppointmentObject(appointment);
     }
 
-    private void updateOwnParticipantStatus(Session session, Context ctx, int objectId, Confirm confirm, AppointmentSQLInterface appSql) throws OXException, DataException {
-        FolderObject calendarFolder = new OXFolderAccess(ctx).getDefaultFolder(session.getUserId(), FolderObject.CALENDAR);
+    private void updateOwnParticipantStatus(final Session session, final Context ctx, final int objectId, final Confirm confirm, final AppointmentSQLInterface appSql) throws OXException, DataException {
+        final FolderObject calendarFolder = new OXFolderAccess(ctx).getDefaultFolder(session.getUserId(), FolderObject.CALENDAR);
         try {
-            CalendarDataObject loadedObject = appSql.getObjectById(objectId, calendarFolder.getObjectID());
-            UserParticipant[] users = loadedObject.getUsers();
+            final CalendarDataObject loadedObject = appSql.getObjectById(objectId, calendarFolder.getObjectID());
+            final UserParticipant[] users = loadedObject.getUsers();
             boolean found = false;
-            for (UserParticipant user : users) {
+            for (final UserParticipant user : users) {
                 if (user.getIdentifier() == session.getUserId()) {
                     found = true;
                     break;
                 }
             }
-            
+
             if (found) {
                 try {
                     appSql.setUserConfirmation(objectId, calendarFolder.getObjectID(), session.getUserId(), confirm.getConfirm(), confirm.getConfirmMessage());
-                } catch (OXException e) {
+                } catch (final OXException e) {
                     throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create("Error during confirmation update.");
                 }
             } else {
                 throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create("Object already exists, but user is not participant.");
             }
-            
-        } catch (SQLException e) {
+
+        } catch (final SQLException e) {
             throw DataExceptionCodes.ERROR.create(e, e.getMessage());
         }
     }
@@ -187,14 +209,17 @@ public abstract class ICalDataHandler implements DataHandler {
      * @param appointment
      * @param confirm
      */
-    private void setConfirmation(Session session, CalendarDataObject appointment, Confirm confirm) {
-        for (Participant participant : appointment.getParticipants()) {
-            if (participant.getType() == Participant.USER) {
-                UserParticipant user = (UserParticipant) participant;
-                if (user.getIdentifier() == session.getUserId()) {
-                    user.setConfirm(confirm.getConfirm());
-                    if (confirm.getConfirmMessage() != null) {
-                        user.setConfirmMessage(confirm.getConfirmMessage());
+    private void setConfirmation(final Session session, final CalendarDataObject appointment, final Confirm confirm) {
+        final Participant[] participants = appointment.getParticipants();
+        if (null != participants) {
+            for (final Participant participant : participants) {
+                if (participant.getType() == Participant.USER) {
+                    final UserParticipant user = (UserParticipant) participant;
+                    if (user.getIdentifier() == session.getUserId()) {
+                        user.setConfirm(confirm.getConfirm());
+                        if (confirm.getConfirmMessage() != null) {
+                            user.setConfirmMessage(confirm.getConfirmMessage());
+                        }
                     }
                 }
             }
@@ -328,11 +353,11 @@ public abstract class ICalDataHandler implements DataHandler {
      */
     protected class Confirm {
 
-        private int confirm;
+        private final int confirm;
 
-        private String confirmMessage;
+        private final String confirmMessage;
 
-        public Confirm(int confirm, String confirmMessage) {
+        public Confirm(final int confirm, final String confirmMessage) {
             this.confirm = confirm;
             this.confirmMessage = confirmMessage;
         }
