@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,6 +68,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.writer.AppointmentWriter;
 import com.openexchange.ajax.writer.TaskWriter;
+import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.api2.OXException;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.conversion.Data;
@@ -79,6 +80,7 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.ICalParser;
+import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.OXCalendarException;
@@ -108,12 +110,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
  * <li>com.openexchange.groupware.calendar.recurrencePosition<br>
  * (optional; default is zero)</li>
  * </ul>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ICalJSONDataHandler implements DataHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ICalJSONDataHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ICalJSONDataHandler.class));
 
     private static final Class<?>[] TYPES = { InputStream.class };
 
@@ -177,6 +179,7 @@ public final class ICalJSONDataHandler implements DataHandler {
                  * Start parsing appointments
                  */
                 appointments = parseAppointmentStream(ctx, iCalParser, inputStreamCopy, conversionErrors, conversionWarnings, timeZone);
+                resolveUid(appointments, dataArguments, session);
                 // TODO: Handle errors/warnings
                 conversionErrors.clear();
                 conversionWarnings.clear();
@@ -234,7 +237,7 @@ public final class ICalJSONDataHandler implements DataHandler {
                         // extractRecurringInformation()
                         // appointmentobject.calculateRecurrence();
                         final RecurringResultsInterface recuResults =
-                            recColl.calculateRecurring(appointment, 0, 0, recurrencePosition, CalendarCollectionService.MAXTC, true);
+                            recColl.calculateRecurring(appointment, 0, 0, recurrencePosition, CalendarCollectionService.MAX_OCCURRENCESE, true);
                         if (recuResults.size() == 0) {
                             if (LOG.isWarnEnabled()) {
                                 LOG.warn(new StringBuilder(32).append("No occurrence at position ").append(recurrencePosition));
@@ -283,9 +286,43 @@ public final class ICalJSONDataHandler implements DataHandler {
         return objects;
     }
 
+    /**
+     * @param appointments
+     * @param dataArguments
+     * @param session
+     * @throws DataException
+     */
+    private void resolveUid(List<CalendarDataObject> appointments, DataArguments dataArguments, Session session) throws DataException {
+        String key = "com.openexchange.groupware.calendar.searchobject";
+        if (!(dataArguments.containsKey(key) && Boolean.parseBoolean(dataArguments.get(key)))) {
+            return;
+        }
+
+        AppointmentSQLInterface appointmentSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(session);
+
+        for (CalendarDataObject calendarData : appointments) {
+            if (!calendarData.containsUid()) {
+                continue;
+            }
+
+            try {
+                int id = appointmentSql.resolveUid(calendarData.getUid());
+                if (id != 0) {
+                    int folder = appointmentSql.getFolder(id);
+                    if (folder != 0) {
+                        calendarData.setParentFolderID(folder);
+                    }
+                    calendarData.setObjectID(id);
+                }
+            } catch (OXException e) {
+                throw new DataException(e);
+            }
+        }
+    }
+
     /*-
-     * 
-     * 
+     *
+     *
     private void insertTasks(final Session session, final int taskFolder, final List<Task> tasks, final JSONArray folderAndIdArray) throws OXException, JSONException {
         final TasksSQLInterface taskSql = new TasksSQLInterfaceImpl(session);
         for (final Task task : tasks) {
