@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.groupware.filestore;
 
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 
@@ -58,20 +59,8 @@ import com.openexchange.groupware.EnumComponent;
  */
 public class FilestoreException extends AbstractOXException {
 
-    /**
-     * Serialization.
-     */
     private static final long serialVersionUID = 4503678033499557993L;
 
-    /**
-     * Constructor with all parameters.
-     * @param component Component.
-     * @param category Category.
-     * @param number detail number.
-     * @param message message of the exception.
-     * @param cause the cause.
-     * @param messageArgs arguments for the exception message.
-     */
     public FilestoreException(final EnumComponent component, final Category category,
         final int detailNumber, final String message, final Throwable cause,
         final Object... messageArgs) {
@@ -79,11 +68,12 @@ public class FilestoreException extends AbstractOXException {
         setMessageArgs(messageArgs);
     }
 
-    /**
-     * Initializes a new {@link FilestoreException}
-     * @param cause The init cause
-     */
     public FilestoreException(final AbstractOXException cause) {
-    	super(cause);
+        super(cause);
+    }
+
+    public FilestoreException(ErrorMessage message, Throwable cause, Object... args) {
+        super(message, cause);
+        setMessageArgs(args);
     }
 }
