@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,9 +75,7 @@ public abstract class FilestoreStorage {
      * @throws FilestoreException if an error occurs generating the URI.
      */
     public static URI createURI(final Context ctx) throws FilestoreException {
-        final int filestoreId = ctx.getFilestoreId();
-        final FilestoreStorage storage = getInstance();
-        final Filestore store = storage.getFilestore(filestoreId);
+        final Filestore store = getInstance().getFilestore(ctx.getFilestoreId());
         return FilestoreTools.createLocation(store, ctx);
     }
 
