@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,7 @@ package com.openexchange.groupware.importexport;
 
 /**
  * This enumeration lists formats for import or export.
- * 
+ *
  * @author Tobias Prinz, mailto:tobias.prinz@open-xchange.com
  *
  */
@@ -60,33 +60,35 @@ public enum Format {
     OUTLOOK_CSV("OUTLOOK_CSV" , "Comma separated values","text/csv","csv"),
     ICAL("ICAL" , "iCal","text/calendar","ics"),
     VCARD("VCARD", "vCard","text/x-vcard","vcf"),
+    FacebookFriends("FacebookFriends", "FacebookFriends","text/html","html"),
+    FacebookArchive("FacebookArchive", "FacebookArchive","application/zip","zip"),
     TNEF("TNEF" , "Transport Neutral Encapsulation Format" , "application/ms-tnef", "tnef");
-    
+
     private String constantName, mimetype, longName, extension;
-    
+
     private Format(final String constantName, final String longName, final String mimetype, final String extension) {
         this.constantName = constantName;
         this.longName = longName;
         this.mimetype = mimetype;
         this.extension = extension;
     }
-    
+
     public String getFullName() {
         return this.longName;
     }
-    
+
     public String getMimeType() {
         return this.mimetype;
     }
-    
+
     public String getExtension() {
         return this.extension;
     }
-    
+
     public String getConstantName() {
         return this.constantName;
     }
-    
+
     public static Format getFormatByMimeType(final String mimeType) {
         for (final Format f : Format.values()) {
             if (f.getMimeType().equals(mimeType)) {
@@ -110,7 +112,7 @@ public enum Format {
         }
         return null;
     }
-    
+
     public static Format getFormatByConstantName(final String constantName) {
         for (final Format f : Format.values()) {
             if (f.getConstantName().equalsIgnoreCase(constantName)) {
@@ -119,7 +121,7 @@ public enum Format {
         }
         return null;
     }
-    
+
     public static boolean containsConstantName(final String name) {
         for (final Format f : Format.values()) {
             if (name.equalsIgnoreCase(f.constantName)) {
