@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,47 +55,20 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.importexport.exceptions.ImportExportException;
-import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionClasses;
-import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionFactory;
 import com.openexchange.tools.session.ServerSession;
 
-
-
-/** 
+/**
  * Selects the appropriate importer or exporter for an import or export.
- * 
+ *
  * The list of importers and exports is usually loaded via Spring in the
- * ImportServlet or ExportServlet, but this might be changed in the future. 
- * 
+ * ImportServlet or ExportServlet, but this might be changed in the future.
+ *
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a>
  */
-@OXThrowsMultiple(
-    category = { 
-        Category.SUBSYSTEM_OR_SERVICE_DOWN,
-        Category.SUBSYSTEM_OR_SERVICE_DOWN
-    }, 
-    desc = { "" , "" }, 
-    exceptionId = { 0 , 1 }, 
-    msg = {
-        "Cannot find an importer for format %s into folders %s",
-        "Cannot find an exporter for folder %s to format %s" 
-    }
-)
-@OXExceptionSource(
-    classId=ImportExportExceptionClasses.IMPORTEREXPORTER, 
-    component=EnumComponent.IMPORT_EXPORT
-)
 public class ImporterExporter {
 
-    private final static ImportExportExceptionFactory EXCEPTIONS = new ImportExportExceptionFactory(ImporterExporter.class);
-
     private List <Importer> importers;
-    
     private List <Exporter> exporters;
 
     public ImporterExporter() {
@@ -137,10 +110,10 @@ public class ImporterExporter {
     }
 
     //--- PROPER METHODS ---//-
-    
+
     /**
      * Imports data to one or more folders
-     * 
+     *
      * @param sessObj: Session object used to determine access rights
      * @param format: Format the imported data is in
      * @param is: InputStream containing the data to be imported
@@ -153,19 +126,19 @@ public class ImporterExporter {
                 return imp.importData(sessObj, format, is, folders, optionalParams);
             }
         }
-        throw EXCEPTIONS.create(0, format, folders);
+        throw ImportExportExceptionCodes.NO_IMPORTER.create(format, folders);
     }
 
     /**
      * Exports data of one folder
-     * 
+     *
      * @param sessObj Session object used to determine access rights
      * @param format Format the exported data should be in
      * @param folder Folder that is to be exported
      * @param fieldsToBeExported Fields of certain data that are to be exported. Convention: If this is empty, all fields are exported
      * @param optionalParams Params that might be needed by a specific implementor of this interface. Note: The format was chosen to be congruent with HTTP-GET
      * @return InputStream containing the exported data in given format
-     * @throws ImportExportException in case of a missing exporter for that kind of data 
+     * @throws ImportExportException in case of a missing exporter for that kind of data
      */
     public SizedInputStream exportData(final ServerSession sessObj, final Format format, final String folder, final int[] fieldsToBeExported, final Map<String, String[]> optionalParams) throws ImportExportException {
         for (final Exporter exp : getExporters()) {
@@ -173,12 +146,12 @@ public class ImporterExporter {
                 return exp.exportData(sessObj, format, folder, fieldsToBeExported, optionalParams);
             }
         }
-        throw EXCEPTIONS.create(1, folder, format);
+        throw ImportExportExceptionCodes.NO_EXPORTER.create(folder, format);
     }
 
     /**
      * Exports the data of one object in one folder
-     * 
+     *
      * @param sessObj
      * @param format
      * @param folder
@@ -195,19 +168,19 @@ public class ImporterExporter {
                 return exp.exportData(sessObj, format, folder, objectId, fieldsToBeExported, optionalParams);
             }
         }
-        throw EXCEPTIONS.create(1, folder, format);
+        throw ImportExportExceptionCodes.NO_EXPORTER.create(folder, format);
     }
 
     /**
-     * Lists all formats a folder (which in OX is always of a certain type) 
+     * Lists all formats a folder (which in OX is always of a certain type)
      * can be converted into.
-     * 
+     *
      * @param sessObj: Session object used to determine access rights
      * @param folder: Identifier of a certain folder within the OX
      * @param type: Type of the folder as defined in class Types
      * @param optionalParams: Params that might be needed by a specific implementor of this interface. Note: The format was chosen to be congruent with HTTP-GET
      * @return A set of possible formats this folder can be exported to
-     * @throws ImportExportException 
+     * @throws ImportExportException
      */
     public Set<Format> getPossibleExportFormats(final ServerSession sessObj, final String folder, final Map<String, String[]> optionalParams) throws ImportExportException {
         final Set<Format> res = new HashSet<Format>();
@@ -222,7 +195,7 @@ public class ImporterExporter {
         }
         return res;
     }
-    
+
     /**
      * Lists all formats a folder can import data from
      *
@@ -230,7 +203,7 @@ public class ImporterExporter {
      * @param folderMapping: Identifier of a certain folder (plus its type as defined in class Type) within the OX
      * @param optionalParams: Params that might be needed by a specific implementor of this interface. Note: The format was chosen to be congruent with HTTP-GET
      * @return A set of possible formats this folder can import
-     * @throws ImportExportException 
+     * @throws ImportExportException
      */
     public Set<Format> getPossibleImportFormats(final ServerSession sessObj, final List<String> folders, final Map<String, String[]> optionalParams) throws ImportExportException {
         final Set<Format> res = new HashSet<Format>();
