@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,71 +49,60 @@
 
 package com.openexchange.groupware.importexport;
 
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
+import static com.openexchange.java.Autoboxing.I;
 import com.openexchange.groupware.Types;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.importexport.exceptions.ImportExportException;
-import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionClasses;
-import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionFactory;
 
 /**
- * This sad little class translates has the sad little task to
- * translate between different constants that are used to identify
- * types of modules.
- * 
- * So, in case yo
- * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a>
+ * This sad little class translates has the sad little task to translate between different constants that are used to identify types of
+ * modules. So, in case yo
  *
+ * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a>
  */
-@OXExceptionSource(
-		classId=ImportExportExceptionClasses.MODULETYPETRANSLATOR, 
-		component=EnumComponent.IMPORT_EXPORT)
-	@OXThrowsMultiple(
-		category={
-			Category.USER_INPUT,
-			Category.USER_INPUT}, 
-		desc={"",""}, 
-		exceptionId={0,1}, 
-		msg={
-			"Cannot translate id=%d to a constant from Types.",
-			"Cannot translate id=%d to a constant from FolderObject."})
-			
 public final class ModuleTypeTranslator {
 
-	private ModuleTypeTranslator() {
-		super();
-	}
+    private ModuleTypeTranslator() {
+        super();
+    }
 
-	private static final ImportExportExceptionFactory EXCEPTIONS = new ImportExportExceptionFactory(ModuleTypeTranslator.class); 
-	
-	/**
-	 * Translates a FolderObject value to a Types value.
-	 */
-	public static int getTypesConstant(final int folderObjectConstant) throws ImportExportException{
-		switch(folderObjectConstant){
-			case FolderObject.CONTACT:		return Types.CONTACT;
-			case FolderObject.INFOSTORE: 	return Types.INFOSTORE;
-			case FolderObject.MAIL: 		return Types.EMAIL;
-			case FolderObject.TASK: 		return Types.TASK;
-			case FolderObject.CALENDAR: 	return Types.APPOINTMENT;
-			default: throw EXCEPTIONS.create(0,Integer.valueOf(folderObjectConstant));
-		}
-	}
-	
-	/**
-	 * Translates a Types value to a FolderObject value
-	 */
-	public static int getFolderObjectConstant(final int typeConstant) throws ImportExportException{
-		switch(typeConstant){
-			case Types.CONTACT:		return FolderObject.CONTACT;
-			case Types.INFOSTORE: 	return FolderObject.INFOSTORE;
-			case Types.EMAIL: 		return FolderObject.MAIL;
-			case Types.TASK: 		return FolderObject.TASK;
-			case Types.APPOINTMENT: return FolderObject.CALENDAR;
-			default: throw EXCEPTIONS.create(1,Integer.valueOf(typeConstant));
-		}
-	}
+    /**
+     * Translates a FolderObject value to a Types value.
+     */
+    public static int getTypesConstant(final int folderObjectConstant) throws ImportExportException {
+        switch (folderObjectConstant) {
+        case FolderObject.CONTACT:
+            return Types.CONTACT;
+        case FolderObject.INFOSTORE:
+            return Types.INFOSTORE;
+        case FolderObject.MAIL:
+            return Types.EMAIL;
+        case FolderObject.TASK:
+            return Types.TASK;
+        case FolderObject.CALENDAR:
+            return Types.APPOINTMENT;
+        default:
+            throw ImportExportExceptionCodes.NO_TYPES_CONSTANT.create(I(folderObjectConstant));
+        }
+    }
+
+    /**
+     * Translates a Types value to a FolderObject value
+     */
+    public static int getFolderObjectConstant(final int typeConstant) throws ImportExportException {
+        switch (typeConstant) {
+        case Types.CONTACT:
+            return FolderObject.CONTACT;
+        case Types.INFOSTORE:
+            return FolderObject.INFOSTORE;
+        case Types.EMAIL:
+            return FolderObject.MAIL;
+        case Types.TASK:
+            return FolderObject.TASK;
+        case Types.APPOINTMENT:
+            return FolderObject.CALENDAR;
+        default:
+            throw ImportExportExceptionCodes.NO_FOLDEROBJECT_CONSTANT.create(I(typeConstant));
+        }
+    }
 }
