@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,30 +50,24 @@
 package com.openexchange.groupware.importexport.exceptions;
 
 import com.openexchange.api2.OXException;
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 
 /**
- * An exception thrown by classes associated with the import or export of
- * OX data.
- * 
- * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a>
+ * An exception thrown by classes associated with the import or export of OX data.
  *
+ * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias 'Tierlieb' Prinz</a>
  */
 public class ImportExportException extends OXException {
 
-	private static final long serialVersionUID = 8368543799201210727L;
+    private static final long serialVersionUID = 8368543799201210727L;
 
-	public ImportExportException(final Category category, final int id, final String message, final Throwable cause, final Object...msgParams){
-		super(EnumComponent.IMPORT_EXPORT, category, id, message, cause);
-		setMessageArgs(msgParams);
-	}
+    public ImportExportException(final AbstractOXException e) {
+        super(e);
+    }
 
-	public ImportExportException(final Category category, final String message, final int id, final Object...msgParams){
-		this(category,id,message, null,msgParams);
-	}
-
-	public ImportExportException(final AbstractOXException e1) {
-		super(e1);
-	}
+    public ImportExportException(ErrorMessage message, Throwable cause, Object... args) {
+        super(message, cause);
+        setMessageArgs(args);
+    }
 }
