@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,6 +56,7 @@ import java.util.TimeZone;
 import com.openexchange.api2.OXException;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
+import com.openexchange.data.conversion.ical.FreeBusyInformation;
 import com.openexchange.data.conversion.ical.ICalParser;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
@@ -72,50 +73,62 @@ import com.openexchange.server.services.ServerServiceRegistry;
  */
 public class ExtraneousSeriesMasterRecoveryParser implements ICalParser {
 
-    private ICalParser delegate;
-    private ServerServiceRegistry registry;
-    
-    public ExtraneousSeriesMasterRecoveryParser(ICalParser delegate, ServerServiceRegistry registry) {
+    private final ICalParser delegate;
+    private final ServerServiceRegistry registry;
+
+    public ExtraneousSeriesMasterRecoveryParser(final ICalParser delegate, final ServerServiceRegistry registry) {
         this.delegate = delegate;
         this.registry = registry;
     }
 
-    public List<CalendarDataObject> parseAppointments(InputStream ical, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
+    public List<CalendarDataObject> parseAppointments(final InputStream ical, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         return splitIfNeeded(delegate.parseAppointments(ical, defaultTZ, ctx, errors, warnings));
     }
 
-    public List<CalendarDataObject> parseAppointments(String icalText, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
+    public List<CalendarDataObject> parseAppointments(final String icalText, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         return splitIfNeeded(delegate.parseAppointments(icalText, defaultTZ, ctx, errors, warnings));
     }
 
-    private List<CalendarDataObject> splitIfNeeded(List<CalendarDataObject> appointments) throws ConversionError {
-        CalendarCollectionService tools = registry.getService(CalendarCollectionService.class);
+    private List<CalendarDataObject> splitIfNeeded(final List<CalendarDataObject> appointments) throws ConversionError {
+        final CalendarCollectionService tools = registry.getService(CalendarCollectionService.class);
         int index = 0;
-        LinkedList<CalendarDataObject> copy = new LinkedList<CalendarDataObject>(appointments);
-        for (CalendarDataObject appointment : appointments) {
+        final LinkedList<CalendarDataObject> copy = new LinkedList<CalendarDataObject>(appointments);
+        for (final CalendarDataObject appointment : appointments) {
             try {
                 if(appointment.isSequence() && !tools.isOccurrenceDate(appointment.getStartDate().getTime(), -1, appointment, new long[0])) {
-                    CalendarDataObject clone = (CalendarDataObject) appointment.clone();
+                    final CalendarDataObject clone = appointment.clone();
                     tools.removeRecurringType(appointment);
                     copy.add(clone);
                 }
-            } catch (OXException e) {
+            } catch (final OXException e) {
                 throw new ConversionError(index, e);
             }
             index++;
         }
-        
+
         return copy;
     }
 
-    public List<Task> parseTasks(InputStream ical, TimeZone defaultTZ, Context context, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
+    public List<Task> parseTasks(final InputStream ical, final TimeZone defaultTZ, final Context context, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         return delegate.parseTasks(ical, defaultTZ, context, errors, warnings);
     }
 
-    public List<Task> parseTasks(String icalText, TimeZone defaultTZ, Context context, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
+    public List<Task> parseTasks(final String icalText, final TimeZone defaultTZ, final Context context, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         return delegate.parseTasks(icalText, defaultTZ, context, errors, warnings);
     }
 
-    
-    
+    public String parseProperty(final String propertyName, final InputStream ical) {
+        return delegate.parseProperty(propertyName, ical);
+    }
+
+	public List<FreeBusyInformation> parseFreeBusy(String icalText, TimeZone defaultTZ, Context ctx, List<ConversionError> errors,
+			List<ConversionWarning> warnings) throws ConversionError {
+		return delegate.parseFreeBusy(icalText, defaultTZ, ctx, errors, warnings);
+	}
+
+	public List<FreeBusyInformation> parseFreeBusy(InputStream ical, TimeZone defaultTZ, Context ctx, List<ConversionError> errors,
+			List<ConversionWarning> warnings) throws ConversionError {
+		return delegate.parseFreeBusy(ical, defaultTZ, ctx, errors, warnings);
+	}
+
 }
