@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,14 +51,14 @@ package com.openexchange.groupware.infostore;
 
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.tx.Service;
+import com.openexchange.tx.TransactionAware;
 
-public interface InfoDatabase extends Service {
+public interface InfoDatabase extends TransactionAware {
 
 	void delete(int[] ids, Context ctx) throws OXException ;
 
 	void insertDocument(DocumentMetadata document, Context ctx) throws OXException;
 	void insertVersion(DocumentMetadata document, Context ctx) throws OXException;
 	void insertVersion(DocumentMetadata document, Context ctx, String filestoreLocation) throws OXException;
-	
+
 }
