@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,13 +71,13 @@ public class InfostoreConfig extends AbstractConfig implements Initialization {
     public static enum InfoProperty{
 		MAX_UPLOAD_SIZE;
 	}
-	
+
     private static final Property KEY = Property.INFOSTORE;
-    
-    private static final Log LOG = LogFactory.getLog(InfostoreConfig.class);
-    
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreConfig.class));
+
     private static InfostoreConfig singleton;
-    
+
     private static final Lock INIT_LOCK = new ReentrantLock();
 
     private static boolean loaded = false;
@@ -114,10 +114,10 @@ public class InfostoreConfig extends AbstractConfig implements Initialization {
 				LOG.error("Can't init config:",e);
 			}
 		}
-			
+
         return singleton.getPropertyInternal(key);
     }
-    
+
     public static long getMaxUploadSize(){
     	final String sizeS = getProperty(InfoProperty.MAX_UPLOAD_SIZE.name());
     	if(null == sizeS) {
@@ -147,7 +147,7 @@ public class InfostoreConfig extends AbstractConfig implements Initialization {
             } finally {
 				INIT_LOCK.unlock();
 			}
-		}   
+		}
     }
 
     public void stop() throws ConfigurationException {
