@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,18 @@
 package com.openexchange.groupware.infostore;
 
 import com.openexchange.api2.OXException;
+import com.openexchange.database.provider.DBProvider;
+import com.openexchange.database.provider.StaticDBPoolProvider;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.downgrade.DowngradeEvent;
 import com.openexchange.groupware.downgrade.DowngradeFailedException;
 import com.openexchange.groupware.downgrade.DowngradeListener;
 import com.openexchange.groupware.infostore.facade.impl.InfostoreFacadeImpl;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.StaticDBPoolProvider;
-import com.openexchange.groupware.tx.TransactionException;
+import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tx.TransactionException;
 
 /**
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
@@ -67,6 +68,11 @@ import com.openexchange.tools.session.ServerSessionAdapter;
 public class InfostoreDowngrade extends DowngradeListener {
     @Override
 	public void downgradePerformed(final DowngradeEvent event) throws DowngradeFailedException {
+        final UserConfiguration newUserConfiguration = event.getNewUserConfiguration();
+        if (newUserConfiguration.hasInfostore()) {
+            // Still access to infostore...
+            return;
+        }
         final DBProvider provider = new StaticDBPoolProvider(event.getWriteCon());
 
         final ServerSession session = new ServerSessionAdapter(event.getSession(), event.getContext());
@@ -77,7 +83,7 @@ public class InfostoreDowngrade extends DowngradeListener {
         try {
 
             final OXFolderAccess access = new OXFolderAccess(event.getContext());
-            final FolderObject fo = access.getDefaultFolder(event.getNewUserConfiguration().getUserId(), FolderObject.INFOSTORE);
+            final FolderObject fo = access.getDefaultFolder(newUserConfiguration.getUserId(), FolderObject.INFOSTORE);
             final int folderId = fo.getObjectID();
 
 
