@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,25 +50,19 @@
 package com.openexchange.groupware.infostore;
 
 import com.openexchange.api2.OXException;
+import com.openexchange.exceptions.ErrorMessage;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 
 public class InfostoreException extends OXException {
-	/**
-	 * 
-	 */
-	private static final long serialVersionUID = -5757775872793698069L;
 
-	public InfostoreException(final Category category, final int id, final String message, final Throwable cause, final Object...msgParams){
-		super(EnumComponent.INFOSTORE, category, id, message,cause);
-		setMessageArgs(msgParams);
-	}
+    private static final long serialVersionUID = -5757775872793698069L;
 
-	public InfostoreException(final Category category, final String message, final int id, final Object...msgParams){
-		this(category,id,message, null,msgParams);
-	}
+    public InfostoreException(final AbstractOXException e) {
+        super(e);
+    }
 
-	public InfostoreException(final AbstractOXException e1) {
-		super(e1);
-	}
+    public InfostoreException(ErrorMessage message, Throwable cause, Object... args) {
+        super(message, cause);
+        setMessageArgs(args);
+    }
 }
