@@ -29,7 +29,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,41 +52,41 @@ package com.openexchange.groupware.infostore;
 
 import java.io.InputStream;
 import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.results.Delta;
 import com.openexchange.groupware.results.TimedResult;
-import com.openexchange.groupware.tx.Service;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.sessiond.impl.SessionHolder;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.SessionHolder;
+import com.openexchange.tx.TransactionAware;
 
-public interface InfostoreFacade extends Service{
+public interface InfostoreFacade extends TransactionAware{
 	/**
 	 * Special Version used if you want to retrieve the latest version of an infostore document
 	 */
 	public static int CURRENT_VERSION = -1;
 	public static int NEW = -1;
-	
+
 	public static final int ASC = 1;
 	public static final int DESC = -1;
-	
+
 	public boolean exists(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
-	
+
 	public DocumentMetadata getDocumentMetadata(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 	public void saveDocumentMetadata(DocumentMetadata document, long sequenceNumber, ServerSession sessionObj) throws OXException ; // No modifiedColumns means all columns
 	public void saveDocumentMetadata(DocumentMetadata document, long sequenceNumber, Metadata[] modifiedColumns, ServerSession sessionObj) throws OXException ;
-	
+
 	public InputStream getDocument(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 	public void saveDocument(DocumentMetadata document, InputStream data, long sequenceNumber, ServerSession sessionObj) throws OXException ;
 	public void saveDocument(DocumentMetadata document, InputStream data, long sequenceNumber, Metadata[] modifiedColumns, ServerSession sessionObj) throws OXException ;
-	
+
 	public void removeDocument(long folderId, long date, ServerSession sessionObj) throws OXException;
 	public int[] removeDocument(int id[], long date, ServerSession sessionObj) throws OXException;
 	public int[] removeVersion(int id, int[] versionId, ServerSession sessionObj) throws OXException;
-	
+
 	public TimedResult<DocumentMetadata> getDocuments(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 	public TimedResult<DocumentMetadata> getDocuments(long folderId, Metadata[] columns, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 
@@ -100,14 +100,14 @@ public interface InfostoreFacade extends Service{
 	public TimedResult<DocumentMetadata> getVersions(int id, Metadata[] columns, Metadata sort, int order, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 
 	public TimedResult<DocumentMetadata> getDocuments(int[] ids, Metadata[] columns, Context ctx, User user, UserConfiguration userConfig) throws IllegalAccessException, OXException;
-	
-	public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws OXException, SearchIteratorException;
+
+	public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws AbstractOXException;
 
 	// order is either ASC or DESC
-	public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, Metadata sort, int order, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws OXException, SearchIteratorException;
-	
+	public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, Metadata sort, int order, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws AbstractOXException;
+
 	public int countDocuments(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
-	
+
 	public boolean hasFolderForeignObjects(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 	public boolean isFolderEmpty(long folderId, Context ctx) throws OXException;
 
@@ -119,7 +119,7 @@ public interface InfostoreFacade extends Service{
 
     public void touch(int id, ServerSession session) throws OXException;
 
-    
+
     public void setSessionHolder(SessionHolder sessionHolder);
 
 }
