@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,11 +53,11 @@ import com.openexchange.api.OXObjectNotFoundException;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.Service;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.tx.TransactionAware;
 import com.openexchange.webdav.protocol.WebdavPath;
 
-public interface PathResolver extends Service {
+public interface PathResolver extends TransactionAware {
 	public Resolved resolve(int relativeToFolder, WebdavPath path, Context ctx, User user, UserConfiguration userConfig) throws OXException, OXObjectNotFoundException;
 	public WebdavPath getPathForFolder(int relativeToFolder, int folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 	public WebdavPath getPathForDocument(int relativeToFolder, int documentId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
