@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,26 +52,26 @@ package com.openexchange.groupware.infostore.database.impl;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.util.Date;
+import com.openexchange.database.tx.AbstractDBAction;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.utils.Metadata;
-import com.openexchange.groupware.tx.AbstractDBAction;
 
 public abstract class AbstractInfostoreAction extends AbstractDBAction {
 
 	private InfostoreQueryCatalog queries = null;
-	
+
 	protected final void fillStmt(final PreparedStatement stmt, final Metadata[] fields, final DocumentMetadata doc, final Object...additional) throws SQLException {
 		final GetSwitch get = new GetSwitch(doc);
 		int i = 1;
 		for(final Metadata m : fields) {
 			stmt.setObject(i++, process(m, m.doSwitch(get)));
 		}
-		
+
 		for(final Object o : additional) {
 			stmt.setObject(i++, o);
 		}
 	}
-	
+
 	private final Object process(final Metadata field, final Object value) {
 		switch(field.getId()) {
 		default : return value;
@@ -82,9 +82,9 @@ public abstract class AbstractInfostoreAction extends AbstractDBAction {
 	public void setQueryCatalog(final InfostoreQueryCatalog queries){
 		this.queries = queries;
 	}
-	
+
 	public InfostoreQueryCatalog getQueryCatalog(){
 		return this.queries;
 	}
-	
+
 }
