@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,30 +58,20 @@ import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrows;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.infostore.Classes;
 import com.openexchange.groupware.infostore.DocumentMetadata;
-import com.openexchange.groupware.infostore.InfostoreExceptionFactory;
+import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
 import com.openexchange.groupware.infostore.utils.Metadata;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.tools.encoding.Charsets;
 import com.openexchange.tools.exceptions.SimpleTruncatedAttribute;
 import com.openexchange.tools.sql.DBUtils;
 
-@OXExceptionSource(
-		classId=Classes.COM_OPENEXCHANGE_GROUPWARE_INFOSTORE_DATABASE_IMPL_CHECKSIZESWITCH,
-		component=EnumComponent.INFOSTORE
-)
 public class CheckSizeSwitch {
-	
-	private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(CheckSizeSwitch.class);
-    private static final Log LOG = LogFactory.getLog(CheckSizeSwitch.class);
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CheckSizeSwitch.class));
 
     private static Map<Metadata, Integer> SIZES = new HashMap<Metadata, Integer>();
     private final DBProvider provider;
@@ -102,20 +92,14 @@ public class CheckSizeSwitch {
         this.ctx = ctx;
     }
 
-    @OXThrows(
-			category = Category.TRUNCATED,
-			desc = "The User entered values that are to long for the database schema.",
-			exceptionId = 0,
-			msg = "Some fields have values, that are too long"
-	)
-	public static void checkSizes(final DocumentMetadata metadata, final DBProvider provider, final Context ctx) throws OXException {
-		boolean error = false;
-		
-		final CheckSizeSwitch checkSize = new CheckSizeSwitch(provider, ctx);
-		final GetSwitch get = new GetSwitch(metadata);
-		
-		final OXException x = EXCEPTIONS.create(0);
-        
+    public static void checkSizes(final DocumentMetadata metadata, final DBProvider provider, final Context ctx) throws OXException {
+        boolean error = false;
+
+        final CheckSizeSwitch checkSize = new CheckSizeSwitch(provider, ctx);
+        final GetSwitch get = new GetSwitch(metadata);
+
+        final OXException x = InfostoreExceptionCodes.TOO_LONG_VALUES.create();
+
         for(final Metadata m : Metadata.VALUES) {
             if(!FIELDS_TO_CHECK.contains(m)) {
                 continue;
@@ -134,12 +118,12 @@ public class CheckSizeSwitch {
                 error = true;
             }
         }
-		
-		if(error) {
-			throw x;
-		}
-	}
-	
+
+        if(error) {
+            throw x;
+        }
+    }
+
 
 
     public int getSize(final Metadata field) {
@@ -157,7 +141,7 @@ public class CheckSizeSwitch {
         } catch (final SQLException e) {
             LOG.error(e.getMessage(), e);
             return 0;
-        } catch (final TransactionException e) {
+        } catch (final DBPoolingException e) {
             LOG.error(e.getMessage(),  e);
             return 0;
         } finally {
