@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,67 +49,42 @@
 
 package com.openexchange.groupware.infostore.database.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.sql.SQLException;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrows;
-import com.openexchange.groupware.AbstractOXException.Category;
-import com.openexchange.groupware.infostore.Classes;
 import com.openexchange.groupware.infostore.DocumentMetadata;
-import com.openexchange.groupware.infostore.InfostoreExceptionFactory;
+import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
 
-@OXExceptionSource(
-		classId = Classes.COM_OPENEXCHANGE_GROUPWARE_INFOSTORE_DATABASE_IMPL_CREATEVERSIONACTION,
-		component = EnumComponent.INFOSTORE
-)
 public class CreateVersionAction extends AbstractDocumentListAction {
 
-	private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(CreateVersionAction.class);
-	
-	
-	@OXThrows(
-			category = Category.CODE_ERROR,
-			desc = "An invalid SQL Query was sent to the server",
-			exceptionId = 0,
-			msg = "Invalid SQL Query : %s")
-	
-	@Override
-	protected void undoAction() throws AbstractOXException {
-		final UpdateBlock update = new Update(getQueryCatalog().getVersionDelete(InfostoreQueryCatalog.Table.INFOSTORE_DOCUMENT, getDocuments())){
+    @Override
+    protected void undoAction() throws AbstractOXException {
+        final UpdateBlock update = new Update(getQueryCatalog().getVersionDelete(InfostoreQueryCatalog.Table.INFOSTORE_DOCUMENT, getDocuments())){
 
-			@Override
-			public void fillStatement() throws SQLException {
-				stmt.setInt(1, getContext().getContextId());
-			}
-			
-		};
-		
-		try {
-			doUpdates(update);
-		} catch (final UpdateException e) {
-			throw EXCEPTIONS.create(0, e.getSQLException(), e.getStatement());
-		}
+            @Override
+            public void fillStatement() throws SQLException {
+                stmt.setInt(1, getContext().getContextId());
+            }
+        };
+        try {
+            doUpdates(update);
+        } catch (final UpdateException e) {
+            throw InfostoreExceptionCodes.SQL_PROBLEM.create(e.getSQLException(), e.getStatement());
+        }
 
-	}
-	
-	@OXThrows(
-			category = Category.CODE_ERROR,
-			desc = "An invalid SQL Query was sent to the server",
-			exceptionId = 1,
-			msg = "Invalid SQL Query : %s")
-	public void perform() throws AbstractOXException {
-	    assureExistence();
-		try {
-			doUpdates(getQueryCatalog().getVersionInsert(), getQueryCatalog().getWritableVersionFields(), getDocuments());
-		} catch (final UpdateException e) {
-			throw EXCEPTIONS.create(1, e.getSQLException(), e.getStatement());
-		}
-	}
+    }
 
-	@Override
-	protected Object[] getAdditionals(final DocumentMetadata doc) {
-		return new Object[]{getContext().getContextId()};
-	}
+    public void perform() throws AbstractOXException {
+        assureExistence();
+        try {
+            doUpdates(getQueryCatalog().getVersionInsert(), getQueryCatalog().getWritableVersionFields(), getDocuments());
+        } catch (final UpdateException e) {
+            throw InfostoreExceptionCodes.SQL_PROBLEM.create(e.getSQLException(), e.getStatement());
+        }
+    }
 
+    @Override
+    protected Object[] getAdditionals(final DocumentMetadata doc) {
+        return new Object[] { I(getContext().getContextId()) };
+    }
 }
