@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,22 +50,22 @@
 package com.openexchange.groupware.infostore.paths.impl;
 
 import com.openexchange.api2.OXException;
+import com.openexchange.database.tx.DBService;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.PathResolver;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.DBService;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.webdav.protocol.WebdavPath;
 
 public abstract class AbstractPathResolver extends DBService implements
 		PathResolver {
-	
+
 	protected final WebdavPath absolute(final int relativeToFolder, final WebdavPath path, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
 		final WebdavPath rel = this.getPathForFolder(FolderObject.SYSTEM_ROOT_FOLDER_ID, relativeToFolder, ctx, user, userConfig);
 		return rel.dup().append(path);
 	}
-	
+
 	protected final WebdavPath relative(final int relativeToFolder, final WebdavPath absolute, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
 		final WebdavPath rel = this.getPathForFolder(FolderObject.SYSTEM_ROOT_FOLDER_ID, relativeToFolder, ctx, user, userConfig);
 	    return absolute.subpath(rel.size());
