@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,48 +54,52 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Queue;
 import com.openexchange.api2.OXException;
+import com.openexchange.database.provider.DBProvider;
+import com.openexchange.database.tx.DBService;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.infostore.Classes;
 import com.openexchange.groupware.infostore.InfostoreException;
-import com.openexchange.groupware.infostore.InfostoreExceptionFactory;
+import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.DBService;
+import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
 import com.openexchange.groupware.userconfiguration.RdbUserConfigurationStorage;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserConfigurationException;
+import com.openexchange.groupware.userconfiguration.UserConfigurationException.UserConfigurationCode;
 import com.openexchange.server.impl.OCLPermission;
-import com.openexchange.tools.iterator.FolderObjectIterator;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 
-@OXExceptionSource(classId = Classes.COM_OPENEXCHANGE_GROUPWARE_INFOSTORE_UTILS_DELUSERFOLDERDISCOVERER, component = EnumComponent.INFOSTORE)
 public class DelUserFolderDiscoverer extends DBService {
 
-	private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(
-			DelUserFolderDiscoverer.class);
+    public DelUserFolderDiscoverer() {
+        super();
+    }
 
-	public DelUserFolderDiscoverer() {
-		super();
-	}
+    public DelUserFolderDiscoverer(final DBProvider provider) {
+        super(provider);
+    }
 
-	public DelUserFolderDiscoverer(final DBProvider provider) {
-		super(provider);
-	}
-
-	public List<FolderObject> discoverFolders(final int userId, final Context ctx) throws OXException {
+    public List<FolderObject> discoverFolders(final int userId, final Context ctx) throws OXException {
         final List<FolderObject> discovered = new ArrayList<FolderObject>();
         try {
             final User user = UserStorage.getInstance().getUser(userId, ctx);
-            final UserConfiguration userConfig = RdbUserConfigurationStorage.loadUserConfiguration(userId, ctx);
+            int[] accessibleModules;
+            try {
+                accessibleModules = RdbUserConfigurationStorage.loadUserConfiguration(userId, ctx).getAccessibleModules();
+            } catch (final UserConfigurationException e) {
+                if (UserConfigurationCode.NOT_FOUND.getNumber() != e.getDetailNumber()) {
+                    throw e;
+                }
+                accessibleModules = null;
+            } catch (final SQLException e) {
+                throw InfostoreExceptionCodes.SQL_PROBLEM.create(e, "");
+            }
 
             final Queue<FolderObject> queue = ((FolderObjectIterator) OXFolderIteratorSQL.getAllVisibleFoldersIteratorOfModule(
                 userId,
                 user.getGroups(),
-                userConfig.getAccessibleModules(),
+                accessibleModules,
                 FolderObject.INFOSTORE,
                 ctx)).asQueue();
             folder: for (final FolderObject fo : queue) {
@@ -112,8 +116,6 @@ public class DelUserFolderDiscoverer extends DBService {
 
         } catch (final AbstractOXException x) {
             throw new InfostoreException(x);
-        } catch (final SQLException e) {
-            throw EXCEPTIONS.create(0, e);
         }
 
         return discovered;
