@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,30 +55,30 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 import com.openexchange.groupware.infostore.DocumentMetadata;
-import com.openexchange.groupware.infostore.SearchEngine;
+import com.openexchange.groupware.infostore.InfostoreSearchEngine;
 import com.openexchange.groupware.infostore.database.impl.GetSwitch;
 
 public class MetadataSorter {
 
 	private String field = Metadata.TITLE_LITERAL.getName();
-	private int direction = SearchEngine.ASC;
-	
+	private int direction = InfostoreSearchEngine.ASC;
+
 	private DocumentMetadata[] metadata;
 	private List<DocumentMetadata> metadataList;
-	
+
 	private static final class MetadataComparator implements Comparator<DocumentMetadata>{
 
 		private final String field;
 		private final int direction;
 		private final Metadata metadataField;
-		
+
 		public MetadataComparator(final String field, final int direction){
 			this.field = field;
 			metadataField = Metadata.get(field);
 			this.direction = direction;
-			
+
 		}
-		
+
 		public int compare(final DocumentMetadata arg0, final DocumentMetadata arg1) {
 			final Comparable<Object> v1 = getValue(arg0);
 			final Comparable<Object> v2 = getValue(arg1);
@@ -92,7 +92,7 @@ public class MetadataSorter {
 				return -1;
 			}
 			switch(direction){
-			case SearchEngine.DESC : return v2.compareTo(v1); 
+			case InfostoreSearchEngine.DESC : return v2.compareTo(v1);
 			default : return v1.compareTo(v2);
 			}
 		}
@@ -105,37 +105,37 @@ public class MetadataSorter {
 			}
 			return metadata.getProperty(field);
 		}
-		
+
 	}
-	
+
 	public MetadataSorter(final DocumentMetadata[] metadata){
 		this.metadata = metadata;
 	}
-	
+
 	public MetadataSorter(final DocumentMetadata[] metadata, final String field){
 		this(metadata);
 		this.field = field;
 	}
-	
+
 	public MetadataSorter(final DocumentMetadata[] metadata,final String field, final int direction){
 		this(metadata, field);
 		this.direction = direction;
 	}
-	
+
 	public MetadataSorter(final List<DocumentMetadata> metadata){
 		this.metadataList = metadata;
 	}
-	
+
 	public MetadataSorter(final List<DocumentMetadata> metadata, final String field){
 		this(metadata);
 		this.field = field;
 	}
-	
+
 	public MetadataSorter(final List<DocumentMetadata> metadata,final String field, final int direction){
 		this(metadata, field);
 		this.direction = direction;
 	}
-	
+
 	public int getDirection() {
 		return direction;
 	}
@@ -151,7 +151,7 @@ public class MetadataSorter {
 	public void setField(final String field) {
 		this.field = field;
 	}
-	
+
 	public DocumentMetadata[] getSorted(){
 		if(null == metadata && metadataList != null){
 			final List<DocumentMetadata> sortedMetadata = getSortedAsList();
@@ -162,7 +162,7 @@ public class MetadataSorter {
 		}
 		return metadata;
 	}
-	
+
 	public List<DocumentMetadata> getSortedAsList(){
 		if(null == metadataList && null != metadata){
 			return Arrays.asList(getSorted());
