@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,83 +53,73 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrows;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreException;
-import com.openexchange.groupware.infostore.InfostoreExceptionFactory;
+import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
 import com.openexchange.groupware.infostore.utils.Metadata;
 
-@OXExceptionSource(classId=0, component=EnumComponent.INFOSTORE)
-
-@OXThrows(category=Category.USER_INPUT, desc="", exceptionId=0, msg="Validation failed: %s")
-
 /**
  * @author francisco.laguna@open-xchange.com
- * 
+ *
  * A validation chain can be used to chain many validators together and have each one check
  * the DocumentMetadata in turn. If validation doesn't pass, an exception is thrown containing an error message.
  * The error message details for each validator the individual error messages. If more than one field is assigned
- * the same error, a list of invalid fields is prepended to the error message. 
+ * the same error, a list of invalid fields is prepended to the error message.
  */
 public class ValidationChain {
 
-	private static final InfostoreExceptionFactory EXCEPTIONS = new InfostoreExceptionFactory(ValidationChain.class);
-	
-	private final List<InfostoreValidator> validators = new ArrayList<InfostoreValidator>();
+    private final List<InfostoreValidator> validators = new ArrayList<InfostoreValidator>();
 
-	public void add(final InfostoreValidator validator) {
-		validators.add(validator);
-	}
+    public void add(final InfostoreValidator validator) {
+        validators.add(validator);
+    }
 
-	public void validate(final DocumentMetadata metadata) throws InfostoreException {
-		final StringBuilder message = new StringBuilder();
-		boolean failed = false;
-		for(final InfostoreValidator validator : validators) {
-			final DocumentMetadataValidation validation = validator.validate(metadata);
-			if(!validation.isValid()) {
-				failed = true;
-				final Map<String, List<Metadata>> errors = new HashMap<String, List<Metadata>>();
-				
-				for(final Metadata field : validation.getInvalidFields()) {
-					final String error = validation.getError(field);
-					List<Metadata> errorList = errors.get(error);
-					if(null == errorList) {
-						errorList = new ArrayList<Metadata>();
-						errors.put(error, errorList);
-					}
-					errorList.add(field);
-				}
-				
-				message.append(validator.getName()).append(": ").append('(');
-				for(final Map.Entry<String, List<Metadata>> entry : errors.entrySet()) {
-				    for(final Metadata field : entry.getValue()) {
-				        message.append(field.getName()).append(", ");
-				    }
-				    message.setLength(message.length()-2);
+    public void validate(final DocumentMetadata metadata) throws InfostoreException {
+        final StringBuilder message = new StringBuilder();
+        boolean failed = false;
+        for(final InfostoreValidator validator : validators) {
+            final DocumentMetadataValidation validation = validator.validate(metadata);
+            if(!validation.isValid()) {
+                failed = true;
+                final Map<String, List<Metadata>> errors = new HashMap<String, List<Metadata>>();
+
+                for(final Metadata field : validation.getInvalidFields()) {
+                    final String error = validation.getError(field);
+                    List<Metadata> errorList = errors.get(error);
+                    if(null == errorList) {
+                        errorList = new ArrayList<Metadata>();
+                        errors.put(error, errorList);
+                    }
+                    errorList.add(field);
+                }
+
+                message.append(validator.getName()).append(": ").append('(');
+                for(final Map.Entry<String, List<Metadata>> entry : errors.entrySet()) {
+                    for(final Metadata field : entry.getValue()) {
+                        message.append(field.getName()).append(", ");
+                    }
+                    message.setLength(message.length()-2);
                     message.append(") ").append(entry.getKey());
                     message.append('\n');
-				}
-				/*-
-				 * 
-				 * Replaced:
-				 * 
-				for(final String error : errors.keySet()) {
-					for(final Metadata field : errors.get(error)) {
-						message.append(field.getName()).append(", ");
-					}
-					message.setLength(message.length()-2);
-					message.append(") ").append(error);
-					message.append("\n");
-				}
-				*/
-			}	
-		}
-		if(failed) {
-			throw EXCEPTIONS.create(0, message.toString());
-		}
-	}
+                }
+                /*-
+                 *
+                 * Replaced:
+                 *
+                for(final String error : errors.keySet()) {
+                    for(final Metadata field : errors.get(error)) {
+                        message.append(field.getName()).append(", ");
+                    }
+                    message.setLength(message.length()-2);
+                    message.append(") ").append(error);
+                    message.append("\n");
+                }
+                */
+            }
+        }
+        if(failed) {
+            throw InfostoreExceptionCodes.VALIDATION_FAILED.create(message.toString());
+        }
+    }
 
 }
