@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,9 +52,9 @@ package com.openexchange.groupware.infostore.webdav;
 import java.util.Arrays;
 import java.util.List;
 import com.openexchange.api2.OXException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 
 public class EntityLockManagerImpl extends LockManagerImpl<Lock> implements
@@ -63,7 +63,7 @@ public class EntityLockManagerImpl extends LockManagerImpl<Lock> implements
 	public EntityLockManagerImpl(final String tablename) {
 		super(tablename);
 	}
-	
+
 	public EntityLockManagerImpl(final DBProvider provider, final String tablename) {
 		super(provider, tablename);
 	}
@@ -74,32 +74,32 @@ public class EntityLockManagerImpl extends LockManagerImpl<Lock> implements
 	}
 
 	public List<Lock> findLocks(final int entity, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
-		return findLocksByEntity(Arrays.asList(Integer.valueOf(entity)), ctx, user, userConfig).get(Integer.valueOf(entity));
+		return findLocksByEntity(Arrays.asList(Integer.valueOf(entity)), ctx).get(Integer.valueOf(entity));
 	}
-	
+
 	public boolean isLocked(final int entity, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
-		return existsLockForEntity(Arrays.asList(new Integer[]{Integer.valueOf(entity)}), ctx, user, userConfig);
+		return existsLockForEntity(Arrays.asList(new Integer[]{Integer.valueOf(entity)}), ctx);
 	}
 
 
 	public int lock(final int entity, final long timeout, final Scope scope, final Type type, final String ownerDesc, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
-		return createLock(entity, timeout, scope, type, ownerDesc, ctx, user, userConfig);
+		return createLock(entity, timeout, scope, type, ownerDesc, ctx, user);
 	}
 
 	public void unlock(final int id, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException {
-		removeLock(id, ctx, user, userConfig);
+		removeLock(id, ctx);
 	}
 
 	public void removeAll(final int entity, final Context context, final User userObject, final UserConfiguration userConfiguration) throws OXException {
-		removeAllFromEntity(entity,context,userObject,userConfiguration);
+		removeAllFromEntity(entity,context);
 	}
 
 	public void relock(final int lockId, final long timeout, final Scope scope, final Type write, final String owner, final Context context, final User userObject, final UserConfiguration userConfiguration) throws OXException {
-		updateLock(lockId, timeout, scope, write, owner, context, userObject, userConfiguration);
+		updateLock(lockId, timeout, scope, write, owner, context);
 	}
 
 	public void insertLock(final int entity, final Lock lock, final Context ctx, final User user, final UserConfiguration userConfig) throws OXException{
-		createLockForceId(entity, lock.getId(), lock.getTimeout(), lock.getScope(), lock.getType(), lock.getOwnerDescription(),ctx,user,userConfig);
+		createLockForceId(entity, lock.getId(), lock.getTimeout(), lock.getScope(), lock.getType(), lock.getOwnerDescription(),ctx,user);
 	}
 
 	public void transferLocks(final Context ctx, final int from_user, final int to_user) throws OXException {
