@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,6 +64,7 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.cache.impl.FolderCacheNotEnabledException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
@@ -72,12 +73,10 @@ import com.openexchange.groupware.infostore.database.impl.InfostoreSecurity;
 import com.openexchange.groupware.infostore.webdav.URLCache.Type;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
-import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.server.impl.OCLPermission;
-import com.openexchange.sessiond.impl.SessionHolder;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.oxfolder.OXFolderException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
@@ -85,7 +84,9 @@ import com.openexchange.tools.oxfolder.OXFolderManager;
 import com.openexchange.tools.oxfolder.OXFolderPermissionException;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tools.session.SessionHolder;
 import com.openexchange.webdav.protocol.Protocol;
+import com.openexchange.webdav.protocol.Protocol.Property;
 import com.openexchange.webdav.protocol.WebdavCollection;
 import com.openexchange.webdav.protocol.WebdavFactory;
 import com.openexchange.webdav.protocol.WebdavLock;
@@ -93,12 +94,11 @@ import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProperty;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
-import com.openexchange.webdav.protocol.Protocol.Property;
-import com.openexchange.webdav.protocol.impl.AbstractCollection;
+import com.openexchange.webdav.protocol.helpers.AbstractCollection;
 
 public class FolderCollection extends AbstractCollection implements OXWebdavResource {
 
-	private static final Log LOG = LogFactory.getLog(FolderCollection.class);
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FolderCollection.class));
 	private final InfostoreWebdavFactory factory;
 	private WebdavPath url;
 	private final PropertyHelper propertyHelper;
@@ -111,17 +111,17 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 	private boolean loaded;
 	private final DBProvider provider;
 	private final Set<OXWebdavResource> children = new HashSet<OXWebdavResource>();
-	
+
 	private boolean loadedChildren;
 	private ArrayList<OCLPermission> overrideNewACL;
     private final InfostoreSecurity security;
 
     private final WebdavFolderAliases aliases;
-    
+
     public FolderCollection(final WebdavPath url, final InfostoreWebdavFactory factory) {
 		this(url,factory,null);
 	}
-	
+
 	public FolderCollection(final WebdavPath url, final InfostoreWebdavFactory factory, final FolderObject folder) {
 		this.url = url;
 		this.factory = factory;
@@ -158,7 +158,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			if(isPermissionException(x)) {
 			    throw new WebdavProtocolException(x, url, HttpServletResponse.SC_FORBIDDEN);
 			}
-			throw new WebdavProtocolException(x, url, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);		
+			throw new WebdavProtocolException(x, url, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 		} catch (final Exception e) {
 		    throw new WebdavProtocolException(e, url, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 		} finally {
@@ -171,10 +171,10 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			res.removedParent();
 		}
 	}
-	
+
 	private WebdavResource mergeTo(final FolderCollection to, final boolean move, final boolean overwrite) throws WebdavProtocolException {
 
-		
+
 		final int lengthUrl = getUrl().size();
 
 		for(final WebdavResource res : getChildren()) {
@@ -186,10 +186,10 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			}
 
 		}
-		
+
 		return this;
 	}
-	
+
 	@Override
 	public WebdavResource move(final WebdavPath dest, final boolean noroot, final boolean overwrite) throws WebdavProtocolException {
 		final FolderCollection coll = (FolderCollection) factory.resolveCollection(dest);
@@ -211,17 +211,17 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		loadFolder();
 		final String name = dest.name();
 		final int parentId =  ((OXWebdavResource) coll.parent()).getId();
-		
+
 
         folder.setFolderName(name);
 		folder.setParentFolderID(parentId);
-		
-		
+
+
 		invalidate();
 		factory.invalidate(url, id, Type.COLLECTION);
 		factory.invalidate(dest, id, Type.COLLECTION);
-		
-		
+
+
 		url = dest;
 		save();
 		try {
@@ -231,8 +231,8 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		}
 		return this;
 	}
-	
-	
+
+
 
 	@Override
 	public WebdavResource copy(final WebdavPath dest, final boolean noroot, final boolean overwrite) throws WebdavProtocolException {
@@ -384,7 +384,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		return lockHelper.getAllLocks();
 	}
 
-	public String getSource() throws WebdavProtocolException { 
+	public String getSource() throws WebdavProtocolException {
 		// IGNORE
 		return null;
 	}
@@ -399,7 +399,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 	public void lock(final WebdavLock lock) throws WebdavProtocolException {
 		lockHelper.addLock(lock);
 	}
-	
+
 	public void save() throws WebdavProtocolException {
 		try {
 			dumpToDB();
@@ -441,7 +441,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 	public void setExists(final boolean b) {
 		this.exists = b;
 	}
-		
+
 	private void loadFolder() throws WebdavProtocolException {
 		if(loaded) {
 			return;
@@ -458,9 +458,9 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			if(FolderCacheManager.isEnabled()) {
 				folder = FolderCacheManager.getInstance().getFolderObject(id, false, ctx, readCon); // FIXME be smarter here
 			} else {
-				
+
 				folder = FolderObject.loadFolderObjectFromDB(id, ctx, readCon);
-				
+
 			}
 		} catch (final FolderCacheNotEnabledException e) {
 			LOG.error("",e);
@@ -470,7 +470,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			provider.releaseReadConnection(ctx, readCon);
 		}
 	}
-	
+
 	private void dumpToDB() throws WebdavProtocolException {
 		//OXFolderAction oxfa = new OXFolderAction(getSession());
 		if(exists) {
@@ -482,11 +482,11 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			initParent(folder);
 			final ServerSession session = getSession();
 			final Context ctx = session.getContext();
-			
+
 			Connection writeCon = null;
-			
+
 			try {
-				
+
 				writeCon = provider.getWriteConnection(ctx);
 				final OXFolderManager oxma = OXFolderManager.getInstance(getSession(), writeCon, writeCon);
 				oxma.updateFolder(folder, true, System.currentTimeMillis());
@@ -509,12 +509,12 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			}
 			initDefaultAcl(folder);
 			initDefaultFields(folder);
-			
+
 			final ServerSession session = getSession();
 			final Context ctx = session.getContext();
-			
+
 			Connection writeCon = null;
-			
+
 			try {
 				writeCon = provider.getWriteConnection(ctx);
 				final OXFolderManager oxma = OXFolderManager.getInstance(getSession(), writeCon, writeCon);
@@ -534,9 +534,9 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 				provider.releaseWriteConnection(ctx, writeCon);
 			}
 		}
-		
+
 	}
-	
+
 	private boolean isPermissionException(final OXFolderException x) {
 		return Category.PERMISSION.equals(x.getCategory());
 	}
@@ -552,48 +552,48 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		}
         folder.removeObjectID();
     }
-	
+
 	private void initParent(final FolderObject folder) throws WebdavProtocolException{
 		try {
 			final FolderCollection parent = (FolderCollection) parent();
 			if(!parent.exists()) {
 				throw new WebdavProtocolException(getUrl(), HttpServletResponse.SC_CONFLICT);
 			}
-			folder.setParentFolderID(parent.id);	
+			folder.setParentFolderID(parent.id);
 		} catch (final ClassCastException x) {
 			throw new WebdavProtocolException(getUrl(), HttpServletResponse.SC_CONFLICT);
 		}
-		
+
 	}
 
 	private void initDefaultAcl(final FolderObject folder) throws WebdavProtocolException {
-		
+
 		final List<OCLPermission> copyPerms;
-		
+
 		if(this.overrideNewACL == null) {
 			final FolderCollection parent = (FolderCollection) parent();
 			parent.loadFolder();
 			final FolderObject parentFolder = parent.folder;
 			if(FolderObject.SYSTEM_MODULE == parentFolder.getType()) {
-			    copyPerms = Collections.emptyList(); 
+			    copyPerms = Collections.emptyList();
 			} else {
-	            copyPerms = parentFolder.getPermissions();          
+	            copyPerms = parentFolder.getPermissions();
 			}
 		} else {
 			copyPerms = this.overrideNewACL;
 		}
-		
+
 		final ArrayList<OCLPermission> newPerms = new ArrayList<OCLPermission>();
 
 		final User owner = UserStorage.getStorageUser(getSession().getUserId(), getSession().getContext());
-		
+
 		for(final OCLPermission perm : copyPerms) {
 			if(perm.getEntity() != owner.getId()){
 				newPerms.add(perm.deepClone());
-			} 
+			}
 		}
-		
-		
+
+
 		// Owner has all permissions
 		final OCLPermission perm = new OCLPermission();
 		perm.setEntity(owner.getId());
@@ -604,9 +604,9 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		perm.setDeleteObjectPermission(OCLPermission.DELETE_ALL_OBJECTS);
 		perm.setGroupPermission(false);
 		newPerms.add(perm);
-		
+
 		// All others may read and write
-		
+
 		/*OCLPermission perm2 = new OCLPermission();
 		perm2.setFolderPermission(OCLPermission.CREATE_SUB_FOLDERS);
 		perm2.setEntity(OCLPermission.ALL_GROUPS_AND_USERS);
@@ -629,17 +629,17 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 			final User user = UserStorage.getStorageUser(session.getUserId(), session.getContext());
 			final UserConfiguration userConfig = UserConfigurationStorage.getInstance().getUserConfigurationSafe(session.getUserId(), session.getContext());
 			final Context ctx = session.getContext();
-			
+
 			final SearchIterator<FolderObject> iter = OXFolderIteratorSQL.getVisibleSubfoldersIterator(id, user.getId(),user.getGroups(), ctx, userConfig, new Timestamp(0));
 			//final SearchIterator iter = OXFolderTools.getVisibleSubfoldersIterator(id, user.getId(),user.getGroups(), ctx, userConfig, new Timestamp(0));
-			
+
 
 			while(iter.hasNext()) {
 				final FolderObject folder = iter.next();
 				final WebdavPath newUrl = getUrl().dup().append(getFolderName(folder));
                 children.add(new FolderCollection(newUrl, factory, folder));
 			}
-			
+
 			//children.addAll(factory.getCollections(folder.getSubfolderIds(true, getSession().getContext())));
 			children.addAll(factory.getResourcesInFolder(this, folder.getObjectID()));
 		} catch (final Exception e) {
@@ -669,7 +669,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 	public void registerChild(final OXWebdavResource resource) {
 		children.add(resource);
 	}
-	
+
 	public void unregisterChild(final OXWebdavResource resource) {
 		children.remove(resource);
 	}
@@ -696,7 +696,7 @@ public class FolderCollection extends AbstractCollection implements OXWebdavReso
 		    throw new WebdavProtocolException(e, url, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 		}
 	}
-	
+
 	@Override
 	public String toString(){
 		return super.toString()+" :"+id;
