@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,33 +62,33 @@ import java.util.List;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
 import com.openexchange.groupware.infostore.webdav.URLCache.Type;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.TransactionException;
-import com.openexchange.sessiond.impl.SessionHolder;
+import com.openexchange.tools.session.SessionHolder;
 import com.openexchange.webdav.protocol.Protocol;
+import com.openexchange.webdav.protocol.Protocol.Property;
+import com.openexchange.webdav.protocol.Protocol.WEBDAV_METHOD;
 import com.openexchange.webdav.protocol.WebdavFactory;
 import com.openexchange.webdav.protocol.WebdavLock;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProperty;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
-import com.openexchange.webdav.protocol.Protocol.Property;
-import com.openexchange.webdav.protocol.Protocol.WEBDAV_METHOD;
-import com.openexchange.webdav.protocol.impl.AbstractCollection;
-import com.openexchange.webdav.protocol.impl.AbstractResource;
+import com.openexchange.webdav.protocol.helpers.AbstractCollection;
+import com.openexchange.webdav.protocol.helpers.AbstractResource;
 
 public class InfostoreLockNullResource extends AbstractCollection implements OXWebdavResource{
 
 	private static final WEBDAV_METHOD[] OPTIONS = {WEBDAV_METHOD.PUT, WEBDAV_METHOD.MKCOL, WEBDAV_METHOD.OPTIONS, WEBDAV_METHOD.PROPFIND, WEBDAV_METHOD.LOCK, WEBDAV_METHOD.UNLOCK, WEBDAV_METHOD.TRACE};
 
 
-	private static final Log LOG = LogFactory.getLog(InfostoreLockNullResource.class);
-	
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreLockNullResource.class));
+
+
 	private final InfostoreWebdavFactory factory;
 	private AbstractResource resource;
 	private final SessionHolder sessionHolder;
@@ -109,12 +109,12 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 		this.lockHelper = new EntityLockHelper(factory.getLockNullLockManager(), sessionHolder, resource.getUrl());
 		this.provider = factory.getProvider();
 	}
-	
+
 	public InfostoreLockNullResource(final AbstractResource resource, final InfostoreWebdavFactory factory, final int id ){
 		this(resource, factory);
 		this.setId(id);
 	}
-	
+
 	public static int findInfostoreLockNullResource(final WebdavPath url, final Connection readCon, final Context ctx) throws WebdavProtocolException {
 		PreparedStatement stmt = null;
 		ResultSet rs = null;
@@ -134,7 +134,7 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 				try {
 					stmt.close();
 				} catch (final SQLException e1) {
-					LOG.debug("",e1);		
+					LOG.debug("",e1);
 				}
 			}
 			if(rs != null) {
@@ -157,7 +157,7 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 	protected WebdavFactory getFactory() {
 		return factory;
 	}
-	
+
 	@Override
 	protected List<WebdavProperty> internalGetAllProps() throws WebdavProtocolException {
 		return Collections.emptyList();
@@ -222,7 +222,7 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 		} catch (final SQLException x) {
 		    rollback(writeCon);
             throw new WebdavProtocolException(getUrl(),HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
-		} catch (final TransactionException e) {
+		} catch (final DBPoolingException e) {
 		    rollback(writeCon);
 			throw new WebdavProtocolException(getUrl(),HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 		} finally {
@@ -349,34 +349,34 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 		// IGNORE
 	}
 
-	
+
 	@Override
 	public boolean isLockNull(){
 		return true;
 	}
-	
+
 	@Override
 	protected boolean isset(final Property p) {
 		switch(p.getId()) {
-		case Protocol.LOCKDISCOVERY : case Protocol.SUPPORTEDLOCK : case Protocol.DISPLAYNAME : 
+		case Protocol.LOCKDISCOVERY : case Protocol.SUPPORTEDLOCK : case Protocol.DISPLAYNAME :
 			return true;
 		default: return false;
 		}
 	}
-	
+
 	public void unlock(final String token) throws WebdavProtocolException {
 		lockHelper.removeLock(token);
 		if(getOwnLocks().isEmpty()) {
 			delete();
 		}
 	}
-	
+
 	@Override
 	public WEBDAV_METHOD[] getOptions(){
 		return OPTIONS;
 	}
-	
-	private void dumpToDB() throws SQLException, TransactionException {
+
+	private void dumpToDB() throws SQLException, DBPoolingException {
 		if(exists) {
 			return;
 		}
@@ -397,7 +397,7 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 		} catch (final SQLException x) {
 		    rollback(writeCon);
 			throw x;
-		} catch (final TransactionException e) {
+		} catch (final DBPoolingException e) {
 		    rollback(writeCon);
 			throw e;
 		} finally {
@@ -438,7 +438,7 @@ public class InfostoreLockNullResource extends AbstractCollection implements OXW
 
 	public void transferLock(final WebdavLock lock) {
 		// TODO Auto-generated method stub
-		
+
 	}
 
 
