@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,21 +53,21 @@ import java.util.List;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.tx.Service;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.tx.TransactionAware;
 
-public interface LockManager extends Service{
+public interface LockManager extends TransactionAware{
 	public static enum Scope {EXCLUSIVE, SHARED}
 	public static enum Type {WRITE}
-	
+
 	public static final int INFINITE = -1;
 
 	List<Lock> findLocks(int id, Context context, User userObject, UserConfiguration userConfiguration) throws OXException;
-	
+
 	void unlock(int lockId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
 
 	void removeAll(int id, Context context, User userObject, UserConfiguration userConfiguration) throws OXException;
-	
+
 	void insertLock(int entity, Lock lock, Context ctx, User user, UserConfiguration userConfig) throws OXException;
-		
+
 }
