@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,24 +58,24 @@ import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.infostore.DocumentMetadata;
-import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.session.Session;
 import com.openexchange.tools.exceptions.LoggingLogic;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tx.TransactionException;
 
 public class PropertyCleaner implements FolderEventInterface, InfostoreEventInterface {
-	
+
 	private final PropertyStore infoProperties;
 	private final PropertyStore folderProperties;
-	
+
 	private static final LoggingLogic LL = LoggingLogic.getLoggingLogic(PropertyCleaner.class);
-	private static final Log LOG = LogFactory.getLog(PropertyCleaner.class);
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PropertyCleaner.class));
+
 	public PropertyCleaner(final PropertyStore folderProperties, final PropertyStore infoProperties){
 		this.folderProperties = folderProperties;
 		this.infoProperties = infoProperties;
-		
+
 	}
 
 	public void folderCreated(final FolderObject folderObj, final Session sessionObj) {
@@ -142,7 +142,7 @@ public class PropertyCleaner implements FolderEventInterface, InfostoreEventInte
 
 	public void infoitemModified(final DocumentMetadata metadata,
 			final Session sessionObj) {
-		
+
 	}
 
 }
