@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,16 +51,25 @@ package com.openexchange.groupware.ldap;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
-import java.io.Serializable;
+import gnu.trove.ConcurrentTIntObjectHashMap;
 import java.sql.Connection;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.Dictionary;
+import java.util.HashMap;
+import java.util.Hashtable;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import com.openexchange.cache.dynamic.impl.OXObjectFactory;
+import org.osgi.framework.BundleContext;
+import org.osgi.framework.ServiceRegistration;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventConstants;
+import org.osgi.service.event.EventHandler;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
 import com.openexchange.caching.CacheKey;
@@ -69,18 +78,25 @@ import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.LdapException.Code;
+import com.openexchange.groupware.userconfiguration.UserConfigurationException;
+import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
+import com.openexchange.server.osgi.ServerActivator;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondEventConstants;
+import com.openexchange.sessiond.SessiondService;
+import com.openexchange.sessiond.SessiondServiceExtended;
 
 /**
  * This class implements the user storage using a cache to store once read
  * objects.
  */
-public class CachingUserStorage extends UserStorage {
+public class CachingUserStorage extends UserStorage implements EventHandler {
 
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(CachingUserStorage.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CachingUserStorage.class));
 
     private static final String REGION_NAME = "User";
 
@@ -90,9 +106,11 @@ public class CachingUserStorage extends UserStorage {
     private final UserStorage delegate;
 
     /**
-     * Lock for the cache.
+     * Lock map for the cache.
      */
-    private final Lock cacheLock;
+    private final ConcurrentTIntObjectHashMap<Lock> cacheLockMap;
+
+    private volatile ServiceRegistration registration;
 
     /**
      * Default constructor.
@@ -100,37 +118,71 @@ public class CachingUserStorage extends UserStorage {
     public CachingUserStorage(final UserStorage delegate) {
         super();
         this.delegate = delegate;
-        cacheLock = new ReentrantLock(true);
+        cacheLockMap = new ConcurrentTIntObjectHashMap<Lock>(1024);
+    }
+
+    public void handleEvent(final Event event) {
+        final String topic = event.getTopic();
+        if (SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic)) {
+            @SuppressWarnings("unchecked") final Map<String, Session> container = (Map<String, Session>) event.getProperty(SessiondEventConstants.PROP_CONTAINER);
+            for (final Session session : container.values()) {
+                handleRemovedSession(session);
+            }
+        } else if (SessiondEventConstants.TOPIC_REMOVE_SESSION.equals(topic)) {
+            final Session session = (Session) event.getProperty(SessiondEventConstants.PROP_SESSION);
+            handleRemovedSession(session);
+        } else if (SessiondEventConstants.TOPIC_REMOVE_CONTAINER.equals(topic)) {
+            @SuppressWarnings("unchecked") final Map<String, Session> container = (Map<String, Session>) event.getProperty(SessiondEventConstants.PROP_CONTAINER);
+            for (final Session session : container.values()) {
+                handleRemovedSession(session);
+            }
+        }
+    }
+
+    private void handleRemovedSession(final Session session) {
+        final SessiondService service = SessiondService.SERVICE_REFERENCE.get();
+        if (service instanceof SessiondServiceExtended) {
+            final SessiondServiceExtended serviceExtended = (SessiondServiceExtended) service;
+            final int contextId = session.getContextId();
+            if (!serviceExtended.hasForContext(contextId)) {
+                cacheLockMap.remove(contextId);
+            }
+        }
+    }
+
+    private Lock lockFor(final Context ctx) {
+        return lockFor(ctx.getContextId());
+    }
+
+    private Lock lockFor(final int contextId) {
+        Lock tmp = cacheLockMap.get(contextId);
+        if (null == tmp) {
+            final Lock newLock = new ReentrantLock(true);
+            tmp = cacheLockMap.putIfAbsent(contextId, newLock);
+            if (null == tmp) {
+                tmp = newLock;
+            }
+        }
+        return tmp;
     }
 
     @Override
     public User getUser(final int uid, final Context context) throws LdapException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
-        User user = delegate.getUser(uid, context);
         if (cacheService == null) {
-            return user;
+            return delegate.getUser(uid, context);
         }
         try {
-            return createProxy(context, uid, cacheService, user);
-        } catch (UserException e) {
+            return createProxy(context, uid, cacheService, null);
+        } catch (final UserException e) {
             throw new LdapException(e);
         }
     }
 
-    private User createProxy(final Context ctx, final int userId, final CacheService cacheService, User user) throws UserException {
-        final OXObjectFactory<User> factory = new OXObjectFactory<User>() {
-            public Serializable getKey() {
-                return cacheService.newCacheKey(ctx.getContextId(), userId);
-            }
-            public User load() throws LdapException {
-                return delegate.getUser(userId, ctx);
-            }
-            public Lock getCacheLock() {
-                return cacheLock;
-            }
-        };
+    private User createProxy(final Context ctx, final int userId, final CacheService cacheService, final User user) throws UserException {
+        final UserFactory factory = new UserFactory(delegate, cacheService, lockFor(ctx), ctx, userId);
         try {
-            return new UserReloader(factory, user, REGION_NAME);
+            return null == user ? new UserReloader(factory, REGION_NAME) : new UserReloader(factory, user, REGION_NAME);
         } catch (final AbstractOXException e) {
             if (e instanceof UserException) {
                 throw (UserException) e;
@@ -138,14 +190,24 @@ public class CachingUserStorage extends UserStorage {
             throw new UserException(e);
         }
     }
+    
+    @Override
+    public int createUser(final Connection con, final Context context, final User user) throws UserException {
+        return delegate.createUser(con, context, user);
+    }
+    
+    @Override
+    public int createUser(final Context context, final User user) throws UserException {
+        return delegate.createUser(context, user);
+    }
 
     @Override
-    public User getUser(final Context ctx, final int userId, Connection con) throws UserException {
+    public User getUser(final Context ctx, final int userId, final Connection con) throws UserException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
-        User user = delegate.getUser(ctx, userId, con);
         if (cacheService == null) {
-            return user;
+            return delegate.getUser(ctx, userId, con);
         }
+        final User user = delegate.getUser(ctx, userId, con);
         return createProxy(ctx, userId, cacheService, user);
     }
 
@@ -155,7 +217,7 @@ public class CachingUserStorage extends UserStorage {
     }
 
     @Override
-    public User[] getUser(final Context ctx, int[] userIds) throws UserException {
+    public User[] getUser(final Context ctx, final int[] userIds) throws UserException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
         if (cacheService == null) {
             return delegate.getUser(ctx);
@@ -163,61 +225,38 @@ public class CachingUserStorage extends UserStorage {
         final Cache cache;
         try {
             cache = cacheService.getCache(REGION_NAME);
-        } catch (CacheException e) {
+        } catch (final CacheException e) {
             throw new UserException(e);
         }
-        List<User> retval = new ArrayList<User>(userIds.length);
-        List<Integer> toLoad = new ArrayList<Integer>(userIds.length);
+        final Map<Integer, User> map = new HashMap<Integer, User>(userIds.length, 1);
+        final List<Integer> toLoad = new ArrayList<Integer>(userIds.length);
+        final Lock lock = lockFor(ctx);
         for (final int userId : userIds) {
-            OXObjectFactory<User> factory = new OXObjectFactory<User>() {
-                public Serializable getKey() {
-                    return cacheService.newCacheKey(ctx.getContextId(), userId);
-                }
-                public User load() throws LdapException {
-                    return delegate.getUser(userId, ctx);
-                }
-                public Lock getCacheLock() {
-                    return cacheLock;
-                }
-            };
-            User user = (User) cache.get(factory.getKey());
-            if (null == user) {
-                toLoad.add(I(userId));
-            } else {
+            final UserFactory factory = new UserFactory(delegate, cacheService, lock, ctx, userId);
+            final Object object = cache.get(factory.getKey());
+            if (object instanceof User) {
                 try {
-                    retval.add(new UserReloader(factory, user, REGION_NAME));
-                } catch (CacheException e) {
+                    map.put(I(userId), new UserReloader(factory, (User) object, REGION_NAME));
+                } catch (final CacheException e) {
                     throw new UserException(e);
                 }
+            } else {
+                toLoad.add(I(userId));
             }
         }
-        User[] loaded = delegate.getUser(ctx, I2i(toLoad));
+        final User[] loaded = delegate.getUser(ctx, I2i(toLoad));
         for (final User user : loaded) {
-            OXObjectFactory<User> factory = new OXObjectFactory<User>() {
-                public Serializable getKey() {
-                    return cacheService.newCacheKey(ctx.getContextId(), user.getId());
-                }
-                public User load() throws LdapException {
-                    return delegate.getUser(user.getId(), ctx);
-                }
-                public Lock getCacheLock() {
-                    return cacheLock;
-                }
-            };
-            try {
-                retval.add(new UserReloader(factory, user, REGION_NAME));
-            } catch (CacheException e) {
-                throw new UserException(e);
-            }
+            map.put(I(user.getId()), createProxy(ctx, user.getId(), cacheService, user));
+        }
+        final List<User> retval = new ArrayList<User>(userIds.length);
+        for (final int userId : userIds) {
+            retval.add(map.get(I(userId)));
         }
         return retval.toArray(new User[retval.size()]);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
-    public void updateUser(final User user, final Context context) throws LdapException {
+    public void updateUserInternal(final User user, final Context context) throws LdapException {
         delegate.updateUser(user, context);
         try {
             invalidateUser(context, user.getId());
@@ -226,9 +265,36 @@ public class CachingUserStorage extends UserStorage {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    @Override
+    public String getUserAttribute(final String name, final int userId, final Context context) throws LdapException {
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (cacheService == null) {
+            return delegate.getUserAttribute(name, userId, context);
+        }
+        final Set<String> set = getUser(userId, context).getAttributes().get(new StringBuilder("attr_").append(name).toString());
+        return null == set ? null : (set.isEmpty() ? null : set.iterator().next());
+    }
+
+    @Override
+    public void setUserAttribute(final String name, final String value, final int userId, final Context context) throws LdapException {
+        delegate.setUserAttribute(name, value, userId, context);
+        try {
+            invalidateUser(context, userId);
+        } catch (final UserException e) {
+            throw new LdapException(e);
+        }
+    }
+
+    @Override
+    public void setAttribute(final String name, final String value, final int userId, final Context context) throws LdapException {
+        delegate.setAttribute(name, value, userId, context);
+        try {
+            invalidateUser(context, userId);
+        } catch (final UserException e) {
+            throw new LdapException(e);
+        }
+    }
+
     @Override
     public int getUserId(final String uid, final Context context) throws LdapException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
@@ -267,32 +333,35 @@ public class CachingUserStorage extends UserStorage {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public int[] listModifiedUser(final Date modifiedSince, final Context context) throws LdapException {
         // Caching doesn't make any sense here.
         return delegate.listModifiedUser(modifiedSince, context);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public User searchUser(final String email, final Context context) throws LdapException {
         // Caching doesn't make any sense here.
         return delegate.searchUser(email, context);
     }
 
+    @Override
+    public User[] searchUserByMailLogin(final String login, final Context context) throws LdapException {
+        // Caching doesn't make any sense here.
+        return delegate.searchUserByMailLogin(login, context);
+    }
+
+    @Override
+    public User[] searchUserByName(final String name, final Context context, final int searchType) throws LdapException {
+        // Caching doesn't make any sense here.
+        return delegate.searchUserByName(name, context, searchType);
+    }
+
     @Override
     public int[] listAllUser(final Context ctx) throws UserException {
         return delegate.listAllUser(ctx);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public int[] resolveIMAPLogin(final String imapLogin, final Context context) throws UserException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
@@ -313,6 +382,9 @@ public class CachingUserStorage extends UserStorage {
             if (null == tmp) {
                 identifiers = delegate.resolveIMAPLogin(imapLogin, context);
                 try {
+                    if (null != cache.get(key)) {
+                        cache.remove(key);
+                    }
                     cache.put(key, identifiers);
                 } catch (final CacheException e) {
                     throw new UserException(UserException.Code.CACHE_PROBLEM, e);
@@ -326,13 +398,9 @@ public class CachingUserStorage extends UserStorage {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void invalidateUser(final Context ctx, final int userId) throws UserException {
-        final CacheService cacheService = ServerServiceRegistry.getInstance()
-            .getService(CacheService.class);
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
         if (null != cacheService) {
             try {
                 final Cache cache = cacheService.getCache(REGION_NAME);
@@ -341,16 +409,31 @@ public class CachingUserStorage extends UserStorage {
                 throw new UserException(UserException.Code.CACHE_PROBLEM, e);
             }
         }
+        try {
+            UserConfigurationStorage.getInstance().removeUserConfiguration(userId, ctx);
+        } catch (final UserConfigurationException e) {
+            // Ignore
+        }
     }
 
     @Override
-    protected void startInternal() throws UserException {
+    protected void startInternal() {
+        final BundleContext context = ServerActivator.getContext();
+        if (null != context) {
+            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
+            serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
+            registration = context.registerService(EventHandler.class.getName(), this, serviceProperties);
+        }
     }
 
     @Override
     protected void stopInternal() throws UserException {
-        final CacheService cacheService = ServerServiceRegistry.getInstance()
-            .getService(CacheService.class);
+        final ServiceRegistration registration = this.registration;
+        if (null != registration) {
+            registration.unregister();
+            this.registration = null;
+        }
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
         if (cacheService != null) {
             try {
                 cacheService.freeCache(REGION_NAME);
@@ -359,4 +442,9 @@ public class CachingUserStorage extends UserStorage {
             }
         }
     }
+
+    UserStorage getDelegate() {
+        return delegate;
+    }
+
 }
