@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -212,7 +212,38 @@ public class UserException extends AbstractOXException {
          /**
           * Attributes of user %1$d in context %2$d have been erased.
           */
-        ERASED_ATTRIBUTES("Attributes of user %1$d in context %2$d have been erased.", Category.WARNING, Detail.ERROR, 16);
+         ERASED_ATTRIBUTES("Attributes of user %1$d in context %2$d have been erased.", Category.WARNING, Detail.ERROR, 16),
+         /**
+          * Loading one or more users failed.
+          */
+         LOAD_FAILED("Loading one or more users failed.", Category.CODE_ERROR, Detail.ERROR, 17),
+         /** Alias entries are missing for user %1$d in context %2$d. */
+         ALIASES_MISSING("Alias entries are missing for user %1$d in context %2$d.", Category.SETUP_ERROR, Detail.ERROR, 18),
+         /** Updating attributes failed in context %1$d for user %2$d. */
+         UPDATE_ATTRIBUTES_FAILED("Updating attributes failed in context %1$d for user %2$d.", Category.CODE_ERROR, Detail.ERROR, 19),
+         /**
+          * Invalid password length. The password must be of minimum length %1$d.
+          */
+         INVALID_MIN_LENGTH("Invalid password length. The password must be of minimum length %1$d.", Category.USER_INPUT, Detail.ERROR, 20),
+         /**
+          * Invalid password length. The password must be of maximum length %1$d.
+          */
+         INVALID_MAX_LENGTH("Invalid password length. The password must be of maximum length %1$d.", Category.USER_INPUT, Detail.ERROR, 21),
+         /**
+          * The parameter %s for this user is missing.
+          */
+         MISSING_PARAMETER("The parameter %s for this user is missing.", Category.USER_INPUT, Detail.ERROR, 22),
+         /**
+          * %s is not a valid locale.
+          */
+         INVALID_LOCALE("%s is not a valid locale.", Category.USER_INPUT, Detail.ERROR, 23),
+         /**
+          * %s is not a valid time zone.
+          */
+         INVALID_TIMEZONE("%s is not a valid time zone.", Category.USER_INPUT, Detail.ERROR, 24)
+         
+         ;
+         
 
         /**
          * Message of the exception.
