@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.groupware.ldap;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import javax.mail.internet.IDNA;
 import com.openexchange.i18n.LocaleTools;
 
 /**
@@ -144,10 +145,14 @@ public class UserImpl implements User, Cloneable {
     private String displayName;
 
     /**
+     * TODO: userPassword had been initialized with "x" in the past. This, however
+     * does not work since we now update the password of a user in {@link RdbUserStorage}
+     *
+     * OLD comment:
      * The hashed and base64 encoded password. The default value is
      * <code>"x"</code> to cause matches fail.
      */
-    private String userPassword = "x";
+    private String userPassword = null;
 
     /**
      * Password encryption mechanism.
@@ -278,7 +283,7 @@ public class UserImpl implements User, Cloneable {
      * @param imapServer IMAP server.
      */
     void setImapServer(final String imapServer) {
-        this.imapServer = imapServer;
+        this.imapServer = imapServer == null ? null : IDNA.toUnicode(imapServer);
     }
 
     /**
@@ -293,7 +298,7 @@ public class UserImpl implements User, Cloneable {
      * @param smtpServer SMTP server.
      */
     void setSmtpServer(final String smtpServer) {
-        this.smtpServer = smtpServer;
+        this.smtpServer = smtpServer == null ? null : IDNA.toUnicode(smtpServer);
     }
 
     /**
@@ -308,7 +313,7 @@ public class UserImpl implements User, Cloneable {
      * @param mailDomain mail domain.
      */
     void setMailDomain(final String mailDomain) {
-        this.mailDomain = mailDomain;
+        this.mailDomain = mailDomain == null ? null : IDNA.toUnicode(mailDomain);
     }
 
     /**
@@ -353,7 +358,7 @@ public class UserImpl implements User, Cloneable {
      * @param mail Mail address.
      */
     void setMail(final String mail) {
-        this.mail = mail;
+        this.mail = mail == null ? mail : IDNA.toIDN(mail);
     }
 
     /**
@@ -394,7 +399,7 @@ public class UserImpl implements User, Cloneable {
     }
 
     /**
-     * Setter for preferredLanguage. The user's locale is implicitely re-set,
+     * Setter for preferredLanguage. The user's locale is implicitly re-set,
      * too.
      *
      * @param preferredLanguage
@@ -402,7 +407,7 @@ public class UserImpl implements User, Cloneable {
      */
     public void setPreferredLanguage(final String preferredLanguage) {
         this.preferredLanguage = preferredLanguage;
-        this.locale = LocaleTools.getLocale(preferredLanguage);
+        this.locale = LocaleTools.getSaneLocale(LocaleTools.getLocale(preferredLanguage));
     }
 
     /**
@@ -477,12 +482,12 @@ public class UserImpl implements User, Cloneable {
      * @param imapLogin the imapLogin to set
      */
     void setImapLogin(final String imapLogin) {
-        this.imapLogin = imapLogin;
+        this.imapLogin = imapLogin == null ? imapLogin : IDNA.toIDN(imapLogin);
     }
 
     /**
      * Gets this user's aliases.
-     * 
+     *
      * @return The aliases
      */
     public String[] getAliases() {
@@ -491,11 +496,18 @@ public class UserImpl implements User, Cloneable {
 
     /**
      * Sets this user's aliases.
-     * 
+     *
      * @param aliases The aliases to set
      */
     public void setAliases(final String[] aliases) {
-        this.aliases = aliases;
+        if (null == aliases) {
+            this.aliases = null;
+            return;
+        }
+        final String[] thisAliases = this.aliases = new String[aliases.length];
+        for (int i = 0; i < aliases.length; i++) {
+            thisAliases[i] = IDNA.toIDN(aliases[i]);
+        }
     }
 
     public Map<String, Set<String>> getAttributes() {
@@ -503,8 +515,8 @@ public class UserImpl implements User, Cloneable {
     }
 
     /**
-     * Sets the user attributes as an unmodifiable map. 
-     * 
+     * Sets the user attributes as an unmodifiable map.
+     *
      * @param attributes The attributes to set as an unmodifiable map
      */
     public void setAttributes(final Map<String, Set<String>> attributes) {
