@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,10 +52,9 @@ package com.openexchange.groupware.ldap;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
-
-import com.openexchange.cache.dynamic.impl.OXObjectFactory;
-import com.openexchange.cache.dynamic.impl.Refresher;
 import com.openexchange.caching.CacheException;
+import com.openexchange.caching.dynamic.OXObjectFactory;
+import com.openexchange.caching.dynamic.Refresher;
 import com.openexchange.groupware.AbstractOXException;
 
 /**
@@ -81,14 +80,13 @@ final class UserReloader extends Refresher<User> implements User {
      * @param regionName Name of the cache region that stores the object.
      * @throws AbstractOXException if initially loading the object fails.
      */
-    UserReloader(final OXObjectFactory<User> factory,
-        final String regionName) throws AbstractOXException {
-        super(factory, regionName);
+    UserReloader(final OXObjectFactory<User> factory, final String regionName) throws AbstractOXException {
+        super(factory, regionName, false);
         this.delegate = refresh();
     }
 
-    public UserReloader(OXObjectFactory<User> factory, User user, String regionName) throws CacheException {
-        super(factory, regionName);
+    public UserReloader(final OXObjectFactory<User> factory, final User user, final String regionName) throws CacheException {
+        super(factory, regionName, false);
         delegate = user;
         cache(user);
     }
@@ -290,7 +288,10 @@ final class UserReloader extends Refresher<User> implements User {
      */
     private void updateDelegate() throws RuntimeException {
         try {
-            this.delegate = refresh();
+            final User tmp = refresh();
+            if (null != tmp) {
+                this.delegate = tmp;
+            }
         } catch (final AbstractOXException e) {
             throw new RuntimeException(e.getMessage(), e);
         }
