@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,7 @@ import com.openexchange.server.services.ServerServiceRegistry;
  */
 public abstract class LinkableState implements State {
 
-    private static final Log LOG = LogFactory.getLog(LinkableState.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(LinkableState.class));
 
     protected static volatile Template object_link_template;
 
