@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,13 +52,14 @@ package com.openexchange.groupware.notify;
 import java.util.Locale;
 import java.util.concurrent.Delayed;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.i18n.tools.RenderMap;
 import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link PooledNotification} - Holds all necessary information about the most up-to-date object status.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PooledNotification implements Delayed {
@@ -68,7 +69,7 @@ public final class PooledNotification implements Delayed {
      */
     private static final long MSEC_DELAY = 120000l;
 
-    private volatile long stamp;
+    private final AtomicLong stamp;
 
     private final EmailableParticipant p;
 
@@ -88,7 +89,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Initializes a new {@link PooledNotification} and sets its last-accessed time stamp to now.
-     * 
+     *
      * @param p The participant to notify
      * @param title The objects's title
      * @param state The notification state
@@ -101,7 +102,7 @@ public final class PooledNotification implements Delayed {
      */
     public PooledNotification(final EmailableParticipant p, final String title, final State state, final Locale locale, final RenderMap renderMap, final ServerSession session, final CalendarObject obj) {
         super();
-        stamp = System.currentTimeMillis();
+        stamp = new AtomicLong(System.currentTimeMillis());
         this.p = p;
         this.state = state;
         this.locale = locale;
@@ -113,12 +114,12 @@ public final class PooledNotification implements Delayed {
     }
 
     public long getDelay(final TimeUnit unit) {
-        return unit.convert(MSEC_DELAY - (System.currentTimeMillis() - stamp), TimeUnit.MILLISECONDS);
+        return unit.convert(MSEC_DELAY - (System.currentTimeMillis() - stamp.get()), TimeUnit.MILLISECONDS);
     }
 
     public int compareTo(final Delayed o) {
-        final long thisStamp = this.stamp;
-        final long otherStamp = ((PooledNotification) o).stamp;
+        final long thisStamp = this.stamp.get();
+        final long otherStamp = ((PooledNotification) o).stamp.get();
         return (thisStamp < otherStamp ? -1 : (thisStamp == otherStamp ? 0 : 1));
     }
 
@@ -126,12 +127,12 @@ public final class PooledNotification implements Delayed {
      * Touches this pooled notification; meaning its last-accessed time stamp is set to now.
      */
     public void touch() {
-        stamp = System.currentTimeMillis();
+        stamp.set(System.currentTimeMillis());
     }
 
     /**
      * Merges this pooled notification with specified pooled notification.
-     * 
+     *
      * @param other The other pooled notification
      */
     public void merge(final PooledNotification other) {
@@ -143,7 +144,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Sets the title.
-     * 
+     *
      * @param title The title
      */
     public void setTitle(final String title) {
@@ -152,7 +153,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Sets the locale.
-     * 
+     *
      * @param locale The locale
      */
     public void setLocale(final Locale locale) {
@@ -161,7 +162,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Sets the state.
-     * 
+     *
      * @param state The state
      */
     public void setState(final State state) {
@@ -170,7 +171,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the participant.
-     * 
+     *
      * @return the participant
      */
     public EmailableParticipant getParticipant() {
@@ -179,7 +180,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the state.
-     * 
+     *
      * @return the state
      */
     public State getState() {
@@ -188,7 +189,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the locale.
-     * 
+     *
      * @return the locale
      */
     public Locale getLocale() {
@@ -197,7 +198,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the render map.
-     * 
+     *
      * @return the render map
      */
     public RenderMap getRenderMap() {
@@ -206,7 +207,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the title.
-     * 
+     *
      * @return the title
      */
     public String getTitle() {
@@ -215,7 +216,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the session.
-     * 
+     *
      * @return the session
      */
     public ServerSession getSession() {
@@ -224,7 +225,7 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets the calendar object.
-     * 
+     *
      * @return the calendar object
      */
     public CalendarObject getCalendarObject() {
@@ -233,16 +234,16 @@ public final class PooledNotification implements Delayed {
 
     /**
      * Gets this pooled notification's last-accessed time stamp.
-     * 
+     *
      * @return The last-accessed time stamp.
      */
     public long lastAccessed() {
-        return stamp;
+        return stamp.get();
     }
 
     /**
      * Checks if the calendar object held by this pooled notification is denoted by specified object ID and context ID.
-     * 
+     *
      * @param objectId The calendar object's ID
      * @param contextId The calendar object's context ID
      * @return <code>true</code> if the calendar object held by this pooled notification denotes the specified calendar object; otherwise
