@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -116,7 +116,15 @@ public class ReminderException extends OXException {
         /** SQL Problem: %1$s. */
         SQL_ERROR("SQL Problem: \"%1$s\"", 13, Category.CODE_ERROR),
         /** No target service is registered for module %1$d. */
-        NO_TARGET_SERVICE("No target service is registered for module %1$d.", 14, Category.CODE_ERROR);
+        NO_TARGET_SERVICE("No target service is registered for module %1$d.", 14, Category.CODE_ERROR),
+        /**
+         * Unexpected error: %1$s
+         */
+        UNEXPECTED_ERROR("Unexpected error: %1$s", 15, Category.CODE_ERROR),
+        /**
+         * Reminder identifier is missing.
+         */
+        MANDATORY_FIELD_ID("Reminder identifier is missing.", 16, Category.CODE_ERROR);
 
         /**
          * Message of the exception.
