@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,14 +69,15 @@ import com.openexchange.api2.OXException;
 import com.openexchange.api2.ReminderService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.Types;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.reminder.ReminderException.Code;
 import com.openexchange.groupware.reminder.internal.GetArisingReminder;
+import com.openexchange.groupware.reminder.internal.RemindAgain;
 import com.openexchange.groupware.reminder.internal.SQL;
 import com.openexchange.groupware.reminder.internal.TargetRegistry;
 import com.openexchange.server.impl.DBPool;
@@ -95,7 +96,7 @@ public class ReminderHandler implements ReminderService {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(ReminderHandler.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ReminderHandler.class));
 
     final Context context;
 
@@ -206,7 +207,7 @@ public class ReminderHandler implements ReminderService {
         }
     }
 
-    public void updateReminder(ReminderObject reminder, Connection con) throws ReminderException {
+    public void updateReminder(final ReminderObject reminder, final Connection con) throws ReminderException {
         isValid(reminder);
         final boolean containsId = (0 != reminder.getObjectId());
         PreparedStatement stmt = null;
@@ -236,11 +237,11 @@ public class ReminderHandler implements ReminderService {
                 stmt.setInt(pos++, reminder.getModule());
                 stmt.setInt(pos++, reminder.getUser());
             }
-            int updateCount = stmt.executeUpdate();
+            final int updateCount = stmt.executeUpdate();
             if (updateCount > 1) {
                 throw new ReminderException(Code.TOO_MANY);
             }
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new ReminderException(Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
@@ -277,7 +278,7 @@ public class ReminderHandler implements ReminderService {
             ps.setInt(++a, reminder.getObjectId());
             final int deleted = ps.executeUpdate();
             if (deleted == 0) {
-                throw new ReminderException(Code.NOT_FOUND, reminder, I(contextId));
+                throw new ReminderException(Code.NOT_FOUND, I(reminder.getObjectId()), I(contextId));
             }
             TargetRegistry.getInstance().getService(reminder.getModule()).updateTargetObject(context, writeCon, reminder.getTargetId(), reminder.getUser());
         } catch (final SQLException exc) {
@@ -329,7 +330,7 @@ public class ReminderHandler implements ReminderService {
         }
     }
 
-    public void deleteReminder(int targetId, int userId, int module, Connection con) throws OXException {
+    public void deleteReminder(final int targetId, final int userId, final int module, final Connection con) throws OXException {
         final int contextId = context.getContextId();
         if (userId == 0) {
             throw new ReminderException(Code.MANDATORY_FIELD_USER, "missing user id");
@@ -346,29 +347,29 @@ public class ReminderHandler implements ReminderService {
                 throw new ReminderException(Code.NOT_FOUND, I(targetId), I(contextId));
             }
             TargetRegistry.getInstance().getService(module).updateTargetObject(context, con, targetId, userId);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new ReminderException(Code.DELETE_EXCEPTION, e);
-        } catch (ReminderException e) {
+        } catch (final ReminderException e) {
             throw e;
-        } catch (AbstractOXException e) {
+        } catch (final AbstractOXException e) {
             throw new ReminderException(e);
         } finally {
             closeSQLStuff(stmt);
         }
     }
 
-    public void deleteReminder(int targetId, int module) throws OXMandatoryFieldException, OXConflictException, OXException {
+    public void deleteReminder(final int targetId, final int module) throws OXMandatoryFieldException, OXConflictException, OXException {
         final Connection con;
         try {
             con = DBPool.pickupWriteable(context);
-        } catch (DBPoolingException e) {
+        } catch (final DBPoolingException e) {
             throw new OXException(e);
         }
         try {
             con.setAutoCommit(false);
             deleteReminder(targetId, module, con);
             con.commit();
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             rollback(con);
             throw new ReminderException(Code.SQL_ERROR, e, e.getMessage());
         } finally {
@@ -377,7 +378,7 @@ public class ReminderHandler implements ReminderService {
         }
     }
 
-    public void deleteReminder(int targetId, int module, Connection con) throws OXException {
+    public void deleteReminder(final int targetId, final int module, final Connection con) throws OXException {
         final int contextId = context.getContextId();
         PreparedStatement stmt = null;
         try {
@@ -390,20 +391,25 @@ public class ReminderHandler implements ReminderService {
                 throw new ReminderException(Code.NOT_FOUND, I(targetId), I(contextId));
             }
             TargetRegistry.getInstance().getService(module).updateTargetObject(context, con, targetId);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new ReminderException(Code.SQL_ERROR, e, e.getMessage());
-        } catch (ReminderException e) {
+        } catch (final ReminderException e) {
             throw e;
-        } catch (AbstractOXException e) {
+        } catch (final AbstractOXException e) {
             throw new ReminderException(e);
         } finally {
             closeSQLStuff(stmt);
         }
     }
 
-    public boolean existsReminder(final int targetId, final int userId, final int module) throws OXMandatoryFieldException, OXConflictException, OXException {
+    public boolean existsReminder(final int targetId, final int userId, final int module, final Connection con) throws OXMandatoryFieldException, OXConflictException, OXException {
         try {
-            loadReminder(targetId, userId, module);
+            if (con == null) {
+                loadReminder(targetId, userId, module);
+            } else {
+                loadReminder(targetId, userId, module, con);
+            }
+
             return true;
         } catch (final ReminderException exc) {
             if (Code.NOT_FOUND.getDetailNumber() == exc.getDetailNumber()) {
@@ -413,10 +419,13 @@ public class ReminderHandler implements ReminderService {
         }
     }
 
+    public boolean existsReminder(final int targetId, final int userId, final int module) throws OXMandatoryFieldException, OXConflictException, OXException {
+        return existsReminder(targetId, userId, module, null);
+    }
+
     public ReminderObject loadReminder( final int targetId, final int userId, final int module) throws OXMandatoryFieldException, OXConflictException, OXException {
         return loadReminder(String.valueOf(targetId), userId, module);
     }
-
     public ReminderObject loadReminder( final String targetId, final int userId, final int module) throws OXMandatoryFieldException, OXConflictException, OXException {
         final Connection readCon;
         try {
@@ -432,10 +441,14 @@ public class ReminderHandler implements ReminderService {
     }
 
     public ReminderObject loadReminder( final int targetId, final int userId, final int module, final Connection readCon) throws OXMandatoryFieldException, OXConflictException, OXException {
-        return loadReminder(String.valueOf(targetId), userId, module, readCon);
+        if (readCon == null) {
+            return loadReminder(String.valueOf(targetId), userId, module);
+        } else {
+            return loadReminder(String.valueOf(targetId), userId, module, readCon);
+        }
     }
 
-    public ReminderObject loadReminder(String targetId, int userId, int module, Connection con) throws OXException {
+    public ReminderObject loadReminder(final String targetId, final int userId, final int module, final Connection con) throws OXException {
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
@@ -447,7 +460,7 @@ public class ReminderHandler implements ReminderService {
             stmt.setInt(pos++, userId);
             result = stmt.executeQuery();
             return result2Object(context, result, stmt, false);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new ReminderException(Code.LOAD_EXCEPTION, e);
         } finally {
             closeSQLStuff(result, stmt);
@@ -471,6 +484,29 @@ public class ReminderHandler implements ReminderService {
             DBPool.closeReaderSilent(context, con);
         }
     }
+    
+    public ReminderObject[] loadReminders(final int[] targetIds,
+        final int userId, final int module, final Connection connection) throws OXException {
+    Connection con = null;
+    boolean externalConnection = false;
+    try {
+        if (connection == null) {
+            con = DBPool.pickup(context);
+        } else {
+            con = connection;
+            externalConnection = true;
+        }
+    } catch (final DBPoolingException e) {
+        throw new OXException(e);
+    }
+    try {
+        return loadReminder(targetIds, userId, module, con);
+    } finally {
+        if (!externalConnection) {
+            DBPool.closeReaderSilent(context, con);
+        }
+    }
+}
 
     /**
      * This method loads the reminder for several target objects.
@@ -481,7 +517,7 @@ public class ReminderHandler implements ReminderService {
      * @return an array of found reminders.
      * @throws OXException if reading the reminder fails.
      */
-    private ReminderObject[] loadReminder(int[] targetIds, int userId, int module, Connection con) throws OXException {
+    private ReminderObject[] loadReminder(final int[] targetIds, final int userId, final int module, final Connection con) throws OXException {
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
@@ -495,7 +531,7 @@ public class ReminderHandler implements ReminderService {
             }
             result = stmt.executeQuery();
             return result2Object(result);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new ReminderException(Code.LOAD_EXCEPTION, e);
         } finally {
             closeSQLStuff(result, stmt);
@@ -509,7 +545,7 @@ public class ReminderHandler implements ReminderService {
      * @return an array of reminder objects.
      * @throws SQLException if an error occurs.
      */
-    private ReminderObject[] result2Object(ResultSet result) throws SQLException {
+    private ReminderObject[] result2Object(final ResultSet result) throws SQLException {
         final Collection<ReminderObject> retval = new LinkedList<ReminderObject>();
         while (result.next()) {
             int pos = 1;
@@ -525,7 +561,7 @@ public class ReminderHandler implements ReminderService {
                 reminder.setFolder(result.getInt(pos++));
                 reminder.setLastModified(new Date(result.getLong(pos++)));
                 retval.add(reminder);
-            } catch (SQLException e) {
+            } catch (final SQLException e) {
                 // Nothing to do here. Missed one reminder.
                 LOG.error(new ReminderException(Code.SQL_ERROR, e, e.getMessage()));
             }
@@ -534,14 +570,14 @@ public class ReminderHandler implements ReminderService {
     }
 
     public ReminderObject loadReminder( final int objectId) throws OXMandatoryFieldException, OXConflictException, OXException {
-        Connection readCon = null;
-
+        final Connection readCon;
         try {
             readCon = DBPool.pickup(context);
-
+        } catch (final DBPoolingException e) {
+            throw new OXException(e);
+        }
+        try {
             return loadReminder(objectId, readCon);
-        } catch (final DBPoolingException exc) {
-            throw new OXException(exc);
         } finally {
             DBPool.closeReaderSilent(context,readCon);
         }
@@ -566,10 +602,12 @@ public class ReminderHandler implements ReminderService {
             throw new ReminderException(Code.NOT_FOUND, I(objectId), I(contextId));
         } catch (final SQLException exc) {
             throw new OXException(EnumComponent.REMINDER, Category.CODE_ERROR, -1, "SQL Problem.", exc);
+        } finally {
+            DBUtils.closeSQLStuff(ps);
         }
     }
 
-    public static ReminderObject result2Object(Context ctx, ResultSet result, PreparedStatement stmt, boolean closeStatements) throws SQLException, ReminderException {
+    public static ReminderObject result2Object(final Context ctx, final ResultSet result, final PreparedStatement stmt, final boolean closeStatements) throws SQLException, ReminderException {
         try {
             if (result.next()) {
                 int pos = 1;
@@ -593,52 +631,91 @@ public class ReminderHandler implements ReminderService {
         }
     }
 
-    public SearchIterator<ReminderObject> listReminder(int module, int targetId) throws OXException {
+    public SearchIterator<ReminderObject> listReminder(final int module, final int targetId) throws OXException {
         final Connection con;
         try {
             con = DBPool.pickup(context);
-        } catch (DBPoolingException e) {
+        } catch (final DBPoolingException e) {
             throw new OXException(e);
         }
+        PreparedStatement ps = null;
+        ResultSet rs = null;
         try {
-            final PreparedStatement ps = con.prepareStatement(SQL.sqlListByTargetId);
+            ps = con.prepareStatement(SQL.sqlListByTargetId);
             int pos = 1;
             ps.setInt(pos++, context.getContextId());
             ps.setInt(pos++, module);
             ps.setString(pos++, String.valueOf(targetId));
-            final ResultSet rs = ps.executeQuery();
+            rs = ps.executeQuery();
             return new ReminderSearchIterator(context, ps, rs, con);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
+            DBUtils.closeSQLStuff(rs, ps);
+            DBPool.closeReaderSilent(context, con);
             throw new ReminderException(Code.SQL_ERROR, e, e.getMessage());
-        } catch (SearchIteratorException e) {
+        } catch (final SearchIteratorException e) {
+            DBUtils.closeSQLStuff(rs, ps);
+            DBPool.closeReaderSilent(context, con);
             throw new OXException(e);
         }
     }
 
-    public SearchIterator<ReminderObject> getArisingReminder(Session session, Context ctx, final User user, final Date end) throws OXException {
-        GetArisingReminder arising = new GetArisingReminder(session, ctx, user, end);
+    public SearchIterator<ReminderObject> getArisingReminder(final Session session, final Context ctx, final User user, final Date end) throws OXException {
+        final GetArisingReminder arising = new GetArisingReminder(session, ctx, user, end);
         return arising.loadWithIterator();
     }
 
-    public SearchIterator<ReminderObject> listModifiedReminder(final int userId, final Date lastModified) throws OXException {
+    public void remindAgain(final ReminderObject reminder, final Session session, final Context ctx) throws OXException {
         Connection readCon = null;
+        try {
+            readCon = DBPool.pickupWriteable(context);
+            remindAgain(reminder, session, ctx, readCon);
+        } catch (final DBPoolingException exc) {
+            throw new OXException(exc);
+        } finally {
+            DBPool.closeWriterSilent(context, readCon);
+        }
+    }
 
+    public void remindAgain(final ReminderObject reminder, final Session session, final Context ctx, final Connection writeCon) throws OXException {
+        final RemindAgain remindAgain = new RemindAgain(reminder, session, ctx, this);
+        remindAgain.remindAgain();
+        /*
+         * Update target
+         */
+        try {
+            TargetRegistry.getInstance().getService(reminder.getModule()).updateTargetObject(context, writeCon, reminder.getTargetId());
+        } catch (final AbstractOXException e) {
+            throw new ReminderException(e);
+        }
+    }
+
+    public SearchIterator<ReminderObject> listModifiedReminder(final int userId, final Date lastModified) throws OXException {
+        final Connection readCon;
         try {
             readCon = DBPool.pickup(context);
+        } catch (DBPoolingException e) {
+            throw new OXException(e);
+        }
 
-            final PreparedStatement ps = readCon.prepareStatement(SQL.sqlModified);
+        PreparedStatement ps = null;
+        ResultSet rs = null;
+        try {
+            ps = readCon.prepareStatement(SQL.sqlModified);
             ps.setInt(1, context.getContextId());
             ps.setInt(2, userId);
             ps.setTimestamp(3, new Timestamp(lastModified.getTime()));
 
-            final ResultSet rs = ps.executeQuery();
-                return new ReminderSearchIterator(context, ps, rs, readCon);
+            rs = ps.executeQuery();
+            return new ReminderSearchIterator(context, ps, rs, readCon);
         } catch (final SearchIteratorException exc) {
+            DBUtils.closeSQLStuff(rs, ps);
+            DBPool.closeReaderSilent(context, readCon);
             throw new OXException(exc);
         } catch (final SQLException exc) {
+            DBUtils.closeSQLStuff(rs, ps);
+            DBPool.closeReaderSilent(context, readCon);
             throw new OXException(EnumComponent.REMINDER, Category.CODE_ERROR, -1, "SQL Problem.", exc);
-        } catch (final DBPoolingException exc) {
-            throw new OXException(exc);
         }
     }
+
 }
