@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -126,7 +126,7 @@ class ReminderSearchIterator implements SearchIterator<ReminderObject> {
     }
 
     public int size() {
-        throw new UnsupportedOperationException("Method size() not implemented");
+        return -1;
     }
 
     public boolean hasSize() {
