@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,9 +64,9 @@ import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.reminder.ReminderException;
+import com.openexchange.groupware.reminder.ReminderException.Code;
 import com.openexchange.groupware.reminder.ReminderObject;
 import com.openexchange.groupware.reminder.ReminderStorage;
-import com.openexchange.groupware.reminder.ReminderException.Code;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
@@ -80,15 +80,15 @@ import com.openexchange.tools.iterator.SearchIterator;
  */
 public class GetArisingReminder {
 
-    private static final Log LOG = LogFactory.getLog(GetArisingReminder.class);
-    private static final ReminderStorage storage = ReminderStorage.getInstance();
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GetArisingReminder.class));
+    private static final ReminderStorage STORAGE = ReminderStorage.getInstance();
 
     private final Session session;
     private final Context ctx;
     private final User user;
     private final Date end;
 
-    public GetArisingReminder(Session session, Context ctx, User user, Date end) {
+    public GetArisingReminder(final Session session, final Context ctx, final User user, final Date end) {
         super();
         this.session = session;
         this.ctx = ctx;
@@ -97,43 +97,50 @@ public class GetArisingReminder {
     }
 
     public SearchIterator<ReminderObject> loadWithIterator() throws ReminderException {
-        ReminderObject[] reminders = storage.selectReminder(ctx, user, end);
+        ReminderObject[] reminders = STORAGE.selectReminder(ctx, user, end);
         reminders = removeAppointments(reminders);
         return new ArrayIterator<ReminderObject>(reminders);
     }
 
-    public ReminderObject[] removeAppointments(ReminderObject[] reminders) throws ReminderException {
+    public ReminderObject[] removeAppointments(final ReminderObject[] reminders) throws ReminderException {
         AppointmentSqlFactoryService factoryService;
         try {
             factoryService = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class, true);
-        } catch (ServiceException e) {
+        } catch (final ServiceException e) {
             throw new ReminderException(e);
         }
-        AppointmentSQLInterface appointmentSql = factoryService.createAppointmentSql(session);
-        List<ReminderObject> retval = new ArrayList<ReminderObject>(reminders.length);
-        for (ReminderObject reminder : reminders) {
+        final AppointmentSQLInterface appointmentSql = factoryService.createAppointmentSql(session);
+        final List<ReminderObject> retval = new ArrayList<ReminderObject>(reminders.length);
+        final Date now = new Date();
+        for (final ReminderObject reminder : reminders) {
             if (Types.APPOINTMENT == reminder.getModule()) {
                 final CalendarDataObject appointment;
                 try {
                     appointment = appointmentSql.getObjectById(reminder.getTargetId(), reminder.getFolder());
-                } catch (OXObjectNotFoundException e) {
-                    storage.deleteReminder(ctx, reminder);
+                } catch (final OXObjectNotFoundException e) {
+                    STORAGE.deleteReminder(ctx, reminder);
                     continue;
-                } catch (OXException e) {
-                    ReminderException re = new ReminderException(e);
-                    LOG.error(re.getMessage(), re);
+                } catch (final OXException e) {
+                    LOG.debug(e.getMessage(), e);
                     continue;
-                } catch (SQLException e) {
-                    ReminderException re = new ReminderException(Code.SQL_ERROR, e, e.getMessage());
-                    LOG.error(re.getMessage(), re);
+                } catch (final SQLException e) {
+                    final ReminderException re = new ReminderException(Code.SQL_ERROR, e, e.getMessage());
+                    LOG.debug(re.getMessage(), re);
                     continue;
                 }
-                if (appointment.containsUntil() && appointment.getUntil().after(new Date())) {
+                if (appointment.containsUntil() && appointment.getUntil().after(now)) {
                     retval.add(reminder);
-                } else if (appointment.getEndDate().after(new Date())) {
+                } else if (appointment.getEndDate().after(now)) {
                     retval.add(reminder);
                 } else {
-                    new DeleteReminder(ctx, reminder).perform();
+                    try {
+                        new DeleteReminder(ctx, reminder).perform();
+                    } catch (final ReminderException e) {
+                        if (ReminderException.Code.NOT_FOUND.getDetailNumber() != e.getDetailNumber()) {
+                            throw e;
+                        }
+                        // Ignore
+                    }
                 }
             } else {
                 retval.add(reminder);
@@ -141,4 +148,5 @@ public class GetArisingReminder {
         }
         return retval.toArray(new ReminderObject[retval.size()]);
     }
+
 }
