@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -108,23 +108,22 @@ public abstract class AbstractMailFuncs implements IValueHandler {
     /**
 	 * {@inheritDoc}
 	 */
-	public void writeValue(final Session session, final Context ctx, final User user,
-	    final Setting setting) throws SettingException {
-        final UserSettingMailStorage storage = UserSettingMailStorage
-            .getInstance();
-		final UserSettingMail settings;
+    public void writeValue(final Session session, final Context ctx, final User user, final Setting setting) throws SettingException {
+        final UserSettingMailStorage storage = UserSettingMailStorage.getInstance();
+        final int userId = user.getId();
+        final UserSettingMail settings;
         try {
-            settings = storage.loadUserSettingMail(user.getId(), ctx);
+            settings = storage.loadUserSettingMail(userId, ctx);
         } catch (final UserConfigurationException e) {
             throw new SettingException(e);
         }
-		setValue(settings, setting.getSingleValue().toString());
-		try {
-			storage.saveUserSettingMail(settings, user.getId(), ctx);
-		} catch (final OXException e) {
-			throw new SettingException(e);
-		}
-	}
+        setValue(settings, setting.getSingleValue().toString());
+        try {
+            storage.saveUserSettingMailBits(settings, userId, ctx);
+        } catch (final OXException e) {
+            throw new SettingException(e);
+        }
+    }
 
 	/**
 	 * @param settings
