@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,8 +57,8 @@ import com.openexchange.groupware.settings.IValueHandler;
 import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.groupware.settings.Setting;
 import com.openexchange.groupware.settings.SettingException;
-import com.openexchange.groupware.settings.SharedNode;
 import com.openexchange.groupware.settings.SettingException.Code;
+import com.openexchange.groupware.settings.SharedNode;
 
 /**
  * This class is a container for the settings tree.
@@ -66,20 +66,19 @@ import com.openexchange.groupware.settings.SettingException.Code;
  */
 public final class ConfigTree {
 
-    /**
-     * Logger.
-     */
-    private static final Log LOG = LogFactory.getLog(ConfigTree.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConfigTree.class));
+
+    private static final ConfigTree SINGLETON = new ConfigTree();
 
     /**
      * Reference to the settings tree.
      */
-    private static Setting tree;
+    private TreeSetting tree;
 
     /**
      * Set of all identifiers for the database to check for duplicate ones.
      */
-    private static Set<Integer> dbIdentifier = new HashSet<Integer>();
+    private final Set<Integer> dbIdentifier = new HashSet<Integer>();
 
     /**
      * Prevent instantiation
@@ -88,6 +87,10 @@ public final class ConfigTree {
         super();
     }
 
+    public static ConfigTree getInstance() {
+        return SINGLETON;
+    }
+
     /**
      * Resolves a path to the according setting object.
      * @param path Path to resolve.
@@ -95,10 +98,9 @@ public final class ConfigTree {
      * @throws SettingException if the path cannot be resolved to a setting
      * object.
      */
-    public static Setting getSettingByPath(final String path)
-        throws SettingException {
+    public Setting getSettingByPath(final String path) throws SettingException {
         final String[] pathParts = path.split("/");
-        return new Setting(getSettingByPath(tree, pathParts));
+        return new ValueSetting(getSettingByPath(tree, pathParts));
     }
 
     /**
@@ -121,7 +123,7 @@ public final class ConfigTree {
                 child = actual.getElement(path[0]);
             }
             if (null == child) {
-                StringBuilder sb = new StringBuilder(path[0]);
+                final StringBuilder sb = new StringBuilder(path[0]);
                 Setting parent = actual;
                 while (null != parent) {
                     sb.insert(0, '/');
@@ -135,26 +137,38 @@ public final class ConfigTree {
         return retval;
     }
 
-    /**
-     * Returns the corresponding reader for a setting.
-     * @param setting shared setting.
-     * @return the reader for the shared setting.
-     */
-    static IValueHandler getSharedValue(final Setting setting) {
-        IValueHandler retval = null;
-        if (setting.isLeaf()) {
-            retval = setting.getShared();
+    private static <T extends AbstractSetting<? extends T>> T getSettingByPath(final T actual, final String[] path) throws SettingException {
+        T retval = actual;
+        if (path.length != 0) {
+            final String[] remainingPath = new String[path.length - 1];
+            System.arraycopy(path, 1, remainingPath, 0, path.length - 1);
+            final T child;
+            if (0 == path[0].length()) {
+                child = actual;
+            } else {
+                child = actual.getElement(path[0]);
+            }
+            if (null == child) {
+                final StringBuilder sb = new StringBuilder(path[0]);
+                Setting parent = actual;
+                while (null != parent) {
+                    sb.insert(0, '/');
+                    sb.insert(0, parent.getName());
+                    parent = parent.getParent();
+                }
+                throw new SettingException(Code.UNKNOWN_PATH, sb.toString());
+            }
+            retval = getSettingByPath(child, remainingPath);
         }
         return retval;
     }
 
-    public static void addPreferencesItem(final PreferencesItemService item)
+    public void addPreferencesItem(final PreferencesItemService item)
         throws SettingException {
         addSharedValue(null, item.getPath(), item.getSharedValue());
     }
 
-    private static void addSharedValue(final Setting actual, final String[] path,
-        final IValueHandler shared) throws SettingException {
+    private void addSharedValue(final TreeSetting actual, final String[] path, final IValueHandler shared) throws SettingException {
         if (null == actual) {
             addSharedValue(tree, path, shared);
         } else if (1 == path.length) {
@@ -165,13 +179,14 @@ public final class ConfigTree {
                 }
                 dbIdentifier.add(tmp);
             }
-            addElementWithoutOverwriting(actual, new Setting(path[0], shared.getId(), shared));
+            addElementWithoutOverwriting(actual, new TreeSetting(path[0], shared.getId(), shared));
         } else {
-            Setting sub = actual.getElement(path[0]);
-            if (null == sub) {
+            TreeSetting sub = actual.getElement(path[0]);
+            if (null == actual.getElement(path[0])) {
                 final IValueHandler node = new SharedNode(path[0]);
-                sub = new Setting(path[0], node.getId(), node);
-                addElementWithoutOverwriting(actual, sub);
+                final TreeSetting toAdd = new TreeSetting(path[0], node.getId(), node);
+                addElementWithoutOverwriting(actual, toAdd);
+                sub = toAdd;
             }
             final String[] subPath = new String[path.length - 1];
             System.arraycopy(path, 1, subPath, 0, subPath.length);
@@ -179,14 +194,15 @@ public final class ConfigTree {
         }
     }
 
-    private static void addElementWithoutOverwriting(final Setting actual, final Setting subSetting) throws SettingException {
-        if(actual.getElement(subSetting.getName()) != null) {
-            throw new SettingException(Code.DUPLICATE_PATH, actual.getPath()+"/"+subSetting.getName());
+    private static void addElementWithoutOverwriting(final TreeSetting actual, final TreeSetting subSetting) throws SettingException {
+        if (actual.getElement(subSetting.getName()) != null) {
+            throw new SettingException(Code.DUPLICATE_PATH, actual.getPath() + "/" + subSetting.getName());
         }
         actual.addElement(subSetting);
+        subSetting.setParent(actual);
     }
 
-    public static void removePreferencesItem(final PreferencesItemService item) {
+    public void removePreferencesItem(final PreferencesItemService item) {
         try {
             removeSharedValue(getSettingByPath(tree, item.getPath()));
         } catch (final SettingException e) {
@@ -194,8 +210,8 @@ public final class ConfigTree {
         }
     }
 
-    private static void removeSharedValue(final Setting setting) {
-        final Setting parent = setting.getParent();
+    private void removeSharedValue(final TreeSetting setting) throws SettingException {
+        final TreeSetting parent = setting.getParent();
         parent.removeElement(setting);
         if (-1 != setting.getId()) {
             dbIdentifier.remove(Integer.valueOf(setting.getId()));
@@ -214,12 +230,15 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.CalendarNotification.class,
             com.openexchange.groupware.settings.tree.ContactID.class,
             com.openexchange.groupware.settings.tree.ContextID.class,
+            com.openexchange.groupware.settings.tree.Login.class,
+            com.openexchange.groupware.settings.tree.CookieLifetime.class,
             com.openexchange.groupware.settings.tree.CurrentTime.class,
             com.openexchange.groupware.settings.tree.FastGUI.class,
             com.openexchange.groupware.settings.tree.folder.Calendar.class,
             com.openexchange.groupware.settings.tree.folder.Contacts.class,
             com.openexchange.groupware.settings.tree.folder.Infostore.class,
             com.openexchange.groupware.settings.tree.folder.Tasks.class,
+            com.openexchange.groupware.settings.tree.folder.EASFolder.class,
             com.openexchange.groupware.settings.tree.GUI.class,
             com.openexchange.groupware.settings.tree.Identifier.class,
             com.openexchange.groupware.settings.tree.Language.class,
@@ -287,12 +306,20 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.mail.LineWrap.class,
             com.openexchange.groupware.settings.tree.modules.mail.Module.class,
             com.openexchange.groupware.settings.tree.modules.mail.PhishingHeaders.class,
+            com.openexchange.groupware.settings.tree.modules.mail.MailProtocols.class,
             com.openexchange.groupware.settings.tree.modules.mail.ReplyAllCc.class,
             com.openexchange.groupware.settings.tree.modules.mail.SendAddress.class,
             com.openexchange.groupware.settings.tree.modules.mail.SpamButton.class,
             com.openexchange.groupware.settings.tree.modules.mail.VCard.class,
             com.openexchange.groupware.settings.tree.modules.mailaccount.Module.class,
+            com.openexchange.groupware.settings.tree.modules.olox20.Active.class,
+            com.openexchange.groupware.settings.tree.modules.olox20.Module.class,
             com.openexchange.groupware.settings.tree.modules.passwordchange.Module.class,
+            com.openexchange.groupware.settings.tree.modules.passwordchange.MaxLength.class,
+            com.openexchange.groupware.settings.tree.modules.passwordchange.MinLength.class,
+            com.openexchange.groupware.settings.tree.modules.passwordchange.Regexp.class,
+            com.openexchange.groupware.settings.tree.modules.passwordchange.ShowStrength.class,
+            com.openexchange.groupware.settings.tree.modules.passwordchange.Special.class,
             com.openexchange.groupware.settings.tree.modules.personaldata.Module.class,
             com.openexchange.groupware.settings.tree.modules.personaldata.InternalUserEditEnabled.class,
             com.openexchange.groupware.settings.tree.modules.portal.GUI.class,
@@ -320,12 +347,12 @@ public final class ConfigTree {
      * Initializes the configuration tree.
      * @throws SettingException if initializing doesn't work.
      */
-    static void init() throws SettingException {
+    void init() throws SettingException {
         if (null != tree) {
             LOG.error("Duplicate initialization of configuration tree.");
             return;
         }
-        tree = new Setting("", -1, new SharedNode(""));
+        tree = new TreeSetting("", -1, new SharedNode(""));
         try {
             final Class< ? extends PreferencesItemService>[] clazzes = getClasses();
             final PreferencesItemService[] items = new PreferencesItemService[clazzes.length];
@@ -342,7 +369,7 @@ public final class ConfigTree {
         }
     }
 
-    static void stop() {
+    void stop() {
         if (null == tree) {
             LOG.error("Duplicate shutdown of configuration tree.");
             return;
