@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,32 +69,20 @@ public final class AvailableModules implements PreferencesItemService {
 
     private static final String NAME = "availableModules";
 
-    /**
-     * Default constructor.
-     */
     public AvailableModules() {
         super();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String[] getPath() {
         return new String[] { NAME };
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public IValueHandler getSharedValue() {
         return new ReadOnlyValue() {
-            public void getValue(final Session session, final Context ctx,
-                final User user, final UserConfiguration userConfig,
-                final Setting setting) throws SettingException {
-                final Setting[] modules = ConfigTree.getSettingByPath("modules")
-                    .getElements();
-                final SettingStorage sStor = SettingStorage.getInstance(session,
-                    ctx, user, userConfig);
+
+            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws SettingException {
+                final Setting[] modules = ConfigTree.getInstance().getSettingByPath("modules").getElements();
+                final SettingStorage sStor = SettingStorage.getInstance(session, ctx, user, userConfig);
                 for (final Setting module : modules) {
                     final Setting enabled = module.getElement("module");
                     if (null != enabled) {
@@ -112,7 +100,7 @@ public final class AvailableModules implements PreferencesItemService {
                         final Object tmp = module.getSingleValue();
                         // The following expression deals with string "true"
                         // and with Boolean.TRUE.
-                        if (Boolean.parseBoolean(tmp.toString())) {
+                        if (null != tmp && Boolean.parseBoolean(tmp.toString())) {
                             setting.addMultiValue(module.getName());
                         }
                     }
