@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,7 +70,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link BetaFeatures} - Configuration tree entry to enabled/disable beta features for a certain user.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class BetaFeatures implements PreferencesItemService {
@@ -89,7 +89,7 @@ public final class BetaFeatures implements PreferencesItemService {
 
     public IValueHandler getSharedValue() {
         return new AbstractUserFuncs() {
-            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) {
+            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws SettingException {
                 final Set<String> set = user.getAttributes().get(NAME);
                 if (null == set || set.isEmpty()) {
                     // Return global configuration setting for beta features
@@ -121,7 +121,7 @@ public final class BetaFeatures implements PreferencesItemService {
 
     /**
      * Gets the specified <code>boolean</code> property from configuration service.
-     * 
+     *
      * @param name The property's name
      * @param defaultValue The default <code>boolean</code> value to return if property is missing
      * @return The <code>boolean</code> value
