@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,30 +66,19 @@ import com.openexchange.session.Session;
  */
 public final class Language implements PreferencesItemService {
 
-    public static final String NAME = "language";
+    private static final String NAME = "language";
 
-    /**
-     * Default constructor.
-     */
     public Language() {
         super();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public String[] getPath() {
         return new String[] { NAME };
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public IValueHandler getSharedValue() {
         return  new AbstractUserFuncs() {
-            public void getValue(final Session session, final Context ctx,
-                final User user, final UserConfiguration userConfig,
-                final Setting setting) throws SettingException {
+            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws SettingException {
                 setting.setSingleValue(user.getPreferredLanguage());
             }
             public boolean isAvailable(final UserConfiguration userConfig) {
