@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -105,10 +105,12 @@ public class SendAddress implements PreferencesItemService {
             public void writeValue(final Session session, final Context ctx, final User user,
                 final Setting setting) throws SettingException {
                 final String newAlias = setting.getSingleValue().toString();
-                final String[] aliases = user.getAliases();
                 boolean found = false;
-                for (int i = 0; aliases != null && i < aliases.length && !found; i++) {
-                    found = aliases[i].equals(newAlias);
+                final String[] aliases = user.getAliases();
+                if (null != aliases) {
+                    for (int i = 0; !found && i < aliases.length; i++) {
+                        found = aliases[i].equals(newAlias);
+                    }
                 }
                 if (user.getMail().equals(newAlias)) {
                     found = true;
