@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -92,7 +92,7 @@ public abstract class FolderStorage {
      * @param type storage type of folder mappings.
      * @throws TaskException if an exception occurs.
      */
-    abstract void insertFolder(Context ctx, Connection con, int taskId,
+    public abstract void insertFolder(Context ctx, Connection con, int taskId,
         Set<Folder> folders, StorageType type) throws TaskException;
 
     /**
@@ -120,7 +120,7 @@ public abstract class FolderStorage {
      * @return the folder objects.
      * @throws TaskException if an exception occurs.
      */
-    abstract Set<Folder> selectFolder(Context ctx, Connection con, int taskId,
+    public abstract Set<Folder> selectFolder(Context ctx, Connection con, int taskId,
         StorageType type) throws TaskException;
 
     /**
@@ -243,7 +243,7 @@ public abstract class FolderStorage {
         throws TaskException {
         deleteFolder(ctx, con, taskId, new int[] { folderId }, type, sanityCheck);
     }
-    
+
     /**
      * Deletes task folder mappings.
      * @param ctx Context.
@@ -258,7 +258,7 @@ public abstract class FolderStorage {
         throws TaskException {
         deleteFolder(ctx, con, taskId, folders, type, true);
     }
-    
+
     /**
      * Deletes task folder mappings.
      * @param ctx Context.
@@ -307,7 +307,7 @@ public abstract class FolderStorage {
      * found entries while the second contains folder and task identifier.
      * @throws TaskException if an exception occurs.
      */
-    abstract int[][] searchFolderByUser(Context ctx, Connection readCon,
+    public abstract int[][] searchFolderByUser(Context ctx, Connection readCon,
         int userId, StorageType type) throws TaskException;
 
     /**
@@ -316,8 +316,7 @@ public abstract class FolderStorage {
      * @return the folder mapping for the user or <code>null</code> if it can't
      * be found.
      */
-    static Folder extractFolderOfUser(final Set<Folder> folders,
-        final int userId) {
+    public static Folder extractFolderOfUser(final Set<Folder> folders, final int userId) {
         Folder retval = null;
         for (final Folder folder : folders) {
             if (folder.getUser() == userId) {
