@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import java.util.Date;
 import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.database.provider.SimpleDBProvider;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.attach.AttachmentBase;
 import com.openexchange.groupware.attach.AttachmentException;
@@ -64,7 +65,6 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.tasks.TaskException.Code;
-import com.openexchange.groupware.tx.SimpleDBProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 
@@ -75,7 +75,7 @@ import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
  */
 public final class GetTask {
 
-    private static final Log LOG = LogFactory.getLog(GetTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GetTask.class));
 
     private final Context ctx;
 
