@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.groupware.tasks;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.lang.reflect.ParameterizedType;
 import java.lang.reflect.Type;
 import java.sql.PreparedStatement;
@@ -65,7 +66,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
 import com.openexchange.groupware.tasks.mapping.ActualCosts;
 import com.openexchange.groupware.tasks.mapping.ActualDuration;
 import com.openexchange.groupware.tasks.mapping.ObjectID;
@@ -73,10 +73,10 @@ import com.openexchange.groupware.tasks.mapping.RecurrenceCount;
 import com.openexchange.groupware.tasks.mapping.Status;
 import com.openexchange.groupware.tasks.mapping.TargetCosts;
 import com.openexchange.groupware.tasks.mapping.TargetDuration;
+import com.openexchange.groupware.tasks.mapping.UID;
 
 /**
- * This class contains the methods for mapping object attributes to database+
- * columns and vice versa.
+ * This class contains the methods for mapping object attributes to database columns and vice versa.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class Mapping {
@@ -92,6 +92,7 @@ public final class Mapping {
      * Mapping array for all object attributes.
      */
     public static final Mapper<? extends Object>[] MAPPERS = new Mapper<?>[] {
+        UID.SINGLETON,
         new Mapper<Boolean>() {
             public int getId() {
                 return Task.PRIVATE_FLAG;
@@ -988,7 +989,7 @@ public final class Mapping {
      * @return the mapper implementation for the given attribute.
      */
     public static Mapper<?> getMapping(final int attributeId) {
-        return ID_MAPPING.get(Integer.valueOf(attributeId));
+        return ID_MAPPING.get(I(attributeId));
     }
     /**
      * returns all known field mappers
