@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,9 +56,8 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
-
+import java.util.Set;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.tasks.TaskException.Code;
@@ -67,15 +66,15 @@ import com.openexchange.server.impl.DBPool;
 
 /**
  * Interface to different SQL implementations for storing task participants.
+ * 
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-abstract class ParticipantStorage {
+public abstract class ParticipantStorage {
 
     /**
      * Singleton attribute.
      */
-    private static final ParticipantStorage SINGLETON =
-        new RdbParticipantStorage();
+    private static final ParticipantStorage SINGLETON = new RdbParticipantStorage();
 
     /**
      * Prevent instantiation
@@ -93,20 +92,19 @@ abstract class ParticipantStorage {
 
     /**
      * Reads the internal participants of some tasks.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param tasks unique identifier of tasks.
      * @param type type of participant that should be selected.
-     * @return a map with the task identifier as key and a set of internal
-     * participants as value.
+     * @return a map with the task identifier as key and a set of internal participants as value.
      * @throws TaskException if an error occurs.
      */
-    protected abstract Map<Integer, Set<InternalParticipant>>
-        selectInternal(Context ctx, Connection con, int[] tasks,
-        StorageType type) throws TaskException;
+    protected abstract Map<Integer, Set<InternalParticipant>> selectInternal(Context ctx, Connection con, int[] tasks, StorageType type) throws TaskException;
 
     /**
      * Reads the internal participants of a task.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param taskId unique identifier of the task.
@@ -114,11 +112,8 @@ abstract class ParticipantStorage {
      * @return a set of participants.
      * @throws TaskException if an error occurs.
      */
-    final Set<InternalParticipant> selectInternal(final Context ctx,
-        final Connection con, final int taskId, final StorageType type)
-        throws TaskException {
-        Set<InternalParticipant> parts = selectInternal(ctx, con,
-            new int[] { taskId }, type).get(Integer.valueOf(taskId));
+    final Set<InternalParticipant> selectInternal(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
+        Set<InternalParticipant> parts = selectInternal(ctx, con, new int[] { taskId }, type).get(Integer.valueOf(taskId));
         if (null == parts) {
             parts = Collections.emptySet();
         }
@@ -127,32 +122,28 @@ abstract class ParticipantStorage {
 
     /**
      * Reads a single internal participant.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param taskId unique identifier of the task.
      * @param userId unique identifier of the user.
      * @return a {@link InternalParticipant} object.
-     * @throws TaskException if an error occurs of the participant doesnot
-     * exist.
+     * @throws TaskException if an error occurs of the participant doesnot exist.
      */
-    final InternalParticipant selectInternal(final Context ctx,
-        final Connection con, final int taskId, final int userId,
-        final StorageType type) throws TaskException {
+    final InternalParticipant selectInternal(final Context ctx, final Connection con, final int taskId, final int userId, final StorageType type) throws TaskException {
         return getParticipant(selectInternal(ctx, con, taskId, type), userId);
     }
 
     /**
      * Reads a single internal participant.
+     * 
      * @param ctx Context.
      * @param taskId unique identifier of the task.
      * @param userId unique identifier of the user.
      * @return a {@link InternalParticipant} object.
-     * @throws TaskException if an error occurs of the participant doesnot
-     * exist.
+     * @throws TaskException if an error occurs of the participant doesnot exist.
      */
-    final InternalParticipant selectInternal(final Context ctx,
-        final int taskId, final int userId, final StorageType type)
-        throws TaskException {
+    final InternalParticipant selectInternal(final Context ctx, final int taskId, final int userId, final StorageType type) throws TaskException {
         final Connection con;
         try {
             con = DBPool.pickup(ctx);
@@ -167,9 +158,9 @@ abstract class ParticipantStorage {
     }
 
     /**
-     * Updates a set of internal participants. This method only updates the
-     * fields group, confirmation status and confirmation message. This method
-     * does not insert new participants or removes participants.
+     * Updates a set of internal participants. This method only updates the fields group, confirmation status and confirmation message. This
+     * method does not insert new participants or removes participants.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
@@ -177,66 +168,54 @@ abstract class ParticipantStorage {
      * @param type storage type of participants that should be updated.
      * @throws TaskException if an error occurs.
      */
-    abstract void updateInternal(Context ctx, Connection con, int taskId,
-        Set<InternalParticipant> participants, StorageType type)
-        throws TaskException;
+    abstract void updateInternal(Context ctx, Connection con, int taskId, Set<InternalParticipant> participants, StorageType type) throws TaskException;
 
-    final void updateInternal(final Context ctx, final Connection con,
-        final int taskId, final InternalParticipant participant,
-        final StorageType type) throws TaskException {
-        final Set<InternalParticipant> participants =
-            new HashSet<InternalParticipant>(1, 1f);
+    final void updateInternal(final Context ctx, final Connection con, final int taskId, final InternalParticipant participant, final StorageType type) throws TaskException {
+        final Set<InternalParticipant> participants = new HashSet<InternalParticipant>(1, 1f);
         participants.add(participant);
         updateInternal(ctx, con, taskId, participants, type);
     }
 
     /**
      * Deletes internal participants of a task.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
      * @param users unique identifier of the internal participants.
      * @param type storage type of participants that should be deleted.
-     * @param check <code>true</code> enables check if all given users are
-     * deleted.
-     * @throws TaskException if an exception occurs or less than the given users
-     * are deleted and the check is enabled.
+     * @param check <code>true</code> enables check if all given users are deleted.
+     * @throws TaskException if an exception occurs or less than the given users are deleted and the check is enabled.
      */
-    abstract void deleteInternal(Context ctx, Connection con, int taskId,
-        int[] users, StorageType type, boolean check) throws TaskException;
+    abstract void deleteInternal(Context ctx, Connection con, int taskId, int[] users, StorageType type, boolean check) throws TaskException;
 
     /**
      * Deletes an internal participant of a task.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
      * @param userId unique identifier of the internal participant.
      * @param type storage type of participant that should be deleted.
      * @param check <code>true</code> enables check if the entry is deleted.
-     * @throws TaskException if an exception occurs or less than the given users
-     * are deleted and the check is enabled.
+     * @throws TaskException if an exception occurs or less than the given users are deleted and the check is enabled.
      */
-    final void deleteInternal(final Context ctx, final Connection con,
-        final int taskId, final int userId, final StorageType type,
-        final boolean check) throws TaskException {
+    final void deleteInternal(final Context ctx, final Connection con, final int taskId, final int userId, final StorageType type, final boolean check) throws TaskException {
         deleteInternal(ctx, con, taskId, new int[] { userId }, type, check);
     }
 
     /**
      * Deletes internal participants of a task.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
      * @param parts set of internal task participants.
      * @param type storage type of participants that should be deleted.
-     * @param check <code>true</code> enables check if all given users are
-     * deleted.
-     * @throws TaskException if an exception occurs or less than the given users
-     * are deleted and the check is enabled.
+     * @param check <code>true</code> enables check if all given users are deleted.
+     * @throws TaskException if an exception occurs or less than the given users are deleted and the check is enabled.
      */
-    final void deleteInternal(final Context ctx, final Connection con,
-        final int taskId, final Set<InternalParticipant> parts,
-        final StorageType type, final boolean check) throws TaskException {
+    final void deleteInternal(final Context ctx, final Connection con, final int taskId, final Set<InternalParticipant> parts, final StorageType type, final boolean check) throws TaskException {
         final int[] partIds = new int[parts.size()];
         final Iterator<InternalParticipant> iter = parts.iterator();
         for (int i = 0; i < partIds.length; i++) {
@@ -247,6 +226,7 @@ abstract class ParticipantStorage {
 
     /**
      * Finds all tasks in a context with the group as participant.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param groupId unique identifier of the group.
@@ -254,11 +234,11 @@ abstract class ParticipantStorage {
      * @return a list of task identifier.
      * @throws TaskException if an error occurs.
      */
-    abstract int[] findTasksWithGroup(Context ctx, Connection con,
-        int groupId, StorageType type) throws TaskException;
+    abstract int[] findTasksWithGroup(Context ctx, Connection con, int groupId, StorageType type) throws TaskException;
 
     /**
      * Finds all tasks with the user as participant.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param userId unique identifier of the user.
@@ -266,25 +246,23 @@ abstract class ParticipantStorage {
      * @return an int array with all tasks identifier found.
      * @throws TaskException if an exception occurs.
      */
-    abstract int[] findTasksWithParticipant(Context ctx, Connection con,
-        int userId, StorageType type) throws TaskException;
+    abstract int[] findTasksWithParticipant(Context ctx, Connection con, int userId, StorageType type) throws TaskException;
 
     /**
      * Reads the internal participants of some tasks.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param tasks unique identifier of tasks.
      * @param type type of participant that should be selected.
-     * @return a map with the task identifier as key and a set of internal
-     * participants as value.
+     * @return a map with the task identifier as key and a set of internal participants as value.
      * @throws TaskException if an error occurs.
      */
-    protected abstract Map<Integer, Set<ExternalParticipant>>
-        selectExternal(Context ctx, Connection con, int[] tasks,
-            StorageType type) throws TaskException;
+    protected abstract Map<Integer, Set<ExternalParticipant>> selectExternal(Context ctx, Connection con, int[] tasks, StorageType type) throws TaskException;
 
     /**
      * Reads the external participants of a task.
+     * 
      * @param ctx Context.
      * @param con readable database connection.
      * @param taskId unique identifier of the task.
@@ -292,11 +270,8 @@ abstract class ParticipantStorage {
      * @return a set of participants.
      * @throws TaskException if an exception occurs.
      */
-    final Set<ExternalParticipant> selectExternal(final Context ctx,
-        final Connection con, final int taskId, final StorageType type)
-        throws TaskException {
-        Set<ExternalParticipant> parts = selectExternal(ctx, con,
-            new int[] { taskId }, type).get(Integer.valueOf(taskId));
+    final Set<ExternalParticipant> selectExternal(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
+        Set<ExternalParticipant> parts = selectExternal(ctx, con, new int[] { taskId }, type).get(Integer.valueOf(taskId));
         if (null == parts) {
             parts = Collections.emptySet();
         }
@@ -305,59 +280,48 @@ abstract class ParticipantStorage {
 
     /**
      * Deletes external participants of a task.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
      * @param addresses email addresses of external participants.
      * @param type storage type of participants that should be deleted.
-     * @param check <code>true</code> enables check if all given addresses are
-     * deleted.
-     * @throws TaskException if an exception occurs or less than the given
-     * addresses are deleted and the check is enabled.
+     * @param check <code>true</code> enables check if all given addresses are deleted.
+     * @throws TaskException if an exception occurs or less than the given addresses are deleted and the check is enabled.
      */
-    abstract void deleteExternal(Context ctx, Connection con, int taskId,
-        String[] addresses, StorageType type, boolean check)
-        throws TaskException;
+    abstract void deleteExternal(Context ctx, Connection con, int taskId, String[] addresses, StorageType type, boolean check) throws TaskException;
 
     /**
      * Deletes participants.
+     * 
      * @param ctx Context.
      * @param con writable connection.
      * @param taskId unique identifier of the task.
      * @param participants participants to delete.
      * @param type type of participants to delete.
-     * @param sanityCheck if <code>true</code> it will be checked if all given
-     * participants have been deleted.
+     * @param sanityCheck if <code>true</code> it will be checked if all given participants have been deleted.
      * @throws SQLException if a SQL error occurs.
      */
-    void deleteParticipants(final Context ctx, final Connection con,
-        final int taskId, final Set<TaskParticipant> participants,
-        final StorageType type, final boolean sanityCheck)
-        throws TaskException {
+    void deleteParticipants(final Context ctx, final Connection con, final int taskId, final Set<TaskParticipant> participants, final StorageType type, final boolean sanityCheck) throws TaskException {
         if (null == participants || participants.size() == 0) {
             return;
         }
-        deleteInternal(ctx, con, taskId, ParticipantStorage.extractInternal(participants),
-            type, sanityCheck);
-        deleteExternal(ctx, con, taskId, ParticipantStorage.extractExternal(participants),
-            type, sanityCheck);
+        deleteInternal(ctx, con, taskId, ParticipantStorage.extractInternal(participants), type, sanityCheck);
+        deleteExternal(ctx, con, taskId, ParticipantStorage.extractExternal(participants), type, sanityCheck);
     }
 
     /**
      * Deletes external participants of a task.
+     * 
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task.
      * @param parts set of external participants.
      * @param type storage type of participants that should be deleted.
-     * @param check <code>true</code> enables check if all given addresses are
-     * deleted.
-     * @throws TaskException if an exception occurs or less than the given
-     * addresses are deleted and the check is enabled.
+     * @param check <code>true</code> enables check if all given addresses are deleted.
+     * @throws TaskException if an exception occurs or less than the given addresses are deleted and the check is enabled.
      */
-    final void deleteExternal(final Context ctx, final Connection con,
-        final int taskId, final Set<ExternalParticipant> parts,
-        final StorageType type, final boolean check) throws TaskException {
+    final void deleteExternal(final Context ctx, final Connection con, final int taskId, final Set<ExternalParticipant> parts, final StorageType type, final boolean check) throws TaskException {
         final String[] addresses = new String[parts.size()];
         final Iterator<ExternalParticipant> iter = parts.iterator();
         for (int i = 0; i < addresses.length; i++) {
@@ -368,14 +332,14 @@ abstract class ParticipantStorage {
 
     /**
      * Reads the participants of a task.
+     * 
      * @param ctx Context.
      * @param taskId unique identifier of the task.
      * @param type type of participant that should be selected.
      * @return a set of participants.
      * @throws TaskException if an exception occurs.
      */
-    final Set<TaskParticipant> selectParticipants(final Context ctx,
-        final int taskId, final StorageType type) throws TaskException {
+    public final Set<TaskParticipant> selectParticipants(final Context ctx, final int taskId, final StorageType type) throws TaskException {
         final Connection con;
         try {
             con = DBPool.pickup(ctx);
@@ -391,6 +355,7 @@ abstract class ParticipantStorage {
 
     /**
      * Reads the participants of a task.
+     * 
      * @param ctx Context.
      * @param con read only database connection.
      * @param taskId unique identifier of the task.
@@ -398,9 +363,7 @@ abstract class ParticipantStorage {
      * @return a set of participants.
      * @throws TaskException if an exception occurs.
      */
-    final Set<TaskParticipant> selectParticipants(final Context ctx,
-        final Connection con, final int taskId, final StorageType type)
-        throws TaskException {
+    final Set<TaskParticipant> selectParticipants(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
         final Set<TaskParticipant> retval = new HashSet<TaskParticipant>();
         retval.addAll(selectInternal(ctx, con, taskId, type));
         retval.addAll(selectExternal(ctx, con, taskId, type));
@@ -409,17 +372,15 @@ abstract class ParticipantStorage {
 
     /**
      * Reads the participants of several task.
+     * 
      * @param ctx Context.
      * @param tasks unique identifier of the tasks.
      * @param type type of participant that should be selected.
-     * @return a map with the task identifier as the key and a set of
-     * participants as values. If for a task no participants are found no entry
-     * exists in this map.
+     * @return a map with the task identifier as the key and a set of participants as values. If for a task no participants are found no
+     *         entry exists in this map.
      * @throws TaskException if an exception occurs.
      */
-    final Map<Integer, Set<TaskParticipant>> selectParticipants(
-        final Context ctx, final int[] tasks, final StorageType type)
-        throws TaskException {
+    final Map<Integer, Set<TaskParticipant>> selectParticipants(final Context ctx, final int[] tasks, final StorageType type) throws TaskException {
         final Connection con;
         try {
             con = DBPool.pickup(ctx);
@@ -434,10 +395,8 @@ abstract class ParticipantStorage {
         } finally {
             DBPool.closeReaderSilent(ctx, con);
         }
-        final Map<Integer, Set<TaskParticipant>> retval =
-            new HashMap<Integer, Set<TaskParticipant>>();
-        for (final Entry<Integer, Set<InternalParticipant>> entry : internals
-            .entrySet()) {
+        final Map<Integer, Set<TaskParticipant>> retval = new HashMap<Integer, Set<TaskParticipant>>();
+        for (final Entry<Integer, Set<InternalParticipant>> entry : internals.entrySet()) {
             Set<TaskParticipant> parts = retval.get(entry.getKey());
             if (null == parts) {
                 parts = new HashSet<TaskParticipant>();
@@ -445,8 +404,7 @@ abstract class ParticipantStorage {
             }
             parts.addAll(entry.getValue());
         }
-        for (final Entry<Integer, Set<ExternalParticipant>> entry : externals
-            .entrySet()) {
+        for (final Entry<Integer, Set<ExternalParticipant>> entry : externals.entrySet()) {
             Set<TaskParticipant> parts = retval.get(entry.getKey());
             if (null == parts) {
                 parts = new HashSet<TaskParticipant>();
@@ -457,29 +415,55 @@ abstract class ParticipantStorage {
         return retval;
     }
 
-    void insertParticipants(final Context ctx, final Connection con,
-        final int taskId, final Set<TaskParticipant> participants,
-        final StorageType type) throws TaskException {
-        final Set<InternalParticipant> internals =
-            ParticipantStorage.extractInternal(participants);
-        final Set<ExternalParticipant> externals =
-            ParticipantStorage.extractExternal(participants);
+    /**
+     * Reads the participants of several task.
+     * 
+     * @param ctx Context.
+     * @param tasks unique identifier of the tasks.
+     * @param type type of participant that should be selected.
+     * @param con Connection to database
+     * @return a map with the task identifier as the key and a set of participants as values. If for a task no participants are found no
+     *         entry exists in this map.
+     * @throws TaskException if an exception occurs.
+     */
+    final Map<Integer, Set<TaskParticipant>> selectParticipants(final Context ctx, final int[] tasks, final StorageType type, final Connection con) throws TaskException {
+        final Map<Integer, Set<InternalParticipant>> internals;
+        final Map<Integer, Set<ExternalParticipant>> externals;
+        internals = selectInternal(ctx, con, tasks, type);
+        externals = selectExternal(ctx, con, tasks, type);
+        final Map<Integer, Set<TaskParticipant>> retval = new HashMap<Integer, Set<TaskParticipant>>();
+        for (final Entry<Integer, Set<InternalParticipant>> entry : internals.entrySet()) {
+            Set<TaskParticipant> parts = retval.get(entry.getKey());
+            if (null == parts) {
+                parts = new HashSet<TaskParticipant>();
+                retval.put(entry.getKey(), parts);
+            }
+            parts.addAll(entry.getValue());
+        }
+        for (final Entry<Integer, Set<ExternalParticipant>> entry : externals.entrySet()) {
+            Set<TaskParticipant> parts = retval.get(entry.getKey());
+            if (null == parts) {
+                parts = new HashSet<TaskParticipant>();
+                retval.put(entry.getKey(), parts);
+            }
+            parts.addAll(entry.getValue());
+        }
+        return retval;
+    }
+
+    void insertParticipants(final Context ctx, final Connection con, final int taskId, final Set<TaskParticipant> participants, final StorageType type) throws TaskException {
+        Set<InternalParticipant> internals = extractInternal(participants);
+        Set<ExternalParticipant> externals = extractExternal(participants);
         insertInternals(ctx, con, taskId, internals, type);
         insertExternals(ctx, con, taskId, externals, type);
     }
 
-    abstract void insertInternals(Context ctx, Connection con, int taskId,
-        Set<InternalParticipant> participants, StorageType type)
-        throws TaskException;
+    public abstract void insertInternals(Context ctx, Connection con, int taskId, Set<InternalParticipant> participants, StorageType type) throws TaskException;
 
-    abstract void insertExternals(Context ctx, Connection con, int taskId,
-        Set<ExternalParticipant> participants, StorageType type)
-        throws TaskException;
+    public abstract void insertExternals(Context ctx, Connection con, int taskId, Set<ExternalParticipant> participants, StorageType type) throws TaskException;
 
-    static Set<ExternalParticipant> extractExternal(
-        final Set<TaskParticipant> participants) {
-        final Set<ExternalParticipant> retval =
-            new HashSet<ExternalParticipant>();
+    public final static Set<ExternalParticipant> extractExternal(final Set<TaskParticipant> participants) {
+        Set<ExternalParticipant> retval = new HashSet<ExternalParticipant>();
         for (final TaskParticipant participant : participants) {
             if (Type.EXTERNAL == participant.getType()) {
                 retval.add((ExternalParticipant) participant);
@@ -488,10 +472,8 @@ abstract class ParticipantStorage {
         return retval;
     }
 
-    static Set<InternalParticipant> extractInternal(
-        final Set<TaskParticipant> participants) {
-        final Set<InternalParticipant> retval =
-            new HashSet<InternalParticipant>();
+    public static Set<InternalParticipant> extractInternal(final Set<TaskParticipant> participants) {
+        final Set<InternalParticipant> retval = new HashSet<InternalParticipant>();
         for (final TaskParticipant participant : participants) {
             if (Type.INTERNAL == participant.getType()) {
                 retval.add((InternalParticipant) participant);
@@ -500,8 +482,7 @@ abstract class ParticipantStorage {
         return retval;
     }
 
-    static InternalParticipant getParticipant(
-        final Set<InternalParticipant> participants, final int userId) {
+    static InternalParticipant getParticipant(final Set<InternalParticipant> participants, final int userId) {
         InternalParticipant retval = null;
         for (final InternalParticipant participant : participants) {
             if (participant.getIdentifier() == userId) {
