@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,7 +69,7 @@ final class PreRead<T> {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(PreRead.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PreRead.class));
 
     /**
      * What is the minimum count of tasks for additional sub requests.
