@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,7 +81,7 @@ public class RdbFolderStorage extends FolderStorage {
      * {@inheritDoc}
      */
     @Override
-    void insertFolder(final Context ctx, final Connection con,
+    public void insertFolder(final Context ctx, final Connection con,
         final int taskId, final Set<Folder> folders, final StorageType type)
         throws TaskException {
         PreparedStatement stmt = null;
@@ -108,7 +108,7 @@ public class RdbFolderStorage extends FolderStorage {
      * {@inheritDoc}
      */
     @Override
-    Set<Folder> selectFolder(final Context ctx, final Connection con,
+    public Set<Folder> selectFolder(final Context ctx, final Connection con,
         final int taskId, final StorageType type) throws TaskException {
         PreparedStatement stmt = null;
         ResultSet result = null;
@@ -245,7 +245,7 @@ public class RdbFolderStorage extends FolderStorage {
      * {@inheritDoc}
      */
     @Override
-    int[][] searchFolderByUser(final Context ctx, final Connection con,
+    public int[][] searchFolderByUser(final Context ctx, final Connection con,
         final int userId, final StorageType type) throws TaskException {
         PreparedStatement stmt = null;
         ResultSet result = null;
