@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,7 +81,7 @@ public class RdbParticipantStorage extends ParticipantStorage {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(RdbParticipantStorage.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(RdbParticipantStorage.class));
 
     /**
      * Default constructor.
@@ -159,6 +159,7 @@ public class RdbParticipantStorage extends ParticipantStorage {
         final StorageType type) throws TaskException {
         PreparedStatement stmt = null;
         try {
+            // UPDATE table SET group_id=?, accepted=?, description=? WHERE cid=? AND task=? AND user=?
             stmt = con.prepareStatement(SQL.UPDATE_PARTS.get(type));
             for (final InternalParticipant participant : participants) {
                 int pos = 1;
@@ -361,7 +362,7 @@ public class RdbParticipantStorage extends ParticipantStorage {
      * {@inheritDoc}
      */
     @Override
-    void insertExternals(final Context ctx, final Connection con,
+    public void insertExternals(final Context ctx, final Connection con,
         final int taskId, final Set<ExternalParticipant> participants,
         final StorageType type) throws TaskException {
         if (0 == participants.size() || StorageType.REMOVED == type) {
@@ -411,7 +412,7 @@ public class RdbParticipantStorage extends ParticipantStorage {
         for (int i = 0; i < fields.length; i++) {
             sFields.append(fields[i]);
             sFields.append(", ");
-            tmp = 0; 
+            tmp = 0;
             try {
                 tmp = DBUtils.getColumnSize(con, SQL.EPARTS_TABLES.get(type),
                     fields[i]);
@@ -452,12 +453,12 @@ public class RdbParticipantStorage extends ParticipantStorage {
         }
         return tske;
     }
-    
+
     /**
      * {@inheritDoc}
      */
     @Override
-    void insertInternals(final Context ctx, final Connection con,
+    public void insertInternals(final Context ctx, final Connection con,
         final int taskId, final Set<InternalParticipant> participants,
         final StorageType type) throws TaskException {
         if (0 == participants.size()) {
