@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -78,12 +78,12 @@ import com.openexchange.tools.sql.DBUtils;
 /**
  * This class implementes the storage methods for tasks using a relational database. The used SQL is currently optimized for MySQL. Maybe
  * other databases need SQL optimized in another way.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public class RdbTaskStorage extends TaskStorage {
 
-    static final Log LOG = LogFactory.getLog(RdbTaskStorage.class);
+    static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(RdbTaskStorage.class));
 
     /**
      * This SQL statement counts the tasks in a folder. TODO Move to {@link SQL} class.
@@ -133,7 +133,7 @@ public class RdbTaskStorage extends TaskStorage {
 
     /**
      * Deletes a task from the given table.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param taskId unique identifier of the task to delete.
@@ -144,7 +144,7 @@ public class RdbTaskStorage extends TaskStorage {
      *             sanityCheck is <code>true</code>.
      */
     @Override
-    void delete(final Context ctx, final Connection con, final int taskId, final Date lastRead, final StorageType type, final boolean sanityCheck) throws TaskException {
+    public void delete(final Context ctx, final Connection con, final int taskId, final Date lastRead, final StorageType type, final boolean sanityCheck) throws TaskException {
         final String sql = "DELETE FROM @table@ WHERE cid=? AND id=? AND last_modified<=?";
         PreparedStatement stmt = null;
         try {
@@ -174,11 +174,8 @@ public class RdbTaskStorage extends TaskStorage {
         return number;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
-    TaskIterator list(final Context ctx, final int folderId, final int from, final int to, final int orderBy, final Order order, final int[] columns, final boolean onlyOwn, final int userId, final boolean noPrivate) throws TaskException {
+    public TaskIterator list(final Context ctx, final int folderId, final int from, final int to, final int orderBy, final Order order, final int[] columns, final boolean onlyOwn, final int userId, final boolean noPrivate) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(SQL.getFields(columns, false));
@@ -204,12 +201,48 @@ public class RdbTaskStorage extends TaskStorage {
             }
         }, folderId, columns, ACTIVE);
     }
+    
+    @Override
+    public TaskIterator list(final Context ctx, final int folderId, final int from, final int to, final int orderBy, final Order order, final int[] columns, final boolean onlyOwn, final int userId, final boolean noPrivate, final Connection con) throws TaskException {
+        if (con == null) {
+            return list(ctx, folderId, from, to, orderBy, order, columns, onlyOwn, userId, noPrivate);
+        } else {
+            final StringBuilder sql = new StringBuilder();
+            sql.append("SELECT ");
+            sql.append(SQL.getFields(columns, false));
+            sql.append(" FROM task JOIN task_folder USING (cid,id) ");
+            if (folderId != -1) {
+                sql.append("WHERE task.cid=? AND task_folder.folder=?");
+            } else {
+                sql.append("WHERE task.cid=?");
+            }
+            if (onlyOwn) {
+                sql.append(ONLY_OWN);
+            }
+            if (noPrivate) {
+                sql.append(NO_PRIVATE);
+            }
+            sql.append(SQL.getOrder(orderBy, order));
+            sql.append(SQL.getLimit(from, to));
+            return new TaskIterator2(ctx, userId, sql.toString(), new StatementSetter() {
+
+                public void perform(final PreparedStatement stmt) throws SQLException {
+                    int pos = 1;
+                    stmt.setInt(pos++, ctx.getContextId());
+                    stmt.setInt(pos++, folderId);
+                    if (onlyOwn) {
+                        stmt.setInt(pos++, userId);
+                    }
+                }
+            }, folderId, columns, ACTIVE, con);
+        }
+    }
 
     /**
      * {@inheritDoc}
      */
     @Override
-    TaskIterator search(final Context ctx, final int userId, final TaskSearchObject search, final int orderBy, final Order order, final int[] columns, final List<Integer> all, final List<Integer> own, final List<Integer> shared) throws TaskException {
+    public TaskIterator search(final Context ctx, final int userId, final TaskSearchObject search, final int orderBy, final Order order, final int[] columns, final List<Integer> all, final List<Integer> own, final List<Integer> shared) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(SQL.getFields(columns, true));
@@ -263,7 +296,7 @@ public class RdbTaskStorage extends TaskStorage {
 
     /**
      * Counts the tasks in a folder.
-     * 
+     *
      * @param ctx Context.
      * @param folderId unique identifier of the folder.
      * @param onlyOwn <code>true</code> if only own objects can be seen.
@@ -313,7 +346,7 @@ public class RdbTaskStorage extends TaskStorage {
      * {@inheritDoc}
      */
     @Override
-    void insertTask(final Context ctx, final Connection con, final Task task, final StorageType type) throws TaskException {
+    public void insertTask(final Context ctx, final Connection con, final Task task, final StorageType type) throws TaskException {
         final StringBuilder insert = new StringBuilder();
         insert.append("INSERT INTO ");
         insert.append(SQL.TASK_TABLES.get(type));
@@ -332,6 +365,7 @@ public class RdbTaskStorage extends TaskStorage {
         }
         insert.append("?,?)");
         PreparedStatement stmt = null;
+        ResultSet rs = null;
         try {
             stmt = con.prepareStatement(insert.toString());
             int pos = 1;
@@ -356,7 +390,7 @@ public class RdbTaskStorage extends TaskStorage {
      * {@inheritDoc}
      */
     @Override
-    boolean existsTask(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
+    public boolean existsTask(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(Mapping.getMapping(Task.OBJECT_ID).getDBColumnName());
@@ -388,7 +422,7 @@ public class RdbTaskStorage extends TaskStorage {
      * {@inheritDoc}
      */
     @Override
-    Task selectTask(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
+    public Task selectTask(final Context ctx, final Connection con, final int taskId, final StorageType type) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(SQL.getAllFields());
@@ -424,7 +458,7 @@ public class RdbTaskStorage extends TaskStorage {
 
     /**
      * Updates a task in the database.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param type ACTIVE or DELETED.
@@ -434,7 +468,7 @@ public class RdbTaskStorage extends TaskStorage {
      * @throws TaskException if no task is updated.
      */
     @Override
-    void updateTask(final Context ctx, final Connection con, final Task task, final Date lastRead, final int[] modified, final StorageType type) throws TaskException {
+    public void updateTask(final Context ctx, final Connection con, final Task task, final Date lastRead, final int[] modified, final StorageType type) throws TaskException {
         if (modified.length == 0) {
             return;
         }
@@ -473,7 +507,7 @@ public class RdbTaskStorage extends TaskStorage {
 
     /**
      * Parses the truncated fields out of the DataTruncation exception and transforms this to a TaskException.
-     * 
+     *
      * @param exc DataTruncation exception.
      * @return a TaskException.
      */
