@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,8 +62,8 @@ import com.openexchange.groupware.tasks.mapping.Alarm;
 
 /**
  * This class defines the data container for tasks.
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  * @author <a href="mailto:marcus@open-xchange.com">Marcus Klein</a>
  */
 public class Task extends CalendarObject {
@@ -100,7 +100,7 @@ public class Task extends CalendarObject {
         TRIP_METER, COMPANIES, DATE_COMPLETED,
 
         // From CalendarObject
-        TITLE, START_DATE, END_DATE, NOTE, ALARM, RECURRENCE_TYPE, DAYS, DAY_IN_MONTH, MONTH, INTERVAL, UNTIL, PARTICIPANTS,
+        TITLE, START_DATE, END_DATE, NOTE, ALARM, RECURRENCE_TYPE, DAYS, DAY_IN_MONTH, MONTH, INTERVAL, UNTIL, PARTICIPANTS, UID,
         // not yet implemented: NOTIFICATION, USERS,
         // not implemented anymore: RECURRING_OCCURRENCE, PROJECT_ID,
 
@@ -110,9 +110,9 @@ public class Task extends CalendarObject {
         // NUMBER_OF_LINKS,
 
         // From FolderChildObject
-        // FOLDER_ID,
+        FOLDER_ID,
         // From DataObject
-        OBJECT_ID, CREATED_BY, MODIFIED_BY, CREATION_DATE, LAST_MODIFIED, LAST_MODIFIED_UTC };
+        OBJECT_ID, CREATED_BY, MODIFIED_BY, CREATION_DATE, LAST_MODIFIED};//, LAST_MODIFIED_UTC };
 
     public static final int LOW = 1;
 
@@ -280,12 +280,12 @@ public class Task extends CalendarObject {
         projectIdSet = true;
     }
 
-    public void setTargetCosts(Float target_costs) {
+    public void setTargetCosts(final Float target_costs) {
         this.targetCosts = target_costs;
         targetCostsSet = true;
     }
 
-    public void setActualCosts(Float actual_costs) {
+    public void setActualCosts(final Float actual_costs) {
         this.actualCosts = actual_costs;
         actualCostsSet = true;
     }
@@ -293,7 +293,7 @@ public class Task extends CalendarObject {
     /**
      * @param targetDuration the target duration to set
      */
-    public void setTargetDuration(Long targetDuration) {
+    public void setTargetDuration(final Long targetDuration) {
         this.targetDuration = targetDuration;
         targetDurationSet = true;
     }
@@ -301,7 +301,7 @@ public class Task extends CalendarObject {
     /**
      * @param actualDuration the actual duration to set
      */
-    public void setActualDuration(Long actualDuration) {
+    public void setActualDuration(final Long actualDuration) {
         this.actualDuration = actualDuration;
         actualDurationSet = true;
     }
@@ -557,7 +557,7 @@ public class Task extends CalendarObject {
     }
 
     @Override
-    public Set<Integer> findDifferingFields(DataObject dataObject) {
+    public Set<Integer> findDifferingFields(final DataObject dataObject) {
         Set<Integer> differingFields = super.findDifferingFields(dataObject);
         if (!getClass().isAssignableFrom(dataObject.getClass())) {
             return differingFields;
@@ -573,7 +573,7 @@ public class Task extends CalendarObject {
     }
 
     @Override
-    public void set(int field, Object value) {
+    public void set(final int field, final Object value) {
         switch (field) {
         case STATUS:
             setStatus(((Integer) value).intValue());
@@ -623,7 +623,7 @@ public class Task extends CalendarObject {
     }
 
     @Override
-    public Object get(int field) {
+    public Object get(final int field) {
         switch (field) {
         case STATUS:
             return I(getStatus());
@@ -659,7 +659,7 @@ public class Task extends CalendarObject {
     }
 
     @Override
-    public boolean contains(int field) {
+    public boolean contains(final int field) {
         switch (field) {
         case STATUS:
             return containsStatus();
@@ -695,7 +695,7 @@ public class Task extends CalendarObject {
     }
 
     @Override
-    public void remove(int field) {
+    public void remove(final int field) {
         switch (field) {
         case STATUS:
             removeStatus();
