@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,10 @@ import static com.openexchange.groupware.tasks.StorageType.ACTIVE;
 import static com.openexchange.groupware.tasks.StorageType.DELETED;
 import static com.openexchange.groupware.tasks.StorageType.REMOVED;
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.I2i;
 import static com.openexchange.java.Autoboxing.f;
+import static com.openexchange.tools.sql.DBUtils.autocommit;
+import static com.openexchange.tools.sql.DBUtils.isTransactionRollbackException;
 import static com.openexchange.tools.sql.DBUtils.rollback;
 import java.sql.Connection;
 import java.sql.SQLException;
@@ -65,6 +68,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.UUID;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
@@ -77,6 +81,7 @@ import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.Constants;
 import com.openexchange.groupware.calendar.RecurringResultInterface;
 import com.openexchange.groupware.calendar.RecurringResultsInterface;
+import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.ExternalUserParticipant;
 import com.openexchange.groupware.container.GroupParticipant;
 import com.openexchange.groupware.container.Participant;
@@ -94,10 +99,11 @@ import com.openexchange.server.ServiceException;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * This class contains logic methods for the tasks.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class TaskLogic {
@@ -105,7 +111,7 @@ public final class TaskLogic {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(TaskLogic.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TaskLogic.class));
 
     /**
      * Prevent instantiation
@@ -117,7 +123,7 @@ public final class TaskLogic {
     /**
      * Checks if a new task is not missing any data, does not contains any wrong data and if the user is allowed to create a task in tasks
      * folder.
-     * 
+     *
      * @param task Task to create.
      * @param userId unique identifier of the user that wants to create the task.
      * @param userConfig groupware configuration of the user that wants to create the task.
@@ -138,7 +144,7 @@ public final class TaskLogic {
 
     /**
      * Checks if the data of an to update task is correct.
-     * 
+     *
      * @param task Task object with the updated attributes.
      * @param oldTask Task object that should be updated.
      * @param user user that wants to change the task.
@@ -148,6 +154,12 @@ public final class TaskLogic {
      * @throws TaskException if the check fails.
      */
     static void checkUpdateTask(final Task task, final Task oldTask, final User user, final UserConfiguration userConfig, final Set<TaskParticipant> newParts, final Set<TaskParticipant> oldParts) throws TaskException {
+        if (task.containsUid()) {
+            if (!oldTask.getUid().equals(task.getUid())) {
+                throw new TaskException(Code.NO_UID_CHANGE);
+            }
+            task.removeUid();
+        }
         if (!task.containsLastModified()) {
             task.setLastModified(new Date());
         }
@@ -173,7 +185,7 @@ public final class TaskLogic {
 
     /**
      * Checks if the new task is missing some attributes so that it can't be stored to the database.
-     * 
+     *
      * @param task Task to create.
      * @param userId user that wants to create the task and will be therefore used as task creator if no one is defined.
      * @throws TaskException if the task can't be created.
@@ -182,6 +194,9 @@ public final class TaskLogic {
         if (!task.containsParentFolderID()) {
             throw new TaskException(Code.FOLDER_IS_MISSING);
         }
+        if (!task.containsUid()) {
+            task.setUid(UUID.randomUUID().toString());
+        }
         final Date timestamp = new Date();
         if (!task.containsCreationDate()) {
             task.setCreationDate(timestamp);
@@ -208,7 +223,7 @@ public final class TaskLogic {
 
     /**
      * Checks every string attribute of a task for invalid characters.
-     * 
+     *
      * @param task task to check.
      * @throws TaskException if a string contains invalid characters.
      */
@@ -233,7 +248,7 @@ public final class TaskLogic {
     /**
      * Checks if the start date is before the end date of a task. Some additional checks are done before. <code>null</code> dates are
      * ignored.
-     * 
+     *
      * @param task Task to check the dates of.
      * @throws TaskException if the start date is before the end date.
      */
@@ -295,7 +310,7 @@ public final class TaskLogic {
 
     /**
      * This method checks if the user tries to delegate a private flagged task.
-     * 
+     *
      * @param privat private flag of the old or new task.
      * @param changed if updated task contains participants.
      * @param oldParts original participants of the task.
@@ -319,7 +334,7 @@ public final class TaskLogic {
 
     /**
      * Checks that the creator can't be participant if the according global option isn't set.
-     * 
+     *
      * @param participants Participants of the task.
      * @throws TaskException if the check fails.
      */
@@ -332,7 +347,7 @@ public final class TaskLogic {
 
     /**
      * Checks if external participants contain consistent data. Currently external participants are checked to contain an email address.
-     * 
+     *
      * @param participants external participants.
      * @throws TaskException if an external participant does not contain an email address.
      */
@@ -347,7 +362,7 @@ public final class TaskLogic {
 
     /**
      * This method checks if the necessary fields for a recurring task are defined.
-     * 
+     *
      * @param task Recurring task.
      * @param oldTask Original recurring task on update.
      * @throws TaskException if a necessary recurrence attribute is missing.
@@ -394,7 +409,7 @@ public final class TaskLogic {
             recColl.checkRecurring(task);
         } catch (final OXException e) {
             throw new TaskException(e);
-        } catch (ServiceException e) {
+        } catch (final ServiceException e) {
             throw new TaskException(e);
         }
         if (daysRemoved) {
@@ -410,7 +425,7 @@ public final class TaskLogic {
     /**
      * If a task is updated, it only contains the changed values. If the recurrence type is changed but not the interval it must be copied
      * from the original task to be able to perform the recurrence check.
-     * 
+     *
      * @param task updated task.
      * @param oldTask original task.
      */
@@ -445,9 +460,9 @@ public final class TaskLogic {
         }
     }
 
-    private static void moveToFirstOccurrence(Task task) throws TaskException {
+    private static void moveToFirstOccurrence(final Task task) throws TaskException {
         // WebDAV/XML sets null values if value is missing.
-        if (!task.containsStartDate() || !task.containsEndDate() || null == task.getStartDate() || null == task.getEndDate()) {
+        if (!task.containsStartDate() || !task.containsEndDate() || null == task.getStartDate() || null == task.getEndDate() || !task.containsRecurrenceType() || CalendarObject.NO_RECURRENCE == task.getRecurrenceType()) {
             return;
         }
         try {
@@ -457,14 +472,14 @@ public final class TaskLogic {
             if (null == results || 0 == results.size()) {
                 return;
             }
-            RecurringResultInterface result = results.getRecurringResult(0);
+            final RecurringResultInterface result = results.getRecurringResult(0);
             if (!new Date(result.getStart()).equals(task.getStartDate())) {
                 task.setStartDate(new Date(result.getStart()));
             }
             if (!new Date(result.getEnd()).equals(task.getEndDate())) {
                 task.setEndDate(new Date(result.getEnd()));
             }
-        } catch (OXException e) {
+        } catch (final OXException e) {
             throw new TaskException(e);
         }
     }
@@ -485,7 +500,7 @@ public final class TaskLogic {
 
     /**
      * Creates task participant set from the user and group participants.
-     * 
+     *
      * @param ctx Context.
      * @param participants user and group participants.
      * @return a set of task participants.
@@ -510,13 +525,13 @@ public final class TaskLogic {
                         throw new TaskException(Code.GROUP_IS_EMPTY, group.getDisplayName());
                     }
                     for (final int userId : member) {
-                        InternalParticipant tParticipant = new InternalParticipant(new UserParticipant(userId), I(group.getIdentifier()));
+                        final InternalParticipant tParticipant = new InternalParticipant(new UserParticipant(userId), I(group.getIdentifier()));
                         foundGroupParticipants.add(tParticipant);
                         if (!retval.contains(tParticipant)) {
                             retval.add(tParticipant);
                         }
                     }
-                } catch (LdapException e) {
+                } catch (final LdapException e) {
                     throw new TaskException(e);
                 }
                 break;
@@ -577,7 +592,7 @@ public final class TaskLogic {
 
     /**
      * Creates the folder mappings for a task.
-     * 
+     *
      * @param folderId unique identifier of the folder that is the main folder of the task.
      * @param userId unique identifier of the user who created the task. The primary folder of the task will be added with this user
      *            identifier. On shared folders the user identifier should be the owner of the shared folder.
@@ -605,19 +620,20 @@ public final class TaskLogic {
         final List<Integer> fields = new ArrayList<Integer>();
         for (final Mapper<?> mapper : Mapping.MAPPERS) {
             if (mapper.isSet(task) && (!mapper.isSet(oldTask) || !mapper.equals(task, oldTask))) {
-                fields.add(Integer.valueOf(mapper.getId()));
+                fields.add(I(mapper.getId()));
             }
         }
-        final int[] retval = new int[fields.size()];
-        for (int i = 0; i < fields.size(); i++) {
-            retval[i] = fields.get(i).intValue();
+        // If the end of recurrence information is changed from 'after x occurrences' to 'at *date*'
+        // the field recurrence_count has explicitly to be unset.
+        if (oldTask.containsOccurrence() && !task.containsOccurrence() && task.containsUntil()) {
+            fields.add(I(Task.RECURRENCE_COUNT));
         }
-        return retval;
+        return I2i(fields);
     }
 
     /**
      * Calculates the next time values for a recurring task.
-     * 
+     *
      * @param task the task object.
      * @return <code>true</code> if a next occurence exists.
      * @throws OXException if an error occurs.
@@ -642,7 +658,7 @@ public final class TaskLogic {
 
     /**
      * This method does compatability changes to the task in that way that the recurrence calculation for appointment also works for tasks.
-     * 
+     *
      * @param task Task to modify and to calculate the recurrence for.
      * @return the new start and end date for the task.
      * @throws OXException if an error occurs.
@@ -668,7 +684,7 @@ public final class TaskLogic {
 
     /**
      * Extracts all participants that are added by the group.
-     * 
+     *
      * @param participants internal task participants.
      * @param groupId the group identifier.
      * @return All participants that are added by the group.
@@ -700,7 +716,7 @@ public final class TaskLogic {
 
     /**
      * Stores a task with its participants and folders.
-     * 
+     *
      * @param ctx Context.
      * @param task Task to store.
      * @param participants Participants of the task.
@@ -743,7 +759,7 @@ public final class TaskLogic {
 
     /**
      * Deletes an ACTIVE task object. This stores the task as a DELETED task object, deletes all reminders and sends the task delete event.
-     * 
+     *
      * @param ctx Conetxt
      * @param task fully loaded task object to delete.
      * @param lastModified last modification timestamp for concurrent conflicts.
@@ -772,40 +788,69 @@ public final class TaskLogic {
 
     /**
      * Deletes an ACTIVE task object. This stores the task as a DELETED task object, deletes all reminders and sends the task delete event.
-     * 
+     *
      * @param session Session.
      * @param task fully loaded task object to delete.
      * @param lastModified last modification timestamp for concurrent conflicts.
      * @throws TaskException if an exception occurs.
      */
     public static void deleteTask(final Session session, final Context ctx, final int userId, final Task task, final Date lastModified) throws TaskException {
-        Connection con;
         try {
-            con = DBPool.pickupWriteable(ctx);
-        } catch (final DBPoolingException e) {
-            throw new TaskException(Code.NO_CONNECTION, e);
-        }
-        try {
-            con.setAutoCommit(false);
-            deleteTask(ctx, con, userId, task, lastModified);
-            informDelete(session, ctx, con, task);
-            con.commit();
+            final DBUtils.TransactionRollbackCondition condition = new DBUtils.TransactionRollbackCondition(3);
+            do {
+                Connection con;
+                try {
+                    con = DBPool.pickupWriteable(ctx);
+                } catch (final DBPoolingException e) {
+                    throw new TaskException(Code.NO_CONNECTION, e);
+                }
+                condition.resetTransactionRollbackException();
+                try {
+                    DBUtils.startTransaction(con);
+                    final Task t = clone(task);
+                    deleteTask(ctx, con, userId, t, lastModified);
+                    informDelete(session, ctx, con, t);
+                    con.commit();
+                } catch (final SQLException e) {
+                    rollback(con);
+                    if (!condition.isFailedTransactionRollback(e)) {
+                        throw new TaskException(Code.DELETE_FAILED, e, e.getMessage());
+                    }
+                } catch (final TaskException e) {
+                    rollback(con);
+                    if (!condition.isFailedTransactionRollback(e)) {
+                        throw e;
+                    }
+                } catch (final RuntimeException e) {
+                    rollback(con);
+                    if (!condition.isFailedTransactionRollback(e)) {
+                        throw new TaskException(Code.DELETE_FAILED, e, e.getMessage());
+                    }
+                } finally {
+                    autocommit(con);
+                    DBPool.closeWriterSilent(ctx, con);
+                }
+            } while (condition.checkRetry());
         } catch (final SQLException e) {
-            rollback(con);
-            throw new TaskException(Code.DELETE_FAILED, e, e.getMessage());
-        } catch (final TaskException e) {
-            rollback(con);
-            throw e;
-        } finally {
-            try {
-                con.setAutoCommit(true);
-            } catch (final SQLException e) {
-                LOG.error("Problem setting auto commit to true.", e);
+            if (isTransactionRollbackException(e)) {
+                throw new TaskException(Code.DELETE_FAILED_RETRY, e, e.getMessage());
             }
-            DBPool.closeWriterSilent(ctx, con);
+            throw new TaskException(Code.DELETE_FAILED, e, e.getMessage());
         }
     }
 
+    private static final int[] ALL_COLUMNS = Task.ALL_COLUMNS;
+
+    private static Task clone(final Task task) {
+        final Task ret = new Task();
+        for (final int field : ALL_COLUMNS) {
+            if (task.contains(field)) {
+                ret.set(field, task.get(field));
+            }
+        }
+        return ret;
+    }
+
     private static Set<Folder> deleteParticipants(final Context ctx, final Connection con, final int taskId) throws TaskException {
         final Set<InternalParticipant> participants = new HashSet<InternalParticipant>(partStor.selectInternal(ctx, con, taskId, ACTIVE));
         partStor.deleteInternal(ctx, con, taskId, participants, ACTIVE, true);
@@ -835,7 +880,7 @@ public final class TaskLogic {
 
     /**
      * Informs other systems about a deleted task.
-     * 
+     *
      * @param session Session.
      * @param ctx the context.
      * @param con writable database connection.
@@ -857,7 +902,7 @@ public final class TaskLogic {
 
     /**
      * Removes a task object completely.
-     * 
+     *
      * @param session Session (for event handling)
      * @param ctx Context.
      * @param con writable database connection.
