@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.container.Participant;
 import com.openexchange.groupware.contexts.Context;
@@ -66,7 +67,6 @@ import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 
 /**
@@ -79,7 +79,7 @@ public class TasksDowngrade extends DowngradeListener {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(TasksDowngrade.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TasksDowngrade.class));
 
     /**
      * Default constructor.
@@ -105,22 +105,14 @@ public class TasksDowngrade extends DowngradeListener {
             // - All tasks in public folders that can be only edited by this user.
             try {
                 removeTasks(session, ctx, userConfig.getUserId(), con);
-            } catch (final TaskException e) {
-                throw new DowngradeFailedException(e);
-            } catch (final OXException e) {
-                throw new DowngradeFailedException(e);
-            } catch (final SearchIteratorException e) {
+            } catch (final AbstractOXException e) {
                 throw new DowngradeFailedException(e);
             }
         } else if (!userConfig.canDelegateTasks()) {
             // Remove all delegations of tasks that the user created.
             try {
                 removeDelegations(session, ctx, userConfig.getUserId(), userConfig, con);
-            } catch (final TaskException e) {
-                throw new DowngradeFailedException(e);
-            } catch (final SearchIteratorException e) {
-                throw new DowngradeFailedException(e);
-            } catch (final OXException e) {
+            } catch (final AbstractOXException e) {
                 throw new DowngradeFailedException(e);
             }
         }
@@ -129,8 +121,7 @@ public class TasksDowngrade extends DowngradeListener {
     private static final ParticipantStorage partStor = ParticipantStorage.getInstance();
 
     private void removeTasks(final Session session, final Context ctx,
-        final int userId, final Connection con) throws TaskException,
-        OXException, SearchIteratorException {
+        final int userId, final Connection con) throws AbstractOXException {
         final User user = Tools.getUser(ctx, userId);
         // Find private task folder.
         SearchIterator<FolderObject> iter = OXFolderIteratorSQL
@@ -140,7 +131,7 @@ public class TasksDowngrade extends DowngradeListener {
         try {
             while (iter.hasNext()) {
                 final FolderObject folder = iter.next();
-                removeTaskInPrivateFolder(session, ctx, con, userId, folder);        
+                removeTaskInPrivateFolder(session, ctx, con, userId, folder);
             }
         } finally {
             iter.close();
@@ -236,8 +227,7 @@ public class TasksDowngrade extends DowngradeListener {
 
     private void removeDelegations(final Session session, final Context ctx,
         final int userId, final UserConfiguration userConfig,
-        final Connection con) throws TaskException, SearchIteratorException,
-        OXException {
+        final Connection con) throws AbstractOXException {
         final User user = Tools.getUser(ctx, userId);
         // Find all private folder.
         SearchIterator<FolderObject> iter = OXFolderIteratorSQL
@@ -292,7 +282,7 @@ public class TasksDowngrade extends DowngradeListener {
                 TaskLogic.removeTask(session, ctx, con, folder.getObjectID(),
                     taskId, type);
             }
-        }        
+        }
     }
 
     private void removeDelegationsInFolder(final Session session,
