@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,12 +64,11 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.event.EventException;
 import com.openexchange.event.impl.EventClient;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
@@ -80,21 +79,16 @@ import com.openexchange.groupware.tasks.mapping.Status;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.session.Session;
-import com.openexchange.tools.Arrays;
+import com.openexchange.tools.arrays.Arrays;
 import com.openexchange.tools.iterator.SearchIteratorException;
 
 /**
  * This class contains the logic for updating tasks. It calculates what is to modify.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 class UpdateData {
 
-    /**
-     * Logger.
-     */
-    private static final Log LOG = LogFactory.getLog(UpdateData.class);
-
     /**
      * Context.
      */
@@ -217,7 +211,7 @@ class UpdateData {
 
     /**
      * Easier constructor for live data.
-     * 
+     *
      * @param ctx Context.
      * @param user User.
      * @param userConfig User configuration.
@@ -231,7 +225,7 @@ class UpdateData {
 
     /**
      * Default constructor.
-     * 
+     *
      * @param ctx Context.
      * @param user User.
      * @param userConfig User configuration.
@@ -253,7 +247,7 @@ class UpdateData {
 
     /**
      * Proxy loading method for the task.
-     * 
+     *
      * @return the original task.
      * @throws TaskException if loading of the original tasks fails.
      */
@@ -330,7 +324,7 @@ class UpdateData {
 
     /**
      * Checks everything and prepares the data structures for an update.
-     * 
+     *
      * @throws TaskException if an error occurs
      */
     void prepare() throws TaskException {
@@ -346,7 +340,7 @@ class UpdateData {
 
     /**
      * Prepares the data structures for an update.
-     * 
+     *
      * @throws TaskException if an error occurs.
      */
     void prepareWithoutChecks() throws TaskException {
@@ -649,7 +643,7 @@ class UpdateData {
 
     /**
      * This method executes the prepared update.
-     * 
+     *
      * @throws TaskException
      */
     void doUpdate() throws TaskException {
@@ -674,7 +668,7 @@ class UpdateData {
                 getRemovedFolder(),
                 type);
             if (ACTIVE == type && isMove()) {
-                final Task dummy = Tools.createDummyTask(getTaskId(), getUserId());
+                final Task dummy = Tools.createDummyTask(getTaskId(), getUserId(), getOrigTask().getUid());
                 storage.insertTask(ctx, con, dummy, DELETED, true);
                 final Folder sourceFolder = FolderStorage.getFolder(getRemovedFolder(), getFolderId());
                 foldStor.insertFolder(ctx, con, getTaskId(), sourceFolder, DELETED);
@@ -703,7 +697,7 @@ class UpdateData {
 
     /**
      * This method execute the SQL statements on the given connection defined by the given data for the update.
-     * 
+     *
      * @param ctx Context.
      * @param con writable database connection.
      * @param task task object with changed values.
@@ -742,6 +736,17 @@ class UpdateData {
     }
 
     void sentEvent(final Session session) throws TaskException {
+        final Task orig = getOrigTask();
+        if (getUserId() != orig.getCreatedBy() && null == ParticipantStorage.getParticipant(ParticipantStorage.extractInternal(getChangedParticipants()), orig.getCreatedBy())) {
+            // Delegator not participant and participant changed task. Change parent folder of original task to delegators folder identifier
+            // so we are able to use that for participant notification.
+            Folder delegatorFolder = FolderStorage.extractFolderOfUser(getOrigFolder(), orig.getCreatedBy());
+            if (null == delegatorFolder) {
+                // Delegator has been removed from participant list.
+                delegatorFolder = FolderStorage.extractFolderOfUser(getOrigFolder(), getUserId());
+            }
+            orig.setParentFolderID(delegatorFolder.getIdentifier());
+        }
         sentEvent(session, getUpdated(), getOrigTask(), getDestFolder());
     }
 
@@ -766,7 +771,7 @@ class UpdateData {
         }
     }
 
-    void makeNextRecurrence(final Session session) throws TaskException, OXException {
+    void makeNextRecurrence(final Session session) throws AbstractOXException {
         if (Task.NO_RECURRENCE != updated.getRecurrenceType() && Task.DONE == updated.getStatus() && Arrays.contains(
             getModifiedFields(),
             Status.SINGLETON.getId())) {
@@ -790,10 +795,10 @@ class UpdateData {
             TaskIterator ti;
             if (own) {
                 ti = storage.search(ctx, getUserId(), search, 0, Order.ASCENDING, new int[] {
-                    Task.PERCENT_COMPLETED, Task.CREATED_BY, Task.START_DATE }, emptyList, listWithFolder, emptyList);
+                    Task.PERCENT_COMPLETED, Task.CREATED_BY, Task.START_DATE, Task.TITLE }, emptyList, listWithFolder, emptyList);
             } else {
                 ti = storage.search(ctx, getUserId(), search, 0, Order.ASCENDING, new int[] {
-                    Task.PERCENT_COMPLETED, Task.CREATED_BY, Task.START_DATE }, listWithFolder, emptyList, emptyList);
+                    Task.PERCENT_COMPLETED, Task.CREATED_BY, Task.START_DATE, Task.TITLE }, listWithFolder, emptyList, emptyList);
             }
 
             final boolean next = TaskLogic.makeRecurrence(updated);
@@ -804,6 +809,7 @@ class UpdateData {
                     final Task actual = ti.next();
                     final boolean percentComplete = actual.getPercentComplete() == updated.getPercentComplete();
                     final boolean createdBy = actual.getCreatedBy() == updated.getCreatedBy();
+                    final boolean title = null != actual.getTitle() && actual.getTitle().equals(updated.getTitle());
                     boolean startDate;
 
                     if (actual.getStartDate() != null) {
@@ -817,7 +823,7 @@ class UpdateData {
                             startDate = false;
                         }
                     }
-                    if (percentComplete && createdBy && startDate) {
+                    if (percentComplete && createdBy && startDate && title) {
 
                         duplicateExists = true;
                         break;
@@ -835,7 +841,7 @@ class UpdateData {
 
     /**
      * Inserts a new task according to the recurrence.
-     * 
+     *
      * @param task recurring task.
      * @param parts participants of the updated task.
      * @param folders folders of the updated task.
