@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,6 +60,7 @@ import com.openexchange.groupware.tasks.Task;
 
 /**
  * Methods for iterated processing of the actual duration of task objects.
+ * 
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public final class ActualDuration implements Mapper<Long> {
@@ -101,6 +102,12 @@ public final class ActualDuration implements Mapper<Long> {
     }
 
     public boolean equals(Task task1, Task task2) {
+        if (task1.getActualDuration() == null) {
+            return (task2.getActualDuration() == null);
+        }
+        if (task2.getActualDuration() == null) {
+            return (task1.getActualDuration() == null);
+        }
         return task1.getActualDuration().equals(task2.getActualDuration());
     }
 
@@ -111,4 +118,4 @@ public final class ActualDuration implements Mapper<Long> {
     public void set(Task task, Long value) {
         task.setActualDuration(value);
     }
-}
\ No newline at end of file
+}
