@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -101,6 +101,12 @@ public class TargetDuration implements Mapper<Long> {
     }
 
     public boolean equals(Task task1, Task task2) {
+        if (task1.getTargetDuration() == null) {
+            return (task2.getTargetDuration() == null);
+        }
+        if (task2.getTargetDuration() == null) {
+            return (task1.getTargetDuration() == null);
+        }
         return task1.getTargetDuration().equals(task2.getTargetDuration());
     }
 
