@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,102 +49,105 @@
 
 package com.openexchange.groupware.update;
 
+import static com.openexchange.tools.sql.DBUtils.autocommit;
+import static com.openexchange.tools.sql.DBUtils.rollback;
+import java.sql.Connection;
+import java.sql.SQLException;
+import com.openexchange.caching.CacheService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.SchemaException;
-import com.openexchange.groupware.update.exception.SchemaExceptionFactory;
+import com.openexchange.groupware.update.internal.SchemaExceptionCodes;
+import com.openexchange.groupware.update.internal.SchemaStoreImpl;
 
 /**
- * Abstract class defining the interface for reading the schema version
- * information.
- * 
+ * Abstract class defining the interface for reading the schema version information.
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
-@OXExceptionSource(classId = Classes.SCHEMA_STORE, component = EnumComponent.UPDATE)
 public abstract class SchemaStore {
 
-    /**
-     * For creating exceptions.
-     */
-    private static final SchemaExceptionFactory EXCEPTION = new SchemaExceptionFactory(SchemaStore.class);
+    private static final SchemaStoreImpl SINGLETON = new SchemaStoreImpl();
 
-    /**
-     * Class implementing this abstract interface.
-     */
-    private static Class<? extends SchemaStore> implementingClass;
-
-    /**
-     * Default constructor.
-     */
     protected SchemaStore() {
         super();
     }
 
     /**
      * Factory method.
-     * 
-     * @param className
-     *            Class name of the implementation.
+     *
      * @return an implementation for this interface.
      */
-    @OXThrowsMultiple(category = { Category.SETUP_ERROR, Category.SETUP_ERROR }, desc = { "", "" }, exceptionId = { 1,
-            2 }, msg = { "Class %1$s can not be loaded.", "Cannot instantiate class %1$s." })
-    public static SchemaStore getInstance(final String className) throws SchemaException {
-        try {
-            synchronized (SchemaStore.class) {
-                if (null == implementingClass) {
-                    implementingClass = Class.forName(className).asSubclass(SchemaStore.class);
-                }
-            }
-            return implementingClass.newInstance();
-        } catch (final InstantiationException e) {
-            throw EXCEPTION.create(2, e, className);
-        } catch (final IllegalAccessException e) {
-            throw EXCEPTION.create(2, e, className);
-        } catch (final ClassNotFoundException e) {
-            throw EXCEPTION.create(1, e, className);
-        }
+    public static SchemaStore getInstance() {
+        return SINGLETON;
     }
 
-    public abstract Schema getSchema(int poolId, String schema) throws SchemaException;
+    public abstract SchemaUpdateState getSchema(int poolId, String schemaName) throws SchemaException;
 
     /**
-     * Marks given schema as locked due to a start of an update process
-     * 
-     * @param schema -
-     *            the schema
-     * @param contextId TODO
-     * 
+     * Marks given schema as locked due to a start of an update process.
+     *
+     * @param schema the schema
+     * @param contextId unique context identifier
+     * @param background <code>false</code> if blocking tasks are executed.
      * @throws SchemaException
      */
-    public abstract void lockSchema(final Schema schema, int contextId) throws SchemaException;
-    
-    /**
-     * Marks given schem as unlocked to release this schema from an update
-     * process
-     * 
-     * @param schema -
-     *            the schema
-     * @param contextId TODO
-     * @throws SchemaException
-     */
-    public abstract void unlockSchema(final Schema schema, int contextId) throws SchemaException;
+    public abstract void lockSchema(Schema schema, int contextId, boolean background) throws SchemaException;
 
-    public Schema getSchema(Context ctx) throws SchemaException {
+    /**
+     * Marks given schem as unlocked to release this schema from an update process.
+     *
+     * @param schema the schema
+     * @param contextId the unique context identifier
+     * @param background <code>false</code> if blocking tasks finished.
+     * @throws SchemaException
+     */
+    public abstract void unlockSchema(Schema schema, int contextId, boolean background) throws SchemaException;
+
+    public final Schema getSchema(final Context ctx) throws SchemaException {
         return getSchema(ctx.getContextId());
     }
 
-    public Schema getSchema(int contextId) throws SchemaException {
+    public final SchemaUpdateState getSchema(final int contextId) throws SchemaException {
         try {
             return getSchema(Database.resolvePool(contextId, true), Database.getSchema(contextId));
-        } catch (DBPoolingException e) {
+        } catch (final DBPoolingException e) {
             throw new SchemaException(e);
         }
     }
+
+    public abstract ExecutedTask[] getExecutedTasks(int poolId, String schemaName) throws SchemaException;
+
+    public final void addExecutedTask(final int contextId, final String taskName, final boolean success, final int poolId, final String schema) throws SchemaException {
+        final Connection con;
+        try {
+            con = Database.get(contextId, true);
+        } catch (final DBPoolingException e) {
+            throw new SchemaException(e);
+        }
+        try {
+            con.setAutoCommit(false);
+            addExecutedTask(con, taskName, success, poolId, schema);
+            con.commit();
+        } catch (final SQLException e) {
+            rollback(con);
+            throw SchemaExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
+        } catch (final SchemaException e) {
+            rollback(con);
+            throw e;
+        } finally {
+            autocommit(con);
+            Database.back(contextId, true, con);
+        }
+    }
+
+    /**
+     * @param con a writable database connection but into transaction mode.
+     */
+    public abstract void addExecutedTask(Connection con, String taskName, boolean success, int poolId, String schema) throws SchemaException;
+
+    public abstract void setCacheService(CacheService cacheService);
+
+    public abstract void removeCacheService();
+
 }
