@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,18 @@
 
 package com.openexchange.groupware.update;
 
-import static com.openexchange.groupware.update.UpdateExceptionMessages.*;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.BLOCKING_FIRST_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.COLUMN_NOT_FOUND_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.LOADING_TASK_FAILED_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.ONLY_REDUCE_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.RESET_FORBIDDEN_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.SQL_PROBLEM_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.UNKNOWN_CONCURRENCY_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.UNKNOWN_SCHEMA_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.UNKNOWN_TASK_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.UNRESOLVABLE_DEPENDENCIES_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.UPDATE_FAILED_MSG;
+import static com.openexchange.groupware.update.UpdateExceptionMessages.WRONG_ROW_COUNT_MSG;
 import com.openexchange.exceptions.OXErrorMessage;
 import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.internal.UpdateExceptionFactory;
@@ -104,9 +115,11 @@ public enum UpdateExceptionCodes implements OXErrorMessage {
     /**
      * Blocking tasks (%1$s) must be executed before background tasks can be executed (%2$s).
      */
-    FIRST_BLOCKING(FIRST_BLOCKING_MSG, Category.CODE_ERROR, 23),
+    BLOCKING_FIRST(BLOCKING_FIRST_MSG, Category.CODE_ERROR, 23),
     /** Unknown task: %1$s */
-    UNKNOWN_TASK(UNKNOWN_TASK_MSG, Category.SETUP_ERROR, 24);
+    UNKNOWN_TASK(UNKNOWN_TASK_MSG, Category.SETUP_ERROR, 24),
+    /** Column "%1$s" not found in table %2$s. */
+    COLUMN_NOT_FOUND(COLUMN_NOT_FOUND_MSG, Category.CODE_ERROR, 25);
 
     final String message;
 
