@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,6 +54,14 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.UpdateTaskAdapter;
 import com.openexchange.groupware.update.UpdateTaskV2;
+import com.openexchange.groupware.update.tasks.AllowTextInValuesOfDynamicContextAttributesTask;
+import com.openexchange.groupware.update.tasks.AllowTextInValuesOfDynamicUserAttributesTask;
+import com.openexchange.groupware.update.tasks.CorrectAttachmentCountInAppointments;
+import com.openexchange.groupware.update.tasks.CorrectFileAsInContacts;
+import com.openexchange.groupware.update.tasks.CorrectOrganizerInAppointments;
+import com.openexchange.groupware.update.tasks.CreateIndexOnContextAttributesTask;
+import com.openexchange.groupware.update.tasks.CreateIndexOnUserAttributesForAliasLookupTask;
+import com.openexchange.groupware.update.tasks.VirtualFolderAddSortNumTask;
 
 /**
  * Lists all update tasks of the com.openexchange.server bundle.
@@ -62,7 +70,7 @@ import com.openexchange.groupware.update.UpdateTaskV2;
  */
 public final class InternalList {
 
-    private static final Log LOG = LogFactory.getLog(InternalList.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InternalList.class));
 
     private static final InternalList SINGLETON = new InternalList();
 
@@ -327,7 +335,7 @@ public final class InternalList {
 
         // Adds a column to the table user_setting_server named folderTree to store the selected folder tree.
         new com.openexchange.groupware.update.tasks.FolderTreeSelectionTask(),
-        
+
         // Repairs appointments where the number of attachments does not match the real amount of attachments.
         new com.openexchange.groupware.update.tasks.AttachmentCountUpdateTask(),
 
@@ -337,12 +345,112 @@ public final class InternalList {
         // Currently users contacts are created with the display name attribute filed. Outlook primarily uses the fileAs attribute. This
         // task copies the display name to fileAs if that is empty.
         new com.openexchange.groupware.update.tasks.AddFileAsForUserContacts(),
-        
+
         // Extend field "reason" for participants.
-        new com.openexchange.groupware.update.tasks.ParticipantCommentFieldLength()
+        new com.openexchange.groupware.update.tasks.ParticipantCommentFieldLength(),
+
+        // New table for linking several appointments (from different sources) together that represent the same person.
+        new com.openexchange.groupware.update.tasks.AggregatingContactTableService(),
+
+        // Creates new table for multi-purpose ID generation
+        new com.openexchange.groupware.update.tasks.IDCreateTableTask(),
 
         // TODO: Enable virtual folder tree update task when needed
         // Migrates existing folder data to new outlook-like folder tree structure
-        // new com.openexchange.folderstorage.virtual.VirtualTreeMigrationTask()        
+        // new com.openexchange.folderstorage.virtual.VirtualTreeMigrationTask()
+
+        // +++++++++++++++++++++++++++++++++ Version 6.20 starts here. +++++++++++++++++++++++++++++++++
+
+        // Transforms the "info" field to a TEXT field. This fields seems not to be used anywhere.
+        new com.openexchange.groupware.update.tasks.ContactInfoField2Text(),
+
+        // Creates new Contact fields (First Name, Last Name, Company) for Kana based search in japanese environments.
+        new com.openexchange.groupware.update.tasks.ContactFieldsForJapaneseKanaSearch(),
+
+        // Remove facebook subscriptions to force use of new oauth
+        new com.openexchange.groupware.update.tasks.FacebookCrawlerSubscriptionRemoverTask(),
+
+        // Remove linkedin subscriptions to force use of new oauth
+        new com.openexchange.groupware.update.tasks.LinkedInCrawlerSubscriptionsRemoverTask(),
+
+        // Remove yahoo subscriptions to force use of new oauth
+        new com.openexchange.groupware.update.tasks.DeleteOldYahooSubscriptions(),
+
+        // Switch the column type of 'value' in contextAttribute to TEXT
+        new AllowTextInValuesOfDynamicContextAttributesTask(),
+
+        // Switch the column type of 'value' in user_attribute to TEXT
+        new AllowTextInValuesOfDynamicUserAttributesTask(),
+
+        // Recreate the index on the context attributes table
+        new CreateIndexOnContextAttributesTask(),
+
+        // Recreate the index on the user attributes table for alias lookup
+        new CreateIndexOnUserAttributesForAliasLookupTask(),
+
+        // Correct the attachment count in the dates table
+        new CorrectAttachmentCountInAppointments(),
+
+        // Corrects the organizer in appointments. When exporting iCal and importing it again the organizer gets value 'null' instead of SQL
+        // NULL. This task corrects this.
+        new CorrectOrganizerInAppointments(),
+
+        // Corrects field90 aka fileAs in contacts to have proper contact names in card view of Outlook OXtender 2.
+        new CorrectFileAsInContacts(),
+
+        // Add "sortNum" column to virtual folder table.
+        new VirtualFolderAddSortNumTask(),
+
+        // Restores the initial permissions on the public root folder.
+        new com.openexchange.groupware.update.tasks.DropIndividualUserPermissionsOnPublicFolderTask(),
+
+        // Adds Outlook address fields to contact tables
+        new com.openexchange.groupware.update.tasks.ContactAddOutlookAddressFieldsTask(),
+
+        // Add UID field to contact tables.
+        new com.openexchange.groupware.update.tasks.ContactAddUIDFieldTask(),
+
+        // Add UIDs to contacts if missing
+        new com.openexchange.groupware.update.tasks.ContactAddUIDValueTask(),
+
+        // Adds UIDs to tasks.
+        new com.openexchange.groupware.update.tasks.TasksAddUidColumnTask(),
+
+        // Adds UID indexes.
+        new com.openexchange.groupware.update.tasks.CalendarAddUIDIndexTask(),
+
+        // Drops rather needless foreign keys
+        new com.openexchange.groupware.update.tasks.DropFKTask(),
+        
+        // Adds 'organizerId', 'principal' and 'principalId' to prg_dates and del_dates
+        new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask(),
+
+        // Adds index to prg_dates_members and del_dates_members
+        new com.openexchange.groupware.update.tasks.CalendarAddIndex2DatesMembers(),
+
+        // Adds index to oxfolder_tree and del_oxfolder_tree
+        new com.openexchange.groupware.update.tasks.FolderAddIndex2LastModified(),
+
+        // Checks for missing folder 'public_infostore' (15) in any available context
+        new com.openexchange.groupware.update.tasks.CheckForPublicInfostoreFolderTask(),
+
+        // Fixes inconsistencies concerning possible "replyTo" column in mail account tables
+        new com.openexchange.groupware.update.tasks.MailAccountFixReplyToMessupTask(),
+
+        // Drops useless foreign keys from 'malPollHash' table
+        new com.openexchange.groupware.update.tasks.MALPollDropConstraintsTask(),
+        
+        // Extends dn fields in calendar tables to 320 chars.
+        new com.openexchange.groupware.update.tasks.CalendarExtendDNColumnTaskV2(),
+
+        // Creates indexes on tables "prg_dlist" and "del_dlist" to improve look-up.
+        new com.openexchange.groupware.update.tasks.DListAddIndexForLookup(),
+
+        // Another attempt: Adds 'organizerId', 'principal' and 'principalId' to prg_dates and del_dates
+        new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask2(),
+
+        // Add UIDs to appointments if missing.
+        new com.openexchange.groupware.update.tasks.CalendarAddUIDValueTask(),
+        
     };
 }
