@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,25 +59,17 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * Update task for adding an index on prg_dates_members.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class AddAppointmentParticipantsIndexTask implements UpdateTask {
 
-    private static final Log LOG = LogFactory.getLog(AddAppointmentParticipantsIndexTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(AddAppointmentParticipantsIndexTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AddAppointmentParticipantsIndexTask.class));
 
     public AddAppointmentParticipantsIndexTask() {
         super();
@@ -91,11 +83,6 @@ public class AddAppointmentParticipantsIndexTask implements UpdateTask {
         return UpdateTaskPriority.NORMAL.priority;
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "An SQL error occurred: %1$s." }
-    )
     public void perform(Schema schema, int contextId) throws AbstractOXException {
         final Connection con = Database.getNoTimeout(contextId, true);
         try {
@@ -104,7 +91,7 @@ public class AddAppointmentParticipantsIndexTask implements UpdateTask {
             con.commit();
         } catch (final SQLException e) {
             rollback(con);
-            throw EXCEPTION.create(1, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             autocommit(con);
             Database.backNoTimeout(contextId, true, con);
