@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,15 +57,10 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
@@ -73,42 +68,22 @@ import com.openexchange.tools.sql.DBUtils;
  * as 0. This task fixes those appointments.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class AppointmentChangedFromZeroTask implements UpdateTask {
 
-    private static final Log LOG = LogFactory.getLog(AppointmentChangedFromZeroTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AppointmentChangedFromZeroTask.class));
 
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(AppointmentChangedFromZeroTask.class);
-
-    /**
-     * Default constructor.
-     */
     public AppointmentChangedFromZeroTask() {
         super();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int addedWithVersion() {
         return 21;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getPriority() {
         return UpdateTaskPriority.NORMAL.priority;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "An SQL error occurred: %1$s." }
-    )
     public void perform(final Schema schema, final int contextId) throws DBPoolingException, UpdateException {
         if (LOG.isInfoEnabled()) {
             LOG.info("Performing update task to remove 0 set changed_from in appointments.");
@@ -122,7 +97,7 @@ public final class AppointmentChangedFromZeroTask implements UpdateTask {
             con.commit();
         } catch (final SQLException e) {
             DBUtils.rollback(con);
-            throw EXCEPTION.create(1, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             DBUtils.autocommit(con);
             closeSQLStuff(null, st);
