@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,78 +57,44 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * Removes the duplicate recurrence date positions from appointment exceptions.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
-public final class AppointmentExceptionRemoveDuplicateDatePosition implements
-    UpdateTask {
+public final class AppointmentExceptionRemoveDuplicateDatePosition implements UpdateTask {
 
-    /**
-     * Logger.
-     */
-    private static final Log LOG = LogFactory.getLog(
-        AppointmentExceptionRemoveDuplicateDatePosition.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AppointmentExceptionRemoveDuplicateDatePosition.class));
 
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(AppointmentExceptionRemoveDuplicateDatePosition.class);
-
-    /**
-     * Default constructor.
-     */
     public AppointmentExceptionRemoveDuplicateDatePosition() {
         super();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int addedWithVersion() {
         return 22;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getPriority() {
         return UpdateTaskPriority.NORMAL.priority;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "An SQL error occurred: %1$s." }
-    )
     public void perform(final Schema schema, final int contextId)
         throws AbstractOXException {
-        LOG.info("Performing update task to remove duplicate date recurrence "
-            + "position from appointment change exceptions on schema "
-            + schema.getSchema());
+        LOG.info("Performing update task to remove duplicate date recurrence position from appointment change exceptions on schema " + schema.getSchema());
         final Connection con = Database.get(contextId, true);
         Statement st = null;
         try {
             con.setAutoCommit(false);
             st = con.createStatement();
-            st.executeUpdate("UPDATE prg_dates SET "
-                + "field08=SUBSTR(field08,1,LOCATE(',', field08)-1) "
-                + "WHERE intfield01!=intfield02 AND field08 LIKE '%,%';");
+            st.executeUpdate("UPDATE prg_dates SET field08=SUBSTR(field08,1,LOCATE(',', field08)-1) WHERE intfield01!=intfield02 AND field08 LIKE '%,%';");
             con.commit();
         } catch (final SQLException e) {
             DBUtils.rollback(con);
-            throw EXCEPTION.create(1, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             DBUtils.autocommit(con);
             closeSQLStuff(null, st);
@@ -136,7 +102,6 @@ public final class AppointmentExceptionRemoveDuplicateDatePosition implements
                 Database.back(contextId, true, con);
             }
         }
-        LOG.info("Update task to remove duplicate date recurrence position from"
-            + " appointment change exceptions performed.");
+        LOG.info("Update task to remove duplicate date recurrence position from appointment change exceptions performed.");
     }
 }
