@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,15 +58,10 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
@@ -75,16 +70,10 @@ import com.openexchange.tools.sql.DBUtils;
  * string from the series.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class AppointmentRepairRecurrenceString implements UpdateTask {
 
-    private static final Log LOG = LogFactory.getLog(AppointmentRepairRecurrenceString.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AppointmentRepairRecurrenceString.class));
 
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(AppointmentRepairRecurrenceString.class);
-
-    /**
-     * Default constructor.
-     */
     public AppointmentRepairRecurrenceString() {
         super();
     }
@@ -106,11 +95,6 @@ public final class AppointmentRepairRecurrenceString implements UpdateTask {
     /**
      * {@inheritDoc}
      */
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "An SQL error occurred: %1$s." }
-    )
     public void perform(final Schema schema, final int contextId)
         throws DBPoolingException, UpdateException {
         if (LOG.isInfoEnabled()) {
@@ -145,7 +129,7 @@ public final class AppointmentRepairRecurrenceString implements UpdateTask {
             con.commit();
         } catch (final SQLException e) {
             DBUtils.rollback(con);
-            throw EXCEPTION.create(1, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             DBUtils.autocommit(con);
             closeSQLStuff(result, stmt);
