@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,28 +58,20 @@ import java.sql.SQLException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * {@link CalendarExtendDNColumnTask} - Extends size of <tt>VARCHAR</tt> column <i>dn</i> in both working and backup table of
  * <i>prg_date_rights</i>.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class CalendarExtendDNColumnTask implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CalendarExtendDNColumnTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(CalendarExtendDNColumnTask.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CalendarExtendDNColumnTask.class));
 
     /**
      * Desired size for display name taken from ContactsFieldSizeUpdateTask.
@@ -111,73 +103,58 @@ public class CalendarExtendDNColumnTask implements UpdateTask {
     private static final String SQL_MODIFY = "ALTER TABLE #TABLE# MODIFY dn varchar(" + DESIRED_SIZE + ") collate utf8_unicode_ci default NULL";
 
     private void modifyColumnInTable(final String tableName, final int contextId) throws UpdateException {
-        if (checkColumnInTable(tableName, contextId)) {
-            if (LOG.isInfoEnabled()) {
-                LOG.info(CalendarExtendDNColumnTask.class.getSimpleName() + ": Going to extend size of column `dn` in table `" + tableName + "`.");
-            }
-            /*
-             * Column does not exist yet
-             */
-            final Connection writeCon;
-            try {
-                writeCon = Database.getNoTimeout(contextId, true);
-            } catch (final DBPoolingException e) {
-                throw new UpdateException(e);
-            }
-            PreparedStatement stmt = null;
-            try {
-                try {
-                    stmt = writeCon.prepareStatement(SQL_MODIFY.replaceFirst("#TABLE#", tableName));
-                    stmt.executeUpdate();
-                } catch (final SQLException e) {
-                    throw wrapSQLException(e);
-                }
-            } finally {
-                closeSQLStuff(null, stmt);
-                if (writeCon != null) {
-                    Database.backNoTimeout(contextId, true, writeCon);
-                }
-            }
-            if (LOG.isInfoEnabled()) {
-                LOG.info(CalendarExtendDNColumnTask.class.getSimpleName() + ": Size of column `dn` in table `" + tableName + "` successfully extended.");
-            }
+        if (LOG.isInfoEnabled()) {
+            LOG.info(CalendarExtendDNColumnTask.class.getSimpleName() + ": Going to extend size of column `dn` in table `" + tableName + "`.");
         }
-    }
-
-    private boolean checkColumnInTable(final String tableName, final int contextId) throws UpdateException {
-        final Connection writeCon;
+        final Connection con;
         try {
-            writeCon = Database.get(contextId, true);
+            con = Database.getNoTimeout(contextId, true);
         } catch (final DBPoolingException e) {
             throw new UpdateException(e);
         }
-        ResultSet rs = null;
         try {
-            final DatabaseMetaData metadata = writeCon.getMetaData();
-            rs = metadata.getColumns(null, null, tableName, null);
-            while (rs.next()) {
-                final String name = rs.getString("COLUMN_NAME");
-                if ("dn".equals(name)) {
-                    final int size = rs.getInt("COLUMN_SIZE");
-                    return (size < DESIRED_SIZE);
+            // Check if size needs to be increased
+            ResultSet rs = null;
+            try {
+                final DatabaseMetaData metadata = con.getMetaData();
+                rs = metadata.getColumns(null, null, tableName, null);
+                final String columnName = "dn";
+                while (rs.next()) {
+                    final String name = rs.getString("COLUMN_NAME");
+                    if (columnName.equals(name)) {
+                        // A column whose VARCHAR size shall possibly be changed
+                        final int size = rs.getInt("COLUMN_SIZE");
+                        if (size >= DESIRED_SIZE) {
+                            LOG.info(CalendarExtendDNColumnTask.class.getSimpleName() + ": Column " + tableName + '.' + name + " with size " + size + " is already equal to/greater than " + DESIRED_SIZE);
+                            return;
+                        }
+                    }
                 }
+            } catch (final SQLException e) {
+                throw wrapSQLException(e);
+            } finally {
+                closeSQLStuff(rs);
+                rs = null;
+            }
+            // ALTER TABLE...
+            PreparedStatement stmt = null;
+            try {
+                stmt = con.prepareStatement(SQL_MODIFY.replaceFirst("#TABLE#", tableName));
+                stmt.executeUpdate();
+            } catch (final SQLException e) {
+                throw wrapSQLException(e);
+            } finally {
+                closeSQLStuff(stmt);
             }
-            throw notFound(tableName);
-        } catch (final SQLException e) {
-            throw wrapSQLException(e);
         } finally {
-            closeSQLStuff(rs);
-            Database.back(contextId, true, writeCon);
+            Database.backNoTimeout(contextId, true, con);
+        }
+        if (LOG.isInfoEnabled()) {
+            LOG.info(CalendarExtendDNColumnTask.class.getSimpleName() + ": Size of column `dn` in table `" + tableName + "` successfully extended.");
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "SQL error occurred while performing task CalendarExtendDNColumnTask: %1$s." })
     private static UpdateException wrapSQLException(final SQLException e) {
-        return EXCEPTION.create(1, e, e.getMessage());
-    }
-
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 2 }, msg = { "Column \"dn\" not found in table: %1$s." })
-    private static UpdateException notFound(final String tableName) {
-        return EXCEPTION.create(2, tableName);
+        return UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
     }
 }
