@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,7 +65,6 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.OXThrowsMultiple;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
 import com.openexchange.groupware.update.UpdateExceptionCodes;
@@ -77,7 +76,7 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
 
     private final ThreadLocal<Map<Integer, FileStorage>> filestorages = new ThreadLocal<Map<Integer,FileStorage>>();
 
-    private static final Log LOG = LogFactory.getLog(ClearLeftoverAttachmentsUpdateTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ClearLeftoverAttachmentsUpdateTask.class));
 
     public int addedWithVersion() {
         return 11;
@@ -87,12 +86,6 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
         return UpdateTaskPriority.NORMAL.priority;
     }
 
-    @OXThrowsMultiple(
-        category = { AbstractOXException.Category.CODE_ERROR,AbstractOXException.Category.SETUP_ERROR },
-        desc = { "" },
-        exceptionId = { 1,2 },
-        msg = { "An SQL error occurred while performing task ClearLeftoverAttachmentsUpdateTask: %1$s.", "Can't resolve filestore." }
-    )
     public void perform(final Schema schema, final int contextId) throws AbstractOXException {
         try {
             filestorages.set(new HashMap<Integer, FileStorage>());
@@ -100,11 +93,11 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
                 removeFile(att.getFileId(), att.getContextId()); //FIXME will not work during update
                 try {
                     removeDatabaseEntry(att.getId(),att.getContextId());
-                } catch (SQLException e) {
+                } catch (final SQLException e) {
                     throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
                 }
             }
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             filestorages.set(null);
@@ -152,10 +145,8 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
                     LOG.warn("Can't reset auto commit", x);
                 }
 
-                if(writeCon != null) {
-                    Database.back(contextId, true, writeCon);
-                }
-            }   
+                Database.back(contextId, true, writeCon);
+            }
         }
     }
 
@@ -246,9 +237,7 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
             }
 
             if(readCon != null) {
-                if(readCon != null) {
-                    Database.back(false, readCon);
-                }
+                Database.back(false, readCon);
             }
         }
     }
@@ -259,7 +248,7 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
                 "JOIN sequence_attachment ON prg_attachment.cid = sequence_attachment.cid  WHERE prg_attachment.id > sequence_attachment.id";
 
         final List<LeftoverAttachment> attachments = new ArrayList<LeftoverAttachment>();
-        
+
         Connection readCon = null;
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -291,9 +280,7 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
             }
 
             if(readCon != null) {
-                if(readCon != null) {
-                    Database.back(contextId, false, readCon);
-                }
+                Database.back(contextId, false, readCon);
             }
         }
     }
@@ -303,7 +290,7 @@ public class ClearLeftoverAttachmentsUpdateTask implements UpdateTask {
         int id;
         int contextId;
 
-        private LeftoverAttachment(final String fileId, final int id, final int contextId) {
+        LeftoverAttachment(final String fileId, final int id, final int contextId) {
             this.fileId = fileId;
             this.id = id;
             this.contextId = contextId;
