@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,36 +55,24 @@ import static com.openexchange.tools.update.Tools.createIndex;
 import static com.openexchange.tools.update.Tools.existsIndex;
 import java.sql.Connection;
 import java.sql.SQLException;
+import org.apache.commons.logging.Log;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contact.Contacts;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * {@link ContactsAddIndex4AutoCompleteSearch} - Creates indexes on tables "prg_contacts" and "del_contacts" to improve auto-complete
  * search.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class ContactsAddIndex4AutoCompleteSearch implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ContactsAddIndex4AutoCompleteSearch.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(ContactsAddIndex4AutoCompleteSearch.class);
-
-    /**
-     * Initializes a new {@link ContactsAddIndex4AutoCompleteSearch}.
-     */
     public ContactsAddIndex4AutoCompleteSearch() {
         super();
     }
@@ -119,6 +107,7 @@ public final class ContactsAddIndex4AutoCompleteSearch implements UpdateTask {
     }
 
     private void createContactIndex(final Connection con, final String[] tables, final int field, final String name) {
+        final Log log = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ContactsAddIndex4AutoCompleteSearch.class));
         final String fieldName = Contacts.mapping[field].getDBFieldName();
         final String[] columns = { "cid", fieldName };
         final StringBuilder sb = new StringBuilder(64);
@@ -126,7 +115,7 @@ public final class ContactsAddIndex4AutoCompleteSearch implements UpdateTask {
             try {
                 final String indexName = existsIndex(con, table, columns);
                 if (null == indexName) {
-                    if (LOG.isInfoEnabled()) {
+                    if (log.isInfoEnabled()) {
                         sb.setLength(0);
                         sb.append("Creating new index named \"");
                         sb.append(name);
@@ -135,11 +124,11 @@ public final class ContactsAddIndex4AutoCompleteSearch implements UpdateTask {
                         sb.append(") on table ");
                         sb.append(table);
                         sb.append('.');
-                        LOG.info(sb.toString());
+                        log.info(sb.toString());
                     }
                     createIndex(con, table, name, columns, false);
                 } else {
-                    if (LOG.isInfoEnabled()) {
+                    if (log.isInfoEnabled()) {
                         sb.setLength(0);
                         sb.append("New index named \"");
                         sb.append(indexName);
@@ -148,19 +137,18 @@ public final class ContactsAddIndex4AutoCompleteSearch implements UpdateTask {
                         sb.append(") already exists on table ");
                         sb.append(table);
                         sb.append('.');
-                        LOG.info(sb.toString());
+                        log.info(sb.toString());
                     }
                 }
             } catch (final SQLException e) {
-                LOG.error(
+                log.error(
                     new StringBuilder("Problem adding index ").append(name).append(" on table ").append(table).append('.').toString(),
                     e);
             }
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task ContactsAddIndex4AutoCompleteSearch: %1$s." })
     private static UpdateException createSQLError(final SQLException e) {
-        return EXCEPTION.create(1, e, e.getMessage());
+        return UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
     }
 }
