@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,19 +55,16 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 
 /**
@@ -76,24 +73,17 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
  * @author <a href="mailto:ben.pahne@open-xchange.com">Ben Pahne</a>
  *
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class ContactsGlobalMoveUpdateTask implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-    .getLog(ContactsGlobalMoveUpdateTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactsGlobalMoveUpdateTask.class));
 
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(ContactsGlobalMoveUpdateTask.class);
-    
-    /**
-     * Default constructor
-     */
     public ContactsGlobalMoveUpdateTask() {
         super();
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.groupware.update.UpdateTask#addedWithVersion()
      */
     public int addedWithVersion() {
@@ -102,7 +92,7 @@ public final class ContactsGlobalMoveUpdateTask implements UpdateTask {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.groupware.update.UpdateTask#getPriority()
      */
     public int getPriority() {
@@ -118,37 +108,31 @@ public final class ContactsGlobalMoveUpdateTask implements UpdateTask {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.groupware.update.UpdateTask#perform(com.openexchange.groupware.update.Schema,
      *      int)
      */
 
     public void perform(final Schema schema, final int contextId) throws AbstractOXException {
-        correctTable("prg_contacts", contextId);   
+        correctTable("prg_contacts", contextId);
     }
-    
+
     private static final String SQL_QUERY = "SELECT created_from,cid,intfield01 FROM prg_contacts WHERE fid = "+FolderObject.SYSTEM_LDAP_FOLDER_ID+" AND userid is NULL";
 
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 1 },
-            msg = { "An SQL error occurred while performing task ContactsFieldSizeUpdateTask: %1$s." }
-    )    
-    
     public void correctTable(final String sqltable, final int contextId) throws AbstractOXException {
 
         if (LOG.isInfoEnabled()) {
             LOG.info(STR_INFO);
         }
-        
+
         Connection writeCon = null;
         final PreparedStatement stmt = null;
         Statement st = null;
         ResultSet resultSet = null;
         FolderObject des = null;
         try {
-            
+
             writeCon = Database.get(contextId, true);
             try {
                 st = writeCon.createStatement();
@@ -156,46 +140,46 @@ public final class ContactsGlobalMoveUpdateTask implements UpdateTask {
                 Context ct = null;
                 OXFolderAccess oxa = null;
                 resultSet = st.executeQuery(SQL_QUERY);
-                
+
                 if (LOG.isDebugEnabled()) {
                     LOG.debug("UPDATING WRONG GLOBAL ADDRESSBOOK CONTACTS: MOVING BACK TO OWNER'S PRIVATE ADDRESSBOOK");
                 }
-                    
+
                 while (resultSet.next()) {
                     final int creator  = resultSet.getInt(1);
                     final int cid = resultSet.getInt(2);
                     final int id  = resultSet.getInt(3);
-                    
-                    
-                    ct = ContextStorage.getInstance().loadContext(cid);                    
+
+
+                    ct = ContextStorage.getInstance().loadContext(cid);
                     oxa = new OXFolderAccess(writeCon, ct);
                     des = oxa.getDefaultFolder(creator, FolderObject.CONTACT);
-                
+
                     if (LOG.isWarnEnabled()) {
                         LOG.warn("UPDATING OPBJECT "+id+" IN CONTEXT "+cid+" MOVING TO "+des.getObjectID());
                     }
-                        
+
                     final StringBuilder sb = new StringBuilder("UPDATE prg_contacts SET fid = ");
                     sb.append(des.getObjectID());
                     sb.append(" , changing_date = ");
-                    sb.append(System.currentTimeMillis());    
-                    
+                    sb.append(System.currentTimeMillis());
+
                     sb.append(" , changed_from = ");
-                    sb.append(ct.getMailadmin()); 
-                    
+                    sb.append(ct.getMailadmin());
+
                     sb.append(" WHERE cid = ");
                     sb.append(cid);
                     sb.append(" AND intfield01 = ");
                     sb.append(id);
                     st.addBatch(sb.toString());
                 }
-                            
-                
+
+
                 st.executeBatch();
                 st.close();
-                
+
             } catch (final SQLException e) {
-                throw EXCEPTION.create(1, e, e.getMessage());
+                throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
             }
         } finally {
             closeSQLStuff(resultSet, stmt);
@@ -205,5 +189,5 @@ public final class ContactsGlobalMoveUpdateTask implements UpdateTask {
             }
         }
     }
-    
+
 }
