@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,28 +53,19 @@ import java.sql.Connection;
 import java.sql.SQLException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.update.Tools;
 
-
 /**
  * {@link CreateGenconfTablesTask}
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
- *
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class CreateGenconfTablesTask implements UpdateTask {
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(CreateGenconfTablesTask.class);
-    
+
     private static final String STRING_TABLE_CREATE = "CREATE TABLE `genconf_attributes_strings` ( "+
    "`cid` int(10) unsigned NOT NULL,"+
    "`id` int(10) unsigned NOT NULL,"+
@@ -82,7 +73,7 @@ public class CreateGenconfTablesTask implements UpdateTask {
    "`value` varchar(256) COLLATE utf8_unicode_ci DEFAULT NULL,"+
    "KEY (`cid`,`id`,`name`)"+
    ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    
+
     private static final String BOOL_TABLE_CREATE = "CREATE TABLE `genconf_attributes_bools` ("+
     "`cid` int(10) unsigned NOT NULL,"+
    "`id` int(10) unsigned NOT NULL,"+
@@ -90,15 +81,15 @@ public class CreateGenconfTablesTask implements UpdateTask {
    "`value` tinyint(1) COLLATE utf8_unicode_ci DEFAULT NULL,"+
    "KEY (`cid`,`id`,`name`)"+
    ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    
+
     private static final String SEQUENCE_TABLE_CREATE = "CREATE TABLE `sequence_genconf` ("+
     "`cid` int(10) unsigned NOT NULL,"+
     "`id` int(10) unsigned NOT NULL,"+
     "PRIMARY KEY (`cid`)"+
     ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
-    
+
     private static final String INSERT_IN_SEQUENCE = "INSERT INTO sequence_genconf (cid, id) VALUES (?, 0)";
-    
+
     public int addedWithVersion() {
         return 44;
     }
@@ -133,15 +124,8 @@ public class CreateGenconfTablesTask implements UpdateTask {
             }
         }
     }
-    
-    @OXThrowsMultiple(
-        category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "A SQL error occurred while performing task CreateGenconfTablesTask: %1$s." }
-    )
-    private static UpdateException createSQLError(final SQLException e) {
-        return EXCEPTION.create(1, e, e.getMessage());
-    }
 
+    private static UpdateException createSQLError(final SQLException e) {
+        return UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
+    }
 }
