@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,34 +49,20 @@
 
 package com.openexchange.groupware.update.tasks;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * Creates the table version and inserts a single line.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
-@OXExceptionSource(
-        classId = Classes.UPDATE_TASK,
-        component = EnumComponent.UPDATE
-    )
 public final class CreateTableVersion implements UpdateTask {
-    
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-            .getLog(CreateTableVersion.class);
-    
-    /**
-     * For creating exceptions.
-     */
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(CreateTableVersion.class);
-    
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CreateTableVersion.class));
+
 //    private static final String CREATE = "CREATE TABLE foobar (" +
 //            "version INT4 UNSIGNED NOT NULL," +
 //            "boolfield01 BOOLEAN NOT NULL," +
@@ -84,7 +70,7 @@ public final class CreateTableVersion implements UpdateTask {
 //            "boolfield03 BOOLEAN NOT NULL," +
 //            "server VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL)" +
 //            " ENGINE = InnoDB";
-//    
+//
 //    private static final String INSERT = "INSERT INTO foobar VALUES (?, ?, ?, ?, ?)";
 
     /**
@@ -101,15 +87,6 @@ public final class CreateTableVersion implements UpdateTask {
         return 1;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    @OXThrowsMultiple(
-            category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 1 },
-            msg = { "An SQL error occurred while performing task CreateTableVersion: %1$s." }
-    )
     public void perform(final Schema schema, final int contextId) throws AbstractOXException {
         if (LOG.isInfoEnabled()) {
             LOG.info("UpdateTask 'CreateTableVersion' performed!");
@@ -130,7 +107,7 @@ public final class CreateTableVersion implements UpdateTask {
 //                stmt.setString(5, Server.getServerName());
 //                stmt.executeUpdate();
 //            } catch (SQLException e) {
-//                throw EXCEPTION.create(1, e, e.getMessage());
+//                throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 //            }
 //        } finally {
 //            closeSQLStuff(null, stmt);
@@ -139,7 +116,7 @@ public final class CreateTableVersion implements UpdateTask {
 //            }
 //        }
     }
-    
+
     /**
      * {@inheritDoc}
      */
