@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,27 +52,32 @@ package com.openexchange.groupware.update.tasks;
 import static com.openexchange.tools.sql.DBUtils.autocommit;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
 import static com.openexchange.tools.sql.DBUtils.rollback;
-import gnu.trove.TIntObjectHashMap;
-import gnu.trove.TIntObjectProcedure;
+import gnu.trove.map.hash.TIntObjectHashMap;
+import gnu.trove.procedure.TIntObjectProcedure;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Dictionary;
 import java.util.HashMap;
+import java.util.Hashtable;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventAdmin;
 import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
+import com.openexchange.folderstorage.FolderEventConstants;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.AbstractOXException.Category;
+import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.calendar.CalendarCache;
 import com.openexchange.groupware.contact.Contacts;
 import com.openexchange.groupware.container.FolderObject;
@@ -86,13 +91,15 @@ import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTaskAdapter;
 import com.openexchange.i18n.LocaleTools;
 import com.openexchange.i18n.tools.StringHelper;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.Collections.SmartIntArray;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderSQL;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 
 /**
  * {@link DuplicateContactCollectFolderRemoverTask} - Removes duplicate contact collector folders.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAdapter {
@@ -121,7 +128,7 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
         /*
          * Logger
          */
-        final Log log = LogFactory.getLog(DuplicateContactCollectFolderRemoverTask.class);
+        final Log log = com.openexchange.log.Log.valueOf(LogFactory.getLog(DuplicateContactCollectFolderRemoverTask.class));
         /*
          * Progress state
          */
@@ -137,7 +144,7 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
          */
         final Map<Locale, String> names = new HashMap<Locale, String>(4);
         m.forEachEntry(new TIntObjectProcedure<List<Integer>>() {
-            
+
             public boolean execute(final int currentContextId, final List<Integer> list) {
                 try {
                     iterateUsersPerContext(list, names, currentContextId, status, log);
@@ -306,7 +313,7 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
                 }
                 /*-
                  * For each duplicate folder:
-                 * 
+                 *
                  * 1. If it contains contacts: Move all contacts to contact collect folder
                  * 2. Delete folder
                  */
@@ -347,7 +354,7 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
 
         String name = names.get(l);
         if (null == name) {
-            name = new StringHelper(l).getString(FolderStrings.DEFAULT_CONTACT_COLLECT_FOLDER_NAME);
+            name = StringHelper.valueOf(l).getString(FolderStrings.DEFAULT_CONTACT_COLLECT_FOLDER_NAME);
             names.put(l, name);
         }
         return name;
@@ -509,11 +516,14 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
         /*
          * Update caches
          */
+        ConditionTreeMapManagement.dropFor(ctx.getContextId());
         try {
             if (FolderCacheManager.isEnabled()) {
                 FolderCacheManager.getInstance().removeFolderObject(id, ctx);
                 FolderCacheManager.getInstance().removeFolderObject(parent, ctx);
             }
+            broadcastEvent(id, true, userId, ctx.getContextId(), ServerServiceRegistry.getInstance().getService(EventAdmin.class));
+            broadcastEvent(parent, true, userId, ctx.getContextId(), ServerServiceRegistry.getInstance().getService(EventAdmin.class));
             if (CalendarCache.isInitialized()) {
                 CalendarCache.getInstance().invalidateGroup(ctx.getContextId());
             }
@@ -521,4 +531,24 @@ public final class DuplicateContactCollectFolderRemoverTask extends UpdateTaskAd
             log.error(e.getMessage(), e);
         }
     }
+
+    private static void broadcastEvent(final int fuid, final boolean deleted, final int entity, final int contextId, final EventAdmin eventAdmin) {
+        if (null == eventAdmin) {
+            return;
+        }
+        final Dictionary<String, Object> properties = new Hashtable<String, Object>(6);
+        properties.put(FolderEventConstants.PROPERTY_CONTEXT, Integer.valueOf(contextId));
+        properties.put(FolderEventConstants.PROPERTY_USER, Integer.valueOf(entity));
+        properties.put(FolderEventConstants.PROPERTY_FOLDER, String.valueOf(fuid));
+        properties.put(FolderEventConstants.PROPERTY_CONTENT_RELATED, Boolean.valueOf(!deleted));
+        /*
+         * Create event with push topic
+         */
+        final Event event = new Event(FolderEventConstants.TOPIC, properties);
+        /*
+         * Finally deliver it
+         */
+        eventAdmin.sendEvent(event);
+    }
+
 }
