@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,32 +56,23 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.Arrays;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link FolderAddPermColumnUpdateTask}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class FolderAddPermColumnUpdateTask implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-            .getLog(FolderAddPermColumnUpdateTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(
-            FolderAddPermColumnUpdateTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FolderAddPermColumnUpdateTask.class));
 
     public int addedWithVersion() {
         return 28;
@@ -102,7 +93,6 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
 
     private static final String SQL_MODIFY4 = "ALTER TABLE del_oxfolder_permissions DROP PRIMARY KEY, ADD PRIMARY KEY(cid, fuid, permission_id, system)";
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "SQL error occurred while performing task FolderAddPermColumnUpdateTask: %1$s." })
     public void perform(final Schema schema, final int contextId) throws AbstractOXException {
         if (checkColumn(contextId)) {
             if (LOG.isInfoEnabled()) {
@@ -124,7 +114,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                     stmt = writeCon.prepareStatement(SQL_MODIFY2);
                     stmt.executeUpdate();
                 } catch (final SQLException e) {
-                    throw EXCEPTION.create(1, e, e.getMessage());
+                    throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
                 }
             } finally {
                 closeSQLStuff(null, stmt);
@@ -153,7 +143,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                     stmt = writeCon.prepareStatement(SQL_MODIFY4);
                     stmt.executeUpdate();
                 } catch (final SQLException e) {
-                    throw EXCEPTION.create(1, e, e.getMessage());
+                    throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
                 }
             } finally {
                 closeSQLStuff(null, stmt);
@@ -171,13 +161,12 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
     /**
      * Determines if column named 'system' already exists in table
      * 'oxfolder_permissions'
-     * 
+     *
      * @param contextId - the context ID
      * @return <code>true</code> if column named 'system' was found; otherwise
      *         <code>false</code>
      * @throws AbstractOXException
      */
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 2 }, msg = { "SQL error occurred while performing task FolderAddPermColumnUpdateTask: %1$s." })
     private static final boolean checkColumn(final int contextId) throws AbstractOXException {
         Connection readCon = null;
         ResultSet rs = null;
@@ -202,7 +191,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                  * 11. NULLABLE int => is NULL allowed.
                  *                     - columnNoNulls - might not allow NULL values
                  *                     - columnNullable - definitely allows NULL values
-                 *                     - columnNullableUnknown - nullability unknown 
+                 *                     - columnNullableUnknown - nullability unknown
                  * 12. REMARKS String => comment describing column (may be null)
                  * 13. COLUMN_DEF String => default value (may be null)14. SQL_DATA_TYPE int => unused
                  * 15. SQL_DATETIME_SUB int => unused
@@ -218,7 +207,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                  *                           (null if the DATA_TYPE isn't REF)
                  * 22. SOURCE_DATA_TYPE short => source type of a distinct type or user-generated Ref type, SQL type
                  *                               from java.sql.Types (null if DATA_TYPE isn't DISTINCT or user-generated
-                 *                               REF) 
+                 *                               REF)
                  */
                 boolean found = false;
                 while (rs.next() && !found) {
@@ -229,7 +218,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                 }
                 return found;
             } catch (final SQLException e) {
-                throw EXCEPTION.create(2, e, e.getMessage());
+                throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
             }
         } finally {
             DBUtils.closeSQLStuff(rs, null);
@@ -244,13 +233,12 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
     /**
      * Determines if table 'oxfolder_permissions' already has its primary key
      * set to <code>[cid,&nbsp;fuid,&nbsp;permission_id,&nbsp;system]</code>
-     * 
+     *
      * @param contextId - the context ID
      * @return <code>true</code> if table 'oxfolder_permissions' already has its
      *         primary key properly set; otherwise <code>false</code>
      * @throws AbstractOXException
      */
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 3 }, msg = { "SQL error occurred while performing task FolderAddPermColumnUpdateTask: %1$s." })
     private static final boolean checkPrimaryKey(final int contextId) throws AbstractOXException {
         Connection readCon = null;
         ResultSet rs = null;
@@ -287,7 +275,7 @@ public class FolderAddPermColumnUpdateTask implements UpdateTask {
                 }
                 return true;
             } catch (final SQLException e) {
-                throw EXCEPTION.create(3, e, e.getMessage());
+                throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
             }
         } finally {
             closeSQLStuff(rs, null);
