@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,8 +68,8 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.AbstractOXException.Category;
+import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.groupware.update.ProgressState;
@@ -81,12 +81,12 @@ import com.openexchange.tools.oxfolder.OXFolderProperties;
 
 /**
  * {@link GlobalAddressBookPermissionsResolverTask} - Resolves GAB's group permission to individual user permissions.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class GlobalAddressBookPermissionsResolverTask extends UpdateTaskAdapter {
 
-    private static final Log LOG = LogFactory.getLog(GlobalAddressBookPermissionsResolverTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GlobalAddressBookPermissionsResolverTask.class));
 
     /**
      * Initializes a new {@link GlobalAddressBookPermissionsResolverTask}.
