@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,25 +61,15 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
-
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
-
-@OXThrowsMultiple(category={Category.CODE_ERROR}, desc={""}, exceptionId={0}, msg={"A SQL Error occurred while resolving folder name conflicts: %s"})
 
 public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
 
-    private static final Log LOG = LogFactory.getLog(InfostoreRenamePersonalInfostoreFolders.class);
-    private static final UpdateExceptionFactory EXCEPTIONS = new UpdateExceptionFactory(InfostoreRenamePersonalInfostoreFolders.class);
-    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreRenamePersonalInfostoreFolders.class));
+
     public int addedWithVersion() {
         return 8;
     }
@@ -92,14 +82,14 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
             throws AbstractOXException {
         try {
             final List<NameCollision> collisions = NameCollision.getCollisions(contextId, getParentFolder());
-            
+
             for(final NameCollision collision : collisions) {
                 collision.resolve();
             }
-            
+
         } catch (final SQLException e) {
             LOG.error("Error resolving name collisions: ",e);
-            EXCEPTIONS.create(1, e.getMessage(), e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         }
     }
 
@@ -111,34 +101,34 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
     private static final class NameCollision {
         private final String name;
         private final int contextId;
-        
+
         private int nameCount = 1;
-        
+
         public NameCollision(final String name, final int contextId) {
             this.name = name;
             this.contextId = contextId;
         }
-        
+
         public void resolve() throws SQLException, DBPoolingException {
             LOG.info(String.format("Resolving name collisions for folders named %s in context %d", name, contextId));
-            
+
             Connection writeCon = null;
             PreparedStatement stmt = null;
             PreparedStatement checkAvailable = null;
             ResultSet rs = null;
-            
+
             try {
                 writeCon = Database.get(contextId, true);
                 writeCon.setAutoCommit(false);
                 stmt = writeCon.prepareStatement("UPDATE oxfolder_tree SET fname = ? WHERE cid = ? and fuid = ?");
                 stmt.setInt(2, contextId);
-                
+
                 checkAvailable = writeCon.prepareStatement("SELECT 1 FROM oxfolder_tree WHERE cid = ? AND fname = ?");
                 checkAvailable.setInt(1, contextId);
-                
-                
+
+
                 final List<Integer> rename = discoverIds(writeCon);
-            
+
                 for(final int id : rename) {
                     String newName = String.format("%s (%d)", name, nameCount++);
                     boolean free = false;
@@ -156,7 +146,7 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                     stmt.setInt(3, id);
                     stmt.executeUpdate();
                 }
-                
+
                 writeCon.commit();
             } catch (final SQLException x) {
                 try {
@@ -180,7 +170,7 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                         LOG.warn("Couldn't close statement", x);
                     }
                 }
-                
+
                 if(null != rs) {
                     try {
                         rs.close();
@@ -188,22 +178,22 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                         LOG.warn("Couldn't close result set", x);
                     }
                 }
-                
+
                 if(writeCon != null) {
                     try {
                         writeCon.setAutoCommit(true);
                     } catch (final SQLException x){
                         LOG.warn("Can't reset auto commit", x);
                     }
-                    
+
                     if(writeCon != null) {
                         Database.back(contextId, true, writeCon);
                     }
                 }
             }
         }
-        
-        
+
+
         private List<Integer> discoverIds(final Connection writeCon) throws SQLException {
             PreparedStatement stmt = null;
             ResultSet rs = null;
@@ -212,11 +202,11 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                 stmt = writeCon.prepareStatement("SELECT fuid FROM oxfolder_tree WHERE cid = ? and fname = ?");
                 stmt.setInt(1, contextId);
                 stmt.setString(2,name);
-                
+
                 rs = stmt.executeQuery();
                 while(rs.next()) { ids.add(rs.getInt(1)); }
-                
-                
+
+
             } finally {
                 if(null != stmt) {
                     try {
@@ -233,7 +223,7 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                     }
                 }
             }
-            
+
             Collections.sort(ids);
             ids.remove(ids.size()-1);
             return ids;
@@ -242,13 +232,13 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
         public String getName(){
             return name;
         }
-        
+
         public int getContextId(){
             return contextId;
         }
-        
-        
-        
+
+
+
         public static List<NameCollision> getCollisions(final int contextId, final int parentFolder) throws SQLException, DBPoolingException {
             final List<NameCollision> c = new ArrayList<NameCollision>();
             Connection writeCon = null;
@@ -266,18 +256,18 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                 }
 
                 rs = stmt.executeQuery();
-                
+
                 while(rs.next()) {
                     final NameCollision nc = new NameCollision(rs.getString(1), rs.getInt(2));
                     c.add(nc);
                 }
-                
+
                 rs.close();
                 rs = null;
-                
+
                 return c;
             } finally {
-                
+
                 if(null != stmt) {
                     try {
                         stmt.close();
@@ -292,7 +282,7 @@ public class InfostoreRenamePersonalInfostoreFolders implements UpdateTask {
                         LOG.warn("Couldn't close result set", x);
                     }
                 }
-                
+
                 if(null != writeCon) {
                     Database.back(contextId, true, writeCon);
                 }
