@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,27 +58,19 @@ import java.sql.SQLException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * {@link MailAccountCreateTablesTask} - Inserts necessary tables to support multiple mail accounts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class MailAccountCreateTablesTask implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountCreateTablesTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(MailAccountCreateTablesTask.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccountCreateTablesTask.class));
 
     public int addedWithVersion() {
         return 40;
@@ -89,85 +81,83 @@ public class MailAccountCreateTablesTask implements UpdateTask {
     }
 
     private static final String getCreateMailAccount() {
-        return "CREATE TABLE `user_mail_account` (" + 
-            "id INT4 unsigned NOT NULL," + 
-            "cid INT4 unsigned NOT NULL," + 
-            "user INT4 unsigned NOT NULL," + 
-            "name VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "url VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "login varchar(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "password VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," + 
-            "primary_addr VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "personal VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," + 
-            "default_flag TINYINT unsigned NOT NULL default 0," + 
-            "spam_handler VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "trash VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "sent VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "drafts VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "spam VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "confirmed_spam VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "confirmed_ham VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "unified_inbox TINYINT unsigned default 0," + 
-            "trash_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "sent_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "drafts_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "spam_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "confirmed_spam_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "confirmed_ham_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-            "PRIMARY KEY  (cid, id, user)," + 
-            "INDEX (cid, user)," + 
-            "FOREIGN KEY (cid, user) REFERENCES user (cid, id)" + 
+        return "CREATE TABLE `user_mail_account` (" +
+            "id INT4 unsigned NOT NULL," +
+            "cid INT4 unsigned NOT NULL," +
+            "user INT4 unsigned NOT NULL," +
+            "name VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "url VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "login varchar(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "password VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +
+            "primary_addr VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "personal VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +
+            /*"replyTo VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +*/
+            "default_flag TINYINT unsigned NOT NULL default 0," +
+            "spam_handler VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "trash VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "sent VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "drafts VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "spam VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "confirmed_spam VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "confirmed_ham VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "unified_inbox TINYINT unsigned default 0," +
+            "trash_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "sent_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "drafts_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "spam_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "confirmed_spam_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "confirmed_ham_fullname VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+            "PRIMARY KEY  (cid, id, user)," +
+            "INDEX (cid, user)" +
             ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
     }
 
     private static final String getCreateTransportAccount() {
-        return "CREATE TABLE `user_transport_account` (" + 
-                "id INT4 unsigned NOT NULL," + 
-                "cid INT4 unsigned NOT NULL," + 
-                "user INT4 unsigned NOT NULL," + 
-                "name VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "url VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "login varchar(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "password VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," + 
-                "send_addr VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "personal VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," + 
-                "default_flag TINYINT unsigned NOT NULL default 0," + 
-                "unified_inbox TINYINT unsigned default 0," + 
-                "PRIMARY KEY  (cid, id, user)," + 
-                "INDEX (cid, user)," + 
-                "FOREIGN KEY (cid, user) REFERENCES user (cid, id)" + 
+        return "CREATE TABLE `user_transport_account` (" +
+                "id INT4 unsigned NOT NULL," +
+                "cid INT4 unsigned NOT NULL," +
+                "user INT4 unsigned NOT NULL," +
+                "name VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "url VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "login varchar(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "password VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +
+                "send_addr VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "personal VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +
+                /*"replyTo VARCHAR(64) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL," +*/
+                "default_flag TINYINT unsigned NOT NULL default 0," +
+                "unified_inbox TINYINT unsigned default 0," +
+                "PRIMARY KEY  (cid, id, user)," +
+                "INDEX (cid, user)" +
                 ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
     }
 
     private static final String getCreateMailAccountProperties() {
-        return "CREATE TABLE user_mail_account_properties (" + 
-                "id INT4 unsigned NOT NULL," + 
-                "cid INT4 unsigned NOT NULL," + 
-                "user INT4 unsigned NOT NULL," + 
-                "name VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "value VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "PRIMARY KEY  (cid, id, user, name)," + 
-                "FOREIGN KEY (cid, id, user) REFERENCES user_mail_account (cid, id, user)" + 
+        return "CREATE TABLE user_mail_account_properties (" +
+                "id INT4 unsigned NOT NULL," +
+                "cid INT4 unsigned NOT NULL," +
+                "user INT4 unsigned NOT NULL," +
+                "name VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "value VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "PRIMARY KEY  (cid, id, user, name)" +
                 ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
     }
 
     private static final String getCreateTransportAccountProperties() {
-        return "CREATE TABLE user_transport_account_properties (" + 
-                "id INT4 unsigned NOT NULL," + 
-                "cid INT4 unsigned NOT NULL," + 
-                "user INT4 unsigned NOT NULL," + 
-                "name VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "value VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," + 
-                "PRIMARY KEY  (cid, id, user, name)," + 
-                "FOREIGN KEY (cid, id, user) REFERENCES user_transport_account (cid, id, user)" + 
+        return "CREATE TABLE user_transport_account_properties (" +
+                "id INT4 unsigned NOT NULL," +
+                "cid INT4 unsigned NOT NULL," +
+                "user INT4 unsigned NOT NULL," +
+                "name VARCHAR(128) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "value VARCHAR(256) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+                "PRIMARY KEY  (cid, id, user, name)" +
                 ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
     }
 
     private static final String getCreateSequence() {
-        return "CREATE TABLE sequence_mail_service (" + 
-                "cid INT4 unsigned NOT NULL," + 
-                "id INT4 unsigned NOT NULL," + 
-                "PRIMARY KEY (cid)" + 
+        return "CREATE TABLE sequence_mail_service (" +
+                "cid INT4 unsigned NOT NULL," +
+                "id INT4 unsigned NOT NULL," +
+                "PRIMARY KEY (cid)" +
                 ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
     }
 
@@ -213,7 +203,7 @@ public class MailAccountCreateTablesTask implements UpdateTask {
 
     /**
      * Check a table's existence
-     * 
+     *
      * @param tableName The table name to check
      * @param dbmd The database's meta data
      * @return <code>true</code> if table exists; otherwise <code>false</code>
@@ -229,13 +219,7 @@ public class MailAccountCreateTablesTask implements UpdateTask {
         }
     }
 
-    @OXThrowsMultiple(
-        category = { Category.CODE_ERROR },
-        desc = { "" },
-        exceptionId = { 1 },
-        msg = { "A SQL error occurred while performing task MailAccountCreateTablesTask: %1$s." }
-    )
     private static UpdateException createSQLError(final SQLException e) {
-        return EXCEPTION.create(1, e, e.getMessage());
+        return UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
     }
 }
