@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,52 +64,58 @@ import java.util.Map;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
-import com.openexchange.groupware.ldap.LdapException;
+import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.groupware.ldap.RdbUserStorage;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
+import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.groupware.update.ProgressState;
+import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTaskAdapter;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateException;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountDescription;
+import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.spamhandler.SpamHandler;
 
 /**
  * {@link MailAccountMigrationTask} - Migrates mail account data kept in user table to mail account table.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class MailAccountMigrationTask extends UpdateTaskAdapter {
 
     public MailAccountMigrationTask() {
         super();
     }
 
+    @Override
     public int addedWithVersion() {
         return 40;
     }
 
+    @Override
     public int getPriority() {
         return UpdateTaskPriority.HIGH.priority;
     }
 
+    private static final String[] DEPENDENCIES = { MailAccountCreateTablesTask.class.getName() };
+
+    public String[] getDependencies() {
+        return DEPENDENCIES;
+    }
+
     public void perform(final PerformParameters params) throws AbstractOXException {
         final int contextId = params.getContextId();
         final Map<Integer, List<Integer>> m = getAllUsers(contextId);
         final ProgressState state = params.getProgressState();
+        state.setTotal(m.size());
         for (final Iterator<Map.Entry<Integer, List<Integer>>> it = m.entrySet().iterator(); it.hasNext();) {
             final Map.Entry<Integer, List<Integer>> me = it.next();
             final int currentContextId = me.getKey().intValue();
@@ -121,7 +127,7 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
                 sb.append(currentContextId);
                 sb.append(":\n");
                 sb.append(e.getMessage());
-                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class);
+                final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class));
                 LOG.error(sb.toString(), e);
             }
             state.incrementState();
@@ -158,7 +164,7 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
             } while (rs.next());
             return m;
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             Database.back(contextId, true, writeCon);
@@ -173,28 +179,29 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
             throw new UpdateException(e);
         }
         PreparedStatement stmt = null;
+        ResultSet result = null;
         try {
             stmt = writeCon.prepareStatement("SELECT id FROM user_mail_account WHERE cid = ? AND id = ? AND user = ?");
             stmt.setInt(1, contextId);
             stmt.setInt(2, MailAccount.DEFAULT_ID);
             stmt.setInt(3, userId);
-            return stmt.executeQuery().next();
+            result = stmt.executeQuery();
+            return result.next();
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(stmt);
+            closeSQLStuff(result, stmt);
             Database.back(contextId, true, writeCon);
         }
     }
 
     private static void iterateUsersPerContext(final List<Integer> users, final int contextId) throws UpdateException {
         final Context ctx = new ContextImpl(contextId);
-        final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class);
+        final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class));
         // First check (and possibly insert) a sequence for specified context
         checkAndInsertMailAccountSequence(ctx);
         // Proceed with user data migration to new mail account tables
         try {
-            final RdbUserStorage rdbUserStorage = new RdbUserStorage();
             final StringBuilder sb = new StringBuilder(256);
             for (final Integer userId : users) {
                 // Check for default account
@@ -213,20 +220,51 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
                         ctx.getContextId()));
                 }
                 // Create default account
-                final User user = rdbUserStorage.getUser(userId.intValue(), ctx);
-                final UserSettingMail usm = UserSettingMailStorage.getInstance().getUserSettingMail(userId.intValue(), ctx);
+                final User user = loadUser(ctx, userId.intValue());
+                final UserSettingMail usm = loadUserSettingMail(ctx, userId.intValue());
                 try {
                     handleUser(user, getNameProvderFromUSM(usm), ctx, sb, LOG);
                 } catch (final UpdateException e) {
                     LOG.error("Default mail account for user " + user.getId() + " in context " + contextId + " could not be created", e);
+                } catch (final MailAccountException e) {
+                    LOG.error("Default mail account for user " + user.getId() + " in context " + contextId + " could not be created", e);
                 }
             }
-        } catch (final LdapException e) {
+        } catch (final UserException e) {
             throw new UpdateException(e);
         }
     }
 
-    private static void handleUser(final User user, final FolderNameProvider folderNameProvdider, final Context ctx, final StringBuilder sb, final org.apache.commons.logging.Log LOG) throws UpdateException {
+    private static User loadUser(final Context ctx, final int userId) throws UpdateException, UserException {
+        final Connection con;
+        try {
+            con = Database.get(ctx, true);
+        } catch (final DBPoolingException e) {
+            throw new UpdateException(e);
+        }
+        try {
+            final UserStorage userStorage = new RdbUserStorage();
+            return userStorage.getUser(ctx, userId, con);
+        } finally {
+            Database.back(ctx, true, con);
+        }
+    }
+
+    private static UserSettingMail loadUserSettingMail(final Context ctx, final int userId) throws UpdateException {
+        final Connection con;
+        try {
+            con = Database.get(ctx, true);
+        } catch (final DBPoolingException e) {
+            throw new UpdateException(e);
+        }
+        try {
+            return UserSettingMailStorage.getInstance().getUserSettingMail(userId, ctx, con);
+        } finally {
+            Database.back(ctx, true, con);
+        }
+    }
+
+    private static void handleUser(final User user, final FolderNameProvider folderNameProvdider, final Context ctx, final StringBuilder sb, final org.apache.commons.logging.Log LOG) throws UpdateException, MailAccountException {
         /*
          * Insert
          */
@@ -239,7 +277,7 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
         }
     }
 
-    private static MailAccountDescription createAccountDescription(final User user, final FolderNameProvider folderNameProvdider) {
+    private static MailAccountDescription createAccountDescription(final User user, final FolderNameProvider folderNameProvdider) throws MailAccountException {
         final MailAccountDescription account = new MailAccountDescription();
         account.setDefaultFlag(true);
         account.setConfirmedHam(prepareNonNullString(folderNameProvdider.getConfirmedHam()));
@@ -263,12 +301,6 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
         return null == string ? "" : string;
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task MailAccountMigrationTask: %1$s." })
-    private static UpdateException createSQLError(final SQLException e) {
-        final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(MailAccountMigrationTask.class);
-        return EXCEPTION.create(1, e, e.getMessage());
-    }
-
     private static interface FolderNameProvider {
 
         String getTrash();
@@ -287,27 +319,27 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
     private static final FolderNameProvider DEFAULT_NAME_PROVIDER = new FolderNameProvider() {
 
         public String getConfirmedHam() {
-            return UserSettingMail.STD_CONFIRMED_HAM;
+            return MailStrings.CONFIRMED_HAM;
         }
 
         public String getConfirmedSpam() {
-            return UserSettingMail.STD_CONFIRMED_SPAM;
+            return MailStrings.CONFIRMED_SPAM;
         }
 
         public String getDrafts() {
-            return UserSettingMail.STD_DRAFTS;
+            return MailStrings.DRAFTS;
         }
 
         public String getSent() {
-            return UserSettingMail.STD_SENT;
+            return MailStrings.SENT;
         }
 
         public String getSpam() {
-            return UserSettingMail.STD_SPAM;
+            return MailStrings.SPAM;
         }
 
         public String getTrash() {
-            return UserSettingMail.STD_TRASH;
+            return MailStrings.TRASH;
         }
     };
 
@@ -403,7 +435,9 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
             stmt.setInt(pos++, 1);
             stmt.executeUpdate();
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
+        } catch (final MailAccountException e) {
+            throw new UpdateException(e);
         } finally {
             closeSQLStuff(stmt);
             Database.back(cid, true, con);
@@ -435,11 +469,10 @@ public final class MailAccountMigrationTask extends UpdateTaskAdapter {
             stmt.setLong(2, 0);
             stmt.executeUpdate();
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             Database.back(cid, true, con);
         }
     }
-
 }
