@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -46,6 +46,7 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.groupware.update.tasks;
 
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
@@ -58,34 +59,25 @@ import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.Map;
-import com.openexchange.database.DBPoolingException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * @author choeger
- * 
+ *
  */
-@OXExceptionSource(
-        classId = Classes.TASK_NEW_ADMIN_EXTENSIONS,
-        component = EnumComponent.UPDATE)
 public class NewAdminExtensionsUpdateTask implements UpdateTask {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(NewAdminExtensionsUpdateTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(NewAdminExtensionsUpdateTask.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(NewAdminExtensionsUpdateTask.class));
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.groupware.update.UpdateTask#addedWithVersion()
      */
     public int addedWithVersion() {
@@ -94,7 +86,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.groupware.update.UpdateTask#getPriority()
      */
     public int getPriority() {
@@ -105,7 +97,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
     }
 
     private static final String STR_INFO = "Performing update task 'NewAdminExtensionsUpdateTask'";
-    
+
     private static final String CREATE_SEQUENCE_UID  = "CREATE TABLE IF NOT EXISTS `sequence_uid_number` ( `cid` INT4 unsigned NOT NULL, `id` INT4 unsigned NOT NULL, PRIMARY KEY  (`cid`)) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
     private static final String CREATE_SEQUENCE_GID  = "CREATE TABLE IF NOT EXISTS `sequence_gid_number` ( `cid` INT4 unsigned NOT NULL, `id` INT4 unsigned NOT NULL, PRIMARY KEY  (`cid`)) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
     private static final String CREATE_SEQUENCE_MAIL = "CREATE TABLE IF NOT EXISTS `sequence_mail_service` ( `cid` INT4 unsigned NOT NULL, `id` INT4 unsigned NOT NULL, PRIMARY KEY  (`cid`)) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
@@ -115,27 +107,18 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
     private static final String TABLE_GROUPS       = "groups";
     private static final String TABLE_DEL_GROUPS   = "del_groups";
 
-    private static final String COL_UID_NUMBER     = "uidNumber"; 
-    private static final String COL_GID_NUMBER     = "gidNumber"; 
-    private static final String COL_HOME_DIRECTORY = "homeDirectory"; 
-    private static final String COL_LOGIN_SHELL    = "loginShell"; 
-    private static final String COL_PASSWORD_MECH  = "passwordMech"; 
+    private static final String COL_UID_NUMBER     = "uidNumber";
+    private static final String COL_GID_NUMBER     = "gidNumber";
+    private static final String COL_HOME_DIRECTORY = "homeDirectory";
+    private static final String COL_LOGIN_SHELL    = "loginShell";
+    private static final String COL_PASSWORD_MECH  = "passwordMech";
 
     private static final int NOGROUP    = 65534;
     private static final int NOBODY     = 65534;
     private static final String NOHOME  = "/dev/null";
     private static final String NOSHELL = "/bin/false";
-    private static final String SHA     = "{SHA}";    
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.groupware.update.UpdateTask#perform(com.openexchange.groupware.update.Schema,
-     *      int)
-     */
-    @OXThrowsMultiple(category = { Category.SUBSYSTEM_OR_SERVICE_DOWN, Category.CODE_ERROR },
-            desc = { "", "" },
-            exceptionId = { 1, 2 },
-            msg = { "Cannot get database connection.", "SQL Problem: \"%s\"." })
+    private static final String SHA     = "{SHA}";
+
     public void perform(final Schema schema, final int contextId) throws AbstractOXException {
         if (LOG.isInfoEnabled()) {
             LOG.info(STR_INFO);
@@ -144,12 +127,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
         final Hashtable<String, ArrayList<String>> missingCols = missingColumns(contextId);
         final boolean deleteLastmodified = tableContainsColumn(contextId, "del_user", "lastModified");
 
-        Connection writeCon = null;
-        try {
-            writeCon = Database.get(contextId, true);
-        } catch (final DBPoolingException e) {
-            throw EXCEPTION.create(1, e);
-        }
+        Connection writeCon = Database.get(contextId, true);
         try {
             writeCon.setAutoCommit(false);
             createSequenceTables(writeCon, contextId);
@@ -160,7 +138,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
             }
             writeCon.commit();
         } catch (final SQLException e) {
-            throw EXCEPTION.create(2, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             try {
                 writeCon.setAutoCommit(true);
@@ -172,12 +150,8 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
 
     }
 
-    @OXThrowsMultiple(category = { Category.SUBSYSTEM_OR_SERVICE_DOWN, Category.CODE_ERROR },
-            desc = { "", "" },
-            exceptionId = { 3, 4 },
-            msg = { "Cannot get database connection.", "SQL Problem: \"%s\"." })
     private final Hashtable<String, ArrayList<String>> missingColumns(final int contextId) throws AbstractOXException {
-        Connection readCon = null;
+        Connection readCon = Database.get(contextId, false);
         Statement stmt = null;
         ResultSet rs = null;
 
@@ -196,11 +170,6 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
             retTables.put(table, ret);
         }
 
-        try {
-            readCon = Database.get(contextId, false);
-        } catch (final DBPoolingException e) {
-            throw EXCEPTION.create(3, e);
-        }
         try {
             stmt = readCon.createStatement();
             for(final String table : new String[]{ TABLE_USER, TABLE_GROUPS, TABLE_DEL_USER, TABLE_DEL_GROUPS } ) {
@@ -221,7 +190,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
 
             return retTables;
         } catch (final SQLException e) {
-            throw EXCEPTION.create(4, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             if (readCon != null) {
@@ -230,10 +199,6 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 5 },
-            msg = { "SQL Problem: \"%s\"." })
     private void createSequenceTables(final Connection con, final int contextId) throws AbstractOXException {
         PreparedStatement stmt = null;
         try {
@@ -245,23 +210,19 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                 stmt.close();
             }
         } catch (final SQLException e) {
-            throw EXCEPTION.create(5, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(null, stmt);
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 6 },
-            msg = { "SQL Problem: \"%s\"." })
     private void alterTables(final Connection con, final int contextId, final Hashtable<String, ArrayList<String>> missingCols) throws AbstractOXException {
         PreparedStatement stmt = null;
         try {
             for(final Map.Entry<String, ArrayList<String>> entry : missingCols.entrySet() ) {
                 final String table = entry.getKey();
                 final ArrayList<String> cols = entry.getValue();
-                if( cols.size() > 0 && 
+                if( cols.size() > 0 &&
                         ( table.equals(TABLE_USER) || table.equals(TABLE_DEL_USER) ) ) {
                     for( final String col : cols ) {
                         if( col.equals(COL_GID_NUMBER) ) {
@@ -285,8 +246,8 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                             stmt.executeUpdate();
                             stmt.close();
                         }
-                    }                        
-                } else if( cols.size() > 0 && 
+                    }
+                } else if( cols.size() > 0 &&
                         ( table.equals(TABLE_GROUPS) || table.equals(TABLE_DEL_GROUPS) ) ) {
                     for( final String col : cols ) {
                         if( col.equals(COL_GID_NUMBER) ) {
@@ -298,23 +259,19 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                 }
             }
         } catch (final SQLException e) {
-            throw EXCEPTION.create(6, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(null, stmt);
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 7 },
-            msg = { "SQL Problem: \"%s\"." })
     private void updateTables(final Connection con, final int contextId, final Hashtable<String, ArrayList<String>> missingCols) throws AbstractOXException {
         PreparedStatement stmt = null;
         try {
             for(final Map.Entry<String, ArrayList<String>> entry : missingCols.entrySet() ) {
                 final String table = entry.getKey();
                 final ArrayList<String> cols = entry.getValue();
-                if( cols.size() > 0 && 
+                if( cols.size() > 0 &&
                         ( table.equals(TABLE_USER) || table.equals(TABLE_DEL_USER) ) ) {
                     for( final String col : cols ) {
                         if( col.equals(COL_GID_NUMBER) ) {
@@ -343,8 +300,8 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                             stmt.executeUpdate();
                             stmt.close();
                         }
-                    }                        
-                } else if( cols.size() > 0 && 
+                    }
+                } else if( cols.size() > 0 &&
                         ( table.equals(TABLE_GROUPS) || table.equals(TABLE_DEL_GROUPS) ) ) {
                     for( final String col : cols ) {
                         if( col.equals(COL_GID_NUMBER) ) {
@@ -357,26 +314,17 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                 }
             }
         } catch (final SQLException e) {
-            throw EXCEPTION.create(7, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(null, stmt);
         }
     }
 
-    @OXThrowsMultiple(category = { Category.SUBSYSTEM_OR_SERVICE_DOWN, Category.CODE_ERROR },
-            desc = { "", "" },
-            exceptionId = { 8, 9 },
-            msg = { "Cannot get database connection.", "SQL Problem: \"%s\"." })
     private final boolean tableContainsColumn(final int contextId, final String table, final String column) throws AbstractOXException {
-        Connection readCon = null;
+        Connection readCon = Database.get(contextId, false);
         Statement stmt = null;
         ResultSet rs = null;
 
-        try {
-            readCon = Database.get(contextId, false);
-        } catch (final DBPoolingException e) {
-            throw EXCEPTION.create(8, e);
-        }
         try {
             try {
                 stmt = readCon.createStatement();
@@ -391,7 +339,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
                 }
                 return found;
             } catch (final SQLException e) {
-                throw EXCEPTION.create(9, e, e.getMessage());
+                throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
             }
         } finally {
             closeSQLStuff(rs, stmt);
@@ -401,10 +349,6 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR },
-            desc = { "" },
-            exceptionId = { 10 },
-            msg = { "SQL Problem: \"%s\"." })
     private void removeColumnFromTable(final Connection con, final int contextId, final String column, final String table) throws AbstractOXException {
         PreparedStatement stmt = null;
         try {
@@ -412,7 +356,7 @@ public class NewAdminExtensionsUpdateTask implements UpdateTask {
             stmt.executeUpdate();
             stmt.close();
         } catch (final SQLException e) {
-            throw EXCEPTION.create(10, e, e.getMessage());
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(null, stmt);
         }
