@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,44 +56,32 @@ import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.sql.Statement;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * PasswordMechUpdateTask - Adds column <tt>passwordMech</tt> to table
  * <tt>user</tt> if it does not exist, yet
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class PasswordMechUpdateTask implements UpdateTask {
 
-	private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-			.getLog(PasswordMechUpdateTask.class);
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PasswordMechUpdateTask.class));
 
-	private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(PasswordMechUpdateTask.class);
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.openexchange.groupware.update.UpdateTask#addedWithVersion()
-	 */
 	public int addedWithVersion() {
 		return 1;
 	}
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see com.openexchange.groupware.update.UpdateTask#getPriority()
 	 */
 	public int getPriority() {
@@ -111,13 +99,6 @@ public class PasswordMechUpdateTask implements UpdateTask {
 
 	private static final String STR_INFO = "Performing update task 'PasswordMechUpdateTask'";
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.openexchange.groupware.update.UpdateTask#perform(com.openexchange.groupware.update.Schema,
-	 *      int)
-	 */
-	@OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 2 }, msg = { "An SQL error occurred while performing task PasswordMechUpdateTask: %1$s." })
 	public void perform(final Schema schema, final int contextId) throws AbstractOXException {
 		if (LOG.isInfoEnabled()) {
 			LOG.info(STR_INFO);
@@ -140,7 +121,7 @@ public class PasswordMechUpdateTask implements UpdateTask {
 				stmt.setString(1, SHA);
 				stmt.executeUpdate();
 			} catch (final SQLException e) {
-				throw EXCEPTION.create(2, e, e.getMessage());
+	            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 			}
 		} finally {
 			closeSQLStuff(null, stmt);
@@ -156,14 +137,13 @@ public class PasswordMechUpdateTask implements UpdateTask {
 
 	/**
 	 * Determines if column named 'passwordMech' already exists in table 'user'
-	 * 
+	 *
 	 * @param contextId -
 	 *            the context ID
 	 * @return <code>true</code> if column named 'passwordMech' was found;
 	 *         otherwise <code>false</code>
 	 * @throws AbstractOXException
 	 */
-	@OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "An SQL error occurred while performing task PasswordMechUpdateTask: %1$s." })
 	private static final boolean checkColumn(final int contextId) throws AbstractOXException {
 		Connection readCon = null;
 		Statement stmt = null;
@@ -181,7 +161,7 @@ public class PasswordMechUpdateTask implements UpdateTask {
 				}
 				return found;
 			} catch (final SQLException e) {
-				throw EXCEPTION.create(1, e, e.getMessage());
+	            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 			}
 		} finally {
 			closeSQLStuff(rs, stmt);
