@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,45 +56,33 @@ import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.sql.Statement;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
+import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
-import com.openexchange.mail.usersetting.UserSettingMail;
 
 /**
  * SpamUpdateTask - Inserts columns <tt>confirmed_spam</tt> and
  * <tt>confirmed_ham</tt> to table <tt>user_setting_mail</tt>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public class SpamUpdateTask implements UpdateTask {
 
-	private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-			.getLog(SpamUpdateTask.class);
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(SpamUpdateTask.class));
 
-	private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(SpamUpdateTask.class);
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.openexchange.groupware.update.UpdateTask#addedWithVersion()
-	 */
 	public int addedWithVersion() {
 		return 1;
 	}
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see com.openexchange.groupware.update.UpdateTask#getPriority()
 	 */
 	public int getPriority() {
@@ -107,27 +95,15 @@ public class SpamUpdateTask implements UpdateTask {
 	private static final String SQL_MODIFY = "ALTER TABLE user_setting_mail "
 			+ "ADD COLUMN confirmed_spam VARCHAR(128) character set utf8 collate utf8_unicode_ci NOT NULL, "
 			+ "ADD COLUMN confirmed_ham VARCHAR(128) character set utf8 collate utf8_unicode_ci NOT NULL";
-	
+
 	private static final String SQL_UPDATE = "UPDATE user_setting_mail SET confirmed_spam = ?, confirmed_ham = ?";
-	
+
 	private static final String STR_INFO = "Performing update task 'SpamUpdateTask'";
-	
+
 	private static final String CONFIRMED_SPAM = "confirmed_spam";
-	
+
 	private static final String CONFIRMED_HAM = "confirmed_ham";
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.openexchange.groupware.update.UpdateTask#perform(com.openexchange.groupware.update.Schema,
-	 *      int)
-	 */
-	@OXThrowsMultiple(
-			category = { Category.CODE_ERROR },
-			desc = { "" },
-			exceptionId = { 1 },
-			msg = { "An SQL error occurred while performing task SpamUpdateTask: %1$s." }
-		)
 	public void perform(final Schema schema, final int contextId) throws AbstractOXException {
 		if (LOG.isInfoEnabled()) {
 			LOG.info(STR_INFO);
@@ -144,11 +120,11 @@ public class SpamUpdateTask implements UpdateTask {
 				stmt.executeUpdate();
 				stmt.close();
 				stmt = writeCon.prepareStatement(SQL_UPDATE);
-				stmt.setString(1, UserSettingMail.STD_CONFIRMED_SPAM);
-				stmt.setString(2, UserSettingMail.STD_CONFIRMED_HAM);
+				stmt.setString(1, MailStrings.CONFIRMED_SPAM);
+				stmt.setString(2, MailStrings.CONFIRMED_HAM);
 				stmt.executeUpdate();
 			} catch (final SQLException e) {
-				throw EXCEPTION.create(1, e, e.getMessage());
+	            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 			}
 		} finally {
 			closeSQLStuff(null, stmt);
@@ -157,15 +133,9 @@ public class SpamUpdateTask implements UpdateTask {
 			}
 		}
 	}
-	
+
 	private static final String SQL_SELECT_ALL = "SELECT * FROM user_setting_mail";
-	
-	@OXThrowsMultiple(
-			category = { Category.CODE_ERROR },
-			desc = { "" },
-			exceptionId = { 2 },
-			msg = { "An SQL error occurred while performing task PasswordMechUpdateTask: %1$s." }
-	)
+
 	private static final boolean checkExistence(final String colName, final int contextId) throws AbstractOXException {
 		Connection readCon = null;
 		Statement stmt = null;
@@ -183,7 +153,7 @@ public class SpamUpdateTask implements UpdateTask {
 				}
 				return found;
 			} catch (final SQLException e) {
-				throw EXCEPTION.create(2, e, e.getMessage());
+	            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 			}
 		} finally {
 			closeSQLStuff(rs, stmt);
