@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,32 +55,24 @@ import java.sql.DatabaseMetaData;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.update.Schema;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
 
 /**
  * {@link SpellCheckUserDictTableTask} - Creates the table
  * <i>spellcheck_user_dict</i> used to store user dictionaries.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
 public final class SpellCheckUserDictTableTask implements UpdateTask {
 
-	private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
-			.getLog(SpellCheckUserDictTableTask.class);
-
-	private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(
-			SpellCheckUserDictTableTask.class);
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(SpellCheckUserDictTableTask.class));
 
 	private static final String CREATE = "CREATE TABLE spellcheck_user_dict (" + "cid INT4 UNSIGNED NOT NULL,"
 			+ "user INT4 UNSIGNED NOT NULL,"
@@ -96,7 +88,7 @@ public final class SpellCheckUserDictTableTask implements UpdateTask {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see com.openexchange.groupware.update.UpdateTask#addedWithVersion()
 	 */
 	public int addedWithVersion() {
@@ -105,20 +97,13 @@ public final class SpellCheckUserDictTableTask implements UpdateTask {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see com.openexchange.groupware.update.UpdateTask#getPriority()
 	 */
 	public int getPriority() {
 		return UpdateTaskPriority.HIGH.priority;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.openexchange.groupware.update.UpdateTask#perform(com.openexchange.groupware.update.Schema,
-	 *      int)
-	 */
-	@OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task SpellCheckUserDictTableTask: %1$s." })
 	public void perform(final Schema schema, final int contextId) throws AbstractOXException {
 		Connection writeCon = null;
 		PreparedStatement stmt = null;
@@ -131,7 +116,7 @@ public final class SpellCheckUserDictTableTask implements UpdateTask {
 				stmt = writeCon.prepareStatement(CREATE);
 				stmt.executeUpdate();
 			} catch (final SQLException e) {
-				throw EXCEPTION.create(1, e, e.getMessage());
+	            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
 			}
 		} finally {
 			closeSQLStuff(null, stmt);
@@ -152,7 +137,7 @@ public final class SpellCheckUserDictTableTask implements UpdateTask {
 
 	/**
 	 * Check a table's existence
-	 * 
+	 *
 	 * @param tableName
 	 *            The table name to check
 	 * @param dbmd
