@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,13 +85,13 @@ import com.openexchange.groupware.update.internal.UpdateProcess;
 
 /**
  * MBean for update task toolkit.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public final class UpdateTaskMBean implements DynamicMBean {
 
-    private static final Log LOG = LogFactory.getLog(UpdateTaskMBean.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(UpdateTaskMBean.class));
 
     private final MBeanInfo mbeanInfo;
 
@@ -150,6 +150,8 @@ public final class UpdateTaskMBean implements DynamicMBean {
             forceAllParams,
             "void",
             MBeanOperationInfo.ACTION));
+        // Run update on all database schemas
+        operations.add(new MBeanOperationInfo("runAllUpdate", "Runs the update on all schemas.", null, "void", MBeanOperationInfo.ACTION));
         try {
             // List executed update tasks
             String[] taskTypeDescriptions = {
@@ -324,6 +326,22 @@ public final class UpdateTaskMBean implements DynamicMBean {
                 LOG.error(e.getMessage(), e);
                 throw e;
             }
+        } else if (actionName.equals("runAllUpdate")) {
+            try {
+                UpdateTaskToolkit.runUpdateOnAllSchemas();
+            } catch (final UpdateException e) {
+                LOG.error(e.getMessage(), e);
+                final Exception wrapMe = new Exception(e.getMessage());
+                throw new MBeanException(wrapMe);
+            } catch (final RuntimeException e) {
+                LOG.error(e.getMessage(), e);
+                throw e;
+            } catch (final Error e) {
+                LOG.error(e.getMessage(), e);
+                throw e;
+            }
+            // Void
+            return null;
         }
         final ReflectionException e = new ReflectionException(new NoSuchMethodException(actionName));
         LOG.error(e.getMessage(), e);
