@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,16 +80,17 @@ import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.internal.DynamicList;
 import com.openexchange.groupware.update.internal.SchemaExceptionCodes;
 import com.openexchange.groupware.update.internal.UpdateExecutor;
+import com.openexchange.groupware.update.internal.UpdateProcess;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link UpdateTaskToolkit} - Toolkit for update tasks.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UpdateTaskToolkit {
 
-    private static final Log LOG = LogFactory.getLog(UpdateTaskToolkit.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(UpdateTaskToolkit.class));
 
     private static final Object LOCK = new Object();
 
@@ -102,7 +103,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Force (re-)run of update task denoted by given class name
-     * 
+     *
      * @param className The update task's class name
      * @param schemaName A valid schema name
      * @throws UpdateException If update task cannot be performed
@@ -113,7 +114,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Force (re-)run of update task denoted by given class name
-     * 
+     *
      * @param className The update task's class name
      * @param contextId The context identifier
      * @throws UpdateException If update task cannot be performed
@@ -126,7 +127,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Force (re-)run of update task denoted by given class name. This method should only be called when holding <code>LOCK</code>.
-     * 
+     *
      * @param task The update task
      * @param contextId The context identifier
      * @throws UpdateException If update task cannot be performed
@@ -139,7 +140,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Force (re-)run of update task denoted by given class name on all schemas.
-     * 
+     *
      * @param className The update task's class name
      * @throws UpdateException If update task cannot be performed
      */
@@ -160,9 +161,25 @@ public final class UpdateTaskToolkit {
         }
     }
 
+    public static void runUpdateOnAllSchemas() throws UpdateException {
+        synchronized (LOCK) {
+            // Get all available schemas
+            final Map<String, Set<Integer>> map = getSchemasAndContexts();
+            // ... and iterate them
+            final Iterator<Set<Integer>> iter = map.values().iterator();
+            while (iter.hasNext()) {
+                final Set<Integer> set = iter.next();
+                if (!set.isEmpty()) {
+                    final int contextId = set.iterator().next().intValue();
+                    new UpdateProcess(contextId).run();
+                }
+            }
+        }        
+    }
+
     /**
      * Gets all schemas with their versions.
-     * 
+     *
      * @return All schemas with their versions
      * @throws UpdateException If retrieving schemas and versions fails
      */
@@ -181,7 +198,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Gets schemas and their contexts as a map.
-     * 
+     *
      * @return A map containing schemas and their contexts.
      * @throws UpdateException If an error occurs
      */
@@ -229,7 +246,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Sets the schema's version number to given version number
-     * 
+     *
      * @param versionNumber The version number to set
      * @param schemaName A valid schema name
      * @throws UpdateException If changing version number fails
@@ -240,7 +257,7 @@ public final class UpdateTaskToolkit {
 
     /**
      * Sets the schema's version number to given version number
-     * 
+     *
      * @param versionNumber The version number to set
      * @param contextId A valid context identifier contained in target schema
      * @throws UpdateException If changing version number fails
