@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,11 @@
 
 package com.openexchange.groupware.upload.impl;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
 
 /**
  * {@link UploadUtility} - Utility class for uploads.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UploadUtility {
@@ -86,7 +86,7 @@ public final class UploadUtility {
 
     /**
      * Converts given number of bytes to a human readable format.
-     * 
+     *
      * @param size The number of bytes
      * @param precision The number of digits allowed after dot
      * @param longName <code>true</code> to use unit's long name (e.g. <code>Megabytes</code>) or short name (e.g. <code>MB</code>)
