@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,12 +60,12 @@ import com.openexchange.session.Session;
 
 /**
  * {@link MailUploadQuotaChecker} - Quota checker for mail module.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailUploadQuotaChecker extends UploadQuotaChecker {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailUploadQuotaChecker.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailUploadQuotaChecker.class));
 
     private final long uploadQuota;
 
@@ -73,7 +73,38 @@ public final class MailUploadQuotaChecker extends UploadQuotaChecker {
 
     /**
      * Initializes a new {@link MailUploadQuotaChecker}.
-     * 
+     *
+     * @param usm The settings
+     */
+    public MailUploadQuotaChecker(final UserSettingMail settings) {
+        super();
+        if (settings.getUploadQuota() > 0) {
+            uploadQuota = settings.getUploadQuota();
+        } else if (settings.getUploadQuota() == 0) {
+            uploadQuota = -1;
+        } else {
+            /*
+             * Fallback to global upload quota
+             */
+            int globalQuota;
+            try {
+                globalQuota = ServerConfig.getInt(Property.MAX_UPLOAD_SIZE);
+            } catch (final ConfigurationException e) {
+                LOG.error(e.getMessage(), e);
+                globalQuota = 0;
+            }
+            if (globalQuota > 0) {
+                uploadQuota = globalQuota;
+            } else {
+                uploadQuota = -1;
+            }
+        }
+        uploadQuotaPerFile = settings.getUploadQuotaPerFile() > 0 ? settings.getUploadQuotaPerFile() : -1;
+    }
+
+    /**
+     * Initializes a new {@link MailUploadQuotaChecker}.
+     *
      * @param session The session
      * @param ctx The context
      */
