@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,18 +50,18 @@
 package com.openexchange.groupware.userconfiguration;
 
 import static com.openexchange.tools.sql.DBUtils.closeResources;
-import static com.openexchange.tools.sql.DBUtils.getIN;
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntIntHashMap;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.List;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
+import com.openexchange.groupware.downgrade.DowngradeEvent;
+import com.openexchange.groupware.downgrade.DowngradeFailedException;
+import com.openexchange.groupware.downgrade.DowngradeRegistry;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
@@ -71,9 +71,9 @@ import com.openexchange.server.impl.DBPool;
 /**
  * {@link RdbUserConfigurationStorage} - The database storage implementation of
  * an user configuration storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public class RdbUserConfigurationStorage extends UserConfigurationStorage {
 
@@ -158,7 +158,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
      * Saves given user configuration to database. If <code>insert</code> is
      * <code>true</code> an INSERT command is performed, otherwise an UPDATE
      * command.
-     * 
+     *
      * @param userConfig - the user configuration to save
      * @param insert - <code>true</code> for an INSERT; otherwise UPDATE
      * @param writeCon - the writable connection; may be <code>null</code>
@@ -166,7 +166,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
      * @throws DBPoolingException - if a writable connection could not be
      *             obtained from database
      */
-    public static void saveUserConfiguration(UserConfiguration userConfig, boolean insert, Connection writeCon) throws SQLException, DBPoolingException {
+    public static void saveUserConfiguration(final UserConfiguration userConfig, final boolean insert, final Connection writeCon) throws SQLException, DBPoolingException {
         saveUserConfiguration(userConfig.getPermissionBits(), userConfig.getUserId(), insert, userConfig.getContext(), writeCon);
     }
 
@@ -175,7 +175,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
     /**
      * Saves given user configuration to database by self-determining if an
      * INSERT or UPDATE is going to be performed.
-     * 
+     *
      * @param permissionBits The permission bits.
      * @param userId The user ID.
      * @param ctx The context the user belongs to.
@@ -214,7 +214,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
      * Saves given user configuration to database. If <code>insert</code> is
      * <code>true</code> an INSERT command is performed, otherwise an UPDATE
      * command.
-     * 
+     *
      * @param permissionBits The permission bits.
      * @param userId The user ID.
      * @param insert - <code>true</code> for an INSERT; otherwise UPDATE
@@ -265,7 +265,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
     /**
      * Loads the user configuration from database specified through user ID and
      * context
-     * 
+     *
      * @param userId - the user ID
      * @param ctx - the context
      * @return the instance of <code>{@link UserConfiguration}</code>
@@ -287,7 +287,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
     /**
      * Loads the user configuration from database specified through user ID and
      * context
-     * 
+     *
      * @param userId - the user ID
      * @param groups - the group IDs the user belongs to; may be
      *            <code>null</code>
@@ -313,7 +313,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
      * exception is thrown if no matching config could be found. In this case an
      * instance of {@link UserConfiguration} is returned that does not hold any
      * permissions.
-     * 
+     *
      * @param userId - the user ID
      * @param groups - the group IDs the user belongs to; may be
      *            <code>null</code>
@@ -352,7 +352,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
 
     /**
      * Counts all users with the permission as set in {@link UserConfiguration} object
-     * 
+     *
      * @param cid - the context id
      * @param userconf {@link UserConfiguration} object containing set of permissions to count
      * @param readConArg - the readable context; may be <code>null</code>
@@ -391,7 +391,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
     /**
      * Loads the user configuration from database specified through user ID and
      * context
-     * 
+     *
      * @param userId - the user ID
      * @param groupsArg - the group IDs the user belongs to; may be
      *            <code>null</code>
@@ -435,8 +435,11 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
         }
     }
 
+    private static final int LIMIT = 1000;
+
     public static UserConfiguration[] loadUserConfiguration(final Context ctx, final Connection conArg, final User[] users) throws DBPoolingException, SQLException {
-        if (0 == users.length) {
+        final int length = users.length;
+        if (0 == length) {
             return new UserConfiguration[0];
         }
         final Connection con;
@@ -450,25 +453,52 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
         }
         PreparedStatement stmt = null;
         ResultSet result = null;
-        final List<UserConfiguration> retval = new ArrayList<UserConfiguration>(users.length);
+        final UserConfiguration[] retval = new UserConfiguration[length];
         try {
-            stmt = con.prepareStatement(getIN(LOAD_SOME_USER_CONFIGURATIONS, users.length));
-            int pos = 1;
-            stmt.setInt(pos++, ctx.getContextId());
-            final TIntObjectHashMap<User> userMap = new TIntObjectHashMap<User>(users.length, 1);
-            for (final User user : users) {
-                stmt.setInt(pos++, user.getId());
-                userMap.put(user.getId(), user);
+            final TIntIntHashMap userMap;
+            if (length <= LIMIT) {
+                final StringBuilder sb = new StringBuilder(512);
+                sb.append("SELECT u.user, u.permissions FROM user_configuration AS u");
+                if (1 == length) {
+                    sb.append(" WHERE u.user = ? AND u.cid = ?");
+                } else {
+                    sb.append(" INNER JOIN (");
+                    sb.append("SELECT ? AS user");
+                    for (int i = 1; i < length; i++) {
+                        sb.append(" UNION ALL SELECT ?");
+                    }
+                    sb.append(") AS x ON u.user = x.user WHERE u.cid = ?");
+                }
+                stmt = con.prepareStatement(sb.toString());
+                int pos = 1;
+                userMap = new TIntIntHashMap(length, 1);
+                for (int index = 0; index < length; index++) {
+                    final User user = users[index];
+                    stmt.setInt(pos++, user.getId());
+                    userMap.put(user.getId(), index);
+                }
+                stmt.setInt(pos++, ctx.getContextId());
+            } else {
+                stmt = con.prepareStatement("SELECT u.user, u.permissions FROM user_configuration AS u WHERE u.cid = ?");
+                userMap = new TIntIntHashMap(length, 1);
+                for (int index = 0; index < length; index++) {
+                    userMap.put(users[index].getId(), index);
+                }
+                stmt.setInt(1, ctx.getContextId());
             }
             result = stmt.executeQuery();
             while (result.next()) {
-                final User user = userMap.get(result.getInt(1));
-                retval.add(new UserConfiguration(result.getInt(2), user.getId(), user.getGroups(), ctx));
+                final int userId = result.getInt(1);
+                if (userMap.containsKey(userId)) {
+                    final int index = userMap.get(userId);
+                    final User user = users[index];
+                    retval[index] = new UserConfiguration(result.getInt(2), user.getId(), user.getGroups(), ctx);
+                }
             }
         } finally {
             closeResources(result, stmt, closeCon ? con : null, true, ctx);
         }
-        return retval.toArray(new UserConfiguration[retval.size()]);
+        return retval;
     }
 
     /*-
@@ -481,7 +511,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
      * <code>{@link #deleteUserConfiguration(int, Connection, Context)}</code>.
      * whereby connection is set to <code>null</code>, thus a new writeable
      * connection is going to be obtained from connection pool.
-     * 
+     *
      * @param userId - the user ID
      * @param ctx - the context
      * @throws SQLException - if user configuration cannot be removed from
@@ -498,7 +528,7 @@ public class RdbUserConfigurationStorage extends UserConfigurationStorage {
     /**
      * Deletes the user configuration from database specified through ID and
      * context.
-     * 
+     *
      * @param userId - the user ID
      * @param writeConArg - the writeable connection
      * @param ctx - the context
