@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,76 +55,176 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.LdapException;
-import com.openexchange.groupware.ldap.UserAttributeAccess;
-import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.tools.Collections.SmartIntArray;
 
 /**
  * {@link UserConfiguration} - Represents a user configuration.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UserConfiguration implements Serializable, Cloneable {
 
     private static final long serialVersionUID = -8277899698366715803L;
 
-    private static final transient Log LOG = LogFactory.getLog(UserConfiguration.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(UserConfiguration.class));
 
+    /**
+     * The permission bit for mail access.
+     */
     public static final int WEBMAIL = 1;
 
+    /**
+     * The permission bit for calendar access.
+     */
     public static final int CALENDAR = 1 << 1;
 
+    /**
+     * The permission bit for contacts access.
+     */
     public static final int CONTACTS = 1 << 2;
 
+    /**
+     * The permission bit for tasks access.
+     */
     public static final int TASKS = 1 << 3;
 
+    /**
+     * The permission bit for infostore access.
+     */
     public static final int INFOSTORE = 1 << 4;
 
+    /**
+     * The permission bit for projects access.
+     */
     public static final int PROJECTS = 1 << 5;
 
+    /**
+     * The permission bit for forum access.
+     */
     public static final int FORUM = 1 << 6;
 
+    /**
+     * The permission bit for pinboard access.
+     */
     public static final int PINBOARD_WRITE_ACCESS = 1 << 7;
 
+    /**
+     * The permission bit for WebDAV/XML access.
+     */
     public static final int WEBDAV_XML = 1 << 8;
 
+    /**
+     * The permission bit for WebDAV access.
+     */
     public static final int WEBDAV = 1 << 9;
 
+    /**
+     * The permission bit for iCal access.
+     */
     public static final int ICAL = 1 << 10;
 
+    /**
+     * The permission bit for vCard access.
+     */
     public static final int VCARD = 1 << 11;
 
+    /**
+     * The permission bit for RSS bookmarks access.
+     */
     public static final int RSS_BOOKMARKS = 1 << 12;
 
+    /**
+     * The permission bit for RSS portal access.
+     */
     public static final int RSS_PORTAL = 1 << 13;
 
+    /**
+     * The permission bit for mobility access.
+     */
     public static final int MOBILITY = 1 << 14;
 
+    /**
+     * The permission bit whether write access to public folders is granted.
+     */
     public static final int EDIT_PUBLIC_FOLDERS = 1 << 15;
 
+    /**
+     * The permission bit whether shared folders are accessible.
+     */
     public static final int READ_CREATE_SHARED_FOLDERS = 1 << 16;
 
+    /**
+     * The permission bit if tasks may be delegated.
+     */
     public static final int DELEGATE_TASKS = 1 << 17;
 
+    /**
+     * The permission bit whether groups may be modified.
+     */
     public static final int EDIT_GROUP = 1 << 18;
 
+    /**
+     * The permission bit for whether resources may be modified.
+     */
     public static final int EDIT_RESOURCE = 1 << 19;
 
+    /**
+     * The permission bit for whether password may be changed.
+     */
     public static final int EDIT_PASSWORD = 1 << 20;
 
+    /**
+     * The permission bit whether email addresses shall be collected.
+     */
     public static final int COLLECT_EMAIL_ADDRESSES = 1 << 21;
 
+    /**
+     * The permission bit for multiple mail account access.
+     */
     public static final int MULTIPLE_MAIL_ACCOUNTS = 1 << 22;
 
+    /**
+     * The permission bit for subscription access.
+     */
     public static final int SUBSCRIPTION = 1 << 23;
 
+    /**
+     * The permission bit for publication access.
+     */
     public static final int PUBLICATION = 1 << 24;
 
+    /**
+     * The permission bit for active sync access.
+     */
     public static final int ACTIVE_SYNC = 1 << 25;
 
+    /**
+     * The permission bit for USM access.
+     */
     public static final int USM = 1 << 26;
 
+    /**
+     * The permission bit for OLOX v2.0 access.
+     */
+    public static final int OLOX20 = 1 << 27;
+
+    /**
+     * The permission bit for denied portal access.
+     */
+    public static final int DENIED_PORTAL = 1 << 28;
+
+    /**
+     * The permission bit for caldav access. ATTENTION: This is actually handled by the config cascade!
+     */
+    public static final int CALDAV = 1 << 29;
+
+
+    /**
+     * The permission bit for carddav access. ATTENTION: This is actually handled by the config cascade!
+     */
+    public static final int CARDDAV = 1 << 30;
+
+
     /*-
      * Field members
      */
@@ -161,7 +261,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Initializes a new {@link UserConfiguration}.
-     * 
+     *
      * @param permissionBits The permissions' bit mask
      * @param userId The user ID
      * @param groups The user's group IDs
@@ -250,7 +350,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Gets this user configuration's bit pattern.
-     * 
+     *
      * @return the bit pattern as an <code>int</code>.
      */
     public int getPermissionBits() {
@@ -259,7 +359,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets this user configuration's bit pattern.
-     * 
+     *
      * @param permissionBits - the bit pattern.
      */
     public void setPermissionBits(final int permissionBits) {
@@ -269,7 +369,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows web mail access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>.
      */
     public boolean hasWebMail() {
@@ -278,7 +378,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables web mail access in user configuration.
-     * 
+     *
      * @param enableWebMail
      */
     public void setWebMail(final boolean enableWebMail) {
@@ -288,7 +388,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows calendar access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasCalendar() {
@@ -297,7 +397,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables calendar access in user configuration.
-     * 
+     *
      * @param enableCalender
      */
     public void setCalendar(final boolean enableCalender) {
@@ -307,7 +407,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows contact access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasContact() {
@@ -316,7 +416,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables contact access in user configuration.
-     * 
+     *
      * @param enableContact
      */
     public void setContact(final boolean enableContact) {
@@ -326,7 +426,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows task access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasTask() {
@@ -335,7 +435,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables task access in user configuration.
-     * 
+     *
      * @param enableTask
      */
     public void setTask(final boolean enableTask) {
@@ -345,7 +445,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows infostore access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasInfostore() {
@@ -354,7 +454,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables infostore access in user configuration.
-     * 
+     *
      * @param enableInfostore
      */
     public void setInfostore(final boolean enableInfostore) {
@@ -364,7 +464,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows project access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasProject() {
@@ -373,7 +473,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables project access in user configuration.
-     * 
+     *
      * @param enableProject
      */
     public void setProject(final boolean enableProject) {
@@ -383,7 +483,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows forum access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasForum() {
@@ -392,7 +492,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables forum access in user configuration.
-     * 
+     *
      * @param enableForum
      */
     public void setForum(final boolean enableForum) {
@@ -401,7 +501,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows pinboard write access.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasPinboardWriteAccess() {
@@ -410,7 +510,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables pinboard write access in user configuration.
-     * 
+     *
      * @param enablePinboardWriteAccess
      */
     public void setPinboardWriteAccess(final boolean enablePinboardWriteAccess) {
@@ -419,7 +519,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows WebDAV XML.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasWebDAVXML() {
@@ -428,7 +528,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables WebDAV XML access in user configuration.
-     * 
+     *
      * @param enableWebDAVXML
      */
     public void setWebDAVXML(final boolean enableWebDAVXML) {
@@ -437,7 +537,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows WebDAV.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasWebDAV() {
@@ -446,7 +546,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables WebDAV access in user configuration.
-     * 
+     *
      * @param enableWebDAV
      */
     public void setWebDAV(final boolean enableWebDAV) {
@@ -455,7 +555,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows ICalendar.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasICal() {
@@ -464,7 +564,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables ICalendar access in user configuration.
-     * 
+     *
      * @param enableICal
      */
     public void setICal(final boolean enableICal) {
@@ -473,7 +573,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows VCard.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasVCard() {
@@ -482,7 +582,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables VCard access in user configuration.
-     * 
+     *
      * @param enableVCard
      */
     public void setVCard(final boolean enableVCard) {
@@ -491,7 +591,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows RSS bookmarks.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasRSSBookmarks() {
@@ -500,7 +600,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables RSS bookmarks access in user configuration.
-     * 
+     *
      * @param enableRSSBookmarks
      */
     public void setRSSBookmarks(final boolean enableRSSBookmarks) {
@@ -509,7 +609,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows RSS portal.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasRSSPortal() {
@@ -518,7 +618,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables RSS portal access in user configuration.
-     * 
+     *
      * @param enableRSSPortal
      */
     public void setRSSPortal(final boolean enableRSSPortal) {
@@ -527,7 +627,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows mobility functionality.
-     * 
+     *
      * @return <code>true</code> if enabled; otherwise <code>false</code>
      */
     public boolean hasSyncML() {
@@ -536,7 +636,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Enables/Disables mobility access in user configuration
-     * 
+     *
      * @param enableSyncML
      */
     public void setSyncML(final boolean enableSyncML) {
@@ -545,7 +645,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows PIM functionality (Calendar, Contact, and Task).
-     * 
+     *
      * @return <code>true</code> if PIM functionality (Calendar, Contact, and Task) is allowed; otherwise <code>false</code>
      */
     public boolean hasPIM() {
@@ -554,7 +654,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows team view.
-     * 
+     *
      * @return <code>true</code> if team view is allowed; otherwise <code>false</code>
      */
     public boolean hasTeamView() {
@@ -563,7 +663,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows free busy.
-     * 
+     *
      * @return <code>true</code> if free busy is allowed; otherwise <code>false</code>
      */
     public boolean hasFreeBusy() {
@@ -572,7 +672,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows conflict handling.
-     * 
+     *
      * @return <code>true</code> if conflict handling is allowed; otherwise <code>false</code>
      */
     public boolean hasConflictHandling() {
@@ -581,7 +681,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Calculates if the user configuration allows the participant dialog.
-     * 
+     *
      * @return <code>true</code> if the participant dialog should be shown.
      */
     public boolean hasParticipantsDialog() {
@@ -590,11 +690,18 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Detects if user configuration allows portal page in GUI.
-     * 
+     *
      * @return <code>true</code> if portal page is allowed; otherwise <code>false</code>
      */
     public boolean hasPortal() {
-        return hasCalendar() && hasContact() && hasTask();
+        return !hasPermission(DENIED_PORTAL);
+    }
+
+    /**
+     * Sets if this user is denied to access portal.
+     */
+    public void setDeniedPortal(final boolean deniedPortal) {
+        setPermission(deniedPortal, DENIED_PORTAL);
     }
 
     /**
@@ -604,7 +711,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
      * <p>
      * The <code>int</code> values matches the constants <code>{@link FolderObject#TASK}</code>, <code>{@link FolderObject#CALENDAR}</code>,
      * <code>{@link FolderObject#CONTACT}</code>, <code>{@link FolderObject#UNBOUND}</code>, <code>{@link FolderObject#SYSTEM_MODULE}</code>, <code>{@link FolderObject#PROJECT}</code>, <code>{@link FolderObject#MAIL}</code>, <code>{@link FolderObject#INFOSTORE}</code>
-     * 
+     *
      * @return A sorted array of <code>int</code> carrying accessible module integer constants
      */
     public int[] getAccessibleModules() {
@@ -636,7 +743,10 @@ public final class UserConfiguration implements Serializable, Cloneable {
             }
             array.append(FolderObject.SYSTEM_MODULE);
             array.append(FolderObject.UNBOUND);
+            // TODO: Switcher for messaging module
             array.append(FolderObject.MESSAGING);
+            // TODO: Switcher for file storage module
+            array.append(FolderObject.FILE);
             accessibleModules = array.toArray();
             Arrays.sort(accessibleModules);
             accessibleModulesComputed = true;
@@ -646,7 +756,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if user has access to given module.
-     * 
+     *
      * @param module The module carrying a value defined in constants <code>
      *            {@link FolderObject#TASK}</code> , <code>
      *            {@link FolderObject#CALENDAR}</code>
@@ -673,7 +783,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
     /**
      * If this permission is not granted, it is prohibited for the user to create or edit public folders. Existing public folders are
      * visible in any case.
-     * 
+     *
      * @return <code>true</code> full public folder access is granted; otherwise <code>false</code>
      */
     public boolean hasFullPublicFolderAccess() {
@@ -682,7 +792,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Set enableFullPublicFolderAccess.
-     * 
+     *
      * @param enableFullPublicFolderAccess
      */
     public void setFullPublicFolderAccess(final boolean enableFullPublicFolderAccess) {
@@ -692,7 +802,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
     /**
      * If this permission is not granted, neither folders are allowed to be shared nor shared folders are allowed to be seen by user.
      * Existing permissions are not removed if user loses this right, but the display of shared folders is suppressed.
-     * 
+     *
      * @return <code>true</code> full shared folder access is granted; otherwise <code>false</code>
      */
     public boolean hasFullSharedFolderAccess() {
@@ -701,7 +811,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Set enableFullSharedFolderAccess.
-     * 
+     *
      * @param enableFullSharedFolderAccess
      */
     public void setFullSharedFolderAccess(final boolean enableFullSharedFolderAccess) {
@@ -710,7 +820,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration allows to delegate tasks.
-     * 
+     *
      * @return <code>true</code> if user can delegate tasks; otherwise <code>false</code>
      */
     public boolean canDelegateTasks() {
@@ -719,7 +829,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets enableDelegateTasks.
-     * 
+     *
      * @param enableDelegateTasks
      */
     public void setDelegateTasks(final boolean enableDelegateTasks) {
@@ -728,7 +838,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates to collect email addresses.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates to collect email addresses; otherwise <code>false</code>
      */
     public boolean isCollectEmailAddresses() {
@@ -737,7 +847,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets if this user configuration indicates to collect email addresses.
-     * 
+     *
      * @param collectEmailAddresses <code>true</code> if this user configuration indicates to collect email addresses; otherwise
      *            <code>false</code>
      */
@@ -747,26 +857,16 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates to enable multiple mail accounts.
-     * <p>
-     * Since this is currently a beta feature, it is globally configurable via user's attribute <code>"beta"</code>.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates to enable multiple mail accounts; otherwise <code>false</code>
      */
     public boolean isMultipleMailAccounts() {
-        try {
-            return hasBetaEnabled() && hasPermission(MULTIPLE_MAIL_ACCOUNTS);
-        } catch (final LdapException e) {
-            LOG.error(e.getMessage(), e);
-        }
-        /*
-         * Return flag
-         */
         return hasPermission(MULTIPLE_MAIL_ACCOUNTS);
     }
 
     /**
      * Sets if this user configuration indicates to enable multiple mail accounts.
-     * 
+     *
      * @param multipleMailAccounts <code>true</code> if this user configuration indicates to enable multiple mail accounts; otherwise
      *            <code>false</code>
      */
@@ -776,24 +876,16 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates to enable subscription.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates to enable subscription; otherwise <code>false</code>
      */
     public boolean isSubscription() {
-        try {
-            return hasBetaEnabled() && hasPermission(SUBSCRIPTION);
-        } catch (final LdapException e) {
-            LOG.error(e.getMessage(), e);
-        }
-        /*
-         * Return flag
-         */
         return hasPermission(SUBSCRIPTION);
     }
 
     /**
      * Sets if this user configuration indicates to enable subscription.
-     * 
+     *
      * @param subscription <code>true</code> if this user configuration indicates to enable subscription; otherwise <code>false</code>
      */
     public void setSubscription(final boolean subscription) {
@@ -803,24 +895,16 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates to enable publication.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates to enable publication; otherwise <code>false</code>
      */
     public boolean isPublication() {
-        try {
-            return hasBetaEnabled() && hasPermission(PUBLICATION);
-        } catch (final LdapException e) {
-            LOG.error(e.getMessage(), e);
-        }
-        /*
-         * Return flag
-         */
         return hasPermission(PUBLICATION);
     }
 
     /**
      * Sets if this user configuration indicates to enable publication.
-     * 
+     *
      * @param publication <code>true</code> if this user configuration indicates to enable publication; otherwise <code>false</code>
      */
     public void setPublication(final boolean publication) {
@@ -842,22 +926,36 @@ public final class UserConfiguration implements Serializable, Cloneable {
     }
 
     /**
-     * Cheks if this user configuration indicates that the user may use USM.
+     * Checks if this user configuration indicates that the user may use USM.
      */
     public boolean hasUSM() {
         return hasPermission(USM);
     }
 
     /**
-     * Sets if this user is able to user USM.
+     * Sets if this user is able to use USM.
      */
     public void setUSM(final boolean usm) {
         setPermission(usm, USM);
     }
 
+    /**
+     * Checks if this user configuration indicates that the user may use OLOX2.0.
+     */
+    public boolean hasOLOX20() {
+        return hasPermission(OLOX20);
+    }
+
+    /**
+     * Sets if this user is able to user OLOX2.0.
+     */
+    public void setOLOX20(final boolean olox20) {
+        setPermission(olox20, OLOX20);
+    }
+
     /**
      * Checks if this user configuration indicates that groups are allowed to be edited.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates that groups are allowed to be edited; otherwise <code>false</code>
      */
     public boolean isEditGroup() {
@@ -866,7 +964,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets if this user configuration indicates that groups are allowed to be edited.
-     * 
+     *
      * @param editGroup <code>true</code> if this user configuration indicates that groups are allowed to be edited; otherwise
      *            <code>false</code>
      */
@@ -876,7 +974,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates that resources are allowed to be edited.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates that resources are allowed to be edited; otherwise <code>false</code>
      */
     public boolean isEditResource() {
@@ -885,7 +983,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets if this user configuration indicates that resources are allowed to be edited.
-     * 
+     *
      * @param editResource <code>true</code> if this user configuration indicates that resources are allowed to be edited; otherwise
      *            <code>false</code>
      */
@@ -895,7 +993,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates that user password is allowed to be edited.
-     * 
+     *
      * @return <code>true</code> if this user configuration indicates that user password is allowed to be edited; otherwise
      *         <code>false</code>
      */
@@ -905,7 +1003,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Sets if this user configuration indicates that user password is allowed to be edited.
-     * 
+     *
      * @param editPassword <code>true</code> if this user configuration indicates that user password is allowed to be edited; otherwise
      *            <code>false</code>
      */
@@ -913,6 +1011,12 @@ public final class UserConfiguration implements Serializable, Cloneable {
         setPermission(editPassword, EDIT_PASSWORD);
     }
 
+    /**
+     * Checks if this user configuration enables specified permission bit.
+     *
+     * @param permission The permission bit to check
+     * @return <code>true</code> if this user configuration enabled specified permission bit; otherwise <code>false</code>
+     */
     public boolean hasPermission(final int permission) {
         return (permissionBits & permission) == permission;
     }
@@ -926,7 +1030,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Gets the user ID.
-     * 
+     *
      * @return The user ID
      */
     public int getUserId() {
@@ -935,7 +1039,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Gets the group IDs.
-     * 
+     *
      * @return The group IDs
      */
     public int[] getGroups() {
@@ -949,7 +1053,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Gets the context.
-     * 
+     *
      * @return The context
      */
     public Context getContext() {
@@ -960,20 +1064,4 @@ public final class UserConfiguration implements Serializable, Cloneable {
     public String toString() {
         return new StringBuilder(32).append("UserConfiguration_").append(userId).append('@').append(Integer.toBinaryString(permissionBits)).toString();
     }
-
-    private static final String BETA = "beta";
-
-    private static final String PROP_BETA = "com.openexchange.user.beta";
-
-    /**
-     * Checks whether configuration's user has beta features enabled.
-     * 
-     * @return <code>true</code> if configuration's user has beta features enabled; otherwise <code>false</code>
-     * @throws LdapException If user cannot be fetched from storage
-     */
-    private boolean hasBetaEnabled() throws LdapException {
-        final UserAttributeAccess uaa = UserAttributeAccess.getDefaultInstance();
-        return uaa.getBooleanAttribute(BETA, UserStorage.getInstance().getUser(userId, ctx), uaa.getBooleanProperty(PROP_BETA, true));
-    }
-
 }
