@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,12 +58,12 @@ import com.openexchange.server.Initialization;
 
 /**
  * {@link UserConfigurationStorageInit}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UserConfigurationStorageInit implements Initialization {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UserConfigurationStorageInit.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UserConfigurationStorageInit.class));
 
     private static enum UserConfigurationImpl {
 
@@ -98,7 +98,7 @@ public final class UserConfigurationStorageInit implements Initialization {
 
     /**
      * Gets the singleton instance of {@link UserConfigurationStorageInit}
-     * 
+     *
      * @return The singleton instance of {@link UserConfigurationStorageInit}
      */
     public static UserConfigurationStorageInit getInstance() {
