@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,14 +59,14 @@ import org.apache.commons.logging.LogFactory;
  * {@link CompiledLineParserTemplate} - Compiles a template as per
  * LineParserUtility syntax, with a simple substitution of [variables]. Allows
  * escaping via \
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco
  *         Laguna</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class CompiledLineParserTemplate extends AbstractTemplate {
 
-    private static final Log LOG = LogFactory.getLog(CompiledLineParserTemplate.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CompiledLineParserTemplate.class));
 
     private static final String STR_EMPTY = "";
 
@@ -83,7 +83,7 @@ public abstract class CompiledLineParserTemplate extends AbstractTemplate {
      * {@inheritDoc}
      */
     public String render(final Locale locale, final RenderMap renderMap) {
-        final char[] content = new StringHelper(locale).getString(getContent()).toCharArray();
+        final char[] content = StringHelper.valueOf(locale).getString(getContent()).toCharArray();
         if (null == content) {
             return STR_EMPTY;
         }
