@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,7 +63,7 @@ import org.apache.commons.logging.LogFactory;
  */
 public class FileTemplate extends CompiledLineParserTemplate {
 
-    private static final Log LOG = LogFactory.getLog(CompiledLineParserTemplate.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CompiledLineParserTemplate.class));
 
     private final File file;
 
@@ -71,7 +71,7 @@ public class FileTemplate extends CompiledLineParserTemplate {
 
     /**
      * Default constructor.
-     * 
+     *
      * @param f from this file the template is read.
      * @param charset this charset is used to have proper special characters.
      */
