@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,17 @@
 
 package com.openexchange.i18n.tools;
 
+import java.util.ArrayList;
 import java.util.EnumMap;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Locale;
 import java.util.TimeZone;
 
 /**
- * {@link RenderMap} - A map containing replacements for tokens to render a
- * {@link Template template}
- * 
+ * {@link RenderMap} - A map containing replacements for tokens to render a {@link Template template}
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
  */
 public final class RenderMap implements Cloneable {
 
@@ -75,7 +75,7 @@ public final class RenderMap implements Cloneable {
 
     /**
      * Initializes a new {@link RenderMap} from given replacements
-     * 
+     *
      * @param replacements The replacements
      */
     public RenderMap(final TemplateReplacement... replacements) {
@@ -85,6 +85,35 @@ public final class RenderMap implements Cloneable {
         }
     }
 
+    /**
+     * Gets those {@link TemplateReplacement}s that are marked as changed.
+     *
+     * @return The changed {@link TemplateReplacement}s
+     */
+    public List<TemplateReplacement> getChanges() {
+        final List<TemplateReplacement> list = new ArrayList<TemplateReplacement>(map.size() >> 1);
+        for (final TemplateReplacement templateReplacement : map.values()) {
+            if (templateReplacement.changed()) {
+                list.add(templateReplacement);
+            }
+        }
+        return list;
+    }
+
+    /**
+     * Checks if any of the contained {@link TemplateReplacement}s is marked as changed.
+     *
+     * @return <code>true</code> if any of the contained {@link TemplateReplacement}s is marked as changed; otherwise <code>false</code>
+     */
+    public boolean containsChanges() {
+        for (final TemplateReplacement templateReplacement : map.values()) {
+            if (templateReplacement.changed()) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     /**
      * Removes all mappings from this map.
      */
@@ -93,13 +122,9 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Returns <code>true</code> if this map contains no token-replacement
-     * mappings.
-     * <p>
-     * This implementation returns size() == 0.
-     * 
-     * @return <code>true</code> if this map contains no token-replacement
-     *         mappings; otherwise <code>false</code>
+     * Returns <code>true</code> if this map contains no token-replacement mappings.
+     *
+     * @return <code>true</code> if this map contains no token-replacement mappings; otherwise <code>false</code>
      */
     public boolean isEmpty() {
         return map.isEmpty();
@@ -107,7 +132,7 @@ public final class RenderMap implements Cloneable {
 
     /**
      * Returns the number of token-replacement mappings in this map.
-     * 
+     *
      * @return The number of token-replacement mappings in this map.
      */
     public int size() {
@@ -115,29 +140,23 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Associates the specified replacement with the specified token in this
-     * map. If the map previously contained a mapping for this token, the old
-     * replacement is replaced.
-     * 
+     * Associates the specified replacement with the specified token in this map. If the map previously contained a mapping for this token,
+     * the old replacement is replaced.
+     *
      * @param replacement The replacement to put into this map
-     * @return The previous replacement associated with specified token, or
-     *         <code>null</code> if there was no mapping for token. (A
-     *         <code>null</code> return can also indicate that the map
-     *         previously associated <code>null</code> with the specified
-     *         token.)
+     * @return The previous replacement associated with specified token, or <code>null</code> if there was no mapping for token. (A
+     *         <code>null</code> return can also indicate that the map previously associated <code>null</code> with the specified token.)
      */
     public TemplateReplacement put(final TemplateReplacement replacement) {
         return map.put(replacement.getToken(), replacement);
     }
 
     /**
-     * Returns the replacement to which this map maps the specified token, or
-     * <code>null</code> if this map contains no mapping for the specified
-     * token.
-     * 
+     * Returns the replacement to which this map maps the specified token, or <code>null</code> if this map contains no mapping for the
+     * specified token.
+     *
      * @param token The token whose associated value is to be returned
-     * @return The replacement to which this map maps the specified token, or
-     *         <code>null</code> if this map contains no mapping for the
+     * @return The replacement to which this map maps the specified token, or <code>null</code> if this map contains no mapping for the
      *         specified token.
      */
     public TemplateReplacement get(final TemplateToken token) {
@@ -145,13 +164,11 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Returns the replacement to which this map maps the specified token, or
-     * <code>null</code> if this map contains no mapping for the specified
-     * token.
-     * 
+     * Returns the replacement to which this map maps the specified token, or <code>null</code> if this map contains no mapping for the
+     * specified token.
+     *
      * @param tokenStr The token whose associated value is to be returned
-     * @return The replacement to which this map maps the specified token, or
-     *         <code>null</code> if this map contains no mapping for the
+     * @return The replacement to which this map maps the specified token, or <code>null</code> if this map contains no mapping for the
      *         specified token.
      */
     public TemplateReplacement get(final String tokenStr) {
@@ -163,21 +180,18 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Returns <code>true</code> if this map contains a mapping for the
-     * specified token.
-     * 
+     * Returns <code>true</code> if this map contains a mapping for the specified token.
+     *
      * @param token The token whose presence in this map is to be tested
-     * @return <code>true</code> if this map contains a mapping for the
-     *         specified token
+     * @return <code>true</code> if this map contains a mapping for the specified token
      */
     public boolean contains(final TemplateToken token) {
         return map.containsKey(token);
     }
 
     /**
-     * Returns an iterator over the tokens in this map. The template tokens are
-     * returned in no particular order.
-     * 
+     * Returns an iterator over the tokens in this map. The template tokens are returned in no particular order.
+     *
      * @return An iterator over the tokens in this map.
      */
     public Iterator<TemplateToken> getKeys() {
@@ -185,9 +199,8 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Returns an iterator over the replacements in this map. The replacements
-     * are returned in no particular order.
-     * 
+     * Returns an iterator over the replacements in this map. The replacements are returned in no particular order.
+     *
      * @return An iterator over the replacements in this map.
      */
     public Iterator<TemplateReplacement> getValues() {
@@ -196,25 +209,20 @@ public final class RenderMap implements Cloneable {
 
     /**
      * Removes the mapping for specified token from this map if present.
-     * 
+     *
      * @param token The token whose mapping is to be removed from the map
-     * @return The previous replacement associated with specified token, or
-     *         <code>null</code> if there was no entry for token. (A
-     *         <code>null</code> return can also indicate that the map
-     *         previously associated <code>null</code> with the specified
-     *         token.)
+     * @return The previous replacement associated with specified token, or <code>null</code> if there was no entry for token. (A
+     *         <code>null</code> return can also indicate that the map previously associated <code>null</code> with the specified token.)
      */
     public TemplateReplacement remove(final TemplateToken token) {
         return map.remove(token);
     }
 
     /**
-     * Applies specified changed status to all contained token-replacement
-     * mappings.
-     * 
+     * Applies specified changed status to all contained token-replacement mappings.
+     *
      * @param changed The changed status to apply
-     * @return This render map with specified changed status applied to all
-     *         contained token-replacement mappings.
+     * @return This render map with specified changed status applied to all contained token-replacement mappings.
      */
     public RenderMap applyChangedStatus(final boolean changed) {
         final Iterator<TemplateReplacement> iter = map.values().iterator();
@@ -227,10 +235,9 @@ public final class RenderMap implements Cloneable {
 
     /**
      * Applies specified locale to all contained token-replacement mappings.
-     * 
+     *
      * @param locale The locale to apply
-     * @return This render map with specified locale applied to all contained
-     *         token-replacement mappings.
+     * @return This render map with specified locale applied to all contained token-replacement mappings.
      */
     public RenderMap applyLocale(final Locale locale) {
         final Iterator<TemplateReplacement> iter = map.values().iterator();
@@ -243,10 +250,9 @@ public final class RenderMap implements Cloneable {
 
     /**
      * Applies specified time zone to all contained token-replacement mappings.
-     * 
+     *
      * @param timeZone The time zone to apply
-     * @return This render map with specified time zone applied to all contained
-     *         token-replacement mappings.
+     * @return This render map with specified time zone applied to all contained token-replacement mappings.
      */
     public RenderMap applyTimeZone(final TimeZone timeZone) {
         final Iterator<TemplateReplacement> iter = map.values().iterator();
@@ -274,9 +280,8 @@ public final class RenderMap implements Cloneable {
     }
 
     /**
-     * Merges this render map's token-replacement mappings with specified render
-     * map's token-replacement mappings.
-     * 
+     * Merges this render map's token-replacement mappings with specified render map's token-replacement mappings.
+     *
      * @param other The other render map to merge with
      * @return This render map merged with specified render map
      */
