@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,9 +59,9 @@ import com.openexchange.i18n.tools.TemplateToken;
 /**
  * {@link ChangeExceptionsReplacement} - The replacement for change exceptions
  * of a recurring calendar object
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDateReplacement {
 
@@ -71,7 +71,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
 
     /**
      * Initializes a new {@link ChangeExceptionsReplacement}
-     * 
+     *
      * @param dates The change exception dates
      */
     public ChangeExceptionsReplacement(final Date[] dates) {
@@ -80,7 +80,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
 
     /**
      * Initializes a new {@link ChangeExceptionsReplacement}
-     * 
+     *
      * @param dates The change exception dates
      * @param locale The locale
      * @param timeZone The time zone
@@ -108,12 +108,12 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
         if (changeException) {
             // Event denotes a change exception
             format = Notifications.FORMAT_CHANGE_EXCEPTION_OF;
-            final String result = String.format(new StringHelper(locale == null ? Locale.ENGLISH : locale)
+            final String result = String.format(StringHelper.valueOf(locale == null ? Locale.ENGLISH : locale)
                     .getString(format), recurrenceTitle, datesRepl);
             return new StringBuilder(1 + result.length()).append(result).append('\n').toString();
         }
         // Normal replacement
-        final String result = String.format(new StringHelper(locale == null ? Locale.ENGLISH : locale)
+        final String result = String.format(StringHelper.valueOf(locale == null ? Locale.ENGLISH : locale)
                 .getString(format), datesRepl);
         if (changed) {
             return new StringBuilder(PREFIX_MODIFIED.length() + result.length() + 1).append(PREFIX_MODIFIED).append(
@@ -128,7 +128,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
 
     /**
      * Checks if associated event is a change exception.
-     * 
+     *
      * @return <code>true</code> if associated event is a change exception;
      *         otherwise <code>false</code>
      */
@@ -138,7 +138,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
 
     /**
      * Sets whether associated event is a change exception.
-     * 
+     *
      * @param changeException <code>true</code> if associated event is a change
      *            exception; otherwise <code>false</code>
      */
@@ -149,7 +149,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
     /**
      * Gets the recurrence title.<br>
      * Only useful if {@link #isChangeException()} returns <code>true</code>.
-     * 
+     *
      * @return The recurrence title
      */
     public String getRecurrenceTitle() {
@@ -159,7 +159,7 @@ public final class ChangeExceptionsReplacement extends AbstractFormatMultipleDat
     /**
      * Sets the recurrence title.<br>
      * Only useful if {@link #isChangeException()} returns <code>true</code>.
-     * 
+     *
      * @param recurrenceTitle The recurrence title
      */
     public void setRecurrenceTitle(final String recurrenceTitle) {
