@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,9 +57,9 @@ import com.openexchange.i18n.tools.TemplateToken;
 
 /**
  * {@link LocalizedStringReplacement}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public abstract class LocalizedStringReplacement implements TemplateReplacement {
 
@@ -97,9 +97,9 @@ public abstract class LocalizedStringReplacement implements TemplateReplacement
     protected final StringHelper getStringHelper() {
         if (stringHelper == null) {
             if (locale == null) {
-                stringHelper = new StringHelper(Locale.ENGLISH);
+                stringHelper = StringHelper.valueOf(Locale.ENGLISH);
             } else {
-                stringHelper = new StringHelper(locale);
+                stringHelper = StringHelper.valueOf(locale);
             }
         }
         return stringHelper;
@@ -109,6 +109,10 @@ public abstract class LocalizedStringReplacement implements TemplateReplacement
         return changed;
     }
 
+    public boolean relevantChange() {
+        return changed();
+    }
+
     public String getReplacement() {
         return getStringHelper().getString(replacement);
     }
