@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,9 +56,9 @@ import com.openexchange.i18n.tools.TemplateToken;
 
 /**
  * {@link ModuleReplacement}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public final class ModuleReplacement implements TemplateReplacement {
 
@@ -76,7 +76,7 @@ public final class ModuleReplacement implements TemplateReplacement {
 
     /**
      * Initializes a new {@link ModuleReplacement}
-     * 
+     *
      * @param module The module; supposed to be either {@link #MODULE_CALENDAR}
      *            or {@link #MODULE_TASK}
      */
@@ -97,6 +97,10 @@ public final class ModuleReplacement implements TemplateReplacement {
         return changed;
     }
 
+    public boolean relevantChange() {
+        return changed();
+    }
+
     public TemplateReplacement setChanged(final boolean changed) {
         this.changed = changed;
         return this;
