@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,9 +63,9 @@ import com.openexchange.i18n.tools.TemplateToken;
 /**
  * {@link ResourcesReplacement} - Replacement for
  * {@link TemplateToken#RESOURCES resources}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public final class ResourcesReplacement implements TemplateReplacement {
 
@@ -107,6 +107,27 @@ public final class ResourcesReplacement implements TemplateReplacement {
         return (TemplateReplacement) clone();
     }
 
+    public boolean relevantChange() {
+        if (!changed) {
+            return false;
+        }
+        for (final Iterator<EmailableParticipant> iter = resourcesSet.iterator(); iter.hasNext();) {
+            final EmailableParticipant participant = iter.next();
+            if (participant.state == EmailableParticipant.STATE_NEW) {
+                /*
+                 * Resource was newly added
+                 */
+                return true;
+            } else if (participant.state == EmailableParticipant.STATE_REMOVED) {
+                /*
+                 * Resource was removed
+                 */
+                return true;
+            }
+        }
+        return false;
+    }
+
     public String getReplacement() {
         if (resourcesSet.isEmpty()) {
             return getStringHelper().getString(Notifications.NO_RESOURCES);
@@ -188,7 +209,7 @@ public final class ResourcesReplacement implements TemplateReplacement {
 
     private StringHelper getStringHelper() {
         if (stringHelper == null) {
-            stringHelper = new StringHelper(getLocale());
+            stringHelper = StringHelper.valueOf(getLocale());
         }
         return stringHelper;
     }
