@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.i18n.tools.replacement;
 
+import java.util.EnumSet;
 import java.util.Locale;
 import java.util.TimeZone;
 import com.openexchange.i18n.tools.TemplateReplacement;
@@ -57,9 +58,9 @@ import com.openexchange.i18n.tools.TemplateToken;
 /**
  * {@link StringReplacement} - An implementation of a
  * {@link TemplateReplacement template replacement} with a fixed string.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public class StringReplacement implements TemplateReplacement {
 
@@ -71,7 +72,7 @@ public class StringReplacement implements TemplateReplacement {
 
     /**
      * Initializes a new {@link StringReplacement}
-     * 
+     *
      * @param token The token
      * @param replacement The replacement
      */
@@ -81,7 +82,7 @@ public class StringReplacement implements TemplateReplacement {
 
     /**
      * Initializes a new {@link StringReplacement}
-     * 
+     *
      * @param token The token
      * @param replacement The replacement
      * @param changed <code>true</code> to prepend <i>modified</i> marker
@@ -115,6 +116,12 @@ public class StringReplacement implements TemplateReplacement {
         return changed;
     }
 
+    private static final EnumSet<TemplateToken> IRRELEVANT = EnumSet.of(TemplateToken.FOLDER_ID, TemplateToken.FOLDER_NAME, TemplateToken.LINK, TemplateToken.UI_WEB_PATH);
+
+    public boolean relevantChange() {
+        return !IRRELEVANT.contains(token);
+    }
+
     public TemplateReplacement setChanged(final boolean changed) {
         this.changed = changed;
         return this;
