@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,10 @@
 
 package com.openexchange.login;
 
+import java.util.List;
+import java.util.Map;
+import com.openexchange.authentication.Cookie;
+
 /**
  * Data to process a login request.
  *
@@ -69,8 +73,12 @@ public interface LoginRequest {
     String getClient();
 
     String getVersion();
-    
+
     String getHash();
 
     Interface getInterface();
+
+    Map<String, List<String>> getHeaders();
+    
+    Cookie[] getCookies();
 }
