@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,14 +50,25 @@
 package com.openexchange.login.internal;
 
 import static com.openexchange.java.Autoboxing.I;
-import java.lang.reflect.UndeclaredThrowableException;
+import java.util.HashMap;
 import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.authentication.Authenticated;
+import com.openexchange.authentication.Cookie;
 import com.openexchange.authentication.LoginException;
 import com.openexchange.authentication.LoginExceptionCodes;
+import com.openexchange.authentication.ResponseEnhancement;
+import com.openexchange.authentication.ResultCode;
+import com.openexchange.authentication.SessionEnhancement;
 import com.openexchange.authentication.service.Authentication;
+import com.openexchange.authentication.service.AutoLoginAuthentication;
+import com.openexchange.authorization.Authorization;
+import com.openexchange.authorization.AuthorizationException;
+import com.openexchange.authorization.AuthorizationService;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
@@ -65,119 +76,164 @@ import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.java.Strings;
-import com.openexchange.login.LoginResult;
 import com.openexchange.login.LoginHandlerService;
 import com.openexchange.login.LoginRequest;
+import com.openexchange.login.LoginResult;
+import com.openexchange.mail.config.MailProperties;
 import com.openexchange.server.ServiceException;
+import com.openexchange.server.ServiceException.Code;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
-import com.openexchange.sessiond.AddSessionParameter;
+import com.openexchange.sessiond.SessiondException;
 import com.openexchange.sessiond.SessiondService;
-import com.openexchange.sessiond.exception.SessiondException;
 import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 
 /**
  * {@link LoginPerformer} - Performs a login for specified credentials.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class LoginPerformer {
 
-    private static final Log LOG = LogFactory.getLog(LoginPerformer.class);
+    private interface LoginPerformerClosure {
+        public Authenticated doAuthentication(LoginResultImpl retval) throws LoginException, ServiceException;
+    }
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(LoginPerformer.class));
 
     private static final LoginPerformer SINGLETON = new LoginPerformer();
 
+    private LoginPerformer() {
+        super();
+    }
+
     public static LoginPerformer getInstance() {
         return SINGLETON;
     }
 
     /**
-     * Initializes a new {@link LoginPerformer}.
-     */
-    private LoginPerformer() {
-        super();
-    }
-
-    /**
-     * Performs the login for specified credentials.
-     * 
-     * @param login The login string
-     * @param password The password string
-     * @param remoteAddress The Internet Protocol (IP) address of the client
+     * Performs the login for specified login request.
+     *
+     * @param request The login request
      * @return The login providing login information
      * @throws LoginException If login fails
      */
     public LoginResult doLogin(final LoginRequest request) throws LoginException {
+        final HashMap<String, Object> properties = new HashMap<String, Object>();
+        return doLogin(request, properties, new LoginPerformerClosure() {
+            public Authenticated doAuthentication(final LoginResultImpl retval) throws LoginException, ServiceException {
+                return Authentication.login(request.getLogin(), request.getPassword(), properties);
+            }
+        });
+    }
+
+    /**
+     * Performs the autologin for specified login request.
+     *
+     * @param request The login request
+     * @return The login providing login information
+     * @throws LoginException If login fails
+     */
+    public LoginResult doAutoLogin(final LoginRequest request) throws LoginException {
+        final HashMap<String, Object> properties = new HashMap<String, Object>();
+        return doLogin(request, properties, new LoginPerformerClosure() {
+            public Authenticated doAuthentication(final LoginResultImpl retval) throws LoginException {
+                return AutoLoginAuthentication.login(request.getLogin(), request.getPassword(), properties);
+            }
+        });
+    }
+
+    private static final int MAX_RETRY = 3;
+
+    /**
+     * Performs the login for specified login request.
+     *
+     * @param request The login request
+     * @return The login providing login information
+     * @throws LoginException If login fails
+     */
+    private LoginResult doLogin(final LoginRequest request, final Map<String, Object> properties, final LoginPerformerClosure loginPerfClosure) throws LoginException {
         final LoginResultImpl retval = new LoginResultImpl();
         retval.setRequest(request);
         try {
-            final Authenticated authed = Authentication.login(request.getLogin(), request.getPassword());
+            final Map<String, List<String>> headers = request.getHeaders();
+            if (headers != null) {
+                properties.put("headers", headers);
+            }
+            final Cookie[] cookies = request.getCookies();
+            if (null != cookies) {
+                properties.put("cookies", cookies);
+            }
+            final Authenticated authed = loginPerfClosure.doAuthentication(retval);
+            if (null == authed) {
+                return null;
+            }
+            if (authed instanceof ResponseEnhancement) {
+                final ResponseEnhancement responseEnhancement = (ResponseEnhancement) authed;
+                retval.setHeaders(responseEnhancement.getHeaders());
+                retval.setCookies(responseEnhancement.getCookies());
+                retval.setRedirect(responseEnhancement.getRedirect());
+                retval.setCode(responseEnhancement.getCode());
+                if (ResultCode.REDIRECT.equals(responseEnhancement.getCode()) || ResultCode.FAILED.equals(responseEnhancement.getCode())) {
+                    return retval;
+                }
+            }
             final Context ctx = findContext(authed.getContextInfo());
             retval.setContext(ctx);
             final String username = authed.getUserInfo();
             final User user = findUser(ctx, username);
             retval.setUser(user);
             // Checks if something is deactivated.
-            try {
-                if (!ctx.isEnabled()) {
-                    throw LoginExceptionCodes.INVALID_CREDENTIALS.create();
-                }
-            } catch (final UndeclaredThrowableException e) {
-                throw LoginExceptionCodes.UNKNOWN.create(e);
-            }
-            if (user.isMailEnabled()) {
-                if (user.getShadowLastChange() == 0) {
-                    throw LoginExceptionCodes.PASSWORD_EXPIRED.create();
-                }
-            } else {
-                throw LoginExceptionCodes.USER_NOT_ACTIVE.create();
+            final AuthorizationService authService = Authorization.getService();
+            if (null == authService) {
+                final ServiceException e = new ServiceException(Code.SERVICE_UNAVAILABLE, AuthorizationService.class.getName());
+                LOG.error("unable to find AuthorizationService", e);
+                throw e;
             }
+            authService.authorizeUser(ctx, user);
+            // Check if indicated client is allowed to perform a login
+            checkClient(request, user, ctx);
             // Create session
             final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class, true);
-            final String sessionId = sessiondService.addSession(new AddSessionParameter() {
-                public String getClientIP() {
-                    return request.getClientIP();
+            Session session = null;
+            {
+                int cnt = 0;
+                while (null == session && cnt++ < MAX_RETRY) {
+                    final String sessionId = sessiondService.addSession(new AddSessionParameterImpl(username, request, user, ctx));
+                    session = sessiondService.getSession(sessionId);
                 }
-                public Context getContext() {
-                    return ctx;
+                if (null == session) {
+                    // Session could not be created
+                    throw LoginExceptionCodes.UNKNOWN.create("Session could not be created.");
                 }
-                public String getFullLogin() {
-                    return request.getLogin();
-                }
-                public String getUserLoginInfo() {
-                    return username;
-                }
-                public String getPassword() {
-                    return request.getPassword();
-                }
-                public int getUserId() {
-                    return user.getId();
-                }
-                public String getAuthId() {
-                    return request.getAuthId();
-                }
-                public String getHash() {
-                    return request.getHash();
-                }
-            });
-            retval.setSession(sessiondService.getSession(sessionId));
+            }
+            if (SessionEnhancement.class.isInstance(authed)) {
+                ((SessionEnhancement) authed).enhanceSession(session);
+            }
+            retval.setSession(session);
             // Trigger registered login handlers
             triggerLoginHandlers(retval);
-        } catch (ServiceException e) {
+        } catch (final ServiceException e) {
             logLoginRequest(request, retval);
             throw LoginExceptionCodes.COMMUNICATION.create(e);
         } catch (final LoginException e) {
             logLoginRequest(request, retval);
             throw e;
-        } catch (ContextException e) {
+        } catch (final ContextException e) {
             logLoginRequest(request, retval);
             throw new LoginException(e);
-        } catch (UserException e) {
+        } catch (final UserException e) {
             logLoginRequest(request, retval);
             throw new LoginException(e);
-        } catch (SessiondException e) {
+        } catch (final SessiondException e) {
+            logLoginRequest(request, retval);
+            throw new LoginException(e);
+        } catch (final AuthorizationException e) {
             logLoginRequest(request, retval);
             throw new LoginException(e);
         }
@@ -185,7 +241,26 @@ public final class LoginPerformer {
         return retval;
     }
 
-    private Context findContext(String contextInfo) throws ContextException {
+    private void checkClient(final LoginRequest request, final User user, final Context ctx) throws LoginException {
+        try {
+            final String client = request.getClient();
+            // Check for OLOX v2.0
+            if ("USM-JSON".equalsIgnoreCase(client)) {
+                final UserConfigurationStorage ucs = UserConfigurationStorage.getInstance();
+                final UserConfiguration userConfiguration = ucs.getUserConfiguration(user.getId(), user.getGroups(), ctx);
+                if (!userConfiguration.hasOLOX20()) {
+                    // Deny login for OLOX v2.0 client since disabled as per user configuration
+                    throw LoginExceptionCodes.CLIENT_DENIED.create(client);
+                }
+            }
+        } catch (final LoginException e) {
+            throw e;
+        } catch (final AbstractOXException e) {
+            throw new LoginException(e);
+        }
+    }
+
+    private Context findContext(final String contextInfo) throws ContextException {
         final ContextStorage contextStor = ContextStorage.getInstance();
         final int contextId = contextStor.getContextId(contextInfo);
         if (ContextStorage.NOT_FOUND == contextId) {
@@ -198,11 +273,17 @@ public final class LoginPerformer {
         return context;
     }
 
-    private User findUser(Context ctx, String userInfo) throws UserException {
+    private User findUser(final Context ctx, final String userInfo) throws UserException {
+        final String proxyDelimiter = MailProperties.getInstance().getAuthProxyDelimiter();
         final UserStorage us = UserStorage.getInstance();
         final User u;
         try {
-            int userId = us.getUserId(userInfo, ctx);
+            int userId = 0;
+            if (null != proxyDelimiter && userInfo.contains(proxyDelimiter)) {
+                userId = us.getUserId(userInfo.substring(userInfo.indexOf(proxyDelimiter) + proxyDelimiter.length(), userInfo.length()), ctx);
+            } else {
+                userId = us.getUserId(userInfo, ctx);
+            }
             u = us.getUser(userId, ctx);
         } catch (final LdapException e) {
             throw new UserException(e);
@@ -212,7 +293,7 @@ public final class LoginPerformer {
 
     /**
      * Performs the logout for specified session ID.
-     * 
+     *
      * @param sessionId The session ID
      * @throws LoginException If logout fails
      */
@@ -221,7 +302,7 @@ public final class LoginPerformer {
         final SessiondService sessiondService;
         try {
             sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class, true);
-        } catch (ServiceException e) {
+        } catch (final ServiceException e) {
             throw LoginExceptionCodes.COMMUNICATION.create(e);
         }
         final Session session = sessiondService.getSession(sessionId);
@@ -240,7 +321,7 @@ public final class LoginPerformer {
             throw new LoginException(e);
         }
         if (null == context) {
-            throw new LoginException(new ContextException(ContextException.Code.NOT_FOUND, Integer.valueOf(session.getContextId())));
+            throw new LoginException(new ContextException(ContextException.Code.NOT_FOUND, I(session.getContextId())));
         }
         // Get user
         final User u;
@@ -260,40 +341,60 @@ public final class LoginPerformer {
     }
 
     private static void triggerLoginHandlers(final LoginResult login) {
-        final ThreadPoolService executor = ServerServiceRegistry.getInstance().getService(ThreadPoolService.class);
-        for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
-            final LoginHandlerService handler = it.next();
-            executor.submit(new LoginPerformerTask() {
-                public Object call() {
-                    try {
-                        handler.handleLogin(login);
-                    } catch (final LoginException e) {
-                        logError(e);
-                    }
-                    return null;
+        final ThreadPoolService executor = ThreadPools.getThreadPool();
+        if (null == executor) {
+            for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
+                try {
+                    it.next().handleLogin(login);
+                } catch (final LoginException e) {
+                    logError(e);
                 }
-            }, CallerRunsBehavior.getInstance());
+            }
+        } else {
+            for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
+                final LoginHandlerService handler = it.next();
+                executor.submit(new LoginPerformerTask() {
+                    public Object call() {
+                        try {
+                            handler.handleLogin(login);
+                        } catch (final LoginException e) {
+                            logError(e);
+                        }
+                        return null;
+                    }
+                }, CallerRunsBehavior.getInstance());
+            }
         }
     }
 
     private static void triggerLogoutHandlers(final LoginResult logout) {
-        final ThreadPoolService executor = ServerServiceRegistry.getInstance().getService(ThreadPoolService.class);
-        for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
-            final LoginHandlerService handler = it.next();
-            executor.submit(new LoginPerformerTask() {
-                public Object call() {
-                    try {
-                        handler.handleLogout(logout);
-                    } catch (final LoginException e) {
-                        logError(e);
-                    }
-                    return null;
+        final ThreadPoolService executor = ThreadPools.getThreadPool();
+        if (null == executor) {
+            for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
+                try {
+                    it.next().handleLogout(logout);
+                } catch (final LoginException e) {
+                    logError(e);
                 }
-            }, CallerRunsBehavior.getInstance());
+            }
+        } else {
+            for (final Iterator<LoginHandlerService> it = LoginHandlerRegistry.getInstance().getLoginHandlers(); it.hasNext();) {
+                final LoginHandlerService handler = it.next();
+                executor.submit(new LoginPerformerTask() {
+                    public Object call() {
+                        try {
+                            handler.handleLogout(logout);
+                        } catch (final LoginException e) {
+                            logError(e);
+                        }
+                        return null;
+                    }
+                }, CallerRunsBehavior.getInstance());
+            }
         }
     }
 
-    static void logError(LoginException e) {
+    static void logError(final LoginException e) {
         switch (e.getCategory()) {
         case USER_INPUT:
             LOG.debug(e.getMessage(), e);
@@ -303,8 +404,8 @@ public final class LoginPerformer {
         }
     }
 
-    private static void logLoginRequest(LoginRequest request, LoginResult result) {
-        StringBuilder sb = new StringBuilder();
+    private static void logLoginRequest(final LoginRequest request, final LoginResult result) {
+        final StringBuilder sb = new StringBuilder();
         sb.append("Login:");
         sb.append(request.getLogin());
         sb.append(" IP:");
@@ -319,7 +420,7 @@ public final class LoginPerformer {
         sb.append(request.getVersion());
         sb.append(") Interface:");
         sb.append(request.getInterface().toString());
-        Context ctx = result.getContext();
+        final Context ctx = result.getContext();
         if (null != ctx) {
             sb.append(" Context:");
             sb.append(ctx.getContextId());
@@ -327,7 +428,7 @@ public final class LoginPerformer {
             sb.append(Strings.join(ctx.getLoginInfo(), ","));
             sb.append(')');
         }
-        User user = result.getUser();
+        final User user = result.getUser();
         if (null != user) {
             sb.append(" User:");
             sb.append(user.getId());
@@ -335,34 +436,44 @@ public final class LoginPerformer {
             sb.append(user.getLoginInfo());
             sb.append(')');
         }
-        Session session = result.getSession();
+        final Session session = result.getSession();
         if (null != session) {
             sb.append(" Session:");
             sb.append(session.getSessionID());
+            sb.append(" Random:");
+            sb.append(session.getRandomToken());
         } else {
             sb.append(" Failed.");
         }
         LOG.info(sb.toString());
     }
 
-    private static void logLogout(LoginResult result) {
-        StringBuilder sb = new StringBuilder();
+    private static void logLogout(final LoginResult result) {
+        final StringBuilder sb = new StringBuilder();
         sb.append("Logout ");
-        Context ctx = result.getContext();
+        final Context ctx = result.getContext();
         sb.append(" Context:");
         sb.append(ctx.getContextId());
         sb.append('(');
         sb.append(Strings.join(ctx.getLoginInfo(), ","));
         sb.append(')');
-        User user = result.getUser();
+        final User user = result.getUser();
         sb.append(" User:");
         sb.append(user.getId());
         sb.append('(');
         sb.append(user.getLoginInfo());
         sb.append(')');
-        Session session = result.getSession();
+        final Session session = result.getSession();
         sb.append(" Session:");
         sb.append(session.getSessionID());
         LOG.info(sb.toString());
     }
+
+    public Session lookupSession(final String sessionId) throws LoginException {
+        try {
+            return ServerServiceRegistry.getInstance().getService(SessiondService.class, true).getSession(sessionId);
+        } catch (final ServiceException x) {
+            throw new LoginException(x);
+        }
+    }
 }
