@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,8 @@
 package com.openexchange.mail;
 
 import static com.openexchange.java.Autoboxing.l;
-import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.concurrent.ConcurrentHashMap;
@@ -66,16 +66,16 @@ import com.openexchange.timer.TimerService;
 /**
  * {@link MailAccessWatcher} - Keeps track of connected instances of {@link MailAccess} and allows a forced close if connection time exceeds
  * allowed time
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailAccessWatcher {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccessWatcher.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccessWatcher.class));
 
-    private static final ConcurrentMap<MailAccess<?, ?>, Long> mailAccesses = new ConcurrentHashMap<MailAccess<?, ?>, Long>();
+    private static final ConcurrentMap<MailAccess<?, ?>, Long> MAIL_ACCESSES = new ConcurrentHashMap<MailAccess<?, ?>, Long>();
 
-    private static final AtomicBoolean initialized = new AtomicBoolean();
+    private static final AtomicBoolean INITIALIZED = new AtomicBoolean();
 
     private static ScheduledTimerTask watcherTask;
 
@@ -83,9 +83,9 @@ public final class MailAccessWatcher {
      * Initializes and starts mail connection watcher if not done, yet
      */
     static void init() {
-        if (!initialized.get()) {
-            synchronized (initialized) {
-                if (initialized.get()) {
+        if (!INITIALIZED.get()) {
+            synchronized (INITIALIZED) {
+                if (INITIALIZED.get()) {
                     return;
                 }
                 if (MailProperties.getInstance().isWatcherEnabled()) {
@@ -94,17 +94,14 @@ public final class MailAccessWatcher {
                      */
                     final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
                     if (null != timer) {
-                        watcherTask =
-                            timer.scheduleWithFixedDelay(
-                                new WatcherTask(mailAccesses, LOG),
-                                1000,
-                                MailProperties.getInstance().getWatcherFrequency());
+                        final int frequencyMillis = MailProperties.getInstance().getWatcherFrequency();
+                        watcherTask = timer.scheduleWithFixedDelay(new WatcherTask(MAIL_ACCESSES, LOG), 1000, frequencyMillis);
                     }
-                    initialized.set(true);
                     if (LOG.isInfoEnabled()) {
                         LOG.info("Mail connection watcher successfully established and ready for tracing");
                     }
                 }
+                INITIALIZED.set(true);
             }
         }
     }
@@ -113,23 +110,25 @@ public final class MailAccessWatcher {
      * Stops mail connection watcher if currently running
      */
     static void stop() {
-        if (initialized.get()) {
-            synchronized (initialized) {
-                if (!initialized.get()) {
+        if (INITIALIZED.get()) {
+            synchronized (INITIALIZED) {
+                if (!INITIALIZED.get()) {
                     return;
                 }
                 if (MailProperties.getInstance().isWatcherEnabled()) {
-                    watcherTask.cancel(false);
-                    final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
-                    if (null != timer) {
-                        timer.purge();
+                    if (null != watcherTask) {
+                        watcherTask.cancel(false);
+                        final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
+                        if (null != timer) {
+                            timer.purge();
+                        }
                     }
-                    mailAccesses.clear();
-                    initialized.set(false);
                     if (LOG.isInfoEnabled()) {
                         LOG.info("Mail connection watcher successfully stopped");
                     }
                 }
+                MAIL_ACCESSES.clear();
+                INITIALIZED.set(false);
             }
         }
     }
@@ -145,31 +144,47 @@ public final class MailAccessWatcher {
      * Adds specified mail access to this watcher's tracing if not already added before. If already present its timestamp is updated.
      * <p>
      * Watcher is established if not running, yet
-     * 
+     *
      * @param mailAccess The mail access to add
      */
     public static void addMailAccess(final MailAccess<?, ?> mailAccess) {
-        if (!initialized.get()) {
-            LOG.error("Mail connection watcher is not running. Aborting addMailAccess()");
-            return;
-        }
         /*
-         * Insert or update timestamp
+         * Insert or update time stamp
          */
-        mailAccesses.put(mailAccess, Long.valueOf(System.currentTimeMillis()));
+        MAIL_ACCESSES.put(mailAccess, Long.valueOf(System.currentTimeMillis()));
     }
 
     /**
      * Removes specified mail access from this watcher's tracing
-     * 
+     *
      * @param mailAccess The mail access to remove
      */
     public static void removeMailAccess(final MailAccess<?, ?> mailAccess) {
-        if (!initialized.get()) {
-            LOG.error("Mail connection watcher is not running. Aborting removeMailAccess()");
-            return;
+        MAIL_ACCESSES.remove(mailAccess);
+    }
+
+    /**
+     * Gets the number of currently tracked mail accesses.
+     *
+     * @return The number of currently tracked mail accesses
+     */
+    public static int getNumberOfMailAccesses() {
+        return MAIL_ACCESSES.size();
+    }
+
+    /**
+     * Gets the number of currently tracked idling mail accesses.
+     *
+     * @return The number of currently tracked idling mail accesses
+     */
+    public static int getNumberOfIdlingMailAccesses() {
+        int count = 0;
+        for (final MailAccess<?, ?> mailAccess : MAIL_ACCESSES.keySet()) {
+            if (mailAccess.isConnectedUnsafe() && mailAccess.isWaiting()) {
+                count++;
+            }
         }
-        mailAccesses.remove(mailAccess);
+        return count;
     }
 
     private static final String INFO_PREFIX = "UNCLOSED MAIL CONNECTION AFTER #N#msec:\n";
@@ -183,29 +198,51 @@ public final class MailAccessWatcher {
      */
     private static class WatcherTask implements Runnable {
 
-        private final ConcurrentMap<MailAccess<?, ?>, Long> mailAccessMap;
+        private final ConcurrentMap<MailAccess<?, ?>, Long> map;
 
         private final org.apache.commons.logging.Log logger;
 
+        private final boolean traceEnabled;
+
         public WatcherTask(final ConcurrentMap<MailAccess<?, ?>, Long> mailAccesses, final org.apache.commons.logging.Log logger) {
             super();
-            mailAccessMap = mailAccesses;
+            map = mailAccesses;
             this.logger = logger;
+            traceEnabled = logger.isTraceEnabled();
         }
 
         public void run() {
             try {
+                if (map.isEmpty()) {
+                    /*
+                     * Nothing to trace...
+                     */
+                    return;
+                }
                 final StringBuilder sb = new StringBuilder(512);
-                final List<MailAccess<?, ?>> exceededCons = new ArrayList<MailAccess<?, ?>>();
+                final List<MailAccess<?, ?>> exceededAcesses = new LinkedList<MailAccess<?, ?>>();
                 final int watcherTime = MailProperties.getInstance().getWatcherTime();
-                for (final Iterator<Entry<MailAccess<?, ?>, Long>> iter = mailAccessMap.entrySet().iterator(); iter.hasNext();) {
+                final long now = System.currentTimeMillis();
+                for (final Iterator<Entry<MailAccess<?, ?>, Long>> iter = map.entrySet().iterator(); iter.hasNext();) {
                     final Entry<MailAccess<?, ?>, Long> e = iter.next();
                     final MailAccess<?, ?> mailAccess = e.getKey();
-                    if (mailAccess.isConnectedUnsafe()) {
-                        final Long val = e.getValue();
-                        if ((null != val) && ((System.currentTimeMillis() - l(val)) > watcherTime)) {
-                            logger.info(INFO_PREFIX.replaceFirst("#N#", Long.toString(System.currentTimeMillis() - l(val))) + mailAccess.getTrace());
-                            exceededCons.add(mailAccess);
+                    if (mailAccess.isConnected()) {
+                        if (mailAccess.isWaiting()) {
+                            if (traceEnabled) {
+                                logger.trace(new StringBuilder("Idling/waiting mail connection:\n").append(mailAccess.getTrace()).toString());
+                            }
+                        } else {
+                            final Long val = e.getValue();
+                            if (null != val) {
+                                final long duration = (now - l(val));
+                                if (duration > watcherTime) {
+                                    sb.setLength(0);
+                                    logger.info(sb.append(INFO_PREFIX.replaceFirst("#N#", Long.toString(duration))).append(
+                                        mailAccess.getTrace()).toString());
+                                    exceededAcesses.add(mailAccess);
+                                }
+
+                            }
                         }
                     } else {
                         /*
@@ -214,15 +251,12 @@ public final class MailAccessWatcher {
                         iter.remove();
                     }
                 }
-                if (!exceededCons.isEmpty()) {
-                    /*
-                     * Remove/Close exceeded accesses
-                     */
-                    final int n = exceededCons.size();
-                    final Iterator<MailAccess<?, ?>> iter = exceededCons.iterator();
+                /*
+                 * Remove/Close exceeded accesses if allowed to
+                 */
+                if (!exceededAcesses.isEmpty()) {
                     if (MailProperties.getInstance().isWatcherShallClose()) {
-                        for (int i = 0; i < n; i++) {
-                            final MailAccess<?, ?> mailAccess = iter.next();
+                        for (final MailAccess<?, ?> mailAccess : exceededAcesses) {
                             try {
                                 sb.setLength(0);
                                 sb.append(INFO_PREFIX2).append(mailAccess.toString());
@@ -230,12 +264,12 @@ public final class MailAccessWatcher {
                                 sb.append(INFO_PREFIX3);
                                 logger.info(sb.toString());
                             } finally {
-                                mailAccessMap.remove(mailAccess);
+                                map.remove(mailAccess);
                             }
                         }
                     } else {
-                        for (int i = 0; i < n; i++) {
-                            mailAccessMap.remove(iter.next());
+                        for (final MailAccess<?, ?> mailAccess : exceededAcesses) {
+                            map.remove(mailAccess);
                         }
                     }
                 }
