@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import com.openexchange.groupware.EnumComponent;
  * <p>
  * The detail number range in subclasses generated in transport bundles is supposed to start with <code>3000</code> and may go up to
  * <code>3999</code>.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class MailException extends AbstractOXException {
@@ -105,9 +105,9 @@ public class MailException extends AbstractOXException {
          */
         UNREADBALE_PART_CONTENT("A part's content could not be read from message %1$s in mail folder %2$s", Category.INTERNAL_ERROR, 7),
         /**
-         * An I/O error occurred %1$s
+         * An I/O error occurred: %1$s
          */
-        IO_ERROR("An I/O error occurred %1$s", Category.CODE_ERROR, 8),
+        IO_ERROR("An I/O error occurred: %1$s", Category.CODE_ERROR, 8),
         /**
          * Invalid message path: %1$s
          */
@@ -129,9 +129,9 @@ public class MailException extends AbstractOXException {
          */
         NO_MAIL_ACCESS("No mail module access permitted", Category.PERMISSION, 13),
         /**
-         * No mail account exists for admin user in context %1$s
+         * Mail account is disabled for admin user in context %1$s
          */
-        ACCOUNT_DOES_NOT_EXIST("No mail account exists for admin user in context %1$s", Category.SETUP_ERROR, 14),
+        ACCOUNT_DOES_NOT_EXIST("Mail account is disabled for admin user in context %1$s", Category.SETUP_ERROR, 14),
         /**
          * Process was interrupted. Please try again.
          */
@@ -247,7 +247,7 @@ public class MailException extends AbstractOXException {
         /**
          * Message has been successfully sent, but a copy could not be placed in your sent folder
          */
-        COPY_TO_SENT_FOLDER_FAILED("Message has been successfully sent, but a copy could not be placed in your sent folder.", Category.EXTERNAL_RESOURCE_FULL, 43),
+        COPY_TO_SENT_FOLDER_FAILED("Message has been successfully sent, but a copy could not be placed in your sent folder.", Category.WARNING, 43),
         /**
          * No provider could be found for protocol/URL "%1$s"
          */
@@ -389,7 +389,7 @@ public class MailException extends AbstractOXException {
          * Mail could not be found in folder %1$s for Message-Id: %2$s
          */
         MAIL_NOT_FOUN_BY_MESSAGE_ID("Mail could not be found in folder %1$s for Message-Id: %2$s", Category.CODE_ERROR, 32),
-        
+
         /**
          * Sent quota exceeded, you are only allowed to sent 1 mail in %1$s seconds.
          */
@@ -398,7 +398,53 @@ public class MailException extends AbstractOXException {
         /**
          * Sent quota exceeded, you are only allowed to sent 1 mail in %1$s seconds.
          */
-        RECIPIENTS_EXCEEDED("Please limit your recipients to %1$s  (including To/Cc/Bcc), and click 'Send' again.", Category.CODE_ERROR, 76);
+        RECIPIENTS_EXCEEDED("Please limit your recipients to %1$s  (including To/Cc/Bcc), and click 'Send' again.", Category.CODE_ERROR, 76),
+        /**
+         * Unable to parse mail server URI "%1$s".
+         */
+        URI_PARSE_FAILED("Unable to parse mail server URI \"%1$s\".", Category.USER_INPUT, 77),
+        /**
+         * Mail attachment expired or absent.
+         */
+        ATTACHMENT_EXPIRED("Mail attachment expired or absent.", Category.USER_INPUT, 78),
+        /**
+         * Account has been checked successfully but with a non-secure connection.
+         */
+        NON_SECURE_WARNING("Account has been checked successfully but with a non-secure connection.", Category.WARNING, 79),
+        /**
+         * Cannot forward more than %1$s messages at once. Please divide the messages to forward in chunks of appropriate size.
+         */
+        TOO_MANY_FORWARD_MAILS("Cannot forward more than %1$s messages at once. Please divide the messages to forward in chunks of appropriate size.", Category.USER_INPUT, 80),
+        /**
+         * Your account has been created but will not use a secure connection.
+         */
+        NON_SECURE_CREATION("Your account has been created but will not use a secure connection.", Category.WARNING, 81),
+        /**
+         * Your E-Mail has been successfully sent, but the original E-Mail could not be flagged as "replied" and/or "forwarded".
+         */
+        FLAG_FAIL("Your E-Mail has been successfully sent, but the original E-Mail could not be flagged as \"replied\" and/or \"forwarded\".", Category.WARNING, 82),
+        /**
+         * Invalid folder name: "%1$s"
+         */
+        INVALID_FOLDER_NAME2("Invalid folder name: \"%1$s\"", INVALID_FOLDER_NAME.getCategory(), INVALID_FOLDER_NAME.getNumber()),
+        /**
+         * Mail folder cannot be created/renamed. Folder name exceeds max length of %1$s.
+         */
+        INVALID_FOLDER_NAME_TOO_LONG("Mail folder cannot be created/renamed. Folder name exceeds max length of %1$s.", Category.USER_INPUT, 83), 
+        /**
+         * The attachments to this mail exceeded the size limit for attachments. Instead of sending the attachment in the email, the attachment was published and the link added to your email. Whoever receives the email can then download the attachment.
+         */
+        USED_PUBLISHING_FEATURE("The attachments to this mail exceeded the size limit for attachments. Instead of sending the attachment in the email, the attachment was published and the link added to your email. Whoever receives the email can then download the attachment.", Category.WARNING, 84),
+        /**
+         * Draft message could not be saved
+         */
+        DRAFT_FAILED_UNKNOWN("Draft message could not be saved", Category.USER_INPUT, 85),
+        /**
+         * There was a problem processing the request. Please (refresh view and) try again.
+         */
+        PROCESSING_ERROR("There was a problem processing the request. Please (refresh view and) try again.", Category.TRY_AGAIN, 86),
+        
+        ;
 
 
         private final String message;
@@ -434,7 +480,7 @@ public class MailException extends AbstractOXException {
 
     /**
      * Initializes a new {@link MailException}
-     * 
+     *
      * @param cause The cause
      */
     public MailException(final AbstractOXException cause) {
@@ -443,7 +489,7 @@ public class MailException extends AbstractOXException {
 
     /**
      * Initializes a new {@link MailException}
-     * 
+     *
      * @param code The code
      * @param messageArgs The message arguments
      */
@@ -453,7 +499,7 @@ public class MailException extends AbstractOXException {
 
     /**
      * Initializes a new {@link MailException}
-     * 
+     *
      * @param code The code
      * @param cause The cause
      * @param messageArgs The message arguments
@@ -465,7 +511,7 @@ public class MailException extends AbstractOXException {
 
     /**
      * Initializes a new {@link MailException}
-     * 
+     *
      * @param component The component
      * @param category The category
      * @param detailNumber The detail number
@@ -478,7 +524,7 @@ public class MailException extends AbstractOXException {
 
     /**
      * Initializes a new {@link MailException}
-     * 
+     *
      * @param component The component
      * @param message The message
      * @param cause The cause
