@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,7 +58,7 @@ import java.util.Comparator;
  * {@link MailPath} - Represents a message's unique path inside a mailbox, that is the account ID followed by the folder fullname followed
  * by the value of {@link #SEPERATOR} followed by mail's unique ID:<br>
  * Example: <i>default1/INBOX.Subfolder/1234</i>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailPath implements Cloneable, Serializable {
@@ -92,7 +92,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets the mail path corresponding to given folder fullname and message UID
-     * 
+     *
      * @param accountId The account ID
      * @param folder The folder fullname
      * @param mailId The mail ID
@@ -105,7 +105,7 @@ public final class MailPath implements Cloneable, Serializable {
     /**
      * Returns the mail paths for given comma-separated mail IDs each conform to pattern &lt;folder-path&gt;&lt;value-of-{@link #SEPERATOR}
      * &gt;&lt;mail-ID&gt;
-     * 
+     *
      * @param mailPaths The comma-separated mail IDs
      * @return The corresponding mail paths
      * @throws MailException If mail paths cannot be generated
@@ -117,7 +117,7 @@ public final class MailPath implements Cloneable, Serializable {
     /**
      * Returns the mail paths for given mail IDs each conform to pattern &lt;folder-path&gt;&lt;value-of-{@link #SEPERATOR}
      * &gt;&lt;mail-ID&gt;
-     * 
+     *
      * @param mailPaths The mail IDs
      * @return The corresponding mail paths
      * @throws MailException If mail paths cannot be generated
@@ -132,7 +132,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Extracts the IDs from given mail paths
-     * 
+     *
      * @param mailPaths The mail IDs
      * @return The extracted IDs
      */
@@ -165,7 +165,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Initializes a new {@link MailPath}
-     * 
+     *
      * @param mailPathStr The mail path's string representation
      * @throws MailException If mail path's string representation does not match expected pattern
      */
@@ -176,7 +176,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Initializes a new {@link MailPath}
-     * 
+     *
      * @param accountId The account ID
      * @param folder Folder fullname
      * @param uid The mail's unique ID
@@ -185,7 +185,7 @@ public final class MailPath implements Cloneable, Serializable {
         super();
         this.accountId = accountId;
         this.folder = folder;
-        this.mailID = uid;
+        mailID = uid;
         str = getMailPath(accountId, folder, mailID);
     }
 
@@ -245,7 +245,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets the account ID.
-     * 
+     *
      * @return The account ID
      */
     public int getAccountId() {
@@ -254,7 +254,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets the folder fullname
-     * 
+     *
      * @return The folder fullname
      */
     public String getFolder() {
@@ -263,7 +263,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets the folder argument; <i>default3/INBOX</i>.
-     * 
+     *
      * @return The folder argument
      */
     public String getFolderArgument() {
@@ -272,7 +272,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets this mail path's string representation.
-     * 
+     *
      * @return This mail path's string representation
      * @see #toString()
      */
@@ -282,7 +282,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Gets the mail ID.
-     * 
+     *
      * @return The mail ID
      */
     public String getMailID() {
@@ -291,7 +291,7 @@ public final class MailPath implements Cloneable, Serializable {
 
     /**
      * Sets this mail path's folder fullname and mail's unique ID (for re-usage).
-     * 
+     *
      * @param mailPathStr The mail paths string representation
      * @return The mail path itself
      * @throws MailException If mail path's string representation does not match expected pattern
@@ -302,9 +302,9 @@ public final class MailPath implements Cloneable, Serializable {
             throw new MailException(MailException.Code.INVALID_MAIL_IDENTIFIER, mailPathStr);
         }
         final FullnameArgument fa = prepareMailFolderParam(mailPathStr.substring(0, pos));
-        this.accountId = fa.getAccountId();
-        this.folder = fa.getFullname();
-        this.mailID = mailPathStr.substring(pos + 1);
+        accountId = fa.getAccountId();
+        folder = fa.getFullname();
+        mailID = mailPathStr.substring(pos + 1);
         str = mailPathStr;
         return this;
     }
@@ -312,7 +312,7 @@ public final class MailPath implements Cloneable, Serializable {
     /**
      * Gets this mail path's string representation following pattern:<br>
      * <i>"default" + &lt;account-id&gt; + &lt;default-separator&gt; + &lt;folder-fullname&gt; + "/" + &lt;mail-id&gt;</i>
-     * 
+     *
      * <pre>
      * default2/INBOX/Subfolder/453&quot;
      * </pre>
