@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,9 +50,14 @@
 package com.openexchange.mail;
 
 import static com.openexchange.mail.utils.ProviderUtility.extractProtocol;
+import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.atomic.AtomicReference;
+import com.openexchange.mail.api.AllMailProvider;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.config.MailProperties;
@@ -65,12 +70,15 @@ import com.openexchange.session.Session;
  */
 public final class MailProviderRegistry {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailProviderRegistry.class);
+    private static final org.apache.commons.logging.Log LOG =
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailProviderRegistry.class));
 
     /**
      * Concurrent map used as set for mail providers
      */
-    private static final Map<Protocol, MailProvider> providers = new ConcurrentHashMap<Protocol, MailProvider>();
+    private static final ConcurrentMap<Protocol, MailProvider> providers = new ConcurrentHashMap<Protocol, MailProvider>();
+
+    private static final AtomicReference<AllMailProvider> allProvider = new AtomicReference<AllMailProvider>();
 
     /**
      * Initializes a new {@link MailProviderRegistry}
@@ -79,6 +87,15 @@ public final class MailProviderRegistry {
         super();
     }
 
+    /**
+     * Gets registered mail providers' protocols
+     * 
+     * @return The protocols
+     */
+    public static List<Protocol> getProtocols() {
+        return new ArrayList<Protocol>(providers.keySet());
+    }
+
     /**
      * Gets the mail provider appropriate for specified session.
      * 
@@ -153,6 +170,30 @@ public final class MailProviderRegistry {
         if (null == protocolName) {
             return null;
         }
+        final AllMailProvider all = allProvider.get();
+        if (null != all) {
+            final MailProvider realMailProvider = getRealMailProvider(protocolName);
+            return (null == realMailProvider) ? null : all.getDelegatingProvider(realMailProvider);
+        }
+        /*
+         * Return real provider
+         */
+        return getRealMailProvider(protocolName);
+    }
+
+    /**
+     * Gets the real mail provider for specified protocol name.
+     * 
+     * @param protocolName The protocol name
+     * @return The mail provider or <code>null</code>
+     */
+    public static MailProvider getRealMailProvider(final String protocolName) {
+        if (null == protocolName) {
+            return null;
+        }
+        /*
+         * Look-up
+         */
         for (final Iterator<Map.Entry<Protocol, MailProvider>> iter = providers.entrySet().iterator(); iter.hasNext();) {
             final Map.Entry<Protocol, MailProvider> entry = iter.next();
             if (entry.getKey().isSupported(protocolName)) {
@@ -172,20 +213,33 @@ public final class MailProviderRegistry {
      * @throws MailException If provider's start-up fails
      */
     public static boolean registerMailProvider(final String protocol, final MailProvider provider) throws MailException {
-        final Protocol p = Protocol.parseProtocol(protocol);
-        if (providers.containsKey(p)) {
-            return false;
-        }
         try {
+            final Protocol p = Protocol.parseProtocol(protocol);
+            if (Protocol.PROTOCOL_ALL.equals(p)) {
+                /*
+                 * All provider
+                 */
+                if (!allProvider.compareAndSet(null, (AllMailProvider) provider)) {
+                    return false;
+                }
+                /*
+                 * Startup
+                 */
+                provider.startUp();
+                provider.setDeprecated(false);
+                return true;
+            }
+            /*
+             * Non-all provider
+             */
+            if (null != providers.putIfAbsent(p, provider)) {
+                return false;
+            }
             /*
              * Startup
              */
             provider.startUp();
             provider.setDeprecated(false);
-            /*
-             * Add to registry
-             */
-            providers.put(p, provider);
             return true;
         } catch (final MailException e) {
             throw e;
@@ -217,6 +271,21 @@ public final class MailProviderRegistry {
          * Clear registry
          */
         providers.clear();
+        final MailProvider all = allProvider.get();
+        if (null != all) {
+            /*
+             * Perform shutdown
+             */
+            try {
+                all.setDeprecated(true);
+                all.shutDown();
+                allProvider.set(null);
+            } catch (final MailException e) {
+                LOG.error("Mail connection implementation could not be shut down", e);
+            } catch (final RuntimeException t) {
+                LOG.error("Mail connection implementation could not be shut down", t);
+            }
+        }
     }
 
     /**
@@ -227,13 +296,32 @@ public final class MailProviderRegistry {
      * @throws MailException If provider's shut-down fails
      */
     public static MailProvider unregisterMailProvider(final MailProvider provider) throws MailException {
-        if (!providers.containsKey(provider.getProtocol())) {
-            return null;
+        final Protocol protocol = provider.getProtocol();
+        if (Protocol.PROTOCOL_ALL.equals(protocol)) {
+            AllMailProvider all;
+            do {
+                all = allProvider.get();
+            } while (!allProvider.compareAndSet(all, null));
+            if (null == all) {
+                return null;
+            }
+            /*
+             * Perform shutdown
+             */
+            try {
+                all.setDeprecated(true);
+                all.shutDown();
+            } catch (final MailException e) {
+                throw e;
+            } catch (final RuntimeException t) {
+                LOG.error(t.getMessage(), t);
+            }
+            return all;
         }
         /*
          * Unregister
          */
-        final MailProvider removed = providers.remove(provider.getProtocol());
+        final MailProvider removed = providers.remove(protocol);
         if (null == removed) {
             return null;
         }
@@ -261,6 +349,30 @@ public final class MailProviderRegistry {
      * @throws MailException If provider's shut-down fails
      */
     public static MailProvider unregisterMailProviderByProtocol(final String protocol) throws MailException {
+        if (Protocol.ALL.equals(protocol)) {
+            AllMailProvider all;
+            do {
+                all = allProvider.get();
+            } while (!allProvider.compareAndSet(all, null));
+            if (null == all) {
+                return null;
+            }
+            /*
+             * Perform shutdown
+             */
+            try {
+                all.setDeprecated(true);
+                all.shutDown();
+            } catch (final MailException e) {
+                throw e;
+            } catch (final RuntimeException t) {
+                LOG.error(t.getMessage(), t);
+            }
+            return all;
+        }
+        /*
+         * Non-all
+         */
         for (final Iterator<Map.Entry<Protocol, MailProvider>> iter = providers.entrySet().iterator(); iter.hasNext();) {
             final Map.Entry<Protocol, MailProvider> entry = iter.next();
             if (entry.getKey().isSupported(protocol)) {
@@ -272,4 +384,5 @@ public final class MailProviderRegistry {
         }
         return null;
     }
+
 }
