@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,7 +70,7 @@ import com.openexchange.tools.iterator.SearchIterator;
  * <p>
  * This interface's purpose is to be conform to other interfaces used in other groupware modules which are used throughout servlet
  * instances.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailServletInterface {
@@ -89,7 +89,7 @@ public abstract class MailServletInterface {
      * Gets a proper implementation of {@link MailServletInterface}
      * <p>
      * <b>NOTE:</b> Don't forget to invoke {@link #close(boolean)} after usage
-     * 
+     *
      * <pre>
      * MailInterface mailInterface = MailInterface.getInstance(session);
      * try {
@@ -98,7 +98,7 @@ public abstract class MailServletInterface {
      *     mailInterface.close(true);
      * }
      * </pre>
-     * 
+     *
      * @param session The session
      * @return An instance of {@link MailServletInterface}
      * @throws MailException
@@ -111,7 +111,7 @@ public abstract class MailServletInterface {
 
     /**
      * Gets a mail's ID by specified "Message-Id" header.
-     * 
+     *
      * @param folder The folder to search in
      * @param messageID The "Message-Id" header
      * @return The ID of the mail corresponding to specified "Message-Id" header
@@ -147,7 +147,7 @@ public abstract class MailServletInterface {
 
     /**
      * Gets both quota limit and quota usage in an array with length set to <code>2</code> for each resource type
-     * 
+     *
      * @param types The resource types; {@link #QUOTA_RESOURCE_STORAGE} or {@link #QUOTA_RESOURCE_MESSAGE}
      * @return Both quota limit and quota usage in an array with length set to <code>2</code> for each resource type
      * @throws MailException If quotas cannot be retrieved
@@ -208,7 +208,7 @@ public abstract class MailServletInterface {
 
     /**
      * Gets the mail identified through given ID from store located in given folder.
-     * 
+     *
      * @param folder The folder path
      * @param msgUID The mail ID
      * @return The mail identified through given ID from store located in given folder.
@@ -219,14 +219,14 @@ public abstract class MailServletInterface {
     /**
      * Returns a message's attachment located at given <code>attachmentPosition</code> wrapped by an instance of
      * <code>JSONMessageAttachmentObject</code> for a convenient access to its attributes and content.
-     * 
+     *
      * @param displayVersion <code>true</code> if returned object is for display purpose; otherwise <code>false</code>
      */
     public abstract MailPart getMessageAttachment(String folder, String msgUID, String attachmentPosition, boolean displayVersion) throws MailException;
 
     /**
      * Returns message's attachments as a ZIP file backed by returned managed file instance.
-     * 
+     *
      * @param folder The folder
      * @param msgUID The message ID
      * @param attachmentPositions The attachment positions
@@ -235,6 +235,16 @@ public abstract class MailServletInterface {
      */
     public abstract ManagedFile getMessageAttachments(String folder, String msgUID, String[] attachmentPositions) throws MailException;
 
+    /**
+     * Returns messages as a ZIP file backed by returned managed file instance.
+     *
+     * @param folder The folder
+     * @param msgIds The message identifiers
+     * @return A ZIP file backed by returned managed file instance
+     * @throws MailException If an error occurs
+     */
+    public abstract ManagedFile getMessages(String folder, String[] msgIds) throws MailException;
+
     /**
      * Returns a message's inline image located identified with given <code>cid</code> wrapped by an instance of
      * <code>JSONMessageAttachmentObject</code> for a convenient access to its attributes and content.
@@ -246,7 +256,7 @@ public abstract class MailServletInterface {
      * <p>
      * If specified draft mail holds a reference to an existing draft mail - {@link MailMessage#getMsgref()} is not <code>null</code> - then
      * the referenced draft mail shall be replaced.
-     * 
+     *
      * @param draftMail The draft mail
      * @param autosave <code>true</code> to indicate an auto-save operation; otherwise <code>false</code>
      * @return The stored draft's mail path
@@ -259,6 +269,16 @@ public abstract class MailServletInterface {
      */
     public abstract void sendReceiptAck(String folder, String msgUID, String fromAddr) throws MailException;
 
+    /**
+     * Sends a form mail.
+     *
+     * @param composedMail The form mail (without any recipients)
+     * @param groupId The identifier of the group to whose members shall receive the mail
+     * @param accountId The account identifier
+     * @throws MailException If mail transport fails
+     */
+    public abstract void sendFormMail(ComposedMailMessage composedMail, int groupId, int accountId) throws MailException;
+
     /**
      * Sends a message described through given instance of <code>msgObj</code> and its possible file attachments contained in given instance
      * of <code>uploadEvent</code>.
@@ -267,7 +287,7 @@ public abstract class MailServletInterface {
 
     /**
      * Appends given messages to given folder.
-     * 
+     *
      * @param destFolder The destination folder
      * @param msgs - The messages to append (<b>must</b> be completely pre-filled incl. content references)
      * @param force <code>true</code> to enforce append and to omit checks; otherwise <code>false</code>
@@ -275,17 +295,17 @@ public abstract class MailServletInterface {
      * @throws MailException If messages cannot be appended.
      */
     public abstract String[] appendMessages(String destFolder, MailMessage[] msgs, boolean force) throws MailException;
-    
+
     /**
      * Overwrite this to implement a different append behaviour for mail imports.
-     * 
+     *
      * @param destFolder The destination folder
      * @param msgs - The messages to append (<b>must</b> be completely pre-filled incl. content references)
      * @param force <code>true</code> to enforce append and to omit checks; otherwise <code>false</code>
      * @return The corresponding mail IDs in destination folder
      * @throws MailException If messages cannot be appended.
      */
-    public String[] importMessages(String destFolder, MailMessage[] msgs, boolean force) throws MailException {
+    public String[] importMessages(final String destFolder, final MailMessage[] msgs, final boolean force) throws MailException {
         return appendMessages(destFolder, msgs, force);
     }
 
@@ -331,7 +351,7 @@ public abstract class MailServletInterface {
 
     /**
      * Gets all updated messages in given folder
-     * 
+     *
      * @param folder The folder fullname
      * @param since The time stamp in UTC milliseconds
      * @param fields The desired fields to fill in returned messages
@@ -342,7 +362,7 @@ public abstract class MailServletInterface {
 
     /**
      * Gets all deleted messages in given folder
-     * 
+     *
      * @param folder The folder fullname
      * @param since The time stamp in UTC milliseconds
      * @param fields The desired fields to fill in returned messages
@@ -373,7 +393,7 @@ public abstract class MailServletInterface {
 
     /**
      * Closes the interface and releases all resources
-     * 
+     *
      * @param putIntoCache - whether or not to put associated conenction into pool
      */
     public abstract void close(boolean putIntoCache) throws MailException;
@@ -430,18 +450,18 @@ public abstract class MailServletInterface {
 
     /**
      * Gets the account ID to which the (primary) mail access is connected
-     * 
+     *
      * @return The account ID
      */
     public abstract int getAccountID();
 
     /**
      * Gets possible warnings.
-     * 
+     *
      * @return Possible warnings
      */
     public abstract Collection<MailException> getWarnings();
-    
+
     /**
      * Get results of imported mails.
      * Implement this if you want to return detailed informations for mail imports.
