@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,7 @@ package com.openexchange.mail;
 
 /**
  * {@link MailSessionParameterNames} - Constants used as keys for session parameters.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailSessionParameterNames {
@@ -70,13 +70,17 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for publishing infostore folder ID.
-     * 
+     *
      * @return The parameter name for publishing infostore folder ID
      */
     public static String getParamPublishingInfostoreFolderID() {
         return PARAM_PUBLISHING_INFOSTORE_FOLDER_ID;
     }
 
+    /*-
+     * ####################### DEFAULT FOLDERS ########################
+     */
+
     /**
      * Default folder flag.
      */
@@ -84,13 +88,31 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for default folder flag.
-     * 
+     *
      * @return The parameter name for default folder flag
      */
     public static String getParamDefaultFolderChecked() {
         return PARAM_DEF_FLD_FLAG;
     }
 
+    /**
+     * Default folder flag.
+     */
+    private static final String PARAM_DEF_FLD_TRASH = "mail.deftrash";
+
+    /**
+     * Gets the parameter name for default trash folder.
+     *
+     * @return The parameter name for default trash folder
+     */
+    public static String getParamDefaultTrashFolder() {
+        return PARAM_DEF_FLD_TRASH;
+    }
+
+    /*-
+     * ####################### OTHER STUFF ########################
+     */
+
     /**
      * Mail folder separator.
      */
@@ -98,7 +120,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for mail folder separator.
-     * 
+     *
      * @return The parameter name for mail folder separator
      */
     public static String getParamSeparator() {
@@ -112,7 +134,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for default folder array.
-     * 
+     *
      * @return The parameter name for default folder array
      */
     public static String getParamDefaultFolderArray() {
@@ -126,7 +148,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for session mail cache.
-     * 
+     *
      * @return The parameter name for session mail cache
      */
     public static String getParamMailCache() {
@@ -140,7 +162,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for session main cache.
-     * 
+     *
      * @return The parameter name for session main cache
      */
     public static String getParamMainCache() {
@@ -154,7 +176,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for mail provider.
-     * 
+     *
      * @return The parameter name for mail provider
      */
     public static String getParamMailProvider() {
@@ -168,7 +190,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for mail transport.
-     * 
+     *
      * @param accountId The account ID
      * @return The parameter name for mail transport
      */
@@ -188,7 +210,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for session's context.
-     * 
+     *
      * @return The parameter name for session's context
      */
     public static String getParamSessionContext() {
@@ -202,7 +224,7 @@ public final class MailSessionParameterNames {
 
     /**
      * Gets the parameter name for spam handler.
-     * 
+     *
      * @return The parameter name for spam handler
      */
     public static String getParamSpamHandler() {
