@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,11 @@
 
 package com.openexchange.mail;
 
-import gnu.trove.TIntObjectHashMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
 
 /**
  * {@link MailSortField} - An enumeration of sortable mail list fields.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public enum MailSortField {
@@ -136,7 +136,7 @@ public enum MailSortField {
 
     /**
      * Creates an array of {@link MailSortField} corresponding to given <code>int</code> values
-     * 
+     *
      * @param fields The <code>int</code> values
      * @return The array of {@link MailSortField} corresponding to given <code>int</code> values
      */
@@ -162,7 +162,7 @@ public enum MailSortField {
 
     /**
      * Determines the corresponding {@link MailSortField} constant to given <code>int</code> value
-     * 
+     *
      * @param field The <code>int</code> value
      * @return The corresponding {@link MailSortField} constant
      */
