@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,10 +54,8 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Properties;
-import java.util.concurrent.atomic.AtomicInteger;
-import java.util.concurrent.locks.Condition;
-import java.util.concurrent.locks.Lock;
-import java.util.concurrent.locks.ReentrantLock;
+import java.util.Queue;
+import java.util.concurrent.ConcurrentLinkedQueue;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
@@ -65,19 +63,27 @@ import com.openexchange.mail.MailAccessWatcher;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailInitialization;
 import com.openexchange.mail.MailProviderRegistry;
-import com.openexchange.mail.MailSessionParameterNames;
-import com.openexchange.mail.cache.MailAccessCache;
+import com.openexchange.mail.api.MailConfig.PasswordSource;
+import com.openexchange.mail.cache.EnqueueingMailAccessCache;
+import com.openexchange.mail.cache.IMailAccessCache;
+import com.openexchange.mail.cache.SingletonMailAccessCache;
+import com.openexchange.mail.config.MailConfigException;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.mime.MimeCleanUp;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondService;
+import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.SessionHolder;
 
 /**
  * {@link MailAccess} - Handles connecting to the mailing system while using an internal cache for connected access objects (see
- * {@link MailAccessCache}).
+ * {@link SingletonMailAccessCache}).
  * <p>
  * Moreover it provides access to either message storage, folder storage and logic tools.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMessageStorage> implements Serializable {
@@ -87,13 +93,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      */
     private static final long serialVersionUID = -2580495494392812083L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccess.class);
-
-    private static final AtomicInteger COUNTER = new AtomicInteger();
-
-    private static final transient Lock LOCK_CON = new ReentrantLock();
-
-    private static final transient Condition LOCK_CON_CONDITION = LOCK_CON.newCondition();
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccess.class));
 
     /*-
      * ############### MEMBERS ###############
@@ -107,6 +107,18 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     protected boolean cacheable;
 
+    /**
+     * Indicates if <tt>MailAccess</tt> is currently held in {@link SingletonMailAccessCache}.
+     */
+    protected boolean cached;
+
+    /**
+     * A flag to check if this <tt>MailAccess</tt> is connected, but in IDLE mode, waiting for any server notifications.
+     */
+    protected boolean waiting;
+
+    protected MailProvider provider;
+
     private transient MailConfig mailConfig;
 
     private Properties mailProperties;
@@ -116,8 +128,8 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     private StackTraceElement[] trace;
 
     /**
-     * Initializes a new {@link MailAccess} for session user's default mail account.
-     * 
+     * Initializes a new <tt>MailAccess</tt> for session user's default mail account.
+     *
      * @param session The session
      */
     protected MailAccess(final Session session) {
@@ -125,8 +137,8 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     }
 
     /**
-     * Initializes a new {@link MailAccess}.
-     * 
+     * Initializes a new <tt>MailAccess</tt>.
+     *
      * @param session The session
      * @param accountId The account ID
      */
@@ -138,18 +150,47 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         cacheable = true;
     }
 
+    /**
+     * Gets the session associated with this <tt>MailAccess</tt> instance.
+     *
+     * @return The session
+     */
+    public Session getSession() {
+        return session;
+    }
+
+    /**
+     * Sets the associated {@link MailProvider} instance.
+     *
+     * @param provider The mail provider
+     * @return This instance with mail provider applied
+     */
+    protected MailAccess<F, M> setProvider(final MailProvider provider) {
+        this.provider = provider;
+        return this;
+    }
+
+    /**
+     * Gets the associated {@link MailProvider} instance.
+     *
+     * @return The mail provider
+     */
+    public MailProvider getProvider() {
+        return provider;
+    }
+
     /**
      * Adds given warnings.
-     * 
+     *
      * @param warnings The warnings to add
      */
-    protected void addWarnings(final Collection<MailException> warnings) {
+    public void addWarnings(final Collection<MailException> warnings) {
         this.warnings.addAll(warnings);
     }
 
     /**
      * Gets possible warnings.
-     * 
+     *
      * @return Possible warnings.
      */
     public Collection<MailException> getWarnings() {
@@ -157,7 +198,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     }
 
     /**
-     * Resets this access' settings.
+     * Resets this access' settings. Should be called when {@link #closeInternal()} is invoked.
      */
     protected final void resetFields() {
         mailProperties = null;
@@ -167,42 +208,62 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Triggers all implementation-specific startup actions.
-     * 
-     * @param mailAccess An instance of {@link MailAccess}
+     *
+     * @param mailAccess An instance of <tt>MailAccess</tt>
      * @throws MailException If implementation-specific startup fails
      */
-    static void startupImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
+    protected static void startupImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
         mailAccess.startup();
     }
 
     /**
      * Triggers all implementation-specific shutdown actions.
-     * 
-     * @param mailAccess An instance of {@link MailAccess}
+     *
+     * @param mailAccess An instance of <tt>MailAccess</tt>
      * @throws MailException If implementation-specific shutdown fails
      */
-    static void shutdownImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
+    protected static void shutdownImpl(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
         mailAccess.shutdown();
     }
 
+    /**-
+     * The max. number of <tt>MailAccess</tt> instanced allowed being cached concurrently for a user's account.
+     *
+     * TODO: Add to configuration?
+     */
+    private static final int MAX_PER_USER = 3;
+
     /**
-     * Gets the proper instance of {@link MailAccess} for session user's default mail account.
+     * Gets the appropriate {@link IMailAccessCache mail access cache} instance.
+     *
+     * @return The mail access cache
+     * @throws MailException If cache cannot be initialized
+     */
+    public static IMailAccessCache getMailAccessCache() throws MailException {
+        return 1 == MAX_PER_USER ? SingletonMailAccessCache.getInstance() : EnqueueingMailAccessCache.getInstance(MAX_PER_USER);
+    }
+
+    /**
+     * Gets the proper instance of <tt>MailAccess</tt> for session user's default mail account.
      * <p>
      * When starting to work with obtained {@link MailAccess mail access} at first its {@link #connect()} method is supposed to be invoked.
      * On finished work the final {@link #close(boolean)} must be called:
-     * 
+     *
      * <pre>
-     * final MailAccess mailAccess = MailAccess.getInstance(session);
-     * mailAccess.connect();
+     * MailAccess mailAccess = null;
      * try {
+     *  mailAccess = MailAccess.getInstance(...);
+     *  mailAccess.connect();
      *  // Do something
      * } finally {
-     *  mailAccess.close(putToCache)
+     *  if (mailAccess != null) {
+     *   mailAccess.close(putToCache);
+     *  }
      * }
      * </pre>
-     * 
+     *
      * @param session The session
-     * @return A proper instance of {@link MailAccess}
+     * @return A proper instance of <tt>MailAccess</tt>
      * @throws MailException If instantiation fails or a caching error occurs
      */
     public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final Session session) throws MailException {
@@ -210,24 +271,27 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     }
 
     /**
-     * Gets the proper instance of {@link MailAccess} parameterized with given session and account ID.
+     * Gets the proper instance of <tt>MailAccess</tt> parameterized with given session and account ID.
      * <p>
      * When starting to work with obtained {@link MailAccess mail access} at first its {@link #connect()} method is supposed to be invoked.
      * On finished work the final {@link #close(boolean)} must be called:
-     * 
+     *
      * <pre>
-     * final MailAccess mailAccess = MailAccess.getInstance(session, accountID);
-     * mailAccess.connect();
+     * MailAccess MailAccess = null;
      * try {
-     * 	// Do something
+     *  mailAccess = mailService.getInstance(...);
+     *  mailAccess.connect();
+     *  // Do something
      * } finally {
-     * 	mailAccess.close(putToCache)
+     *  if (mailAccess != null) {
+     *   mailAccess.close(putToCache);
+     *  }
      * }
      * </pre>
-     * 
+     *
      * @param session The session
      * @param accountId The account ID
-     * @return A proper instance of {@link MailAccess}
+     * @return A proper instance of <tt>MailAccess</tt>
      * @throws MailException If instantiation fails or a caching error occurs
      */
     public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final Session session, final int accountId) throws MailException {
@@ -237,12 +301,6 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         if (!MailInitialization.getInstance().isInitialized()) {
             throw new MailException(MailException.Code.INITIALIZATION_PROBLEM);
         }
-        if (MailAccessCache.getInstance().containsMailAccess(session, accountId)) {
-            final MailAccess<?, ?> mailAccess = MailAccessCache.getInstance().removeMailAccess(session, accountId);
-            if (mailAccess != null) {
-                return mailAccess;
-            }
-        }
         if (MailAccount.DEFAULT_ID == accountId) {
             /*
              * No cached connection available, check for admin login
@@ -250,63 +308,177 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
             checkAdminLogin(session, accountId);
         }
         /*
-         * Check if a new connection may be established
+         * Occupy free slot
          */
-        if ((MailProperties.getInstance().getMaxNumOfConnections() > 0) && (COUNTER.get() > MailProperties.getInstance().getMaxNumOfConnections())) {
-            LOCK_CON.lock();
-            try {
-                while (COUNTER.get() > MailProperties.getInstance().getMaxNumOfConnections()) {
-                    if (LOG.isDebugEnabled()) {
-                        LOG.debug("Too many mail connections currently established. Going asleep.");
-                    }
-                    LOCK_CON_CONDITION.await();
-                }
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Woke up & mail access may again be established");
-                }
-                /*
-                 * Try to fetch from cache again
-                 */
-                if (MailAccessCache.getInstance().containsMailAccess(session, accountId)) {
-                    final MailAccess<?, ?> mailAccess = MailAccessCache.getInstance().removeMailAccess(session, accountId);
-                    if (mailAccess != null) {
-                        return mailAccess;
-                    }
-                }
-            } catch (final InterruptedException e) {
-                LOG.error(e.getMessage(), e);
-                throw new MailException(MailException.Code.INTERRUPT_ERROR, e, new Object[0]);
-            } finally {
-                LOCK_CON.unlock();
+        final Object tmp = session.getParameter("com.openexchange.mail.lookupMailAccessCache");
+        if (null == tmp || toBool(tmp)) {
+            final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = getMailAccessCache().removeMailAccess(session, accountId);
+            if (mailAccess != null) {
+                return mailAccess;
             }
         }
-        return MailProviderRegistry.getMailProviderBySession(session, accountId).createNewMailAccess(session, accountId);
+        final MailProvider mailProvider = MailProviderRegistry.getMailProviderBySession(session, accountId);
+        return mailProvider.createNewMailAccess(session, accountId).setProvider(mailProvider);
+    }
+
+    private static boolean toBool(final Object obj) {
+        if (obj instanceof Boolean) {
+            return ((Boolean) obj).booleanValue();
+        }
+        return Boolean.parseBoolean(obj.toString().trim());
+    }
+
+    /**
+     * Gets a new, un-cached <tt>MailAccess</tt> instance that is initially not connected. 
+     * 
+     * @param session The associated session
+     * @param accountId The account identifier
+     * @return The new, un-cached <tt>MailAccess</tt> instance
+     * @throws MailException If a new, un-cached <tt>MailAccess</tt> instance cannot be returned
+     */
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getNewInstance(final Session session, final int accountId) throws MailException {
+        final String name = "com.openexchange.mail.lookupMailAccessCache";
+        final boolean setParam;
+        {
+            final Object tmp = session.getParameter("com.openexchange.mail.lookupMailAccessCache");
+            setParam = (null == tmp || toBool(tmp));
+        }
+        if (setParam) {
+            session.setParameter(name, Boolean.FALSE);
+        }
+        try {
+            return getInstance(session, accountId);
+        } finally {
+            if (setParam) {
+                session.setParameter(name, null);
+            }
+        }
+    }
+
+    /**
+     * Re-connects specified <tt>MailAccess</tt> instance.
+     * 
+     * @param mailAccess The <tt>MailAccess</tt> instance to re-connect
+     * @return The re-connected <tt>MailAccess</tt> instance.
+     * @throws MailException If re-connect attempt fails
+     * @see #getNewInstance(Session, int)
+     */
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> reconnect(final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws MailException {
+        if (null == mailAccess) {
+            return null;
+        }
+        final Session session = mailAccess.getSession();
+        final int accountId = mailAccess.getAccountId();
+        mailAccess.close(true);
+        // A new instance, freshly initialized
+        final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> newAccess = MailAccess.getNewInstance(session, accountId);
+        newAccess.connect();
+        return newAccess;
+    }
+
+    /**
+     * Gets the proper instance of <tt>MailAccess</tt> for specified user's default account.
+     * <p>
+     * When starting to work with obtained {@link MailAccess mail access} at first its {@link #connect()} method is supposed to be invoked.
+     * On finished work the final {@link #close(boolean)} must be called:
+     *
+     * <pre>
+     * MailAccess mailAccess = null;
+     * try {
+     *  mailAccess = MailAccess.getInstance(...);
+     *  mailAccess.connect();
+     *  // Do something
+     * } finally {
+     *  if (mailAccess != null) {
+     *   mailAccess.close(putToCache);
+     *  }
+     * }
+     * </pre>
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @return An appropriate {@link MailAccess mail access}
+     * @throws MailException If instantiation fails or a caching error occurs
+     */
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final int userId, final int contextId) throws MailException {
+        return getInstance(userId, contextId, MailAccount.DEFAULT_ID);
+    }
+
+    /**
+     * Gets the proper instance of <tt>MailAccess</tt> for specified user and account ID.
+     * <p>
+     * When starting to work with obtained {@link MailAccess mail access} at first its {@link #connect()} method is supposed to be invoked.
+     * On finished work the final {@link #close(boolean)} must be called:
+     *
+     * <pre>
+     * MailAccess mailAccess = null;
+     * try {
+     *  mailAccess = MailAccess.getInstance(...);
+     *  mailAccess.connect();
+     *  // Do something
+     * } finally {
+     *  if (mailAccess != null) {
+     *   mailAccess.close(putToCache);
+     *  }
+     * }
+     * </pre>
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param accountId The account identifier
+     * @return An appropriate {@link MailAccess mail access}
+     * @throws MailException If instantiation fails or a caching error occurs
+     */
+    public static final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getInstance(final int userId, final int contextId, final int accountId) throws MailException {
+     // Firstly let's see if the currently active session matches the one we need here and prefer that one.
+        final SessionHolder sessionHolder = ServerServiceRegistry.getInstance().getService(SessionHolder.class);
+        if (sessionHolder != null) {
+            final Session session = sessionHolder.getSessionObject();
+            if (session != null && session.getUserId() == userId && session.getContextId() == contextId) {
+                return getInstance(session, accountId);
+            }
+        }
+        final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+        if (null != sessiondService) {
+            final Session session = sessiondService.getAnyActiveSessionForUser(userId, contextId);
+            if (session != null) {
+                return getInstance(session, accountId);
+            }
+        }
+        /*
+         * No appropriate session found.
+         */
+        throw new MailException(MailException.Code.UNEXPECTED_ERROR, "No appropriate session found.");
     }
 
     /**
      * @return the global access counter
      */
     public static final int getCounter() {
-        return COUNTER.get();
+        return MailAccessWatcher.getNumberOfMailAccesses();
     }
 
     /**
      * Increments the global access counter.
+     * <p>
+     * <b>Does nothing at all since v6.20.</b>
      */
     protected static final void incrementCounter() {
-        COUNTER.incrementAndGet();
+        // No-op
     }
 
     /**
      * Decrements the global access counter.
+     * <p>
+     * <b>Does nothing at all since v6.20.</b>
      */
     protected static final void decrementCounter() {
-        COUNTER.decrementAndGet();
+        // No-op
     }
 
     /**
      * Gets the optional properties used on connect.
-     * 
+     *
      * @return the mailProperties
      */
     public Properties getMailProperties() {
@@ -315,7 +487,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Sets optional properties used on connect. Herewith additional properties can be applied and checked later on.
-     * 
+     *
      * @param mailProperties The properties
      */
     public void setMailProperties(final Properties mailProperties) {
@@ -326,7 +498,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * Checks if all necessary fields are set in this access object.
      * <p>
      * This routine is implicitly invoked by {@link #connect()}.
-     * 
+     *
      * @throws MailException If a necessary field is missing
      * @see #connect()
      */
@@ -342,7 +514,15 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         } else if (mailConfig.getLogin() == null) {
             throw new MailException(MailException.Code.MISSING_CONNECT_PARAM, "login");
         } else if (mailConfig.getPassword() == null) {
-            throw new MailException(MailException.Code.MISSING_CONNECT_PARAM, "password");
+            final PasswordSource cur = MailProperties.getInstance().getPasswordSource();
+            if (!PasswordSource.GLOBAL.equals(cur)) {
+                throw new MailException(MailException.Code.MISSING_CONNECT_PARAM, "password");
+            }
+            final String masterPw = MailProperties.getInstance().getMasterPassword();
+            if (masterPw == null) {
+                throw new MailConfigException(new StringBuilder().append("Property \"masterPassword\" not set").toString());
+            }
+            mailConfig.setPassword(masterPw);
         }
     }
 
@@ -351,7 +531,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * <p>
      * Default implementation just delegates to {@link #connect()} but may be overridden in implementing subclass if not appropriate or a
      * faster way can be achieved.
-     * 
+     *
      * @return <code>true</code> if a connection can be established; otherwise <code>false</code>
      * @throws MailException If the ping fails
      */
@@ -367,7 +547,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Opens this access. May be invoked on an already opened access.
-     * 
+     *
      * @throws MailException If the connection could not be established for various reasons
      */
     public final void connect() throws MailException {
@@ -376,7 +556,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Opens this access. May be invoked on an already opened access.
-     * 
+     *
      * @param checkDefaultFolders <code>true</code> to check existence of default folders; otherwise <code>false</code> to omit check
      * @throws MailException If the connection could not be established for various reasons
      */
@@ -388,11 +568,11 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * Convenience method to obtain root folder in a fast way; meaning no default folder check is performed which is not necessary to return
      * the root folder.
      * <p>
-     * The same result is yielded through calling <code>getFolderStorage().getRootFolder()</code> on a connected {@link MailAccess}.
+     * The same result is yielded through calling <code>getFolderStorage().getRootFolder()</code> on a connected <tt>MailAccess</tt>.
      * <p>
      * Since this mail access instance is connected if not already done before, the {@link #close(boolean)} operation should be invoked
      * afterwards:
-     * 
+     *
      * <pre>
      * final MailAccess mailAccess = MailAccess.getInstance(session);
      * final MailFolder rootFolder = mailAccess.getRootFolder();
@@ -402,7 +582,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      *  mailAccess.close(putToCache)
      * }
      * </pre>
-     * 
+     *
      * @throws MailException If returning the root folder fails
      */
     public MailFolder getRootFolder() throws MailException {
@@ -416,11 +596,11 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * Convenience method to obtain folder's number of unread messages in a fast way; meaning no default folder check is performed.
      * <p>
      * The same result is yielded through calling <code>getFolderStorage().getFolder().getUnreadMessageCount()</code> on a connected
-     * {@link MailAccess}.
+     * <tt>MailAccess</tt>.
      * <p>
      * Since this mail access instance is connected if not already done before, the {@link #close(boolean)} operation should be invoked
      * afterwards:
-     * 
+     *
      * <pre>
      * final MailAccess mailAccess = MailAccess.getInstance(session);
      * final int unreadCount = mailAccess.getNumberOfUnreadMessages();
@@ -430,7 +610,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      *  mailAccess.close(putToCache)
      * }
      * </pre>
-     * 
+     *
      * @throws MailException If returning the unread count fails
      */
     public int getUnreadMessagesCount(final String fullname) throws MailException {
@@ -480,7 +660,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Internal connect method to establish a mail connection.
-     * 
+     *
      * @param mailConfig The mail configuration providing connect and login data
      * @throws MailException If connection could not be established
      */
@@ -497,15 +677,15 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * Closes this access.
      * <p>
      * An already closed access is not going to be put into cache and is treated as a no-op.
-     * 
+     *
      * @param put2Cache <code>true</code> to try to put this mail connection into cache; otherwise <code>false</code>
      */
     public final void close(final boolean put2Cache) {
-        if (!isConnectedUnsafe()) {
-            return;
-        }
-        boolean put = put2Cache;
         try {
+            if (!isConnectedUnsafe()) {
+                return;
+            }
+            boolean put = put2Cache;
             try {
                 /*
                  * Release all used, non-cachable resources
@@ -523,11 +703,10 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
                 /*
                  * Cache connection if desired/possible anymore
                  */
-                if (put && isCacheable() && MailAccessCache.getInstance().putMailAccess(session, accountId, this)) {
+                if (put && isCacheable() && getMailAccessCache().putMailAccess(session, accountId, this)) {
                     /*
-                     * Successfully cached: signal & return
+                     * Successfully cached: return
                      */
-                    signalAvailableConnection();
                     return;
                 }
             } catch (final MailException e) {
@@ -537,12 +716,39 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
              * Close mail connection
              */
             delegateCloseInternal();
-            signalAvailableConnection();
         } finally {
             /*
              * Remove from watcher no matter if cached or closed
              */
             MailAccessWatcher.removeMailAccess(this);
+            cleanUp();
+        }
+    }
+
+    private static ThreadLocal<Queue<MimeCleanUp>> CLEAN_UPS = new ThreadLocal<Queue<MimeCleanUp>>() {
+        @Override
+        protected Queue<MimeCleanUp> initialValue() {
+            return new ConcurrentLinkedQueue<MimeCleanUp>();
+        }
+    };
+
+    /**
+     * Remembers specified {@link MimeCleanUp} instance.
+     * 
+     * @param mimeCleanUp The {@link MimeCleanUp} instance
+     */
+    public static void rememberMimeCleanUp(final MimeCleanUp mimeCleanUp) {
+        if (null == mimeCleanUp) {
+            return;
+        }
+        CLEAN_UPS.get().offer(mimeCleanUp);
+    }
+
+    private static void cleanUp() {
+        final Queue<MimeCleanUp> queue = CLEAN_UPS.get();
+        MimeCleanUp mimeCleanUp;
+        while ((mimeCleanUp = queue.poll()) != null) {
+            mimeCleanUp.cleanUp();
         }
     }
 
@@ -550,7 +756,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * Gets the trace of the thread that lastly obtained this access.
      * <p>
      * This is useful to detect certain threads which uses an access for a long time
-     * 
+     *
      * @return the trace of the thread that lastly obtained this access
      */
     public final String getTrace() {
@@ -578,9 +784,23 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         return sBuilder.toString();
     }
 
+    @Override
+    public String toString() {
+        final StringBuilder builder = new StringBuilder(256);
+        builder.append("{ MailAccess [accountId=").append(accountId).append(", cached=").append(cached).append(", ");
+        if (provider != null) {
+            builder.append("provider=").append(provider).append(", ");
+        }
+        if (mailConfig != null) {
+            builder.append("mailConfig=").append(mailConfig);
+        }
+        builder.append("] }");
+        return builder.toString();
+    }
+
     /**
      * Returns the mail configuration appropriate for current user. It provides needed connection and login information.
-     * 
+     *
      * @return The mail configuration
      */
     public MailConfig getMailConfig() throws MailException {
@@ -592,7 +812,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Gets this mail access' account ID.
-     * 
+     *
      * @return The account ID
      */
     public int getAccountId() {
@@ -601,7 +821,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Creates a new user-specific mail configuration.
-     * 
+     *
      * @return A new user-specific mail configuration
      * @throws MailException If creating a new mail configuration fails
      */
@@ -611,23 +831,6 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         return MailConfig.getConfig(instance.getClass(), instance, session, accountId);
     }
 
-    /**
-     * Signals an available connection.
-     */
-    private void signalAvailableConnection() {
-        if (MailProperties.getInstance().getMaxNumOfConnections() > 0) {
-            LOCK_CON.lock();
-            try {
-                LOCK_CON_CONDITION.signalAll();
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Sending signal to possible waiting threads");
-                }
-            } finally {
-                LOCK_CON.unlock();
-            }
-        }
-    }
-
     /**
      * Apply new thread's trace information.
      */
@@ -641,7 +844,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Checks if session's user denotes the context admin user and whether admin user's try to login to mail system is permitted or not.
-     * 
+     *
      * @param session The session
      * @param accountId The account ID
      * @throws MailException If session's user denotes the context admin user and admin user's try to login to mail system is not permitted
@@ -651,20 +854,15 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
             /*
              * Admin mail login is not permitted per configuration
              */
-            Context ctx;
-            final String key = MailSessionParameterNames.getParamSessionContext();
-            try {
-                ctx = (Context) session.getParameter(key);
-            } catch (final ClassCastException e1) {
-                ctx = null;
-            }
-            if (ctx == null) {
+            final Context ctx;
+            if (session instanceof ServerSession) {
+                ctx = ((ServerSession) session).getContext();
+            } else {
                 try {
                     ctx = ContextStorage.getStorageContext(session.getContextId());
                 } catch (final ContextException e) {
                     throw new MailException(e);
                 }
-                session.setParameter(key, ctx);
             }
             if (session.getUserId() == ctx.getMailadmin()) {
                 throw new MailException(MailException.Code.ACCOUNT_DOES_NOT_EXIST, Integer.valueOf(ctx.getContextId()));
@@ -673,9 +871,9 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     }
 
     /**
-     * Gets the number of seconds this mail access is allowed to remain idle in {@link MailAccessCache cache} before being removed and
+     * Gets the number of seconds this mail access is allowed to remain idle in {@link SingletonMailAccessCache cache} before being removed and
      * closed. If the default value shall be used for this mail access, return <code>-1</code>.
-     * 
+     *
      * @return The number of allowed idle seconds or <code>-1</code> to signal using default value.
      */
     public int getCacheIdleSeconds() {
@@ -684,7 +882,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Indicates if this mail access is cacheable.
-     * 
+     *
      * @return <code>true</code> if this mail access is cacheable; otherwise <code>false</code>
      */
     public boolean isCacheable() {
@@ -693,16 +891,52 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Sets whether this mail access is cacheable or not.
-     * 
+     *
      * @param cacheable <code>true</code> if this mail access is cacheable; otherwise <code>false</code>
      */
     public void setCacheable(final boolean cacheable) {
         this.cacheable = cacheable;
     }
 
+    /**
+     * Indicates if this mail access is currently cached in {@link IMailAccessCache}.
+     *
+     * @return <code>true</code> if this mail access is cached; otherwise <code>false</code>
+     */
+    public boolean isCached() {
+        return cached;
+    }
+
+    /**
+     * Sets whether this mail access is currently cached or not.
+     *
+     * @param cacheable <code>true</code> if this mail access is cached; otherwise <code>false</code>
+     */
+    public void setCached(final boolean cached) {
+        this.cached = cached;
+    }
+
+    /**
+     * Indicates if this mail access is currently waiting for any server notifications (idle mode).
+     *
+     * @return <code>true</code> if this mail access is waiting; otherwise <code>false</code>
+     */
+    public boolean isWaiting() {
+        return waiting;
+    }
+
+    /**
+     * Sets whether this mail access is currently waiting for any mail server notifications or not.
+     *
+     * @param cacheable <code>true</code> if this mail access is waiting; otherwise <code>false</code>
+     */
+    public void setWaiting(final boolean waiting) {
+        this.waiting = waiting;
+    }
+
     /**
      * Gets an implementation-specific new instance of {@link MailConfig}.
-     * 
+     *
      * @return An implementation-specific new instance of {@link MailConfig}
      */
     protected abstract MailConfig createNewMailConfig();
@@ -716,7 +950,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Gets an implementation-specific new instance of {@link IMailProperties}.
-     * 
+     *
      * @return An implementation-specific new instance of {@link IMailProperties}
      * @throws MailException If creating a new instance of {@link IMailProperties} fails
      */
@@ -731,7 +965,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Defines if mail server port has to be present in provided mail configuration before establishing any connection.
-     * 
+     *
      * @return <code>true</code> if mail server port has to be set before establishing any connection; otherwise <code>false</code>
      */
     protected abstract boolean checkMailServerPort();
@@ -769,7 +1003,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Gets the appropriate {@link IMailFolderStorage} implementation that is considered as the main entry point to a user's mailbox.
-     * 
+     *
      * @return The appropriate {@link IMailFolderStorage} implementation
      * @throws MailException If connection is not established
      */
@@ -777,7 +1011,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Gets the appropriate {@link IMailMessageStorage} implementation that provides necessary message-related operations/methods.
-     * 
+     *
      * @return The appropriate {@link IMailMessageStorage} implementation
      * @throws MailException If connection is not established
      */
@@ -786,7 +1020,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     /**
      * Gets the appropriate {@link MailLogicTools} implementation that provides operations/methods to create a reply/forward message from a
      * referenced message.
-     * 
+     *
      * @return The appropriate {@link MailLogicTools} implementation
      * @throws MailException If connection is not established
      */
@@ -794,7 +1028,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Checks if this connection is currently connected.
-     * 
+     *
      * @return <code>true</code> if connected; otherwise <code>false</code>
      * @see #isConnectedUnsafe()
      */
@@ -802,7 +1036,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Checks if this connection is currently connected in an unsafe, but faster manner than {@link #isConnected()}.
-     * 
+     *
      * @return <code>true</code> if connected; otherwise <code>false</code>
      * @see #isConnected()
      */
@@ -810,14 +1044,14 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
 
     /**
      * Triggers all necessary startup actions.
-     * 
+     *
      * @throws MailException If startup actions fail
      */
     protected abstract void startup() throws MailException;
 
     /**
      * Triggers all necessary shutdown actions.
-     * 
+     *
      * @throws MailException If shutdown actions fail
      */
     protected abstract void shutdown() throws MailException;
