@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,15 +49,25 @@
 
 package com.openexchange.mail.api;
 
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.I2i;
+import static com.openexchange.java.Autoboxing.i;
+import static com.openexchange.mail.utils.ProviderUtility.toSocketAddr;
 import java.net.InetSocketAddress;
-import java.security.GeneralSecurityException;
+import java.util.HashSet;
+import java.util.Iterator;
 import java.util.Locale;
+import java.util.Set;
+import javax.mail.internet.AddressException;
+import javax.mail.internet.IDNA;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.config.MailConfigException;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.partmodifier.DummyPartModifier;
 import com.openexchange.mail.partmodifier.PartModifier;
 import com.openexchange.mail.utils.MailPasswordUtil;
@@ -65,7 +75,6 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountExceptionMessages;
 import com.openexchange.mailaccount.MailAccountStorageService;
-import com.openexchange.secret.SecretService;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
@@ -74,7 +83,7 @@ import com.openexchange.session.Session;
  * {@link MailConfig} - The user-specific mail properties; e.g. containing user's login data.
  * <p>
  * Provides access to global mail properties.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailConfig {
@@ -98,7 +107,7 @@ public abstract class MailConfig {
          * Parses given capability value. If given value equals ignore-case to string <code>true</code>, constant {@link #TRUE} will be
          * returned. Else if given value equals ignore-case to string <code>auto</code>, constant {@link #AUTO} will be returned. Otherwise
          * {@link #FALSE} will be returned.
-         * 
+         *
          * @param capVal - the string value to parse
          * @return an instance of <code>BoolCapVal</code>: either {@link #TRUE}, {@link #FALSE}, or {@link #AUTO}
          */
@@ -140,7 +149,7 @@ public abstract class MailConfig {
 
         /**
          * Parses specified string into a login source.
-         * 
+         *
          * @param loginSourceStr The string to parse to a login source
          * @return An appropriate login source or <code>null</code> if string could not be parsed to a login source
          */
@@ -179,7 +188,7 @@ public abstract class MailConfig {
 
         /**
          * Parses specified string into a password source.
-         * 
+         *
          * @param passwordSourceStr The string to parse to a password source
          * @return An appropriate password source or <code>null</code> if string could not be parsed to a password source
          */
@@ -218,7 +227,7 @@ public abstract class MailConfig {
 
         /**
          * Parses specified string into a server source.
-         * 
+         *
          * @param serverSourceStr The string to parse to a server source
          * @return An appropriate server source or <code>null</code> if string could not be parsed to a server source
          */
@@ -252,7 +261,7 @@ public abstract class MailConfig {
 
     /**
      * Gets the user-specific mail configuration.
-     * 
+     *
      * @param <C> The return value type
      * @param clazz The mail configuration type
      * @param mailConfig A newly created {@link MailConfig mail configuration}
@@ -281,6 +290,7 @@ public abstract class MailConfig {
             throw new MailException(e);
         }
         mailConfig.accountId = accountId;
+        mailConfig.session = session;
         fillLoginAndPassword(mailConfig, session, UserStorage.getStorageUser(userId, contextId).getLoginInfo(), mailAccount);
         String serverURL = MailConfig.getMailServerURL(mailAccount);
         if (serverURL == null) {
@@ -307,11 +317,23 @@ public abstract class MailConfig {
 
     /**
      * Gets the mail login with respect to configured login source.
-     * 
+     *
      * @param mailAccount The mail account used to determine the login
+     * @param userLoginInfo The login information of the user
      * @return The mail login of specified user
      */
     public static final String getMailLogin(final MailAccount mailAccount, final String userLoginInfo) {
+        return saneLogin(getMailLogin0(mailAccount, userLoginInfo));
+    }
+
+    /**
+     * Gets the mail login with respect to configured login source.
+     *
+     * @param mailAccount The mail account used to determine the login
+     * @param userLoginInfo The login information of the user
+     * @return The mail login of specified user
+     */
+    private static final String getMailLogin0(final MailAccount mailAccount, final String userLoginInfo) {
         if (!mailAccount.isDefaultAccount()) {
             return mailAccount.getLogin();
         }
@@ -320,14 +342,22 @@ public abstract class MailConfig {
             return mailAccount.getLogin();
         }
         if (LoginSource.PRIMARY_EMAIL.equals(loginSource)) {
-            return mailAccount.getPrimaryAddress();
+            try {
+                return QuotedInternetAddress.toACE(mailAccount.getPrimaryAddress());
+            } catch (final AddressException e) {
+                final String primaryAddress = mailAccount.getPrimaryAddress();
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailConfig.class)).warn(
+                    "Login source primary email address \"" + primaryAddress + "\" could not be converted to ASCII. Using unicode representation.",
+                    e);
+                return primaryAddress;
+            }
         }
         return userLoginInfo;
     }
 
     /**
      * Gets the mail server URL appropriate to configured mail server source.
-     * 
+     *
      * @param mailAccount The user
      * @return The appropriate mail server URL or <code>null</code>
      */
@@ -336,23 +366,26 @@ public abstract class MailConfig {
             return mailAccount.generateMailServerURL();
         }
         if (ServerSource.GLOBAL.equals(MailProperties.getInstance().getMailServerSource())) {
-            return MailProperties.getInstance().getMailServer();
+            return IDNA.toASCII(MailProperties.getInstance().getMailServer());
         }
         return mailAccount.generateMailServerURL();
     }
 
     /**
      * Gets the mail server URL appropriate to configured mail server source.
-     * 
+     *
      * @param session The user session
      * @param accountId The account ID
      * @return The appropriate mail server URL or <code>null</code>
      * @throws MailException If mail server URL cannot be returned
      */
     public static final String getMailServerURL(final Session session, final int accountId) throws MailException {
+        if (MailAccount.DEFAULT_ID == accountId && ServerSource.GLOBAL.equals(MailProperties.getInstance().getMailServerSource())) {
+            return IDNA.toASCII(MailProperties.getInstance().getMailServer());
+        }
         try {
             final MailAccountStorageService storage = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
-            return getMailServerURL(storage.getMailAccount(accountId, session.getUserId(), session.getContextId()));
+            return storage.getMailAccount(accountId, session.getUserId(), session.getContextId()).generateMailServerURL();
         } catch (final ServiceException e) {
             throw new MailException(e);
         } catch (final MailAccountException e) {
@@ -362,7 +395,7 @@ public abstract class MailConfig {
 
     /**
      * Gets the part modifier.
-     * 
+     *
      * @return the part modifier.
      */
     public static final PartModifier getPartModifier() {
@@ -371,7 +404,7 @@ public abstract class MailConfig {
 
     /**
      * Resolves the user IDs by specified pattern dependent on configuration's setting for mail login source.
-     * 
+     *
      * @param pattern The pattern
      * @param server The server address
      * @param ctx The context
@@ -379,34 +412,69 @@ public abstract class MailConfig {
      * @throws AbstractOXException If resolving user by specified pattern fails
      */
     public static int[] getUserIDsByMailLogin(final String pattern, final boolean isDefaultAccount, final InetSocketAddress server, final Context ctx) throws AbstractOXException {
-        final MailAccountStorageService storageService =
-            ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
+        final MailAccountStorageService storageService = ServerServiceRegistry.getInstance().getService(
+            MailAccountStorageService.class,
+            true);
         if (isDefaultAccount) {
-            final LoginSource loginSource = MailProperties.getInstance().getLoginSource();
-            if (LoginSource.USER_IMAPLOGIN.equals(loginSource)) {
-                /*
-                 * Find user name by user's imap login
-                 */
-                final MailAccount[] accounts = storageService.resolveLogin(pattern, server, ctx.getContextId());
-                final int[] retval = new int[accounts.length];
-                for (int i = 0; i < retval.length; i++) {
-                    retval[i] = accounts[i].getUserId();
+            switch (MailProperties.getInstance().getLoginSource()) {
+            case USER_IMAPLOGIN:
+            case PRIMARY_EMAIL:
+                final MailAccount[] accounts;
+                switch (MailProperties.getInstance().getLoginSource()) {
+                case USER_IMAPLOGIN:
+                    accounts = storageService.resolveLogin(pattern, ctx.getContextId());
+                    break;
+                case PRIMARY_EMAIL:
+                    accounts = storageService.resolvePrimaryAddr(pattern, ctx.getContextId());
+                    break;
+                default:
+                    throw MailAccountExceptionMessages.UNEXPECTED_ERROR.create("Unimplemented mail login source.");
                 }
-                return retval;
-            }
-            if (LoginSource.PRIMARY_EMAIL.equals(loginSource)) {
-                final MailAccount[] accounts = storageService.resolvePrimaryAddr(pattern, server, ctx.getContextId());
-                final int[] retval = new int[accounts.length];
-                for (int i = 0; i < retval.length; i++) {
-                    retval[i] = accounts[i].getUserId();
+                final Set<Integer> userIds = new HashSet<Integer>();
+                if (accounts.length == 1) {
+                    // On ASE some accounts are configured to connect to localhost, some to the full qualified local host name. The socket
+                    // would then not match. If we only find one then, use it.
+                    userIds.add(I(accounts[0].getUserId()));
+                } else {
+                    for (final MailAccount candidate : accounts) {
+                        final InetSocketAddress shouldMatch;
+                        switch (MailProperties.getInstance().getMailServerSource()) {
+                        case USER:
+                            shouldMatch = toSocketAddr(candidate.generateMailServerURL(), 143);
+                            break;
+                        case GLOBAL:
+                            shouldMatch = toSocketAddr(MailProperties.getInstance().getMailServer(), 143);
+                            break;
+                        default:
+                            throw MailAccountExceptionMessages.UNEXPECTED_ERROR.create("Unimplemented mail server source.");
+                        }
+                        if (server.equals(shouldMatch)) {
+                            userIds.add(I(candidate.getUserId()));
+                        }
+                    }
                 }
-                return retval;
+                // Prefer the default mail account.
+                final Set<Integer> notDefaultAccount = new HashSet<Integer>();
+                if (userIds.size() > 1) {
+                    final Iterator<Integer> iter = userIds.iterator();
+                    while (iter.hasNext()) {
+                        final int userId = i(iter.next());
+                        for (final MailAccount candidate : accounts) {
+                            if (candidate.getUserId() == userId && !candidate.isDefaultAccount()) {
+                                notDefaultAccount.add(I(userId));
+                            }
+                        }
+                    }
+                }
+                if (notDefaultAccount.size() < userIds.size()) {
+                    userIds.removeAll(notDefaultAccount);
+                }
+                return I2i(userIds);
+            case USER_NAME:
+                return new int[] { UserStorage.getInstance().getUserId(pattern, ctx) };
             }
-            return new int[] { UserStorage.getInstance().getUserId(pattern, ctx) };
         }
-        /*
-         * Find user name by user's imap login
-         */
+        // Find user name by user's imap login
         final MailAccount[] accounts = storageService.resolveLogin(pattern, server, ctx.getContextId());
         final int[] retval = new int[accounts.length];
         for (int i = 0; i < retval.length; i++) {
@@ -417,7 +485,7 @@ public abstract class MailConfig {
 
     /**
      * Parses protocol out of specified server string according to URL specification; e.g. <i>mailprotocol://dev.myhost.com:1234</i>
-     * 
+     *
      * @param server The server string
      * @return An array of {@link String} with length <code>2</code>. The first element is the protocol and the second the server. If no
      *         protocol pattern could be found <code>null</code> is returned; meaning no protocol is present in specified server string.
@@ -444,7 +512,7 @@ public abstract class MailConfig {
     /**
      * Checks if a part modifier shall be used, that is {@link PartModifier#getInstance()} is not <code>null</code> and not
      * assignment-compatible to {@link DummyPartModifier} (which does nothing at all).
-     * 
+     *
      * @return <code>true</code> if part modifier shall be used; otherwise <code>false</code>
      */
     public static final boolean usePartModifier() {
@@ -480,29 +548,51 @@ public abstract class MailConfig {
     }
 
     /**
-     * Fills login and password in specified instance of {@link MailConfig}.
+     * Gets the sane (puny-code) representation of passed login in case it appears to be an Internet address. 
      * 
+     * @param login The login
+     * @return The sane login
+     */
+    private static final String saneLogin(final String login) {
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        if (!(null == service ? true : service.getBoolProperty("com.openexchange.mail.saneLogin", true))) {
+            return login;
+        }
+        try {
+            return IDNA.toACE(login);
+        } catch (final Exception e) {
+            return login;
+        }
+    }
+
+    /**
+     * Fills login and password in specified instance of {@link MailConfig}.
+     *
      * @param mailConfig The mail config whose login and password shall be set
      * @param sessionPassword The session password
      * @param mailAccount The mail account
      * @throws MailConfigException If a configuration error occurs
      */
     protected static final void fillLoginAndPassword(final MailConfig mailConfig, final Session session, final String userLoginInfo, final MailAccount mailAccount) throws MailConfigException {
+        final String proxyDelimiter = MailProperties.getInstance().getAuthProxyDelimiter();
         // Assign login
-        mailConfig.login = getMailLogin(mailAccount, userLoginInfo);
+        final String slogin = session.getLoginName();
+        if (proxyDelimiter != null && slogin.contains(proxyDelimiter)) {
+            mailConfig.login = saneLogin(slogin);
+        } else {
+            mailConfig.login = getMailLogin(mailAccount, userLoginInfo);
+        }
         // Assign password
-        final String sessionPassword = session.getPassword();
         if (mailAccount.isDefaultAccount()) {
             final PasswordSource cur = MailProperties.getInstance().getPasswordSource();
             if (PasswordSource.GLOBAL.equals(cur)) {
                 final String masterPw = MailProperties.getInstance().getMasterPassword();
                 if (masterPw == null) {
-                    throw new MailConfigException(
-                        new StringBuilder().append("Property \"").append("masterPassword").append("\" not set").toString());
+                    throw new MailConfigException(new StringBuilder().append("Property \"masterPassword\" not set").toString());
                 }
                 mailConfig.password = masterPw;
             } else {
-                mailConfig.password = sessionPassword;
+                mailConfig.password = session.getPassword();
             }
         } else {
             final String mailAccountPassword = mailAccount.getPassword();
@@ -510,18 +600,11 @@ public abstract class MailConfig {
                 // Set to empty string
                 mailConfig.password = "";
             } else {
-                // Decrypt mail account's password using session password
+                // Mail account's password
                 try {
-                    SecretService secretService = ServerServiceRegistry.getInstance().getService(SecretService.class);
-                    String secret = secretService.getSecret(session);
-                    mailConfig.password = MailPasswordUtil.decrypt(mailAccountPassword, secret);
-                } catch (final GeneralSecurityException e) {
-                    throw new MailConfigException(MailAccountExceptionMessages.PASSWORD_DECRYPTION_FAILED.create(
-                        e,
-                        mailConfig.login,
-                        mailAccount.getMailServer(),
-                        Integer.valueOf(session.getUserId()),
-                        Integer.valueOf(session.getContextId())));
+                    mailConfig.password = MailPasswordUtil.decrypt(mailAccountPassword, session, mailAccount.getId(), mailAccount.getLogin(), mailAccount.getMailServer());
+                } catch (final AbstractOXException e) {
+                    throw new MailConfigException(e);
                 }
             }
         }
@@ -533,6 +616,8 @@ public abstract class MailConfig {
 
     protected int accountId;
 
+    protected Session session;
+
     protected String login;
 
     protected String password;
@@ -583,23 +668,32 @@ public abstract class MailConfig {
 
     /**
      * Gets the account ID.
-     * 
+     *
      * @return The account ID
      */
     public int getAccountId() {
         return accountId;
     }
 
+    /**
+     * Gets the session.
+     *
+     * @return The session
+     */
+    public Session getSession() {
+        return session;
+    }
+
     /**
      * Gets the mail system's capabilities
-     * 
+     *
      * @return The mail system's capabilities
      */
     public abstract MailCapabilities getCapabilities();
 
     /**
      * Gets the login.
-     * 
+     *
      * @return the login
      */
     public final String getLogin() {
@@ -608,7 +702,7 @@ public abstract class MailConfig {
 
     /**
      * Gets the password.
-     * 
+     *
      * @return the password
      */
     public final String getPassword() {
@@ -617,18 +711,36 @@ public abstract class MailConfig {
 
     /**
      * Gets the optional port of the server.
-     * 
+     *
      * @return The optional port of the server obtained via {@link #getServer()} or <code>-1</code> if no port needed.
      */
     public abstract int getPort();
 
     /**
      * Gets the host name or IP address of the server.
-     * 
+     *
      * @return The host name or IP address of the server.
      */
     public abstract String getServer();
 
+    @Override
+    public String toString() {
+        final StringBuilder builder = new StringBuilder();
+        builder.append("{ MailConfig [accountId=").append(accountId).append(", ");
+        if (login != null) {
+            builder.append("login=").append(login).append(", ");
+        }
+        if (password != null) {
+            // builder.append("password=").append(password).append(", ");
+        }
+        builder.append("getPort()=").append(getPort()).append(", ");
+        if (getServer() != null) {
+            builder.append("getServer()=").append(getServer()).append(", ");
+        }
+        builder.append("isSecure()=").append(isSecure()).append("] }");
+        return builder.toString();
+    }
+
     @Override
     public int hashCode() {
         final int prime = 31;
@@ -643,32 +755,41 @@ public abstract class MailConfig {
 
     /**
      * Checks if a secure connection shall be established.
-     * 
+     *
      * @return <code>true</code> if a secure connection shall be established; otherwise <code>false</code>
      */
     public abstract boolean isSecure();
 
     /**
      * Sets the account ID (externally).
-     * 
+     *
      * @param accountId The account ID
      */
     public void setAccountId(final int accountId) {
         this.accountId = accountId;
     }
 
+    /**
+     * Sets the session
+     *
+     * @param session The session
+     */
+    public void setSession(final Session session) {
+        this.session = session;
+    }
+
     /**
      * Sets the login (externally).
-     * 
+     *
      * @param login The login
      */
     public void setLogin(final String login) {
-        this.login = login;
+        this.login = saneLogin(login);
     }
 
     /**
      * Sets the password (externally).
-     * 
+     *
      * @param password The password
      */
     public void setPassword(final String password) {
@@ -677,35 +798,35 @@ public abstract class MailConfig {
 
     /**
      * Sets the port (externally).
-     * 
+     *
      * @param port The port
      */
     public abstract void setPort(int port);
 
     /**
      * Sets (externally) whether a secure connection should be established or not.
-     * 
+     *
      * @param secure <code>true</code> if a secure connection should be established; otherwise <code>false</code>
      */
     public abstract void setSecure(boolean secure);
 
     /**
      * Sets the host name or IP address of the server (externally).
-     * 
+     *
      * @param server The host name or IP address of the server
      */
     public abstract void setServer(String server);
 
     /**
      * Gets the mail properties for this mail configuration.
-     * 
+     *
      * @return The mail properties for this mail configuration
      */
     public abstract IMailProperties getMailProperties();
 
     /**
      * Sets the mail properties for this mail configuration.
-     * 
+     *
      * @param mailProperties The mail properties for this mail configuration
      */
     public abstract void setMailProperties(IMailProperties mailProperties);
@@ -717,7 +838,7 @@ public abstract class MailConfig {
      * <p>
      * Moreover this method should check if a secure connection shall be established dependent on URL's protocol. The result is then
      * accessible via {@link #isSecure()}.
-     * 
+     *
      * @param serverURL The server URL of the form:<br>
      *            (&lt;protocol&gt;://)?&lt;host&gt;(:&lt;port&gt;)?
      * @throws MailException If server URL cannot be parsed
