@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import com.openexchange.mail.dataobjects.MailFolderDescription;
 
 /**
  * {@link MailFolderStorage} - Abstract implementation of {@link IMailFolderStorage}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailFolderStorage implements IMailFolderStorage {
@@ -75,7 +75,7 @@ public abstract class MailFolderStorage implements IMailFolderStorage {
      * <p>
      * This is a convenience method that invokes {@link #getFolder(String)} with its parameter set to {@link MailFolder#DEFAULT_FOLDER_ID}.
      * It may be overridden if a faster way can be achieved by specific implementation.
-     * 
+     *
      * @return The mailbox's root folder
      * @throws MailException If mailbox's default folder cannot be delivered
      */
@@ -98,11 +98,11 @@ public abstract class MailFolderStorage implements IMailFolderStorage {
      * necessary.
      * <p>
      * E.g.:
-     * 
+     *
      * <pre>
      * my.path.to.folder -&gt; my.path.to.newfolder
      * </pre>
-     * 
+     *
      * @param fullname The folder fullname
      * @param newName The new name
      * @return The new fullname
@@ -163,6 +163,22 @@ public abstract class MailFolderStorage implements IMailFolderStorage {
 
     public abstract Quota[] getQuotas(String folder, Quota.Type[] types) throws MailException;
 
+    /**
+     * Gets the prefix (incl. separator character) for default folders.
+     * <p>
+     * By now a compound full name is assumed. Override if not appropriate.
+     *
+     * @return The prefix
+     * @throws MailException If a mail error occurs
+     */
+    public String getDefaultFolderPrefix() throws MailException {
+        checkDefaultFolders();
+        final String trashFullName = getTrashFolder();
+        final char separator = getFolder(trashFullName).getSeparator();
+        final int pos = trashFullName.lastIndexOf(separator);
+        return pos < 0 ? "" : trashFullName.substring(0, pos + 1);
+    }
+
     public abstract String getConfirmedHamFolder() throws MailException;
 
     public abstract String getConfirmedSpamFolder() throws MailException;
