@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,7 +67,7 @@ import com.openexchange.mail.search.SearchTerm;
 
 /**
  * {@link MailMessageStorage} - Abstract implementation of {@link IMailMessageStorage}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailMessageStorage implements IMailMessageStorage {
@@ -93,8 +93,8 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
      * Note that sorting needs not to be supported by underlying mailing system. This can be done n application side, too
      * <p>
      * This method may be overridden in implementing subclass if a faster way can be achieved.
-     * 
-     * @param folder The folder fullname
+     *
+     * @param folder The folder full name
      * @param indexRange The index range specifying the desired sub-list in sorted list; may be <code>null</code> to obtain complete list.
      *            Range begins at the specified start index and extends to the message at index <code>end - 1</code>. Thus the length of the
      *            range is <code>end - start</code>.
@@ -109,21 +109,31 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
     }
 
     public MailPart getAttachment(final String folder, final String mailId, final String sequenceId) throws MailException {
+        final MailMessage mail = getMessage(folder, mailId, false);
+        if (null == mail) {
+            throw new MailException(MailException.Code.MAIL_NOT_FOUND, mailId, folder);
+        }
         final MailPartHandler handler = new MailPartHandler(sequenceId);
-        new MailMessageParser().parseMailMessage(getMessage(folder, mailId, false), handler);
-        if (handler.getMailPart() == null) {
+        new MailMessageParser().parseMailMessage(mail, handler);
+        final MailPart ret = handler.getMailPart();
+        if (ret == null) {
             throw new MailException(MailException.Code.ATTACHMENT_NOT_FOUND, sequenceId, mailId, folder);
         }
-        return handler.getMailPart();
+        return ret;
     }
 
     public MailPart getImageAttachment(final String folder, final String mailId, final String contentId) throws MailException {
+        final MailMessage mail = getMessage(folder, mailId, false);
+        if (null == mail) {
+            throw new MailException(MailException.Code.MAIL_NOT_FOUND, mailId, folder);
+        }
         final ImageMessageHandler handler = new ImageMessageHandler(contentId);
-        new MailMessageParser().parseMailMessage(getMessage(folder, mailId, false), handler);
-        if (handler.getImagePart() == null) {
+        new MailMessageParser().parseMailMessage(mail, handler);
+        final MailPart ret = handler.getImagePart();
+        if (ret == null) {
             throw new MailException(MailException.Code.IMAGE_ATTACHMENT_NOT_FOUND, contentId, mailId, folder);
         }
-        return handler.getImagePart();
+        return ret;
     }
 
     /**
@@ -135,8 +145,8 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
      * If no mail could be found for given mail ID, <code>null</code> is returned.
      * <p>
      * This method may be overridden in implementing subclass if a faster way can be achieved.
-     * 
-     * @param folder The folder fullname
+     *
+     * @param folder The folder full name
      * @param mailId The mail ID
      * @param markSeen <code>true</code> to explicitly mark corresponding mail as seen (setting system flag <i>\Seen</i>); otherwise
      *            <code>false</code> to leave as-is
@@ -169,8 +179,8 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
      * {@link #EMPTY_RETVAL} may be returned if no unseen messages available in specified folder.
      * <p>
      * This is a convenience method that may be overridden if a faster way can be achieved.
-     * 
-     * @param folder The folder fullname
+     *
+     * @param folder The folder full name
      * @param sortField The sort field
      * @param order The sort order
      * @param fields The fields to pre-fill in returned instances of {@link MailMessage}
@@ -191,9 +201,9 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
      * If no mail could be found for a given mail ID, the corresponding value in returned array of <code>String</code> is <code>null</code>.
      * <p>
      * This is a convenience method that may be overridden if a faster way can be achieved.
-     * 
-     * @param sourceFolder The source folder fullname
-     * @param destFolder The destination folder fullname
+     *
+     * @param sourceFolder The source folder full name
+     * @param destFolder The destination folder full name
      * @param mailIds The mail IDs in source folder
      * @param fast <code>true</code> to perform a fast move operation, meaning the corresponding mail IDs in destination folder are ignored
      *            and an empty array of String is returned; otherwise <code>false</code>
@@ -244,8 +254,8 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
 
     /**
      * Gets all new and modified messages in specified folder. By default the constant {@link #EMPTY_RETVAL} is returned.
-     * 
-     * @param folder The folder fullname
+     *
+     * @param folder The folder full name
      * @param fields The fields to pre-fill in returned instances of {@link MailMessage}
      * @return All new and modified messages in specified folder
      * @throws MailException If mails cannot be returned
@@ -256,8 +266,8 @@ public abstract class MailMessageStorage implements IMailMessageStorage {
 
     /**
      * Gets all deleted messages in specified folder. By default the constant {@link #EMPTY_RETVAL} is returned.
-     * 
-     * @param folder The folder fullname
+     *
+     * @param folder The folder full name
      * @param fields The fields to pre-fill in returned instances of {@link MailMessage}
      * @return All deleted messages in specified folder
      * @throws MailException If mails cannot be returned
