@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,8 @@ import com.openexchange.spamhandler.SpamHandler;
  */
 public abstract class MailMessageStorageLong extends MailMessageStorage {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailMessageStorageLong.class);
+    private static final org.apache.commons.logging.Log LOG =
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailMessageStorageLong.class));
 
     /**
      * The fields containing {@link MailField#FULL}.
@@ -112,8 +113,8 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * Moreover the implementation should take care if a copy operation from or to default drafts folder is performed. If so, this method
      * should ensure that system flag <tt>DRAFT</tt> is enabled or disabled.
      * 
-     * @param sourceFolder The source folder fullname
-     * @param destFolder The destination folder fullname
+     * @param sourceFolder The source folder full name
+     * @param destFolder The destination folder full name
      * @param mailIds The mail IDs in source folder
      * @param fast <code>true</code> to perform a fast copy operation, meaning the corresponding mail IDs in destination folder are ignored
      *            and an empty array of long is returned; otherwise <code>false</code>
@@ -132,7 +133,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * If no mail could be found for a given mail ID, it is treated as a no-op.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailIds The mail IDs
      * @param hardDelete <code>true</code> to hard delete the messages, meaning not to create a backup copy of each message in default trash
      *            folder; otherwise <code>false</code>
@@ -149,7 +150,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * This method may be overridden in implementing subclass if a faster way can be achieved.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param indexRange The index range specifying the desired sub-list in sorted list; may be <code>null</code> to obtain complete list.
      *            Range begins at the specified start index and extends to the message at index <code>end - 1</code>. Thus the length of the
      *            range is <code>end - start</code>.
@@ -167,7 +168,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
     @Override
     public MailPart getAttachment(final String folder, final String mailId, final String sequenceId) throws MailException {
         try {
-            return getAttachmentLong(folder, Long.parseLong(mailId), sequenceId);
+            return getAttachmentLong(folder, parseUnsignedLong(mailId), sequenceId);
         } catch (final NumberFormatException e) {
             LOG.error("UID cannot be parsed to a number: " + mailId, e);
             return null;
@@ -179,7 +180,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * If no mail could be found for given mail ID, returned mail part is <code>null</code>.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailId The mail ID
      * @param sequenceId The attachment sequence ID
      * @return The attachment wrapped by a {@link MailPart} instance
@@ -187,7 +188,11 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      */
     public MailPart getAttachmentLong(final String folder, final long mailId, final String sequenceId) throws MailException {
         final MailPartHandler handler = new MailPartHandler(sequenceId);
-        new MailMessageParser().parseMailMessage(getMessageLong(folder, mailId, false), handler);
+        final MailMessage mail = getMessageLong(folder, mailId, false);
+        if (null == mail) {
+            throw new MailException(MailException.Code.MAIL_NOT_FOUND, Long.valueOf(mailId), folder);
+        }
+        new MailMessageParser().parseMailMessage(mail, handler);
         if (handler.getMailPart() == null) {
             throw new MailException(MailException.Code.ATTACHMENT_NOT_FOUND, sequenceId, Long.valueOf(mailId), folder);
         }
@@ -197,7 +202,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
     @Override
     public MailPart getImageAttachment(final String folder, final String mailId, final String contentId) throws MailException {
         try {
-            return getImageAttachmentLong(folder, Long.parseLong(mailId), contentId);
+            return getImageAttachmentLong(folder, parseUnsignedLong(mailId), contentId);
         } catch (final NumberFormatException e) {
             LOG.error("UID cannot be parsed to a number: " + mailId, e);
             return null;
@@ -210,7 +215,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * If no mail could be found for given mail ID, returned mail part is <code>null</code>.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailId The mail ID
      * @param contentId The value of header <code>Content-Id</code>
      * @return The image attachment wrapped by an {@link MailPart} instance
@@ -218,17 +223,22 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      */
     public MailPart getImageAttachmentLong(final String folder, final long mailId, final String contentId) throws MailException {
         final ImageMessageHandler handler = new ImageMessageHandler(contentId);
-        new MailMessageParser().parseMailMessage(getMessageLong(folder, mailId, false), handler);
-        if (handler.getImagePart() == null) {
+        final MailMessage mail = getMessageLong(folder, mailId, false);
+        if (null == mail) {
+            throw new MailException(MailException.Code.MAIL_NOT_FOUND, Long.valueOf(mailId), folder);
+        }
+        new MailMessageParser().parseMailMessage(mail, handler);
+        final MailPart imagePart = handler.getImagePart();
+        if (null == imagePart) {
             throw new MailException(MailException.Code.IMAGE_ATTACHMENT_NOT_FOUND, contentId, Long.valueOf(mailId), folder);
         }
-        return handler.getImagePart();
+        return imagePart;
     }
 
     @Override
     public MailMessage getMessage(final String folder, final String mailId, final boolean markSeen) throws MailException {
         try {
-            return getMessageLong(folder, Long.parseLong(mailId), markSeen);
+            return getMessageLong(folder, parseUnsignedLong(mailId), markSeen);
         } catch (final NumberFormatException e) {
             LOG.error("UID cannot be parsed to a number: " + mailId, e);
             return null;
@@ -245,7 +255,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * This method may be overridden in implementing subclass if a faster way can be achieved.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailId The mail ID
      * @param markSeen <code>true</code> to explicitly mark corresponding mail as seen (setting system flag <i>\Seen</i>); otherwise
      *            <code>false</code> to leave as-is
@@ -296,7 +306,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * If underlying mailing system is IMAP, this method requires the IMAPv4 SORT extension or in detail the IMAP <code>CAPABILITY</code>
      * command should contain "SORT THREAD=ORDEREDSUBJECT THREAD=REFERENCES".
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param indexRange The index range specifying the desired sub-list in sorted list; may be <code>null</code> to obtain complete list.
      *            Range begins at the specified start index and extends to the message at index <code>end - 1</code>. Thus the length of the
      *            range is <code>end - start</code>.
@@ -318,7 +328,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * This is a convenience method that may be overridden if a faster way can be achieved.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param sortField The sort field
      * @param order The sort order
      * @param fields The fields to pre-fill in returned instances of {@link MailMessage}
@@ -346,8 +356,8 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <p>
      * This is a convenience method that may be overridden if a faster way can be achieved.
      * 
-     * @param sourceFolder The source folder fullname
-     * @param destFolder The destination folder fullname
+     * @param sourceFolder The source folder full name
+     * @param destFolder The destination folder full name
      * @param mailIds The mail IDs in source folder
      * @param fast <code>true</code> to perform a fast move operation, meaning the corresponding mail IDs in destination folder are ignored
      *            and an empty array of String is returned; otherwise <code>false</code>
@@ -372,7 +382,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * A convenience method that saves given draft mail to default drafts folder and supports deletion of old draft's version (draft-edit
      * operation).
      * 
-     * @param draftFullname The fullname of default drafts folder
+     * @param draftFullname The full name of default drafts folder
      * @param draftMail The draft mail as a composed mail
      * @return The stored draft mail
      * @throws MailException If saving specified draft message fails
@@ -413,7 +423,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * <b>Note</b> that sorting needs not to be supported by underlying mailing system. This can be done on application side, too.<br>
      * Same is for search, but in most cases it's faster to search on mailing system, but this heavily depends on how mails are accessed.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param indexRange The index range specifying the desired sub-list in sorted list; may be <code>null</code> to obtain complete list.
      *            Range begins at the specified start index and extends to the message at index <code>end - 1</code>. Thus the length of the
      *            range is <code>end - start</code>.
@@ -438,7 +448,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * The color labels are user flags with the common prefix <code>"cl_"</code> and its numeric color code appended (currently numbers 0 to
      * 10).
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailIds The mail IDs
      * @param colorLabel The color label to apply
      * @throws MailException If color label cannot be updated
@@ -459,7 +469,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * The color labels are user flags with the common prefix <code>"cl_"</code> and its numeric color code appended (currently numbers 0 to
      * 10).
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailIds The mail IDs
      * @param colorLabel The color label to apply
      * @throws MailException If color label cannot be updated
@@ -500,7 +510,7 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
      * the {@link SpamHandler#handleSpam(String, String[], boolean, MailAccess)}/
      * {@link SpamHandler#handleHam(String, String[], boolean, MailAccess)} methods needs to be executed.
      * 
-     * @param folder The folder fullname
+     * @param folder The folder full name
      * @param mailIds The mail IDs
      * @param flags The bit pattern for the flags to alter
      * @param set <code>true</code> to enable the flags; otherwise <code>false</code>
@@ -520,21 +530,13 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
         }
         final long[] retval = new long[uids.length];
         for (int i = 0; i < retval.length; i++) {
-            final String s = uids[i];
-            if (null == s) {
-                retval[i] = -1L;
-            } else {
-                try {
-                    retval[i] = Long.parseLong(s);
-                } catch (final NumberFormatException e) {
-                    LOG.error("UID cannot be parsed to a number: " + s, e);
-                    retval[i] = -1L;
-                }
-            }
+            retval[i] = parseUnsignedLong(uids[i]);
         }
         return retval;
     }
 
+    private static final int RADIX = 10;
+
     /**
      * Converts specified UID numbers to an array of <code>String</code>.
      * 
@@ -551,10 +553,68 @@ public abstract class MailMessageStorageLong extends MailMessageStorage {
             if (-1 == l) {
                 retval[i] = null;
             } else {
-                retval[i] = String.valueOf(longs[i]);
+                retval[i] = Long.toString(longs[i], RADIX);
             }
         }
         return retval;
     }
 
+    private static final long DEFAULT = -1L;
+
+    /**
+     * Parses the string argument as a signed decimal <code>long</code>. The characters in the string must all be decimal digits.
+     * <p>
+     * Note that neither the character <code>L</code> (<code>'&#92;u004C'</code>) nor <code>l</code> (<code>'&#92;u006C'</code>) is
+     * permitted to appear at the end of the string as a type indicator, as would be permitted in Java programming language source code.
+     * 
+     * @param s A <code>String</code> containing the <code>long</code> representation to be parsed
+     * @return The <code>long</code> represented by the argument in decimal or <code>-1</code> if the string does not contain a parsable
+     *         <code>long</code>.
+     */
+    protected static long parseUnsignedLong(final String s) {
+        if (s == null) {
+            return DEFAULT;
+        }
+        final int max = s.length();
+        if (max <= 0) {
+            return DEFAULT;
+        }
+        if (s.charAt(0) == '-') {
+            return DEFAULT;
+        }
+
+        long result = 0;
+        int i = 0;
+
+        final long limit = -Long.MAX_VALUE;
+        final long multmin = limit / RADIX;
+        int digit;
+
+        if (i < max) {
+            digit = Character.digit(s.charAt(i++), RADIX);
+            if (digit < 0) {
+                return DEFAULT;
+            }
+            result = -digit;
+        }
+        while (i < max) {
+            /*
+             * Accumulating negatively avoids surprises near MAX_VALUE
+             */
+            digit = Character.digit(s.charAt(i++), RADIX);
+            if (digit < 0) {
+                return DEFAULT;
+            }
+            if (result < multmin) {
+                return DEFAULT;
+            }
+            result *= RADIX;
+            if (result < limit + digit) {
+                return DEFAULT;
+            }
+            result -= digit;
+        }
+        return -result;
+    }
+
 }
