@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,7 +63,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.concurrent.TimeoutConcurrentMap;
-import com.openexchange.concurrent.TimeoutConcurrentMap.TimeoutListener;
+import com.openexchange.concurrent.TimeoutListener;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailJSONField;
@@ -73,12 +73,12 @@ import com.openexchange.session.Session;
 
 /**
  * {@link JSONMessageCache} - A JSON message cache.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class JSONMessageCache {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(JSONMessageCache.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JSONMessageCache.class));
 
     private static final boolean DEBUG = LOG.isDebugEnabled();
 
@@ -89,7 +89,7 @@ public final class JSONMessageCache {
 
     /**
      * Gets the cache instance.
-     * 
+     *
      * @return The cache instance or <code>null</code>
      */
     public static JSONMessageCache getInstance() {
@@ -98,7 +98,7 @@ public final class JSONMessageCache {
 
     /**
      * Initializes the cache instance.
-     * 
+     *
      * @return The cache instance
      * @throws MailException If initialization fails
      */
@@ -134,7 +134,7 @@ public final class JSONMessageCache {
 
     /**
      * Initializes a new {@link JSONMessageCache}.
-     * 
+     *
      * @throws MailException If initialization fails
      */
     private JSONMessageCache() throws MailException {
@@ -162,7 +162,7 @@ public final class JSONMessageCache {
     /**
      * Associates given JSON mail object with specified account ID, folder fullname and mail ID. If the cache previously contained a mapping
      * for this key, the old value is replaced by the specified value.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -177,7 +177,7 @@ public final class JSONMessageCache {
     /**
      * Associates given JSON mail object with specified account ID, folder fullname and mail ID. If the cache previously contained a mapping
      * for this key, the old value is replaced by the specified value.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -233,7 +233,7 @@ public final class JSONMessageCache {
 
     /**
      * Checks if a JSON mail object is associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -246,7 +246,7 @@ public final class JSONMessageCache {
 
     /**
      * Checks if a JSON mail object is associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -274,9 +274,41 @@ public final class JSONMessageCache {
         return objectMap.containsKey(id);
     }
 
+    /**
+     * Checks if a JSON mail object is associated with specified account ID, folder fullname and mail ID.
+     *
+     * @param accountId The account ID
+     * @param fullname The folder fullname
+     * @param id The mail ID
+     * @param session The session providing user and context information
+     * @return <code>true</code> If this cache contains a mapping for given key; otherwise <code>false</code>
+     */
+    public boolean containsFolder(final int accountId, final String fullname, final Session session) {
+        return containsFolder(accountId, fullname, session.getUserId(), session.getContextId());
+    }
+
+    /**
+     * Checks if a JSON mail object is associated with specified account ID, folder fullname and mail ID.
+     *
+     * @param accountId The account ID
+     * @param fullname The folder fullname
+     * @param id The mail ID
+     * @param userId The user ID
+     * @param cid The context ID
+     * @return <code>true</code> If this cache contains a mapping for given key; otherwise <code>false</code>
+     */
+    public boolean containsFolder(final int accountId, final String fullname, final int userId, final int cid) {
+        final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
+            superMap.get(new UserKey(userId, cid));
+        if (null == timeoutConcurrentMap) {
+            return false;
+        }
+        return timeoutConcurrentMap.containsKey(new FolderKey(accountId, fullname));
+    }
+
     /**
      * Gets the <b>cloned</b> JSON mail object associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -290,7 +322,7 @@ public final class JSONMessageCache {
 
     /**
      * Gets the <b>cloned</b> JSON mail object associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -305,7 +337,7 @@ public final class JSONMessageCache {
 
     /**
      * Gets the <b>cloned</b> JSON mail object associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -346,7 +378,7 @@ public final class JSONMessageCache {
         /*-
          * A future is already present; meaning associated message's JSON representation is at least planned for being put into cache, but
          * does not guarantee being already present.
-         * 
+         *
          * Therefore:
          * 1. Invoke Future.get() with a time out and return if return value is present within time out range
          * 2. Otherwise catch possible TimeoutException and handle it by performing Future's task with calling thread
@@ -393,7 +425,7 @@ public final class JSONMessageCache {
 
     /**
      * Switch the \Seen flag for specified mails' JSON representations. Decrements unread message counter for each message.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param id The mail ID
@@ -408,7 +440,7 @@ public final class JSONMessageCache {
 
     /**
      * Switch the \Seen flag for specified mails' JSON representations. Decrements unread message counter for each message.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param id The mail ID
@@ -419,6 +451,10 @@ public final class JSONMessageCache {
      * @throws MailException If an error occurs
      */
     public void switchSeenFlag(final int accountId, final String fullname, final String[] ids, final boolean seen, final int unread, final int userId, final int cid) throws MailException {
+        if (null == ids) {
+            switchSeenFlag(accountId, fullname, seen, unread, userId, cid);
+            return;
+        }
         final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
             superMap.get(new UserKey(userId, cid));
         if (null == timeoutConcurrentMap) {
@@ -481,9 +517,87 @@ public final class JSONMessageCache {
         }
     }
 
+    /**
+     * Switch the \Seen flag for specified mails' JSON representations. Decrements unread message counter for each message.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param seen <code>true</code> to set \Seen flag; otherwise <code>false</code>
+     * @param unread The unread count
+     * @param session The session providing user and context information
+     * @throws MailException If an error occurs
+     */
+    public void switchSeenFlag(final int accountId, final String fullname, final boolean seen, final int unread, final Session session) throws MailException {
+        switchSeenFlag(accountId, fullname, seen, unread, session.getUserId(), session.getContextId());
+    }
+
+    /**
+     * Switch the \Seen flag for specified mails' JSON representations. Decrements unread message counter for each message.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param seen <code>true</code> to set \Seen flag; otherwise <code>false</code>
+     * @param unread The unread count for specified folder
+     * @param userId The user ID
+     * @param cid The context ID
+     * @throws MailException If an error occurs
+     */
+    public void switchSeenFlag(final int accountId, final String fullname, final boolean seen, final int unread, final int userId, final int cid) throws MailException {
+        final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
+            superMap.get(new UserKey(userId, cid));
+        if (null == timeoutConcurrentMap) {
+            return;
+        }
+        final FolderKey key = new FolderKey(accountId, fullname);
+        /*
+         * Get JSON object map
+         */
+        final ConcurrentMap<String, FutureTask<JSONObject>> objectMap = timeoutConcurrentMap.get(key);
+        if (null == objectMap) {
+            return;
+        }
+        /*
+         * Iterate
+         */
+        try {
+            /*
+             * Switch seen flag in messages
+             */
+            final int waitTimeMillis = JSONMessageCacheConfiguration.getInstance().getMaxWaitTimeMillis();
+            final String flagsKey = MailJSONField.FLAGS.getKey();
+            for (final FutureTask<JSONObject> ft : objectMap.values()) {
+                try {
+                    final JSONObject jsonObject = getFromFuture(ft, waitTimeMillis);
+                    if (null != jsonObject) {
+                        final int flags = jsonObject.optInt(flagsKey);
+                        jsonObject.put(flagsKey, seen ? (flags | MailMessage.FLAG_SEEN) : (flags & ~MailMessage.FLAG_SEEN));
+                    }
+                } catch (final TimeoutException e) {
+                    // Not yet available
+                }
+            }
+            /*
+             * Apply new unread count to folder's cached JSON messages
+             */
+            final String unreadKey = MailJSONField.UNREAD.getKey();
+            for (final FutureTask<JSONObject> ft : objectMap.values()) {
+                try {
+                    final JSONObject jsonObject = getFromFuture(ft, waitTimeMillis);
+                    if (null != jsonObject) {
+                        jsonObject.put(unreadKey, unread);
+                    }
+                } catch (final TimeoutException e) {
+                    // Not yet available
+                }
+            }
+        } catch (final JSONException e) {
+            throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+        }
+    }
+
     /**
      * Updates flags for specified mails' JSON representations.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param id The mail ID
@@ -498,7 +612,7 @@ public final class JSONMessageCache {
 
     /**
      * Updates flags for specified mails' JSON representations.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param id The mail ID
@@ -509,6 +623,10 @@ public final class JSONMessageCache {
      * @throws MailException If an error occurs
      */
     public void updateFlags(final int accountId, final String fullname, final String[] ids, final int newFlags, final boolean set, final int userId, final int cid) throws MailException {
+        if (null == ids) {
+            updateFlags(accountId, fullname, newFlags, set, userId, cid);
+            return;
+        }
         final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
             superMap.get(new UserKey(userId, cid));
         if (null == timeoutConcurrentMap) {
@@ -555,9 +673,74 @@ public final class JSONMessageCache {
         }
     }
 
+    /**
+     * Updates flags for specified mails' JSON representations.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param flags The flags bit mask
+     * @param set <code>true</code> to set; otherwise <code>false</code>
+     * @param session The session providing user and context information
+     * @throws MailException If an error occurs
+     */
+    public void updateFlags(final int accountId, final String fullname, final int newFlags, final boolean set, final Session session) throws MailException {
+        updateFlags(accountId, fullname, newFlags, set, session.getUserId(), session.getContextId());
+    }
+
+    /**
+     * Updates flags for specified mails' JSON representations.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param flags The flags bit mask
+     * @param set <code>true</code> to set; otherwise <code>false</code>
+     * @param userId The user ID
+     * @param cid The context ID
+     * @throws MailException If an error occurs
+     */
+    public void updateFlags(final int accountId, final String fullname, final int newFlags, final boolean set, final int userId, final int cid) throws MailException {
+        final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
+            superMap.get(new UserKey(userId, cid));
+        if (null == timeoutConcurrentMap) {
+            return;
+        }
+        final FolderKey key = new FolderKey(accountId, fullname);
+        /*
+         * Get JSON object map
+         */
+        final ConcurrentMap<String, FutureTask<JSONObject>> objectMap = timeoutConcurrentMap.get(key);
+        if (null == objectMap) {
+            return;
+        }
+        /*
+         * Get from map
+         */
+        /*
+         * Iterate
+         */
+        try {
+            /*
+             * Switch seen flag in messages
+             */
+            final String flagsKey = MailJSONField.FLAGS.getKey();
+            final int waitTimeMillis = JSONMessageCacheConfiguration.getInstance().getMaxWaitTimeMillis();
+            for (final FutureTask<JSONObject> ft : objectMap.values()) {
+                try {
+                    final JSONObject jsonObject = getFromFuture(ft, waitTimeMillis);
+                    final int flags = jsonObject.optInt(flagsKey);
+                    jsonObject.put(flagsKey, set ? (flags | newFlags) : (flags & ~newFlags));
+                } catch (final TimeoutException e) {
+                    // Not yet available
+                }
+            }
+        } catch (final JSONException e) {
+            throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+        }
+    }
+
     /**
      * Updates the color flag for specified mails' JSON representations.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param ids The mail IDs
@@ -571,7 +754,7 @@ public final class JSONMessageCache {
 
     /**
      * Updates the color flag for specified mails' JSON representations.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname
      * @param ids The mail IDs
@@ -581,6 +764,10 @@ public final class JSONMessageCache {
      * @throws MailException If an error occurs
      */
     public void updateColorFlag(final int accountId, final String fullname, final String[] ids, final int colorFlag, final int userId, final int cid) throws MailException {
+        if (null == ids) {
+            updateColorFlag(accountId, fullname, colorFlag, userId, cid);
+            return;
+        }
         final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
             superMap.get(new UserKey(userId, cid));
         if (null == timeoutConcurrentMap) {
@@ -626,9 +813,68 @@ public final class JSONMessageCache {
         }
     }
 
+    /**
+     * Updates the color flag for specified mails' JSON representations.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param colorFlag The color flag to set
+     * @param session The session providing user and context information
+     * @throws MailException If an error occurs
+     */
+    public void updateColorFlag(final int accountId, final String fullname, final int colorFlag, final Session session) throws MailException {
+        updateColorFlag(accountId, fullname, colorFlag, session.getUserId(), session.getContextId());
+    }
+
+    /**
+     * Updates the color flag for specified mails' JSON representations.
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param colorFlag The color flag to set
+     * @param userId The user ID
+     * @param cid The context ID
+     * @throws MailException If an error occurs
+     */
+    public void updateColorFlag(final int accountId, final String fullname, final int colorFlag, final int userId, final int cid) throws MailException {
+        final TimeoutConcurrentMap<FolderKey, ConcurrentMap<String, FutureTask<JSONObject>>> timeoutConcurrentMap =
+            superMap.get(new UserKey(userId, cid));
+        if (null == timeoutConcurrentMap) {
+            return;
+        }
+        final FolderKey key = new FolderKey(accountId, fullname);
+        /*
+         * Get JSON object map
+         */
+        final ConcurrentMap<String, FutureTask<JSONObject>> objectMap = timeoutConcurrentMap.get(key);
+        if (null == objectMap) {
+            return;
+        }
+        /*
+         * Get from map
+         */
+        try {
+            final String clKey = MailJSONField.COLOR_LABEL.getKey();
+            final int waitTimeMillis = JSONMessageCacheConfiguration.getInstance().getMaxWaitTimeMillis();
+            for (final FutureTask<JSONObject> ft : objectMap.values()) {
+                /*
+                 * Update color flag in message
+                 */
+                try {
+                    final JSONObject jsonObject = getFromFuture(ft, waitTimeMillis);
+                    jsonObject.put(clKey, colorFlag);
+                } catch (final TimeoutException e) {
+                    // Not yet available
+                }
+            }
+        } catch (final JSONException e) {
+            throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+        }
+    }
+
     /**
      * Removes the JSON mail object associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -642,7 +888,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes the JSON mail object associated with specified account ID, folder fullname and mail ID.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param id The mail ID
@@ -657,7 +903,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects associated with specified account ID and folder fullname.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param session The session providing user and context information
@@ -668,7 +914,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects associated with specified account ID and folder fullname.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param userId The user ID
@@ -689,7 +935,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects except the ones associated with specified account ID and folder fullname.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname of the folder whose mails shall be kept
      * @param session The session providing user and context information
@@ -700,7 +946,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects except the ones associated with specified account ID and folder fullname.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The fullname of the folder whose mails shall be kept
      * @param userId The user ID
@@ -726,7 +972,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects associated with specified user ID and context ID.
-     * 
+     *
      * @param session The session providing user and context information
      */
     public void removeUser(final Session session) {
@@ -735,7 +981,7 @@ public final class JSONMessageCache {
 
     /**
      * Removes all JSON mail objects associated with specified user ID and context ID.
-     * 
+     *
      * @param userId The user ID
      * @param cid The context ID
      */
@@ -765,7 +1011,7 @@ public final class JSONMessageCache {
 
     /**
      * Invokes {@link Future#get()} in a safe manner. Throwing an appropriate {@link MailException} if invocation fails.
-     * 
+     *
      * @param future The future whose <tt>get()</tt> method is supposed to be invoked
      * @return The result object
      * @throws MailException If invocation fails
@@ -795,7 +1041,7 @@ public final class JSONMessageCache {
 
     /**
      * Invokes {@link Future#get()} in a safe manner. Throwing an appropriate {@link MailException} if invocation fails.
-     * 
+     *
      * @param future The future whose <tt>get()</tt> method is supposed to be invoked
      * @param timeout The timeout millis
      * @return The result object
@@ -841,7 +1087,7 @@ public final class JSONMessageCache {
             super();
             this.accountId = accountId;
             this.fullname = fullname;
-            this.hash = hashCode0();
+            hash = hashCode0();
         }
 
         private int hashCode0() {
@@ -898,7 +1144,7 @@ public final class JSONMessageCache {
             super();
             this.cid = cid;
             this.userId = userId;
-            this.hash = hashCode0();
+            hash = hashCode0();
         }
 
         private int hashCode0() {
@@ -972,7 +1218,7 @@ public final class JSONMessageCache {
 
     /**
      * Generates a deep-clone of specified JSONObject instance.
-     * 
+     *
      * @param source The JSONObject instance to clone
      * @return The deep-clone of specified JSONObject instance
      * @throws JSONException If a JSON error occurs
@@ -987,7 +1233,7 @@ public final class JSONMessageCache {
 
     /**
      * Generates a deep-clone of specified JSONArray instance.
-     * 
+     *
      * @param source The JSONArray instance to clone
      * @return The deep-clone of specified JSONArray instance
      * @throws JSONException If a JSON error occurs
@@ -1005,7 +1251,7 @@ public final class JSONMessageCache {
      * Clones given object. If the object is an immutable instance of <code>Boolean</code>, <code>Double</code>, <code>Integer</code>,
      * <code>Long</code>, <code>String</code>, or the {@link JSONObject#NULL} object, the object itself is returned. Otherwise the object is
      * an instance of <code>JSONObject</code> or <code>JSONArray</code>, then a deep clone is returned.
-     * 
+     *
      * @param source The object to clone
      * @return The cloned object
      * @throws JSONException If a JSON error occurs
