@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,16 +49,16 @@
 
 package com.openexchange.mail.cache;
 
-import com.openexchange.concurrent.TimeoutConcurrentMap;
+import com.openexchange.concurrent.TimeoutListener;
 import com.openexchange.mail.api.MailAccess;
 
 /**
  * {@link MailAccessTimeoutListener} - The mail access event handler which preludes mail access closure if an instance of {@link MailAccess}
  * is removed from mail access cache.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class MailAccessTimeoutListener implements TimeoutConcurrentMap.TimeoutListener<MailAccess<?, ?>> {
+public final class MailAccessTimeoutListener implements TimeoutListener<MailAccess<?, ?>> {
 
     /**
      * Default constructor
