@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,7 +71,7 @@ import com.openexchange.server.services.ServerServiceRegistry;
  * <p>
  * This cache is highly volatile. With every new list request all caches entries belonging to requesting user are removed. See this cache
  * region's configuration settings in file "@conf-path@/mailcache.ccf" for further information.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailMessageCache {
@@ -148,7 +148,7 @@ public final class MailMessageCache {
         return updaters;
     }
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailMessageCache.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailMessageCache.class));
 
     private static final Object[] EMPTY_ARGS = new Object[0];
 
@@ -166,7 +166,7 @@ public final class MailMessageCache {
 
     /**
      * Singleton instantiation.
-     * 
+     *
      * @throws OXCachingException If cache instantiation fails
      */
     private MailMessageCache() throws OXCachingException {
@@ -176,7 +176,7 @@ public final class MailMessageCache {
 
     /**
      * Initializes cache reference.
-     * 
+     *
      * @throws OXCachingException If initializing the cache reference fails
      */
     public void initCache() throws OXCachingException {
@@ -199,7 +199,7 @@ public final class MailMessageCache {
 
     /**
      * Releases cache reference.
-     * 
+     *
      * @throws OXCachingException If clearing cache fails
      */
     public void releaseCache() throws OXCachingException {
@@ -221,7 +221,7 @@ public final class MailMessageCache {
 
     /**
      * Fetches the appropriate lock.
-     * 
+     *
      * @param key The lock's key
      * @return The appropriate lock
      */
@@ -239,7 +239,7 @@ public final class MailMessageCache {
 
     /**
      * Gets the singleton instance.
-     * 
+     *
      * @return The singleton instance
      * @throws OXCachingException If instance initialization failed
      */
@@ -271,8 +271,8 @@ public final class MailMessageCache {
 
     /**
      * Updates cached message
-     * 
-     * @param uids The messages' identifiers
+     *
+     * @param uids The messages' identifiers; pass <code>null</code>  update all cached message of given folder
      * @param accountId The account ID
      * @param fullname The fullname
      * @param userId The user identifier
@@ -284,6 +284,10 @@ public final class MailMessageCache {
         if (null == cache) {
             return;
         }
+        if (null == uids) {
+            updateCachedMessages(accountId, fullname, userId, cid, changedFields, newValues);
+            return;
+        }
         final CacheKey mapKey = getMapKey(userId, cid);
         final Lock writeLock = getLock(mapKey).writeLock();
         writeLock.lock();
@@ -309,9 +313,48 @@ public final class MailMessageCache {
         }
     }
 
+    /**
+     * Updates cached message
+     *
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param userId The user identifier
+     * @param cid The context identifier
+     * @param changedFields The changed fields
+     * @param newValues The new values
+     */
+    public void updateCachedMessages(final int accountId, final String fullname, final int userId, final int cid, final MailListField[] changedFields, final Object[] newValues) {
+        if (null == cache) {
+            return;
+        }
+        final CacheKey mapKey = getMapKey(userId, cid);
+        final Lock writeLock = getLock(mapKey).writeLock();
+        writeLock.lock();
+        try {
+            final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+            if (map == null) {
+                return;
+            }
+            final MailMessage[] mails = map.getValues(getEntryKey(accountId, fullname));
+            if ((mails != null) && (mails.length > 0)) {
+                final MailFieldUpdater[] updaters = createMailFieldUpdater(changedFields);
+                for (final MailMessage mail : mails) {
+                    if (mail != null) {
+                        for (int i = 0; i < updaters.length; i++) {
+                            updaters[i].updateField(mail, newValues[i]);
+                        }
+                    }
+                }
+            }
+        } finally {
+            writeLock.unlock();
+        }
+    }
+
     /**
      * Detects if cache holds messages belonging to given user.
-     * 
+     *
      * @param userId The user ID
      * @param cid The context ID
      * @return <code>true</code> if messages are present; otherwise <code>false</code>
@@ -325,7 +368,7 @@ public final class MailMessageCache {
 
     /**
      * Detects if cache holds messages belonging to a certain folder.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param userId The user ID
@@ -347,7 +390,7 @@ public final class MailMessageCache {
 
     /**
      * Removes the messages cached for a user.
-     * 
+     *
      * @param userId The user ID
      * @param cid The context ID
      * @throws OXCachingException
@@ -372,7 +415,7 @@ public final class MailMessageCache {
 
     /**
      * Removes cached messages belonging to a certain folder.
-     * 
+     *
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param userId The user ID
@@ -399,8 +442,8 @@ public final class MailMessageCache {
 
     /**
      * Removes the messages appearing in given UIDs belonging to a certain folder.
-     * 
-     * @param uids The mail IDs
+     *
+     * @param uids The mail IDs; pass <code>null</code> to remove all associated with folder
      * @param accountId The account ID
      * @param fullname The folder fullname
      * @param userId The user ID
@@ -419,7 +462,11 @@ public final class MailMessageCache {
             if (map == null) {
                 return;
             }
-            map.removeValues(getEntryKey(accountId, fullname), uids);
+            if (null == uids) {
+                map.removeValues(getEntryKey(accountId, fullname));
+            } else {
+                map.removeValues(getEntryKey(accountId, fullname), uids);
+            }
         } finally {
             writeLock.unlock();
         }
@@ -428,7 +475,7 @@ public final class MailMessageCache {
     /**
      * Gets the corresponding messages from cache. If a cache entry could not be found <code>null</code> is returned to force a reload from
      * mail server.
-     * 
+     *
      * @param uids The UIDs
      * @param accountId The account ID
      * @param fullname The folder fullname
@@ -474,7 +521,7 @@ public final class MailMessageCache {
 
     /**
      * Puts given messages into cache.
-     * 
+     *
      * @param accountId The account ID
      * @param mails The messages to cache
      * @param userId The user ID
