@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,8 @@ package com.openexchange.mail.cache;
 
 import java.text.MessageFormat;
 import java.util.Map;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.cache.OXCachingException;
@@ -58,6 +60,7 @@ import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.event.EventPool;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
@@ -65,7 +68,7 @@ import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 
 /**
  * {@link MailSessionEventHandler} - The {@link EventHandler event handler} for mail bundle to track removed sessions.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailSessionEventHandler implements EventHandler {
@@ -73,44 +76,20 @@ public final class MailSessionEventHandler implements EventHandler {
     /**
      * The logger constant.
      */
-    static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailSessionEventHandler.class);
+    static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MailSessionEventHandler.class));
 
     /**
      * Whether logger allows debug.
      */
     static final boolean DEBUG = LOG.isDebugEnabled();
 
-    /**
-     * The topic on single session removal.
-     */
-    static final String TOPIC_REMOVE_SESSION = "com/openexchange/sessiond/remove/session";
-
-    /**
-     * The topic on session container removal.
-     */
-    static final String TOPIC_REMOVE_CONTAINER = "com/openexchange/sessiond/remove/container";
-
-    /**
-     * The property for a single session kept in event's properties.
-     * <p>
-     * Target object is an instance of <tt>com.openexchange.session.Session</tt>.
-     */
-    static final String PROP_SESSION = "com.openexchange.sessiond.session";
-
-    /**
-     * The property for a session container kept in event's properties.
-     * <p>
-     * Target object is an instance of <tt>java.util.Map&lt;String, Session&gt;</tt>.
-     */
-    static final String PROP_CONTAINER = "com.openexchange.sessiond.container";
-
     /**
      * Gets the topics.
-     * 
+     *
      * @return The topics
      */
     public static String[] getTopics() {
-        return new String[] { TOPIC_REMOVE_SESSION, TOPIC_REMOVE_CONTAINER };
+        return new String[] { SessiondEventConstants.TOPIC_REMOVE_SESSION, SessiondEventConstants.TOPIC_REMOVE_DATA, SessiondEventConstants.TOPIC_REMOVE_CONTAINER };
     }
 
     /**
@@ -125,7 +104,7 @@ public final class MailSessionEventHandler implements EventHandler {
         /*
          * Delegate to thread pool if present
          */
-        final ThreadPoolService threadPoolService = ServerServiceRegistry.getInstance().getService(ThreadPoolService.class);
+        final ThreadPoolService threadPoolService = ThreadPools.getThreadPool();
         if (null == threadPoolService) {
             r.run();
         } else {
@@ -145,18 +124,17 @@ public final class MailSessionEventHandler implements EventHandler {
         public void run() {
             final String topic = event.getTopic();
             try {
-                if (TOPIC_REMOVE_SESSION.equals(topic)) {
-                    final Session session = (Session) event.getProperty(PROP_SESSION);
-                    dropSessionCaches(session);
-                } else if (TOPIC_REMOVE_CONTAINER.equals(topic)) {
+                if (SessiondEventConstants.TOPIC_REMOVE_SESSION.equals(topic)) {
+                    dropSessionCaches((Session) event.getProperty(SessiondEventConstants.PROP_SESSION));
+                } else if (SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic) || SessiondEventConstants.TOPIC_REMOVE_CONTAINER.equals(topic)) {
                     @SuppressWarnings("unchecked") final Map<String, Session> sessionContainer =
-                        (Map<String, Session>) event.getProperty(PROP_CONTAINER);
+                        (Map<String, Session>) event.getProperty(SessiondEventConstants.PROP_CONTAINER);
                     for (final Session session : sessionContainer.values()) {
                         dropSessionCaches(session);
                     }
                 }
             } catch (final Exception e) {
-                LOG.error(MessageFormat.format("Error while handling SessionD event \"{0}\": {1}", topic, e.getMessage()), e);
+                LOG.error(MessageFormat.format("Error while handling session event \"{0}\": {1}", topic, e.getMessage()), e);
             }
         }
 
@@ -189,7 +167,7 @@ public final class MailSessionEventHandler implements EventHandler {
              * Pooled events: Last session removed?
              */
             final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
-            if (null != sessiondService && 0 == sessiondService.getUserSessions(userId, contextId)) {
+            if (null != sessiondService && null == sessiondService.getAnyActiveSessionForUser(userId, contextId)) {
                 final EventPool eventPool = EventPool.getInstance();
                 if (null != eventPool) {
                     eventPool.removeByUser(userId, contextId);
