@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,18 +71,18 @@ import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link MailProperties} - Global mail properties read from properties file.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailProperties implements IMailProperties {
 
-    private static final Log LOG = LogFactory.getLog(MailProperties.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MailProperties.class));
 
     private static volatile MailProperties instance;
 
     /**
      * Gets the singleton instance of {@link MailProperties}.
-     * 
+     *
      * @return The singleton instance of {@link MailProperties}
      */
     public static MailProperties getInstance() {
@@ -147,8 +147,6 @@ public final class MailProperties implements IMailProperties {
 
     private char defaultSeparator;
 
-    private int maxNumOfConnections;
-
     private String[] quoteLineColors;
 
     private Properties javaMailProperties;
@@ -173,12 +171,15 @@ public final class MailProperties implements IMailProperties {
 
     private int mailAccessCacheIdleSeconds;
 
+    private boolean addClientIPAddress;
+
     private boolean rateLimitPrimaryOnly;
 
     private int rateLimit;
 
     private int maxToCcBcc;
 
+    private String authProxyDelimiter;
 
     /**
      * Initializes a new {@link MailProperties}
@@ -191,7 +192,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Exclusively loads the global mail properties
-     * 
+     *
      * @throws MailConfigException If loading of global mail properties fails
      */
     public void loadProperties() throws MailConfigException {
@@ -222,7 +223,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Waits for loading this properties.
-     * 
+     *
      * @throws InterruptedException If another thread interrupted the current thread before or while the current thread was waiting for
      *             loading the properties.
      */
@@ -252,7 +253,6 @@ public final class MailProperties implements IMailProperties {
         ignoreSubscription = false;
         hidePOP3StorageFolders = false;
         defaultSeparator = '/';
-        maxNumOfConnections = 0;
         quoteLineColors = null;
         javaMailProperties = null;
         watcherEnabled = false;
@@ -264,10 +264,11 @@ public final class MailProperties implements IMailProperties {
         adminMailLoginEnabled = false;
         mailAccessCacheShrinkerSeconds = 0;
         mailAccessCacheIdleSeconds = 0;
+        addClientIPAddress = false;
         rateLimitPrimaryOnly = true;
         rateLimit = 0;
         maxToCcBcc = 0;
-
+        authProxyDelimiter = null;
     }
 
     private void loadProperties0() throws MailConfigException {
@@ -465,6 +466,12 @@ public final class MailProperties implements IMailProperties {
             logBuilder.append("\tSupport Subscription: ").append(supportSubscription).append('\n');
         }
 
+        {
+            final String tmp = configuration.getProperty("com.openexchange.mail.addClientIPAddress", "false").trim();
+            addClientIPAddress = Boolean.parseBoolean(tmp);
+            logBuilder.append("\tAdd Client IP Address: ").append(addClientIPAddress).append('\n');
+        }
+
         {
             final char defaultSep = configuration.getProperty("com.openexchange.mail.defaultSeparator", "/").trim().charAt(0);
             if (defaultSep <= 32) {
@@ -477,18 +484,6 @@ public final class MailProperties implements IMailProperties {
             }
         }
 
-        {
-            final String maxNum = configuration.getProperty("com.openexchange.mail.maxNumOfConnections", "0").trim();
-            try {
-                maxNumOfConnections = Integer.parseInt(maxNum);
-                logBuilder.append("\tMax Number of Connections: ").append(maxNumOfConnections).append('\n');
-            } catch (final NumberFormatException e) {
-                maxNumOfConnections = 0;
-                logBuilder.append("\tMax Number of Connections: Invalid value \"").append(maxNum).append(fallbackPrefix).append(
-                    maxNumOfConnections).append('\n');
-            }
-        }
-
         {
             final String partModifierStr = configuration.getProperty(
                 "com.openexchange.mail.partModifierImpl",
@@ -572,7 +567,7 @@ public final class MailProperties implements IMailProperties {
             rateLimitPrimaryOnly = Boolean.parseBoolean(rateLimitPrimaryOnlyStr);
             logBuilder.append("\tRate limit primary only: ").append(rateLimitPrimaryOnly).append('\n');
         }
-        
+
         {
             final String rateLimitStr = configuration.getProperty("com.openexchange.mail.rateLimit", "0").trim();
             try {
@@ -582,7 +577,7 @@ public final class MailProperties implements IMailProperties {
                 rateLimit = 0;
                 logBuilder.append("\tSent Rate limit: Invalid value \"").append(rateLimitStr).append("\". Setting to fallback ").append(
                     rateLimit).append('\n');
-                
+
             }
         }
 
@@ -595,10 +590,10 @@ public final class MailProperties implements IMailProperties {
                 maxToCcBcc = 0;
                 logBuilder.append("\tmaxToCcBcc: Invalid value \"").append(maxToCcBccStr).append("\". Setting to fallback ").append(
                     maxToCcBcc).append('\n');
-                
+
             }
         }
-        
+
         {
             String javaMailPropertiesStr = configuration.getProperty("com.openexchange.mail.JavaMailProperties");
             if (null != javaMailPropertiesStr) {
@@ -618,6 +613,16 @@ public final class MailProperties implements IMailProperties {
             logBuilder.append("\tJavaMail Properties loaded: ").append(javaMailProperties != null).append('\n');
         }
 
+        {
+            authProxyDelimiter = configuration.getProperty("com.openexchange.mail.authProxyDelimiter");
+            if (authProxyDelimiter != null) {
+                authProxyDelimiter = authProxyDelimiter.trim();
+                if (authProxyDelimiter.length() == 0) {
+                    authProxyDelimiter = null;
+                }
+            }
+        }
+
         logBuilder.append("Global mail properties successfully loaded!");
         if (LOG.isInfoEnabled()) {
             LOG.info(logBuilder.toString());
@@ -626,7 +631,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Reads the properties from specified property file and returns an appropriate instance of {@link Properties}
-     * 
+     *
      * @param propFile The property file
      * @return The appropriate instance of {@link Properties}
      * @throws MailConfigException If reading property file fails
@@ -668,7 +673,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the default MIME charset.
-     * 
+     *
      * @return The default MIME charset
      */
     public String getDefaultMimeCharset() {
@@ -677,7 +682,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the default mail provider.
-     * 
+     *
      * @return The default mail provider
      */
     public String getDefaultMailProvider() {
@@ -686,7 +691,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Indicates if admin mail login is enabled; meaning whether admin user's try to login to mail system is permitted or not.
-     * 
+     *
      * @return <code>true</code> if admin mail login is enabled; otherwise <code>false</code>
      */
     public boolean isAdminMailLoginEnabled() {
@@ -709,9 +714,18 @@ public final class MailProperties implements IMailProperties {
         return supportSubscription;
     }
 
+    /**
+     * Checks if client's IP address should be added to mail headers on delivery as custom header <code>"X-Originating-IP"</code>.
+     *
+     * @return <code>true</code> if client's IP address should be added otherwise <code>false</code>
+     */
+    public boolean isAddClientIPAddress() {
+        return addClientIPAddress;
+    }
+
     /**
      * Gets the JavaMail properties.
-     * 
+     *
      * @return The JavaMail properties
      */
     public Properties getJavaMailProperties() {
@@ -720,7 +734,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the login source.
-     * 
+     *
      * @return The login source
      */
     public LoginSource getLoginSource() {
@@ -729,7 +743,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the password source.
-     * 
+     *
      * @return The password source
      */
     public PasswordSource getPasswordSource() {
@@ -738,7 +752,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the mail server source.
-     * 
+     *
      * @return The mail server source
      */
     public ServerSource getMailServerSource() {
@@ -747,7 +761,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the transport server source.
-     * 
+     *
      * @return The transport server source
      */
     public ServerSource getTransportServerSource() {
@@ -760,7 +774,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the global mail server.
-     * 
+     *
      * @return The global mail server
      */
     public String getMailServer() {
@@ -769,20 +783,16 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the master password.
-     * 
+     *
      * @return The master password
      */
     public String getMasterPassword() {
         return masterPassword;
     }
 
-    public int getMaxNumOfConnections() {
-        return maxNumOfConnections;
-    }
-
     /**
-     * Gets the sent mail rate limit (how many mails can be sent in 
-     * 
+     * Gets the sent mail rate limit (how many mails can be sent in
+     *
      * @return
      */
     public int getMaxToCcBcc() {
@@ -791,7 +801,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the quote line colors.
-     * 
+     *
      * @return The quote line colors
      */
     public String[] getQuoteLineColors() {
@@ -799,8 +809,8 @@ public final class MailProperties implements IMailProperties {
     }
 
     /**
-     * Gets the sent mail rate limit (how many mails can be sent in 
-     * 
+     * Gets the sent mail rate limit (how many mails can be sent in
+     *
      * @return
      */
     public int getRateLimit() {
@@ -809,17 +819,17 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the setting if the rate limit should only affect the primary
-     * account or all accounts 
-     * 
+     * account or all accounts
+     *
      * @return
      */
     public boolean getRateLimitPrimaryOnly() {
         return rateLimitPrimaryOnly;
     }
-    
+
     /**
      * Gets the global transport server
-     * 
+     *
      * @return The global transport server
      */
     public String getTransportServer() {
@@ -848,7 +858,7 @@ public final class MailProperties implements IMailProperties {
 
     /**
      * Gets the phishing headers.
-     * 
+     *
      * @return The phishing headers or <code>null</code> if none defined
      */
     public String[] getPhishingHeaders() {
@@ -868,4 +878,12 @@ public final class MailProperties implements IMailProperties {
         return mailAccessCacheIdleSeconds;
     }
 
+
+    /**
+     * @return the authProxyDelimiter
+     */
+    public final String getAuthProxyDelimiter() {
+        return authProxyDelimiter;
+    }
+
 }
