@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,8 @@ package com.openexchange.mail.conversion;
 
 import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.io.InputStream;
+import java.util.Iterator;
+import java.util.Map.Entry;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataArguments;
 import com.openexchange.conversion.DataException;
@@ -59,18 +61,26 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.conversion.SimpleData;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailException;
+import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.conversion.MailPartDataSource.Attachment;
+import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.permission.MailPermission;
 import com.openexchange.session.Session;
 
 /**
  * {@link ICalMailPartDataSource} - The {@link MailPartDataSource} for VCard parts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ICalMailPartDataSource extends MailPartDataSource {
+    
+
+    public static final String PROPERTY_OWNER = "com.openexchange.conversion.owner";
 
     /**
      * Initializes a new {@link ICalMailPartDataSource}
@@ -89,7 +99,8 @@ public final class ICalMailPartDataSource extends MailPartDataSource {
             final String fullname = arg.getFullname();
             final String mailId = dataArguments.get(ARGS[1]);
             final String sequenceId = dataArguments.get(ARGS[2]);
-            mailPart = getMailPart(arg.getAccountId(), fullname, mailId, sequenceId, session);
+            final DataProperties properties = new DataProperties();
+            mailPart = getMailPart(arg.getAccountId(), fullname, mailId, sequenceId, session, properties).mailPart;
             final ContentType contentType = mailPart.getContentType();
             if (contentType == null) {
                 throw DataExceptionCodes.ERROR.create("Missing header 'Content-Type' in requested mail part");
@@ -97,7 +108,6 @@ public final class ICalMailPartDataSource extends MailPartDataSource {
             if (!contentType.isMimeType(MIMETypes.MIME_TEXT_ALL_CALENDAR)) {
                 throw DataExceptionCodes.ERROR.create("Requested mail part is not an ICal: " + contentType.getBaseType());
             }
-            final DataProperties properties = new DataProperties();
             properties.put(DataProperties.PROPERTY_CONTENT_TYPE, contentType.getBaseType());
             final String charset = contentType.getCharsetParameter();
             if (charset == null) {
@@ -107,6 +117,8 @@ public final class ICalMailPartDataSource extends MailPartDataSource {
             }
             properties.put(DataProperties.PROPERTY_SIZE, String.valueOf(mailPart.getSize()));
             properties.put(DataProperties.PROPERTY_NAME, mailPart.getFileName());
+            
+            getMailHeader(arg.getAccountId(), fullname, mailId, session, properties);
             try {
                 return new SimpleData<D>((D) mailPart.getInputStream(), properties);
             } catch (final MailException e) {
@@ -115,4 +127,70 @@ public final class ICalMailPartDataSource extends MailPartDataSource {
         }
     }
 
+    protected Attachment getMailPart(int accountId, String fullname, String mailId, String sequenceId, Session session, DataProperties properties) throws DataException {
+        final MailAccess<?, ?> mailAccess;
+        try {
+            mailAccess = MailAccess.getInstance(session, accountId);
+            mailAccess.connect();
+        } catch (final MailException e) {
+            throw new DataException(e);
+        }
+        try {
+            // TODO: Find Sender
+            final MailPart mailPart = mailAccess.getMessageStorage().getAttachment(fullname, mailId, sequenceId);
+            mailPart.loadContent();
+            Attachment attachment = new Attachment(mailPart, "");
+            
+            // Find real owner if shared
+            MailFolder folder = mailAccess.getFolderStorage().getFolder(fullname);
+            if (folder.isShared()) {
+                MailPermission[] permissions = folder.getPermissions();
+                boolean found = false;
+                boolean foundMoreThanOne = false;
+                int ownerId = 0;
+                for (MailPermission perm : permissions) {
+                    if (perm.isFolderAdmin() && !perm.isGroupPermission()) {
+                        if (found) {
+                            foundMoreThanOne = true;
+                        }
+                        ownerId = perm.getEntity();
+                        found = true;
+                    }
+                }
+                if (found && !foundMoreThanOne && ownerId > 0) {
+                    properties.put(PROPERTY_OWNER, Integer.toString(ownerId));
+                }
+            }
+            
+            return attachment;
+        } catch (final MailException e) {
+            throw new DataException(e);
+        } finally {
+            mailAccess.close(true);
+        }
+    }
+
+    private void getMailHeader(int accountId, String fullname, String mailId, Session session, DataProperties properties) throws DataException {
+        MailAccess<?, ?> mailAccess;
+        try {
+            mailAccess = MailAccess.getInstance(session, accountId);
+            mailAccess.connect();
+        } catch (MailException e) {
+            throw new DataException(e);
+        }
+        try {
+            MailMessage mailMessage = mailAccess.getMessageStorage().getMessage(fullname, mailId, false);
+            Iterator<Entry<String, String>> headers = mailMessage.getHeadersIterator();
+            
+            while (headers.hasNext()) {
+                Entry<String, String> header = headers.next();
+                properties.put(DataProperties.PROPERTY_EMAIL_HEADER_PREFIX + "." + header.getKey(), header.getValue());
+            }
+        } catch (MailException e) {
+            throw new DataException(e);
+        } finally {
+            mailAccess.close(true);
+        }
+    }
+
 }
