@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.mail.conversion;
 
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.shouldRetry;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.io.InputStream;
 import com.openexchange.conversion.Data;
@@ -59,21 +60,37 @@ import com.openexchange.conversion.DataProperties;
 import com.openexchange.conversion.DataSource;
 import com.openexchange.conversion.SimpleData;
 import com.openexchange.image.ImageDataSource;
+import com.openexchange.image.ImageLocation;
+import com.openexchange.image.ImageUtility;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.ContentType;
+import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.session.Session;
 
 /**
  * {@link InlineImageDataSource} - A {@link DataSource} for image parts inside a mail.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class InlineImageDataSource implements ImageDataSource {
 
+    private static final InlineImageDataSource INSTANCE = new InlineImageDataSource();
+
+    /**
+     * Gets the instance
+     *
+     * @return The instance
+     */
+    public static InlineImageDataSource getInstance() {
+        return INSTANCE;
+    }
+
+    private static final long EXPIRES = ImageDataSource.YEAR_IN_MILLIS * 50;
+
     /**
      * Common required arguments for uniquely determining a mail part:
      * <ul>
@@ -90,29 +107,77 @@ public final class InlineImageDataSource implements ImageDataSource {
     /**
      * Initializes a new {@link InlineImageDataSource}
      */
-    public InlineImageDataSource() {
+    private InlineImageDataSource() {
         super();
     }
 
     private MailPart getImagePart(final int accountId, final String fullname, final String mailId, final String cid, final Session session) throws DataException {
-        final MailAccess<?, ?> mailAccess;
+        MailAccess<?, ?> mailAccess = null;
         try {
             mailAccess = MailAccess.getInstance(session, accountId);
             mailAccess.connect();
+            return loadImagePart(fullname, mailId, cid, mailAccess);
         } catch (final MailException e) {
-            throw new DataException(e);
-        }
-        try {
-            final MailPart imagePart = mailAccess.getMessageStorage().getImageAttachment(fullname, mailId, cid);
-            imagePart.loadContent();
-            return imagePart;
-        } catch (final MailException e) {
+            if ((null != mailAccess) && shouldRetry(e)) {
+                try {
+                    // Re-connect
+                    mailAccess = MailAccess.reconnect(mailAccess);
+                    return loadImagePart(fullname, mailId, cid, mailAccess);
+                } catch (MailException me) {
+                    throw new DataException(me);
+                }
+            }
             throw new DataException(e);
         } finally {
-            mailAccess.close(true);
+            if (null != mailAccess) {
+                mailAccess.close(true);
+            }
         }
     }
 
+    private MailPart loadImagePart(final String fullname, final String mailId, final String cid, final MailAccess<?, ?> mailAccess) throws MailException {
+        final MailPart imagePart = mailAccess.getMessageStorage().getImageAttachment(fullname, mailId, cid);
+        imagePart.loadContent();
+        return imagePart;
+    }
+
+    public String generateUrl(final ImageLocation imageLocation, final Session session) {
+        final StringBuilder sb = new StringBuilder(64);
+        /*
+         * Nothing special...
+         */
+        ImageUtility.startImageUrl(imageLocation, session, this, true, sb);
+        return sb.toString();
+    }
+
+    public DataArguments generateDataArgumentsFrom(final ImageLocation imageLocation) {
+        final DataArguments dataArguments = new DataArguments(3);
+        dataArguments.put(ARGS[0], imageLocation.getFolder());
+        dataArguments.put(ARGS[1], imageLocation.getId());
+        dataArguments.put(ARGS[2], imageLocation.getImageId());
+        return dataArguments;
+    }
+
+    public ImageLocation parseUrl(final String url) {
+        return ImageUtility.parseImageLocationFrom(url);
+    }
+
+    public long getExpires() {
+        return EXPIRES;
+    }
+
+    public String getETag(final ImageLocation imageLocation, final Session session) {
+        final char delim = '#';
+        final StringBuilder builder = new StringBuilder(128);
+        builder.append(delim).append(imageLocation.getFolder());
+        builder.append(delim).append(imageLocation.getId());
+        builder.append(delim).append(imageLocation.getImageId());
+        // builder.append(delim).append(session.getUserId());
+        // builder.append(delim).append(session.getContextId());
+        builder.append(delim);
+        return ImageUtility.getMD5(builder.toString(), "hex");
+    }
+
     /**
      * Common required arguments for uniquely determining a mail part:
      * <ul>
@@ -145,7 +210,31 @@ public final class InlineImageDataSource implements ImageDataSource {
                 throw DataExceptionCodes.ERROR.create("Missing header 'Content-Type' in requested mail part");
             }
             if (!contentType.isMimeType(MIMETypes.MIME_IMAGE_ALL)) {
-                throw DataExceptionCodes.ERROR.create("Requested mail part is not an image: " + contentType.getBaseType());
+                /*
+                 * Either general purpose "application/octet-stream" or check by file name
+                 */
+                final String fileName = mailPart.getFileName();
+                if (null == fileName) {
+                    if (!contentType.isMimeType(MIMETypes.MIME_APPL_OCTET)) {
+                        throw DataExceptionCodes.ERROR.create("Requested mail part is not an image: " + contentType.getBaseType());
+                    }
+                } else {
+                    try {
+                        final String byFileName = MIMEType2ExtMap.getContentType(fileName);
+                        if (ContentType.isMimeType(byFileName, MIMETypes.MIME_IMAGE_ALL)) {
+                            /*
+                             * File name indicates an image/* content type
+                             */
+                            contentType.setBaseType(byFileName);
+                        } else {
+                            if (!contentType.isMimeType(MIMETypes.MIME_APPL_OCTET)) {
+                                throw DataExceptionCodes.ERROR.create("Requested mail part is not an image: " + contentType.getBaseType());
+                            }
+                        }
+                    } catch (final MailException e) {
+                        throw new DataException(e);
+                    }
+                }
             }
             final DataProperties properties = new DataProperties();
             properties.put(DataProperties.PROPERTY_CONTENT_TYPE, contentType.getBaseType());
@@ -168,4 +257,11 @@ public final class InlineImageDataSource implements ImageDataSource {
     public String getRegistrationName() {
         return REGISTRATION_NAME;
     }
+
+    private static final String ALIAS = "/mail/picture";
+
+    public String getAlias() {
+        return ALIAS;
+    }
+
 }
