@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.mail.conversion;
 
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.shouldRetry;
 import java.io.InputStream;
 import com.openexchange.conversion.DataException;
 import com.openexchange.conversion.DataSource;
@@ -59,7 +60,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link MailPartDataSource} - A generic {@link DataSource} for mail parts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailPartDataSource implements DataSource {
@@ -83,25 +84,37 @@ public abstract class MailPartDataSource implements DataSource {
         super();
     }
 
-    protected final MailPart getMailPart(final int accountId, final String fullname, final String mailId, final String sequenceId, final Session session) throws DataException {
-        final MailAccess<?, ?> mailAccess;
+    protected Attachment getMailPart(final int accountId, final String fullname, final String mailId, final String sequenceId, final Session session) throws DataException {
+        MailAccess<?, ?> mailAccess = null;
         try {
             mailAccess = MailAccess.getInstance(session, accountId);
             mailAccess.connect();
+        	// TODO: Find Sender
+        	return loadPart(fullname, mailId, sequenceId, mailAccess);
         } catch (final MailException e) {
-            throw new DataException(e);
-        }
-        try {
-            final MailPart mailPart = mailAccess.getMessageStorage().getAttachment(fullname, mailId, sequenceId);
-            mailPart.loadContent();
-            return mailPart;
-        } catch (final MailException e) {
+            if ((null != mailAccess) &&  shouldRetry(e)) {
+                try {
+                    // Re-connect
+                    mailAccess = MailAccess.reconnect(mailAccess);
+                    return loadPart(fullname, mailId, sequenceId, mailAccess);
+                } catch (MailException me) {
+                    throw new DataException(me);
+                }
+            }
             throw new DataException(e);
         } finally {
-            mailAccess.close(true);
+            if (null != mailAccess) {
+                mailAccess.close(true);
+            }
         }
     }
 
+    private Attachment loadPart(final String fullname, final String mailId, final String sequenceId, MailAccess<?, ?> mailAccess) throws MailException {
+        final MailPart mailPart = mailAccess.getMessageStorage().getAttachment(fullname, mailId, sequenceId);
+        mailPart.loadContent();
+        return new Attachment(mailPart, "");
+    }
+
     public String[] getRequiredArguments() {
         return new String[] { ARGS[0], ARGS[1], ARGS[2] };
     }
@@ -109,4 +122,14 @@ public abstract class MailPartDataSource implements DataSource {
     public Class<?>[] getTypes() {
         return new Class<?>[] { InputStream.class };
     }
+    
+    protected static final class Attachment {
+    	public MailPart mailPart;
+    	public String from;
+    	
+    	public Attachment(MailPart mailPart, String from) {
+    		this.mailPart = mailPart;
+    		this.from = from;
+    	}
+    }
 }
