@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,7 +67,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link VCardMailPartDataSource} - The {@link MailPartDataSource} for VCard parts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class VCardMailPartDataSource extends MailPartDataSource {
@@ -89,12 +89,12 @@ public final class VCardMailPartDataSource extends MailPartDataSource {
             final String fullname = arg.getFullname();
             final String mailId = dataArguments.get(ARGS[1]);
             final String sequenceId = dataArguments.get(ARGS[2]);
-            mailPart = getMailPart(arg.getAccountId(), fullname, mailId, sequenceId, session);
+            mailPart = getMailPart(arg.getAccountId(), fullname, mailId, sequenceId, session).mailPart;
             final ContentType contentType = mailPart.getContentType();
             if (contentType == null) {
                 throw DataExceptionCodes.ERROR.create("Missing header 'Content-Type' in requested mail part");
             }
-            if (!contentType.isMimeType(MIMETypes.MIME_TEXT_ALL_CARD)) {
+            if (!contentType.isMimeType(MIMETypes.MIME_TEXT_ALL_CARD) && !contentType.startsWith("text/directory")) {
                 throw DataExceptionCodes.ERROR.create("Requested mail part is not a VCard: " + contentType.getBaseType());
             }
             final DataProperties properties = new DataProperties();
