@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,13 +55,15 @@ import com.openexchange.mail.MailException;
 
 /**
  * {@link IDMailMessage} - Supports only {@link #getMailId()} and {@link #getFolder()}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class IDMailMessage extends MailMessage {
 
     private static final long serialVersionUID = -8945006270321242506L;
 
+    private long uid;
+
     private String mailId;
 
     private char separator;
@@ -74,6 +76,15 @@ public final class IDMailMessage extends MailMessage {
     public IDMailMessage(final String mailId, final String folder) {
         super();
         this.mailId = mailId;
+        if (null == mailId) {
+            uid = -1L;
+        } else {
+            try {
+                uid = Long.parseLong(mailId);
+            } catch (final NumberFormatException e) {
+                uid = -1L;
+            }
+        }
         setFolder(folder);
     }
 
@@ -90,11 +101,38 @@ public final class IDMailMessage extends MailMessage {
     @Override
     public void setMailId(final String id) {
         mailId = id;
+        if (null == id) {
+            uid = -1L;
+        } else {
+            try {
+                uid = Long.parseLong(id);
+            } catch (final NumberFormatException e) {
+                uid = -1L;
+            }
+        }
+    }
+
+    /**
+     * Gets the UID
+     *
+     * @return The UID or <code>-1</code> if absent
+     */
+    public long getUid() {
+        return uid;
+    }
+
+    /**
+     * Sets the UID
+     *
+     * @param uid The UID to set or <code>-1</code> to indicate absence
+     */
+    public void setUid(final long uid) {
+        this.uid = uid;
     }
 
     /**
      * Gets the separator.
-     * 
+     *
      * @return The separator
      */
     public char getSeparator() {
@@ -103,7 +141,7 @@ public final class IDMailMessage extends MailMessage {
 
     /**
      * Sets the separator.
-     * 
+     *
      * @param separator The separator to set
      */
     public void setSeparator(final char separator) {
@@ -112,7 +150,7 @@ public final class IDMailMessage extends MailMessage {
 
     /**
      * Gets the sequence number.
-     * 
+     *
      * @return The sequence number
      */
     public int getSeqnum() {
@@ -121,7 +159,7 @@ public final class IDMailMessage extends MailMessage {
 
     /**
      * Sets the sequence number.
-     * 
+     *
      * @param seqnum The sequence number to set
      */
     public void setSeqnum(final int seqnum) {
