@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,10 +60,10 @@ import com.openexchange.mail.permission.MailPermission;
 
 /**
  * {@link MailFolder} - a data container object for a mail folder
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public class MailFolder implements Serializable {
+public class MailFolder implements Serializable, Cloneable {
 
     /**
      * Serial Version UID
@@ -169,16 +169,24 @@ public class MailFolder implements Serializable {
 
     private boolean b_permissions;
 
+    private boolean shared;
+
+    private boolean b_shared;
+
+    private String owner;
+
+    private boolean b_owner;
+
     /**
      * Virtual name of mailbox's root folder
-     * 
+     *
      * @value "E-Mail"
      */
     public static final String DEFAULT_FOLDER_NAME = "E-Mail";
 
     /**
      * Virtual fullname of mailbox's root folder
-     * 
+     *
      * @value "default"
      */
     public static final String DEFAULT_FOLDER_ID = "default";
@@ -191,9 +199,35 @@ public class MailFolder implements Serializable {
         defaulFolderType = DefaultFolderType.NONE;
     }
 
+    @Override
+    public Object clone() {
+        try {
+            final MailFolder clone = (MailFolder) super.clone();
+            {
+                final MailPermission thisOwnPerm = ownPermission;
+                if (thisOwnPerm != null) {
+                    clone.ownPermission = (MailPermission) thisOwnPerm.clone();
+                }
+            }
+            {
+                final List<MailPermission> thisPerms = permissions;
+                if (thisPerms != null) {
+                    final List<MailPermission> l = new ArrayList<MailPermission>(thisPerms.size());
+                    for (final MailPermission mailPermission : thisPerms) {
+                        l.add((MailPermission) mailPermission.clone());
+                    }
+                    clone.permissions = l;
+                }
+            }
+            return clone;
+        } catch (final CloneNotSupportedException e) {
+            throw new InternalError("Clone failed although Cloneable is implemented.");
+        }
+    }
+
     /**
      * Gets the fullname.
-     * 
+     *
      * @return The fullname ({@link #DEFAULT_FOLDER_ID} if this mail folder denotes the root folder)
      */
     public String getFullname() {
@@ -202,7 +236,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if fullname is set through {@link #setFullname(String)}.
-     * 
+     *
      * @return <code>true</code> if fullname is set; otherwise <code>false</code>
      */
     public boolean containsFullname() {
@@ -221,7 +255,7 @@ public class MailFolder implements Serializable {
      * Sets this mail folder's fullname.
      * <p>
      * If this mail folder denotes the root folder, {@link #DEFAULT_FOLDER_ID} is supposed to be set as fullname.
-     * 
+     *
      * @param fullname the fullname to set
      */
     public void setFullname(final String fullname) {
@@ -231,7 +265,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder has subfolders.
-     * 
+     *
      * @return <code>true</code> if this mail folder has subfolders; otherwise <code>false</code>
      */
     public boolean hasSubfolders() {
@@ -240,7 +274,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if has-subfolders flag was set through {@link #setSubfolders(boolean)}.
-     * 
+     *
      * @return <code>true</code> if has-subfolders flag is set; otherwise <code>false</code>
      */
     public boolean containsSubfolders() {
@@ -257,7 +291,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets if this mail folder has subfolders.
-     * 
+     *
      * @param hasSubfolders the has-subfolders flag to set
      */
     public void setSubfolders(final boolean hasSubfolders) {
@@ -267,7 +301,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder has subscribed subfolders.
-     * 
+     *
      * @return <code>true</code> if this mail folder has subscribed subfolders; otherwise <code>false</code>
      */
     public boolean hasSubscribedSubfolders() {
@@ -276,7 +310,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the has-subscribed-subfolders flag was set through {@link #setSubscribedSubfolders(boolean)}.
-     * 
+     *
      * @return <code>true</code> if the has-subscribed-subfolders flag was set; otherwise <code>false</code>
      */
     public boolean containsSubscribedSubfolders() {
@@ -293,7 +327,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets if this mail folder has subscribed subfolders.
-     * 
+     *
      * @param hasSubscribedSubfolders the has-subscribed-subfolders flag to set
      */
     public void setSubscribedSubfolders(final boolean hasSubscribedSubfolders) {
@@ -303,7 +337,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the default folder type.
-     * 
+     *
      * @return The default folder type
      */
     public DefaultFolderType getDefaultFolderType() {
@@ -312,7 +346,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the INBOX folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the INBOX folder; otherwise <code>false</code>
      */
     public boolean isInbox() {
@@ -321,7 +355,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the DRAFTS folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the DRAFTS folder; otherwise <code>false</code>
      */
     public boolean isDrafts() {
@@ -330,7 +364,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the SENT folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the SENT folder; otherwise <code>false</code>
      */
     public boolean isSent() {
@@ -339,7 +373,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the SPAM folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the SPAM folder; otherwise <code>false</code>
      */
     public boolean isSpam() {
@@ -348,7 +382,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the TRASH folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the TRASH folder; otherwise <code>false</code>
      */
     public boolean isTrash() {
@@ -357,7 +391,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the CONFIRMED_SPAM folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the CONFIRMED_SPAM folder; otherwise <code>false</code>
      */
     public boolean isConfirmedSpam() {
@@ -366,7 +400,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this mail folder denotes the CONFIRMED_HAM folder.
-     * 
+     *
      * @return <code>true</code> if this mail folder denotes the CONFIRMED_HAM folder; otherwise <code>false</code>
      */
     public boolean isConfirmedHam() {
@@ -375,7 +409,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if default folder type was set through {@link #setDefaultFolderType(DefaultFolderType)}.
-     * 
+     *
      * @return <code>true</code> if default folder type is set; otherwise <code>false</code>
      */
     public boolean containsDefaultFolderType() {
@@ -392,7 +426,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets default folder type.
-     * 
+     *
      * @param name the name to set
      */
     public void setDefaultFolderType(final DefaultFolderType defaulFolderType) {
@@ -402,7 +436,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the name.
-     * 
+     *
      * @return The name
      */
     public String getName() {
@@ -411,7 +445,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if name was set through {@link #setName(String)}.
-     * 
+     *
      * @return <code>true</code> if name is set; otherwise <code>false</code>
      */
     public boolean containsName() {
@@ -430,7 +464,7 @@ public class MailFolder implements Serializable {
      * Sets this mail folder's name.
      * <p>
      * If this mail folder denotes the root folder, {@link #DEFAULT_FOLDER_NAME} is supposed to be set as name.
-     * 
+     *
      * @param name the name to set
      */
     public void setName(final String name) {
@@ -442,7 +476,7 @@ public class MailFolder implements Serializable {
      * Returns whether the denoted mail folder is subscribed or not.
      * <p>
      * If mailing system does not support subscription, <code>true</code> is supposed to be returned.
-     * 
+     *
      * @return Whether the denoted mail folder is subscribed or not
      */
     public boolean isSubscribed() {
@@ -451,7 +485,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if subscribed status was set through {@link #setSubscribed(boolean)}.
-     * 
+     *
      * @return <code>true</code> if subscribed is set; otherwise <code>false</code>
      */
     public boolean containsSubscribed() {
@@ -470,7 +504,7 @@ public class MailFolder implements Serializable {
      * Sets the subscription status for this mail folder.
      * <p>
      * If mailing system does not support subscription, <code>true</code> is supposed to be set as subscription status.
-     * 
+     *
      * @param subscribed the subscription status to set
      */
     public void setSubscribed(final boolean subscribed) {
@@ -480,7 +514,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the number of messages marked for deletion in this folder
-     * 
+     *
      * @return The number of messages marked for deletion in this folder or <code>-1</code> if this mail folder does not hold messages
      * @see #isHoldsMessages()
      */
@@ -490,7 +524,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the number of messages was set through {@link #setDeletedMessageCount(int)}.
-     * 
+     *
      * @return <code>true</code> if deletedMessageCount is set; otherwise <code>false</code>
      */
     public boolean containsDeletedMessageCount() {
@@ -507,7 +541,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the number of messages marked for deletion in this folder.
-     * 
+     *
      * @param deletedMessageCount The number of messages marked for deletion or <code>-1</code> if this mail folder does not hold messages
      */
     public void setDeletedMessageCount(final int deletedMessageCount) {
@@ -517,7 +551,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder exists.
-     * 
+     *
      * @return <code>true</code> if folder exists in mailbox; otherwise <code>false</code>
      */
     public boolean exists() {
@@ -526,7 +560,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if folder existence status was set through {@link #setExists(boolean)}.
-     * 
+     *
      * @return <code>true</code> if exists status is set; otherwise <code>false</code>
      */
     public boolean containsExists() {
@@ -543,7 +577,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the exists status.
-     * 
+     *
      * @param exists <code>true</code> if folder exists in mailbox; otherwise <code>false</code>
      */
     public void setExists(final boolean exists) {
@@ -553,7 +587,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the number of messages.
-     * 
+     *
      * @return The number of messages or <code>-1</code> if this mail folder does not hold messages
      * @see #isHoldsMessages()
      */
@@ -563,7 +597,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if number of messages was set through {@link #setMessageCount(int)}.
-     * 
+     *
      * @return <code>true</code> if messageCount is set; otherwise <code>false</code>
      */
     public boolean containsMessageCount() {
@@ -580,7 +614,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the number of messages.
-     * 
+     *
      * @param messageCount The number of messages or <code>-1</code> if this mail folder does not hold messages
      */
     public void setMessageCount(final int messageCount) {
@@ -590,7 +624,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the number of new messages (since last time this folder was accessed).
-     * 
+     *
      * @return The number of new messages or <code>-1</code> if this mail folder does not hold messages.
      * @see #isHoldsMessages()
      */
@@ -600,7 +634,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the number of new messages was set through {@link #setNewMessageCount(int)}.
-     * 
+     *
      * @return <code>true</code> if newMessageCount is set; otherwise <code>false</code>
      */
     public boolean containsNewMessageCount() {
@@ -617,7 +651,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the number of new messages.
-     * 
+     *
      * @param newMessageCount The number of new messages or <code>-1</code> if this mail folder does not hold messages
      */
     public void setNewMessageCount(final int newMessageCount) {
@@ -627,7 +661,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the number of unread messages.
-     * 
+     *
      * @return The number of unread messages or <code>-1</code> if this mail folder does not hold messages
      * @see #isHoldsMessages()
      */
@@ -637,7 +671,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the number of unread messages was set through {@link #setUnreadMessageCount(int)}.
-     * 
+     *
      * @return <code>true</code> if unreadMessageCount is set; otherwise <code>false</code>
      */
     public boolean containsUnreadMessageCount() {
@@ -654,7 +688,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the number of unread messages.
-     * 
+     *
      * @param unreadMessageCount The number of unread messages or <code>-1</code> if this mail folder does not hold messages
      */
     public void setUnreadMessageCount(final int unreadMessageCount) {
@@ -664,7 +698,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the separator character.
-     * 
+     *
      * @see MailConfig#getDefaultSeparator()
      * @return The separator character.
      */
@@ -674,7 +708,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if seperator character was set through {@link #setSeparator(char)}.
-     * 
+     *
      * @return <code>true</code> if separator is set; otherwise <code>false</code>
      */
     public boolean containsSeparator() {
@@ -693,7 +727,7 @@ public class MailFolder implements Serializable {
      * Sets the separator character.
      * <p>
      * If mailing system does not support a separator character, {@link MailConfig#getDefaultSeparator()} should to be used.
-     * 
+     *
      * @param separator the separator to set
      */
     public void setSeparator(final char separator) {
@@ -703,7 +737,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Gets the parent fullname.
-     * 
+     *
      * @return The parent fullname or <code>null</code> if this mail folder denotes the root folder
      */
     public String getParentFullname() {
@@ -712,7 +746,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if parent fullname was set through {@link #setParentFullname(String)}.
-     * 
+     *
      * @return <code>true</code> if parentFullname is set; otherwise <code>false</code>
      */
     public boolean containsParentFullname() {
@@ -731,7 +765,7 @@ public class MailFolder implements Serializable {
      * Sets the parent fullname.
      * <p>
      * If this mail folder denotes the root folder, <code>null</code> is supposed to be set.
-     * 
+     *
      * @param parentFullname the parent fullname to set
      */
     public void setParentFullname(final String parentFullname) {
@@ -741,7 +775,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder is able to hold messages.
-     * 
+     *
      * @return <code>true</code> if this folder is able to hold messages; otherwise <code>false</code>
      */
     public boolean isHoldsMessages() {
@@ -750,7 +784,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if he holds-messages flag was set through {@link #setHoldsMessages(boolean)}.
-     * 
+     *
      * @return <code>true</code> if the holds-messages flag is set; otherwise <code>false</code>
      */
     public boolean containsHoldsMessages() {
@@ -767,7 +801,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets if this folder holds messages.
-     * 
+     *
      * @param holdsMessages <code>true</code> if folder holds messages; otherwise <code>false</code>
      */
     public void setHoldsMessages(final boolean holdsMessages) {
@@ -777,7 +811,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder is able to hold folders.
-     * 
+     *
      * @return <code>true</code> if this folder is able to hold folders; otherwise <code>false</code>
      */
     public boolean isHoldsFolders() {
@@ -786,7 +820,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the holds-folder flag was set through {@link #setHoldsFolders(boolean)}.
-     * 
+     *
      * @return <code>true</code> if this folder has the holds-folder flag set; otherwise <code>false</code>
      */
     public boolean containsHoldsFolders() {
@@ -803,7 +837,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets if this folder holds folders.
-     * 
+     *
      * @param holdsFolders <code>true</code> if folder holds folders; otherwise <code>false</code>
      */
     public void setHoldsFolders(final boolean holdsFolders) {
@@ -818,7 +852,7 @@ public class MailFolder implements Serializable {
      * {@link DefaultMailPermission} is supposed to be returned on missing permissions support except for the root folder. The root folder
      * should indicate no object permissions in any case, but the folder permission varies if mailing system allows subfolder creation below
      * root folder or not. The returned permission must reflect the allowed behavior.
-     * 
+     *
      * @return The own permission
      */
     public MailPermission getOwnPermission() {
@@ -827,7 +861,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if own permission was set through {@link #setOwnPermission(MailPermission)}.
-     * 
+     *
      * @return <code>true</code> if own permission is set; otherwise <code>false</code>
      */
     public boolean containsOwnPermission() {
@@ -846,10 +880,13 @@ public class MailFolder implements Serializable {
      * Sets own permission.
      * <p>
      * Apply an instance of {@link DefaultMailPermission} if mailing system does not support permissions, except if this mail folder denotes
-     * the root folder, then apply altered instance of {@link DefaultMailPermission} with no object permissions but properly reflects folder
+     * the root folder, then apply <code>null</code> or altered instance of {@link DefaultMailPermission} with no object permissions but properly reflects folder
      * permission as described in {@link #getOwnPermission()}.
-     * 
-     * @param ownPermission the own permission to set
+     * <p>
+     * Please note that even if the mail system does not support permissions the entity must be set on the {@link DefaultMailPermission}
+     * object. Please use {@link DefaultMailPermission#setEntity(int)} for this.
+     *
+     * @param ownPermission The own permission to set
      */
     public void setOwnPermission(final MailPermission ownPermission) {
         this.ownPermission = ownPermission;
@@ -858,7 +895,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder denotes the root folder
-     * 
+     *
      * @return <code>true</code> if this folder denotes the root folder; otherwise <code>false</code>
      */
     public boolean isRootFolder() {
@@ -867,7 +904,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if root-folder flag was set through {@link #setRootFolder(boolean)}.
-     * 
+     *
      * @return <code>true</code> if root-folder flag is set; otherwise <code>false</code>
      */
     public boolean containsRootFolder() {
@@ -884,7 +921,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the root folder flag.
-     * 
+     *
      * @param rootFolder the root folder flag to set
      */
     public void setRootFolder(final boolean rootFolder) {
@@ -894,7 +931,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder denotes a default folder (Drafts, Sent, Trash, etc.)
-     * 
+     *
      * @return <code>true</code> if this folder denotes a default folder; otherwise <code>false</code>
      */
     public boolean isDefaultFolder() {
@@ -903,7 +940,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if default-folder flag was set through {@link #setDefaultFolder(boolean)}.
-     * 
+     *
      * @return <code>true</code> if default-folder flag is set; otherwise <code>false</code>
      */
     public boolean containsDefaultFolder() {
@@ -920,7 +957,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Sets the default folder flag.
-     * 
+     *
      * @param defaultFolder the default folder flag to set
      */
     public void setDefaultFolder(final boolean defaultFolder) {
@@ -930,7 +967,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Adds a permission.
-     * 
+     *
      * @param permission The permission to add
      */
     public void addPermission(final MailPermission permission) {
@@ -945,7 +982,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Adds an array of permissions.
-     * 
+     *
      * @param permissions The array of permissions to add
      */
     public void addPermissions(final MailPermission[] permissions) {
@@ -960,7 +997,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Adds a collection of permissions.
-     * 
+     *
      * @param permissions The collection of permissions to add
      */
     public void addPermissions(final Collection<? extends MailPermission> permissions) {
@@ -976,7 +1013,7 @@ public class MailFolder implements Serializable {
     /**
      * Checks if permissions were set through {@link #addPermission(MailPermission)}, {@link #addPermissions(Collection)}, or
      * {@link #addPermissions(MailPermission[])}.
-     * 
+     *
      * @return <code>true</code> if permissions are set; otherwise <code>false</code>
      */
     public boolean containsPermissions() {
@@ -1010,7 +1047,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if this folder supports user flags.
-     * 
+     *
      * @return <code>true</code> if this folder supports user flags; otherwise <code>false</code>
      */
     public boolean isSupportsUserFlags() {
@@ -1019,7 +1056,7 @@ public class MailFolder implements Serializable {
 
     /**
      * Checks if the supports-user-flags flag was set through {@link #setSupportsUserFlags(boolean)}.
-     * 
+     *
      * @return <code>true</code> if supportsUserFlags is set; otherwise <code>false</code>
      */
     public boolean containsSupportsUserFlags() {
@@ -1030,13 +1067,13 @@ public class MailFolder implements Serializable {
      * Removes the supports-user-flags flag.
      */
     public void removeSupportsUserFlags() {
-        b_supportsUserFlags = false;
+        supportsUserFlags = false;
         b_supportsUserFlags = false;
     }
 
     /**
      * Sets the supports-user-flags flag.
-     * 
+     *
      * @param supportsUserFlags the supports-user-flags flag to set
      */
     public void setSupportsUserFlags(final boolean supportsUserFlags) {
@@ -1044,4 +1081,80 @@ public class MailFolder implements Serializable {
         b_supportsUserFlags = true;
     }
 
+    /**
+     * Checks if this folder is shared.
+     *
+     * @return <code>true</code> if this folder is shared; otherwise <code>false</code>
+     */
+    public boolean isShared() {
+        return shared;
+    }
+
+    /**
+     * Checks if the shared flag was set.
+     *
+     * @return <code>true</code> if shared flag is set; otherwise <code>false</code>
+     */
+    public boolean containsShared() {
+        return b_shared;
+    }
+
+    /**
+     * Removes the supports-user-flags flag.
+     */
+    public void removeShared() {
+        shared = false;
+        b_shared = false;
+    }
+
+    /**
+     * Sets the shared flag.
+     *
+     * @param shared The shared flag to set
+     */
+    public void setShared(final boolean shared) {
+        this.shared = shared;
+        b_shared = true;
+    }
+    
+    /**
+     * Gets the shared owner or <code>null</code>.
+     * <p>
+     * <b>Note:</b> {@link #isShared()} needs to return <code>true</code>.
+     * 
+     * @return The owner or <code>null</code>
+     */
+    public String getOwner() {
+        return owner;
+    }
+
+    /**
+     * Checks if the owner was set.
+     *
+     * @return <code>true</code> if owner is set; otherwise <code>false</code>
+     */
+    public boolean containsOwner() {
+        return b_owner;
+    }
+
+    /**
+     * Removes the owner.
+     */
+    public void removeOwne() {
+        owner = null;
+        b_owner = false;
+    }
+
+    /**
+     * Sets the shared owner or <code>null</code>.
+     * <p>
+     * <b>Note:</b> {@link #setShared(boolean)} needs to be invoked with <code>true</code>.
+     * 
+     * @param owner The owner
+     */
+    public void setOwner(String owner) {
+        this.owner = owner;
+        b_owner = true;
+    }
+
 }
