@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,25 +68,26 @@ import com.openexchange.mail.mime.PlainTextAddress;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link MailMessage} - Abstract super class for all {@link MailMessage} subclasses.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailMessage extends MailPart {
 
     private static final long serialVersionUID = 8585899349289256569L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailMessage.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailMessage.class));
 
     /*-
      * ------------------- Flags ------------------------------
      */
     /**
      * This message has been answered. This flag is set by clients to indicate that this message has been answered to.
-     * 
+     *
      * @value 1
      */
     public static final int FLAG_ANSWERED = 1;
@@ -94,21 +95,21 @@ public abstract class MailMessage extends MailPart {
     /**
      * This message is marked deleted. Clients set this flag to mark a message as deleted. The expunge operation on a folder removes all
      * messages in that folder that are marked for deletion.
-     * 
+     *
      * @value 2
      */
     public static final int FLAG_DELETED = 1 << 1;
 
     /**
      * This message is a draft. This flag is set by clients to indicate that the message is a draft message.
-     * 
+     *
      * @value 4
      */
     public static final int FLAG_DRAFT = 1 << 2;
 
     /**
      * This message is flagged. No semantic is defined for this flag. Clients alter this flag.
-     * 
+     *
      * @value 8
      */
     public static final int FLAG_FLAGGED = 1 << 3;
@@ -118,7 +119,7 @@ public abstract class MailMessage extends MailPart {
      * arrived since the last time this folder was opened.
      * <p>
      * Clients cannot alter this flag.
-     * 
+     *
      * @value 16
      */
     public static final int FLAG_RECENT = 1 << 4;
@@ -126,7 +127,7 @@ public abstract class MailMessage extends MailPart {
     /**
      * This message is seen. This flag is implicitly set by the implementation when the this Message's content is returned to the client in
      * some form.
-     * 
+     *
      * @value 32
      */
     public static final int FLAG_SEEN = 1 << 5;
@@ -135,28 +136,28 @@ public abstract class MailMessage extends MailPart {
      * A special flag that indicates that this folder supports user defined flags.
      * <p>
      * Clients cannot alter this flag.
-     * 
+     *
      * @value 64
      */
     public static final int FLAG_USER = 1 << 6;
 
     /**
      * Virtual Spam flag
-     * 
+     *
      * @value 128
      */
     public static final int FLAG_SPAM = 1 << 7;
 
     /**
      * Virtual forwarded flag that marks this message as being forwarded.
-     * 
+     *
      * @value 256
      */
     public static final int FLAG_FORWARDED = 1 << 8;
 
     /**
      * Virtual read acknowledgment flag that marks this message as being notified for delivery.
-     * 
+     *
      * @value 512
      */
     public static final int FLAG_READ_ACK = 1 << 9;
@@ -166,14 +167,14 @@ public abstract class MailMessage extends MailPart {
      */
     /**
      * The value of virtual forwarded flag.
-     * 
+     *
      * @value $Forwarded
      */
     public static final String USER_FORWARDED = "$Forwarded";
 
     /**
      * The value of virtual read acknowledgment flag.
-     * 
+     *
      * @value $MDNSent
      */
     public static final String USER_READ_ACK = "$MDNSent";
@@ -232,7 +233,7 @@ public abstract class MailMessage extends MailPart {
      * &lt;value-of-{@link #COLOR_LABEL_PREFIX}&gt;&lt;color-label-int-value&gt;
      * <p>
      * &lt;value-of-{@link #COLOR_LABEL_PREFIX_OLD} &gt;&lt;color-label-int-value&gt; is also accepted.
-     * 
+     *
      * @param cl The color label's string representation
      * @return The color label's <code>int</code> value
      * @throws MailException
@@ -250,7 +251,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Tests if specified string matches a color label pattern.
-     * 
+     *
      * @param cl The string to check
      * @return <code>true</code> if specified string matches a color label pattern; otherwise <code>false</code>
      */
@@ -262,7 +263,7 @@ public abstract class MailMessage extends MailPart {
      * Parses specified color label's string.
      * <p>
      * <b>Note</b> that this method assumes {@link #isColorLabel(String)} would return <code>true</code> for specified string.
-     * 
+     *
      * @param cl The color label's string
      * @param defaultValue The default value to return if parsing color label's <code>int</code> value fails
      * @return The color label's <code>int</code> value or <code>defaultValue</code> on failure.
@@ -283,7 +284,7 @@ public abstract class MailMessage extends MailPart {
      * <p>
      * A color label's string representation matches the pattern:<br>
      * &lt;value-of-{@link #COLOR_LABEL_PREFIX}&gt;&lt;color-label-int-value&gt;
-     * 
+     *
      * @param cl The color label's <code>int</code> value
      * @return The color abel's string representation
      */
@@ -426,6 +427,13 @@ public abstract class MailMessage extends MailPart {
 
     private boolean b_appendVCard;
 
+    /**
+     * The number of recent messages in associated folder.
+     */
+    private int recentCount;
+
+    private boolean b_recentCount;
+
     /**
      * Default constructor
      */
@@ -433,11 +441,12 @@ public abstract class MailMessage extends MailPart {
         super();
         priority = PRIORITY_NORMAL;
         colorLabel = COLOR_LABEL_NONE;
+        accountId = MailAccount.DEFAULT_ID;
     }
 
     /**
      * Adds an email address to <i>From</i>.
-     * 
+     *
      * @param addr The address
      */
     public void addFrom(final InternetAddress addr) {
@@ -453,7 +462,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds email addresses to <i>From</i>.
-     * 
+     *
      * @param addrs The addresses
      */
     public void addFrom(final InternetAddress[] addrs) {
@@ -495,7 +504,7 @@ public abstract class MailMessage extends MailPart {
             try {
                 addFrom(QuotedInternetAddress.parse(fromStr, true));
             } catch (final AddressException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.debug(e.getMessage(), e);
                 addFrom(new PlainTextAddress(fromStr));
             }
         }
@@ -504,7 +513,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds an email address to <i>To</i>.
-     * 
+     *
      * @param addr The address
      */
     public void addTo(final InternetAddress addr) {
@@ -520,7 +529,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds email addresses to <i>To</i>
-     * 
+     *
      * @param addrs The addresses
      */
     public void addTo(final InternetAddress[] addrs) {
@@ -562,7 +571,7 @@ public abstract class MailMessage extends MailPart {
             try {
                 addTo(QuotedInternetAddress.parse(toStr, true));
             } catch (final AddressException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.debug(e.getMessage(), e);
                 addTo(new PlainTextAddress(toStr));
             }
         }
@@ -571,7 +580,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds an email address to <i>Cc</i>
-     * 
+     *
      * @param addr The address
      */
     public void addCc(final InternetAddress addr) {
@@ -587,7 +596,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds email addresses to <i>Cc</i>
-     * 
+     *
      * @param addrs The addresses
      */
     public void addCc(final InternetAddress[] addrs) {
@@ -629,7 +638,7 @@ public abstract class MailMessage extends MailPart {
             try {
                 addCc(QuotedInternetAddress.parse(ccStr, true));
             } catch (final AddressException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.debug(e.getMessage(), e);
                 addCc(new PlainTextAddress(ccStr));
             }
         }
@@ -638,7 +647,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds an email address to <i>Bcc</i>
-     * 
+     *
      * @param addr The address
      */
     public void addBcc(final InternetAddress addr) {
@@ -654,7 +663,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds email addresses to <i>Bcc</i>
-     * 
+     *
      * @param addrs The addresses
      */
     public void addBcc(final InternetAddress[] addrs) {
@@ -696,7 +705,7 @@ public abstract class MailMessage extends MailPart {
             try {
                 addBcc(QuotedInternetAddress.parse(bccStr, true));
             } catch (final AddressException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.debug(e.getMessage(), e);
                 addBcc(new PlainTextAddress(bccStr));
             }
         }
@@ -705,7 +714,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the flags
-     * 
+     *
      * @return the flags
      */
     public int getFlags() {
@@ -799,7 +808,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the flags
-     * 
+     *
      * @param flags the flags to set
      */
     public void setFlags(final int flags) {
@@ -809,7 +818,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets a system flag
-     * 
+     *
      * @param flag The system flag to set
      * @param enable <code>true</code> to enable; otherwise <code>false</code>
      * @throws MailException If an illegal flag argument is specified
@@ -827,7 +836,7 @@ public abstract class MailMessage extends MailPart {
      * <p>
      * This flag is used when writing the message later on. There a check is performed whether header
      * <code>Disposition-Notification-To</code> is indicated or not.
-     * 
+     *
      * @return the previous \Seen state
      */
     public boolean isPrevSeen() {
@@ -854,7 +863,7 @@ public abstract class MailMessage extends MailPart {
      * <p>
      * This flag is used when writing the message later on. There a check is performed whether header
      * <code>Disposition-Notification-To</code> is indicated or not.
-     * 
+     *
      * @param prevSeen the previous \Seen state to set
      */
     public void setPrevSeen(final boolean prevSeen) {
@@ -864,7 +873,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the threadLevel
-     * 
+     *
      * @return the threadLevel
      */
     public int getThreadLevel() {
@@ -888,7 +897,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the threadLevel
-     * 
+     *
      * @param threadLevel the threadLevel to set
      */
     public void setThreadLevel(final int threadLevel) {
@@ -898,7 +907,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the subject
-     * 
+     *
      * @return the subject
      */
     public String getSubject() {
@@ -929,7 +938,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the subject
-     * 
+     *
      * @param subject the subject to set
      */
     public void setSubject(final String subject) {
@@ -946,7 +955,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the sent date which corresponds to <i>Date</i> header
-     * 
+     *
      * @return the sent date
      */
     public Date getSentDate() {
@@ -986,7 +995,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the sent date
-     * 
+     *
      * @param sentDate the sent date to set
      */
     public void setSentDate(final Date sentDate) {
@@ -996,7 +1005,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the received date which represents the internal timestamp set by mail server on arrival.
-     * 
+     *
      * @return The received date
      */
     public Date getReceivedDate() {
@@ -1005,7 +1014,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the received date directly which represents the internal timestamp set by mail server on arrival.
-     * 
+     *
      * @return The received date
      */
     public Date getReceivedDateDirect() {
@@ -1029,7 +1038,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the received date
-     * 
+     *
      * @param receivedDate the received date to set
      */
     public void setReceivedDate(final Date receivedDate) {
@@ -1039,7 +1048,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds given user flag
-     * 
+     *
      * @param userFlag The user flag to add
      */
     public void addUserFlag(final String userFlag) {
@@ -1054,7 +1063,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Adds given user flags
-     * 
+     *
      * @param userFlags The user flags to add
      */
     public void addUserFlags(final String[] userFlags) {
@@ -1088,7 +1097,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the user flags
-     * 
+     *
      * @return The user flags
      */
     public String[] getUserFlags() {
@@ -1109,7 +1118,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the color label
-     * 
+     *
      * @return the color label
      */
     public int getColorLabel() {
@@ -1133,7 +1142,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the color label
-     * 
+     *
      * @param colorLabel the color label to set
      */
     public void setColorLabel(final int colorLabel) {
@@ -1143,7 +1152,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the priority
-     * 
+     *
      * @return the priority
      */
     public int getPriority() {
@@ -1180,7 +1189,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the priority
-     * 
+     *
      * @param priority the priority to set
      */
     public void setPriority(final int priority) {
@@ -1190,7 +1199,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the dispositionNotification
-     * 
+     *
      * @return the dispositionNotification
      */
     public InternetAddress getDispositionNotification() {
@@ -1200,7 +1209,8 @@ public abstract class MailMessage extends MailPart {
                 try {
                     setDispositionNotification(new QuotedInternetAddress(dispNotTo, true));
                 } catch (final AddressException e) {
-                    LOG.error(e.getMessage(), e);
+                    LOG.debug(e.getMessage(), e);
+                    setDispositionNotification(new PlainTextAddress(dispNotTo));
                 }
             }
         }
@@ -1225,7 +1235,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the dispositionNotification
-     * 
+     *
      * @param dispositionNotification the dispositionNotification to set
      */
     public void setDispositionNotification(final InternetAddress dispositionNotification) {
@@ -1235,7 +1245,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the folder
-     * 
+     *
      * @return the folder
      */
     public String getFolder() {
@@ -1259,7 +1269,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the folder
-     * 
+     *
      * @param folder the folder to set
      */
     public void setFolder(final String folder) {
@@ -1269,7 +1279,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the account ID.
-     * 
+     *
      * @return The account ID
      */
     public int getAccountId() {
@@ -1293,7 +1303,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the account ID.
-     * 
+     *
      * @param accountId The account ID
      */
     public void setAccountId(final int accountId) {
@@ -1303,7 +1313,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the account Name
-     * 
+     *
      * @return The account name
      */
     public String getAccountName() {
@@ -1327,7 +1337,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the account Name
-     * 
+     *
      * @param accountName The account name
      */
     public void setAccountName(final String accountName) {
@@ -1337,7 +1347,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the hasAttachment
-     * 
+     *
      * @return the hasAttachment
      */
     public boolean hasAttachment() {
@@ -1361,7 +1371,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the hasAttachment
-     * 
+     *
      * @param hasAttachment the hasAttachment to set
      */
     public void setHasAttachment(final boolean hasAttachment) {
@@ -1398,7 +1408,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Gets the appendVCard
-     * 
+     *
      * @return the appendVCard
      */
     public boolean isAppendVCard() {
@@ -1422,7 +1432,7 @@ public abstract class MailMessage extends MailPart {
 
     /**
      * Sets the appendVCard
-     * 
+     *
      * @param appendVCard the appendVCard to set
      */
     public void setAppendVCard(final boolean appendVCard) {
@@ -1430,9 +1440,43 @@ public abstract class MailMessage extends MailPart {
         b_appendVCard = true;
     }
 
+    /**
+     * Gets the number of recent mails in associated folder.
+     *
+     * @return The recent count
+     */
+    public int getRecentCount() {
+        return recentCount;
+    }
+
+    /**
+     * @return <code>true</code> if number of recent mails is set; otherwise <code>false</code>
+     */
+    public boolean containsRecentCount() {
+        return b_recentCount;
+    }
+
+    /**
+     * Removes the recent count.
+     */
+    public void removeRecentCount() {
+        recentCount = 0;
+        b_recentCount = false;
+    }
+
+    /**
+     * Sets the number of recent mails in associated folder.
+     *
+     * @param recentCount The recent count
+     */
+    public void setRecentCount(final int recentCount) {
+        this.recentCount = recentCount;
+        b_recentCount = true;
+    }
+
     /**
      * Gets the mail path.
-     * 
+     *
      * @param accountId The account ID
      * @return The mail path
      */
@@ -1446,7 +1490,7 @@ public abstract class MailMessage extends MailPart {
      * <p>
      * <b>Note</b> If ID is numeric, max. 52 bits may be used in returned value which implies a max. allowed value of
      * <code>4503599627370495</code>.
-     * 
+     *
      * @return The ID of this mail or <code>null</code> if not available.
      */
     public abstract String getMailId();
@@ -1457,21 +1501,21 @@ public abstract class MailMessage extends MailPart {
      * <p>
      * <b>Note</b> If ID is numeric, max. 52 bits may be used in specified value which implies a max. allowed value of
      * <code>4503599627370495</code>.
-     * 
+     *
      * @param id The mail ID or <code>null</code> to indicate its absence
      */
     public abstract void setMailId(String id);
 
     /**
      * Gets the number of unread messages
-     * 
+     *
      * @return The number of unread messages
      */
     public abstract int getUnreadMessages();
 
     /**
      * Sets the number of unread messages
-     * 
+     *
      * @param unreadMessages The number of unread messages
      */
     public abstract void setUnreadMessages(int unreadMessages);
