@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,7 +71,7 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
  * {@link MailPart} - Abstract super class for all {@link MailPart} subclasses.
  * <p>
  * It's main purpose is to provide access to common part headers and part's content.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailPart implements Serializable, Cloneable {
@@ -112,7 +112,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     };
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailPart.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailPart.class));
 
     /**
      * The <code>Content-Type</code> header
@@ -184,7 +184,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the content type
-     * 
+     *
      * @return the content type
      */
     public ContentType getContentType() {
@@ -228,7 +228,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the content type
-     * 
+     *
      * @param contentType the contentType to set
      */
     public void setContentType(final ContentType contentType) {
@@ -238,7 +238,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Parses and sets the content type
-     * 
+     *
      * @param contentType the content type to parse
      * @throws MailException If content type is invalid or could not be parsed
      */
@@ -249,7 +249,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the disposition
-     * 
+     *
      * @return the disposition
      */
     public ContentDisposition getContentDisposition() {
@@ -284,7 +284,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the disposition
-     * 
+     *
      * @param disposition the disposition to set
      * @throws MailException If content disposition is invalid or could not be parsed
      */
@@ -295,7 +295,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the disposition
-     * 
+     *
      * @param disposition the disposition to set
      */
     public void setContentDisposition(final ContentDisposition disposition) {
@@ -305,7 +305,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the fileName
-     * 
+     *
      * @return the fileName
      */
     public String getFileName() {
@@ -336,13 +336,13 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the fileName
-     * 
+     *
      * @param fileName the fileName to set
      */
     public void setFileName(final String fileName) {
         this.fileName = fileName;
         if (null != this.fileName) {
-            contentType.setParameter("name", fileName);
+            contentType.setNameParameter(fileName);
             contentDisposition.setFilenameParameter(fileName);
         }
         b_fileName = true;
@@ -350,7 +350,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Adds a header
-     * 
+     *
      * @param name The header name
      * @param value The header value
      */
@@ -365,9 +365,26 @@ public abstract class MailPart implements Serializable, Cloneable {
         headers.addHeader(name, value);
     }
 
+    /**
+     * Sets a header
+     *
+     * @param name The header name
+     * @param value The header value
+     */
+    public void setHeader(final String name, final String value) {
+        if (null == value) {
+            return;
+        }
+        if (null == headers) {
+            headers = new HeaderCollection();
+            b_headers = true;
+        }
+        headers.setHeader(name, value);
+    }
+
     /**
      * Adds a header collection
-     * 
+     *
      * @param headers The header collection
      */
     public void addHeaders(final HeaderCollection headers) {
@@ -397,7 +414,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the number of headers
-     * 
+     *
      * @return The number of headers
      */
     public int getHeadersSize() {
@@ -409,7 +426,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets an instance of {@link Iterator} to iterate all headers
-     * 
+     *
      * @return An instance of {@link Iterator} to iterate all headers
      * @see #getHeadersSize()
      */
@@ -422,7 +439,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Checks for a header entry for specified header
-     * 
+     *
      * @param name The header name
      * @return <code>true</code> if a header entry exists for specified header; otherwise <code>false</code>
      */
@@ -435,7 +452,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets all the values for the specified header. Returns null if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @return The header values or <code>null</code>
      */
@@ -450,7 +467,7 @@ public abstract class MailPart implements Serializable, Cloneable {
      * Gets the first header for specified header name.
      * <p>
      * This is a convenience method that invokes {@link #getHeader(String, String)} with the latter parameter set to <code>null</code>.
-     * 
+     *
      * @param name The header name
      * @return The header's first value or <code>null</code>
      */
@@ -461,7 +478,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Gets all the headers for this header name, returned as a single String, with headers separated by the delimiter. If the delimiter is
      * <code>null</code>, only the first header is returned. Returns null if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @param delimiter The delimiter
      * @return The header values as a single String or <code>null</code>
@@ -476,7 +493,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Gets all the headers for this header name, returned as a single String, with headers separated by the delimiter. If the delimiter is
      * <code>'\0'</code>, only the first header is returned. Returns null if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @param delimiter The delimiter character
      * @return The header values as a single String or <code>null</code>
@@ -490,7 +507,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets a read-only version of this part's headers
-     * 
+     *
      * @return A read-only version of this part's headers
      */
     public HeaderCollection getHeaders() {
@@ -502,7 +519,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets an iterator for non-matching headers
-     * 
+     *
      * @param nonMatchingHeaders The non-matching headers
      * @return An iterator for non-matching headers
      */
@@ -515,7 +532,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets an iterator for matching headers
-     * 
+     *
      * @param matchingHeaders The matching headers
      * @return An iterator for matching headers or <code>null</code> if not exists
      */
@@ -528,7 +545,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Removes the header if present
-     * 
+     *
      * @param name The header name
      */
     public void removeHeader(final String name) {
@@ -539,7 +556,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Checks if this part contains all of specified headers.
-     * 
+     *
      * @param names The names of the headers to check
      * @return <code>true</code> if this part contains all of specified headers; otherwise <code>false</code>
      */
@@ -553,7 +570,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the size
-     * 
+     *
      * @return the size
      */
     public long getSize() {
@@ -577,7 +594,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the size
-     * 
+     *
      * @param size the size to set
      */
     public void setSize(final long size) {
@@ -587,7 +604,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the contentId
-     * 
+     *
      * @return the contentId
      */
     public String getContentId() {
@@ -618,7 +635,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the contentId
-     * 
+     *
      * @param contentId the contentId to set
      */
     public void setContentId(final String contentId) {
@@ -628,7 +645,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the sequenceId
-     * 
+     *
      * @return the sequenceId
      */
     public String getSequenceId() {
@@ -652,7 +669,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the sequenceId
-     * 
+     *
      * @param sequenceId the sequenceId to set
      */
     public void setSequenceId(final String sequenceId) {
@@ -662,7 +679,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the message reference
-     * 
+     *
      * @return the message reference
      */
     public MailPath getMsgref() {
@@ -704,7 +721,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Sets the message reference
-     * 
+     *
      * @param msgref the message reference to set
      */
     public void setMsgref(final MailPath msgref) {
@@ -734,7 +751,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Checks if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @return <code>true</code> if part holds enclosed parts; otherwise <code>false</code>
      * @throws MailException If check fails
      */
@@ -745,7 +762,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Returns the part's content as a Java object dependent on underlying implementation. <br>
      * This method is not applicable if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @return The content as a Java object or <code>null</code> if not applicable
      * @throws MailException If content cannot be returned as a Java object
      */
@@ -754,7 +771,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Returns an appropriate {@link DataHandler} for this mail part. <br>
      * This method is not applicable if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @return an appropriate {@link DataHandler} or <code>null</code> if not applicable
      * @throws MailException If an appropriate {@link DataHandler} cannot be returned
      */
@@ -763,7 +780,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Returns an input stream for this part. <br>
      * This method is not applicable if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @return An input stream for this part or <code>null</code> if not applicable
      * @throws MailException If no input stream could be returned
      */
@@ -772,7 +789,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Gets the number of enclosed mail parts. <br>
      * This method is only applicable if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @see #NO_ENCLOSED_PARTS
      * @return The number of enclosed mail parts or {@link #NO_ENCLOSED_PARTS} if not applicable
      */
@@ -781,7 +798,7 @@ public abstract class MailPart implements Serializable, Cloneable {
     /**
      * Gets the mail part located at given index. <br>
      * This method is only applicable if part's MIME type is <code>multipart/*</code>
-     * 
+     *
      * @param index The index of desired mail part or <code>null</code> if not applicable
      * @return The mail part
      */
@@ -794,23 +811,23 @@ public abstract class MailPart implements Serializable, Cloneable {
      * underlying connection closed, the part's content is no more accessible. Otherwise this method may be implemented with an empty body.
      * <p>
      * Moreover the loaded content is no more discarded when {@link #prepareForCaching()} is invoked.
-     * 
+     *
      * @throws MailException If loading part's content fails
      */
     public abstract void loadContent() throws MailException;
 
     /**
      * Writes complete part's data into given output stream
-     * 
+     *
      * @param out The output stream to write to
      * @throws MailException If writing to output stream fails
      */
     public void writeTo(final OutputStream out) throws MailException {
         final InputStream in = getInputStream();
+        if (null == in) {
+            throw new MailException(MailException.Code.NO_CONTENT);
+        }
         try {
-            if (null == in) {
-                throw new MailException(MailException.Code.NO_CONTENT);
-            }
             final byte[] buf = new byte[8192];
             int count = -1;
             while ((count = in.read(buf, 0, buf.length)) != -1) {
@@ -831,7 +848,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets the mail part's source
-     * 
+     *
      * @return The mail part's source
      * @throws MailException If mail part's source cannot be returned
      */
@@ -848,7 +865,7 @@ public abstract class MailPart implements Serializable, Cloneable {
 
     /**
      * Gets a newly allocated byte array containing the mail part's source bytes
-     * 
+     *
      * @return The mail part's source bytes
      * @throws MailException If mail part's source cannot be returned
      */
