@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,7 +66,6 @@ import com.openexchange.mail.MailException;
 import com.openexchange.mail.config.MailConfigException;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailPart;
-import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
@@ -75,12 +74,13 @@ import com.openexchange.mail.mime.datasource.StreamDataSource.InputStreamProvide
 import com.openexchange.mail.transport.config.TransportProperties;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.tools.io.IOUtils;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link DataMailPart}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class DataMailPart extends MailPart implements ComposedMailPart {
@@ -89,7 +89,7 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
 
     private static final int DEFAULT_BUF_SIZE = 0x2000;
 
-    private static transient final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DataMailPart.class);
+    private static transient final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DataMailPart.class));
 
     private static final int MB = 1048576;
 
@@ -105,7 +105,7 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
 
     /**
      * Initializes a new {@link DataMailPart}
-     * 
+     *
      * @param data The data (from a data source)
      * @param dataProperties The data properties
      * @param session The session
@@ -115,17 +115,21 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
         super();
         setHeaders(dataProperties);
         if (data instanceof InputStream) {
-            final InputStream inputStream = (InputStream) data;
+            /*
+             * Check data properties
+             */
             long size;
             try {
-                size = Long.parseLong(dataProperties.get(DataProperties.PROPERTY_SIZE));
+                final String sSize = dataProperties.get(DataProperties.PROPERTY_SIZE);
+                size = null == sSize ? 0 : Long.parseLong(sSize.trim());
                 setSize(size);
             } catch (final NumberFormatException e) {
                 size = 0;
             }
-            handleInputStream(inputStream, size);
+            handleInputStream((InputStream) data, size);
         } else if (data instanceof byte[]) {
             bytes = (byte[]) data;
+            setSize(bytes.length);
         } else {
             throw new MailException(MailException.Code.UNSUPPORTED_DATASOURCE);
         }
@@ -160,32 +164,41 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
     }
 
     private void copy2ByteArr(final InputStream in) throws IOException {
-        final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_BUF_SIZE << 1);
-        final byte[] bbuf = new byte[DEFAULT_BUF_SIZE];
-        int len;
-        while ((len = in.read(bbuf)) != -1) {
-            out.write(bbuf, 0, len);
+        try {
+            final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_BUF_SIZE << 1);
+            final byte[] bbuf = new byte[DEFAULT_BUF_SIZE];
+            int len;
+            while ((len = in.read(bbuf)) != -1) {
+                out.write(bbuf, 0, len);
+            }
+            out.flush();
+            bytes = out.toByteArray();
+            setSize(bytes.length);
+        } finally {
+            IOUtils.closeStreamStuff(in);
         }
-        out.flush();
-        bytes = out.toByteArray();
     }
 
     private void copy2File(final InputStream in) throws IOException {
-        final ManagedFileManagement mfm = ServerServiceRegistry.getInstance().getService(ManagedFileManagement.class);
-        if (null == mfm) {
-            throw new IOException("Missing file management");
-        }
-        final ManagedFile mf;
         try {
-            mf = mfm.createManagedFile(in);
-        } catch (final ManagedFileException e) {
-            final IOException ioerr = new IOException();
-            ioerr.initCause(e);
-            throw ioerr;
+            final ManagedFileManagement mfm = ServerServiceRegistry.getInstance().getService(ManagedFileManagement.class);
+            if (null == mfm) {
+                throw new IOException("Missing file management");
+            }
+            final ManagedFile mf;
+            try {
+                mf = mfm.createManagedFile(in);
+            } catch (final ManagedFileException e) {
+                final IOException ioerr = new IOException();
+                ioerr.initCause(e);
+                throw ioerr;
+            }
+            setSize(mf.getSize());
+            file = mf;
+            fileId = mf.getID();
+        } finally {
+            IOUtils.closeStreamStuff(in);
         }
-        setSize(mf.getSize());
-        file = mf;
-        fileId = mf.getID();
     }
 
     @Override
@@ -229,7 +242,7 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
             try {
                 final ContentType contentType = getContentType();
                 if (bytes != null) {
-                    if (!contentType.containsCharsetParameter() && contentType.startsWith(TEXT)) {
+                    if (contentType.startsWith(TEXT) && !contentType.containsCharsetParameter()) {
                         /*
                          * Add default mail charset
                          */
@@ -238,13 +251,14 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
                     return (dataSource = new MessageDataSource(bytes, contentType.toString()));
                 }
                 if (file != null) {
-                    if (!contentType.containsCharsetParameter() && contentType.startsWith(TEXT)) {
+                    if (contentType.startsWith(TEXT) && !contentType.containsCharsetParameter()) {
                         /*
                          * Add system charset
                          */
                         contentType.setCharsetParameter(System.getProperty("file.encoding", MailProperties.getInstance().getDefaultMimeCharset()));
                     }
                     final ManagedFile managedFile = file;
+                    final String fileName = getFileName();
                     final InputStreamProvider isp = new InputStreamProvider() {
 
                         public InputStream getInputStream() throws IOException {
@@ -258,7 +272,7 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
                         }
 
                         public String getName() {
-                            return null;
+                            return fileName;
                         }
                     };
                     return (dataSource = new StreamDataSource(isp, contentType.toString()));
@@ -334,7 +348,7 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
 
     /**
      * Gets this data part's file ID if its content has been written to disc.
-     * 
+     *
      * @return The file ID or <code>null</code> if content is kept inside rather than on disc.
      */
     public String getFileID() {
@@ -342,22 +356,31 @@ public abstract class DataMailPart extends MailPart implements ComposedMailPart
     }
 
     private void setHeaders(final Map<String, String> dataProperties) throws MailException {
-        if (!dataProperties.containsKey(DataProperties.PROPERTY_CONTENT_TYPE)) {
-            throw new MailException(MailException.Code.MISSING_PARAMETER, DataProperties.PROPERTY_CONTENT_TYPE);
+        String cts = dataProperties.get(DataProperties.PROPERTY_CONTENT_TYPE);
+        if (null != cts) {
+            setContentType(cts);
         }
-        final ContentType contentType = new ContentType(dataProperties.get(DataProperties.PROPERTY_CONTENT_TYPE));
-        if (dataProperties.containsKey(DataProperties.PROPERTY_CHARSET)) {
-            contentType.setCharsetParameter(dataProperties.get(DataProperties.PROPERTY_CHARSET));
+        final String charset = dataProperties.get(DataProperties.PROPERTY_CHARSET);
+        if (null != charset) {
+            final ContentType contentType = getContentType();
+            if (contentType.startsWith(TEXT)) {
+                /*
+                 * Charset only relevant for textual content
+                 */
+                contentType.setCharsetParameter(charset);
+            }
         }
-        setContentType(contentType);
-        final ContentDisposition contentDisposition = new ContentDisposition();
-        contentDisposition.setContentDisposition(Part.ATTACHMENT);
-        if (dataProperties.containsKey(DataProperties.PROPERTY_NAME)) {
-            final String filename = dataProperties.get(DataProperties.PROPERTY_NAME);
-            setFileName(filename);
-            contentDisposition.setFilenameParameter(filename);
+        final String disp = dataProperties.get(DataProperties.PROPERTY_DISPOSITION);
+        if (null == disp) {
+            getContentDisposition().setDisposition(Part.ATTACHMENT);
+        } else {
+            getContentDisposition().setDisposition(disp);
+        }
+        final String fileName = dataProperties.get(DataProperties.PROPERTY_NAME);
+        if (null != fileName) {
+            getContentType().setNameParameter(fileName);
+            getContentDisposition().setFilenameParameter(fileName);
         }
-        setContentDisposition(contentDisposition);
     }
 
 }
