@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -76,6 +76,7 @@ import com.openexchange.mail.transport.config.TransportConfig;
 import com.openexchange.mail.transport.config.TransportProperties;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.tools.io.IOUtils;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
@@ -85,14 +86,14 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
  * Since a mail part causes troubles when its input stream is read multiple times, corresponding data is either stored in an internal byte
  * array or copied as a temporary file to disk (depending on {@link TransportConfig#getReferencedPartLimit()}). Therefore this part needs
  * special handling to ensure removal of temporary file when it is dispatched.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class ReferencedMailPart extends MailPart implements ComposedMailPart {
 
     private static final long serialVersionUID = 1097727980840011436L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ReferencedMailPart.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ReferencedMailPart.class));
 
     protected static final int DEFAULT_BUF_SIZE = 0x2000;
 
@@ -116,7 +117,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
      * The referenced part's content is loaded dependent on its size. If size exceeds defined
      * {@link TransportConfig#getReferencedPartLimit() limit} its content is temporary written to disc; otherwise its content is kept inside
      * an array of <code>byte</code>.
-     * 
+     *
      * @param referencedPart The referenced part
      * @param session The session used to store a possible temporary disc file
      * @throws MailException If a mail error occurs
@@ -136,7 +137,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
      * The referenced mail's content is loaded dependent on its size. If size exceeds defined
      * {@link TransportConfig#getReferencedPartLimit() limit} its content is temporary written to disc; otherwise its content is kept inside
      * an array of <code>byte</code>.
-     * 
+     *
      * @param referencedMail The referenced mail
      * @param session The session used to store a possible temporary disc file
      * @throws MailException If a mail error occurs
@@ -153,7 +154,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
     /**
      * Handles referenced part dependent on its size. If size exceeds defined {@link TransportConfig#getReferencedPartLimit() limit} its
      * content is temporary written to disc; otherwise its content is kept inside an array of <code>byte</code>.
-     * 
+     *
      * @param referencedPart The referenced mail part
      * @param session The session to manage a possible temporary disc file
      * @return A file ID if content is written to disc; otherwise <code>null</code> to indicate content is held inside.
@@ -198,34 +199,40 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
     }
 
     private void copy2File(final InputStream in) throws IOException {
-        final ManagedFileManagement mfm = ServerServiceRegistry.getInstance().getService(ManagedFileManagement.class);
-        if (null == mfm) {
-            throw new IOException("Missing file management");
-        }
-        final ManagedFile mf;
         try {
-            mf = mfm.createManagedFile(in);
-        } catch (final ManagedFileException e) {
-            final IOException ioerr = new IOException();
-            ioerr.initCause(e);
-            throw ioerr;
+            final ManagedFileManagement mfm = ServerServiceRegistry.getInstance().getService(ManagedFileManagement.class);
+            if (null == mfm) {
+                throw new IOException("Missing file management");
+            }
+            final ManagedFile mf;
+            try {
+                mf = mfm.createManagedFile(in);
+            } catch (final ManagedFileException e) {
+                final IOException ioerr = new IOException();
+                ioerr.initCause(e);
+                throw ioerr;
+            }
+            setSize(mf.getSize());
+            file = mf;
+            fileId = mf.getID();
+        } finally {
+            IOUtils.closeStreamStuff(in);
         }
-        setSize(mf.getSize());
-        file = mf;
-        fileId = mf.getID();
     }
 
     private void copy2ByteArr(final InputStream in) throws IOException {
-        final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_BUF_SIZE << 1);
-        final byte[] bbuf = new byte[DEFAULT_BUF_SIZE];
-        int len;
-        int totalBytes = 0;
-        while ((len = in.read(bbuf)) != -1) {
-            out.write(bbuf, 0, len);
-            totalBytes += len;
+        try {
+            final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_BUF_SIZE << 1);
+            final byte[] bbuf = new byte[DEFAULT_BUF_SIZE];
+            int len;
+            while ((len = in.read(bbuf)) != -1) {
+                out.write(bbuf, 0, len);
+            }
+            out.flush();
+            data = out.toByteArray();
+        } finally {
+            IOUtils.closeStreamStuff(in);
         }
-        out.flush();
-        data = out.toByteArray();
     }
 
     private void setHeaders(final MailPart referencedPart) {
@@ -399,7 +406,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
 
     /**
      * Gets this referenced part's file ID if its content has been written to disc.
-     * 
+     *
      * @return The file ID or <code>null</code> if content is kept inside rather than on disc.
      */
     public String getFileID() {
@@ -408,7 +415,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
 
     /**
      * Checks if referenced part is a mail
-     * 
+     *
      * @return <code>true</code> if referenced part is a mail; otherwise <code>false</code>
      */
     public boolean isMail() {
@@ -418,7 +425,7 @@ public abstract class ReferencedMailPart extends MailPart implements ComposedMai
     /**
      * Generates a UUID using {@link UUID#randomUUID()}; e.g.:<br>
      * <i>a5aa65cb-6c7e-4089-9ce2-b107d21b9d15</i>
-     * 
+     *
      * @return A UUID string
      */
     private static String randomUUID() {
