@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,13 +54,15 @@ import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import javax.activation.DataHandler;
 import javax.activation.DataSource;
+import com.openexchange.html.HTMLService;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
+import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link TextBodyMailPart} - Designed to keep a mail's (text) body while offering a suitable implementation of {@link MailPart}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class TextBodyMailPart extends MailPart implements ComposedMailPart {
@@ -69,23 +71,25 @@ public abstract class TextBodyMailPart extends MailPart implements ComposedMailP
 
     private StringBuilder mailBody;
 
+    private StringBuilder plainText;
+
     private transient DataSource dataSource;
 
     /**
      * Constructs a new {@link TextBodyMailPart}
      * <p>
      * The body part is supposed to be HTML content which is ought to be converted to appropriate MIME type on transport.
-     * 
+     *
      * @param mailBody The mail body as HTML content
      */
     public TextBodyMailPart(final String mailBody) {
         super();
-        this.mailBody = new StringBuilder(mailBody);
+        this.mailBody = null == mailBody ? null : new StringBuilder(mailBody);
     }
 
-/**
+    /**
      * Gets a copy of this {@link TextBodyMailPart}.
-     * 
+     *
      * @return A copy of this {@link TextBodyMailPart
      * @throws MailException If creating a copy fails
      */
@@ -95,12 +99,12 @@ public abstract class TextBodyMailPart extends MailPart implements ComposedMailP
      * Fills specified instance with this body part's content.
      * <p>
      * This method is supposed to be invoked in subclass' {@link #copy()} method.
-     * 
+     *
      * @param newInstance The new instance to fill
      */
     protected final void fillInstance(final TextBodyMailPart newInstance) {
-        newInstance.mailBody = new StringBuilder(this.mailBody.length());
-        newInstance.mailBody.append(this.mailBody.toString());
+        newInstance.mailBody = null == mailBody ? null : new StringBuilder(mailBody.toString());
+        newInstance.plainText = null == plainText ? null : new StringBuilder(plainText.toString());
         newInstance.dataSource = null;
     }
 
@@ -108,21 +112,80 @@ public abstract class TextBodyMailPart extends MailPart implements ComposedMailP
      * Sets this part's text.
      * <p>
      * The body part is supposed to be HTML content which is ought to be converted to appropriate MIME type on transport.
-     * 
+     *
      * @param mailBody The mail body as HTML content
      */
     public void setText(final String mailBody) {
+        if (null == mailBody) {
+            this.mailBody = null;
+        }
+        if (null == this.mailBody) {
+            this.mailBody = new StringBuilder(mailBody);
+            return;
+        }
         this.mailBody.setLength(0);
         this.mailBody.append(mailBody);
     }
 
     /**
      * Appends specified HTML text to this part.
-     * 
-     * @param text The HTML content to append
+     *
+     * @param html The HTML text to append
      */
-    public void append(final String text) {
-        mailBody.append(text);
+    public void append(final String html) {
+        if (null == html) {
+            return;
+        }
+        if (null == this.mailBody) {
+            this.mailBody = new StringBuilder(html);
+            return;
+        }
+        mailBody.append(html);
+    }
+
+    /**
+     * Sets this part's optional plain text.
+     *
+     * @param text The mail body as plain text
+     */
+    public void setPlainText(final String text) {
+        if (null == plainText) {
+            plainText = new StringBuilder(text);
+        } else {
+            plainText.setLength(0);
+            plainText.append(text);
+        }
+    }
+
+    /**
+     * Gets this part's optional plain text.
+     *
+     * @return The mail body as plain text or <code>null</code>
+     */
+    public String getPlainText() {
+        return null == plainText ? null : plainText.toString();
+    }
+
+    /**
+     * Gets this part's HTML text.
+     *
+     * @return The mail body as HTML text or <code>null</code>
+     */
+    public String getHTML() {
+        return null == mailBody ? null : mailBody.toString();
+    }
+
+    /**
+     * Appends specified plain text to this part.
+     *
+     * @param text The plain text to append
+     */
+    public void appendPlainText(final String text) {
+        if (null == plainText) {
+            plainText = new StringBuilder(text);
+        } else {
+            plainText.append(text);
+        }
     }
 
     private DataSource getDataSource() throws MailException {
@@ -131,7 +194,7 @@ public abstract class TextBodyMailPart extends MailPart implements ComposedMailP
          */
         if (null == dataSource) {
             try {
-                dataSource = new MessageDataSource(mailBody.toString(), getContentType());
+                dataSource = new MessageDataSource(getHTMLContent(), getContentType());
             } catch (final UnsupportedEncodingException e) {
                 throw new MailException(MailException.Code.ENCODING_ERROR, e, e.getMessage());
             }
@@ -145,7 +208,18 @@ public abstract class TextBodyMailPart extends MailPart implements ComposedMailP
      */
     @Override
     public Object getContent() throws MailException {
-        return mailBody.toString();
+        return getHTMLContent();
+    }
+
+    private String getHTMLContent() throws MailException {
+        if (null != mailBody) {
+            return mailBody.toString();
+        }
+        if (null != plainText) {
+            final HTMLService htmlService = ServerServiceRegistry.getInstance().getService(HTMLService.class);
+            return htmlService.htmlFormat(plainText.toString());
+        }
+        throw new MailException(MailException.Code.UNEXPECTED_ERROR, "Missing text.");
     }
 
     /*
