@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,18 +59,21 @@ import java.io.InputStream;
 import javax.activation.DataHandler;
 import javax.activation.DataSource;
 import javax.mail.Part;
-import com.openexchange.groupware.upload.impl.UploadFile;
+import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.ContentDisposition;
+import com.openexchange.mail.mime.ContentType;
+import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.datasource.FileDataSource;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
+import com.openexchange.mail.utils.CharsetDetector;
 
 /**
  * {@link UploadFileMailPart} - A {@link MailPart} implementation that keeps a reference to a temporary uploaded file that shall be added as
  * an attachment later
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class UploadFileMailPart extends MailPart implements ComposedMailPart {
@@ -78,7 +81,7 @@ public abstract class UploadFileMailPart extends MailPart implements ComposedMai
     private static final long serialVersionUID = 257902073011243269L;
 
     private static final transient org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(UploadFileMailPart.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UploadFileMailPart.class));
 
     private final File uploadFile;
 
@@ -88,15 +91,45 @@ public abstract class UploadFileMailPart extends MailPart implements ComposedMai
 
     /**
      * Initializes a new {@link UploadFileMailPart}
-     * 
+     *
      * @param uploadFile The upload file
      * @throws MailException If upload file's content type cannot be parsed
      */
     protected UploadFileMailPart(final UploadFile uploadFile) throws MailException {
         super();
         this.uploadFile = uploadFile.getTmpFile();
-        setContentType(prepareContentType(uploadFile.getContentType()));
-        setFileName(uploadFile.getPreparedFileName());
+        final String preparedFileName = uploadFile.getPreparedFileName();
+        try {
+            setContentType(prepareContentType(uploadFile.getContentType(), preparedFileName));
+        } catch (final MailException e) {
+            // Retry with guess by file name
+            setContentType(MIMEType2ExtMap.getContentType(preparedFileName));
+        }
+        {
+            final ContentType contentType = getContentType();
+            if (contentType.startsWith("text/") && "GB18030".equalsIgnoreCase(contentType.getCharsetParameter())) {
+                InputStream in = null;
+                try {
+                    in = new FileInputStream(this.uploadFile);
+                    contentType.setCharsetParameter(CharsetDetector.detectCharset(in));
+                    setContentType(contentType);
+                } catch (final IOException e) {
+                    // Ignore
+                } finally {
+                    if (null != in) {
+                        try {
+                            in.close();
+                        } catch (final IOException e) {
+                            // Ignore
+                        }
+                    }
+                }
+            } else if (contentType.startsWith("application/force")) {
+                contentType.setBaseType(MIMEType2ExtMap.getContentType(preparedFileName));
+                setContentType(contentType);
+            }
+        }
+        setFileName(preparedFileName);
         setSize(uploadFile.getSize());
         final ContentDisposition cd = new ContentDisposition();
         cd.setDisposition(Part.ATTACHMENT);
@@ -104,13 +137,22 @@ public abstract class UploadFileMailPart extends MailPart implements ComposedMai
         setContentDisposition(cd);
     }
 
-    private static String prepareContentType(final String contentType) {
+    private static String prepareContentType(final String contentType, final String preparedFileName) {
         if (null == contentType || contentType.length() == 0) {
             return MIMETypes.MIME_APPL_OCTET;
         }
-        final int mlen = contentType.length() - 1;
-        if (0 == contentType.indexOf('"') && mlen == contentType.lastIndexOf('"')) {
-            return contentType.substring(1, mlen);
+        final String retval;
+        {
+            final int mlen = contentType.length() - 1;
+            if (0 == contentType.indexOf('"') && mlen == contentType.lastIndexOf('"')) {
+                retval = contentType.substring(1, mlen);
+            } else {
+                retval = contentType;
+            }
+        }
+        if ("multipart/form-data".equalsIgnoreCase(retval)) {
+            return MIMEType2ExtMap.getContentType(preparedFileName);
+
         }
         return contentType;
     }
@@ -145,7 +187,7 @@ public abstract class UploadFileMailPart extends MailPart implements ComposedMai
 
     /**
      * Gets the upload file associated with this mail part
-     * 
+     *
      * @return The upload file associated with this mail part
      */
     public File getUploadFile() {
