@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import java.util.concurrent.TimeUnit;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventAdmin;
 import com.openexchange.concurrent.Blocker;
-import com.openexchange.concurrent.NonBlockingBlocker;
+import com.openexchange.concurrent.ConcurrentBlocker;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.push.PushEventConstants;
@@ -70,12 +70,12 @@ import com.openexchange.timer.TimerService;
 
 /**
  * {@link EventPool} - The mail event pool.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class EventPool implements Runnable {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(EventPool.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(EventPool.class));
 
     /**
      * The delay for a pooled event. TODO: Make configurable
@@ -117,14 +117,14 @@ public final class EventPool implements Runnable {
 
     /**
      * Gets the event pool instance.
-     * 
+     *
      * @return The event pool instance
      */
     public static EventPool getInstance() {
         return instance;
     }
 
-    /*- 
+    /*-
      * ############################# Member section #############################
      */
 
@@ -140,14 +140,14 @@ public final class EventPool implements Runnable {
 
     /**
      * Initializes a new {@link EventPool}.
-     * 
+     *
      * @throws MailException If initialization fails
      */
     private EventPool() throws MailException {
         super();
         map = new ConcurrentHashMap<PooledEvent, PooledEvent>(1024);
         queue = new DelayQueue<PooledEvent>();
-        blocker = new NonBlockingBlocker();
+        blocker = new ConcurrentBlocker();
         try {
             eventAdmin = ServerServiceRegistry.getInstance().getService(EventAdmin.class, true);
         } catch (final ServiceException e) {
@@ -183,7 +183,7 @@ public final class EventPool implements Runnable {
 
     /**
      * Removes all pooled events from this pool associated with given user.
-     * 
+     *
      * @param userId The user ID
      * @param contextId The context ID
      */
@@ -204,7 +204,7 @@ public final class EventPool implements Runnable {
 
     /**
      * Puts given pooled event into this pool. If an equal pooled event is already present its time stamp is updated.
-     * 
+     *
      * @param pooledEvent The pooled event to put.
      */
     public void put(final PooledEvent pooledEvent) {
@@ -264,14 +264,14 @@ public final class EventPool implements Runnable {
                 } while ((pooledEvent = queue.poll()) != null);
             }
         } catch (final Throwable t) {
-            org.apache.commons.logging.LogFactory.getLog(EventPool.class).error(t.getMessage(), t);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(EventPool.class)).error(t.getMessage(), t);
         } finally {
             blocker.unblock();
         }
     }
 
     private void broadcastEvent(final PooledEvent pooledEvent) {
-        final Dictionary<String, Object> properties = new Hashtable<String, Object>();
+        final Dictionary<String, Object> properties = new Hashtable<String, Object>(6);
         properties.put(PushEventConstants.PROPERTY_CONTEXT, Integer.valueOf(pooledEvent.getContextId()));
         properties.put(PushEventConstants.PROPERTY_USER, Integer.valueOf(pooledEvent.getUserId()));
         properties.put(PushEventConstants.PROPERTY_SESSION, pooledEvent.getSession());
@@ -285,9 +285,13 @@ public final class EventPool implements Runnable {
         final String topic = pooledEvent.getTopic();
         final Event event = new Event(null == topic ? PushEventConstants.TOPIC : topic, properties);
         /*
-         * Finally post it
+         * Finally deliver it
          */
-        eventAdmin.postEvent(event);
+        if (pooledEvent.isAsync()) {
+            eventAdmin.postEvent(event);
+        } else {
+            eventAdmin.sendEvent(event);
+        }
         if (DEBUG_ENABLED) {
             LOG.debug(new StringBuilder(64).append("Notified ").append(pooledEvent.isContentRelated() ? "content-related" : "hierarchical").append(
                 "-wise changed folder \"").append(pooledEvent.getFullname()).append("\" in account ").append(pooledEvent.getAccountId()).append(
