@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,7 +56,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link PooledEvent} - A pooled event.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PooledEvent implements Delayed {
@@ -81,9 +81,11 @@ public final class PooledEvent implements Delayed {
 
     private final int hash;
 
+    private boolean async;
+
     /**
      * Initializes a new {@link PooledEvent} with {@link PushEventConstants#TOPIC default topic}.
-     * 
+     *
      * @param contextId The context ID
      * @param userId The user ID
      * @param accountId The account ID
@@ -98,7 +100,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Initializes a new {@link PooledEvent}.
-     * 
+     *
      * @param contextId The context ID
      * @param userId The user ID
      * @param accountId The account ID
@@ -109,6 +111,7 @@ public final class PooledEvent implements Delayed {
      */
     public PooledEvent(final String topic, final int contextId, final int userId, final int accountId, final String fullname, final boolean contentRelated, final boolean immediateDelivery, final Session session) {
         super();
+        async = true;
         this.topic = topic;
         stamp = System.currentTimeMillis();
         this.contextId = contextId;
@@ -131,19 +134,45 @@ public final class PooledEvent implements Delayed {
         hash = result;
     }
 
+    /**
+     * Sets whether the event should be delivered asynchronously (default behavior). If <code>false</code>
+     * {@link EventPool#put(PooledEvent)} does not return to the caller until delivery of the event is completed.
+     * <p>
+     * <b>Note</b>: Works only if this pooled event is considered for immediate delivery.
+     *
+     * @param async <code>true</code> to deliver asynchronously; otherwise <code>false</code>
+     * @return This pooled event with new behavior applied
+     */
+    public PooledEvent setAsync(final boolean async) {
+        this.async = async;
+        return this;
+    }
+
+    /**
+     * Checks whether the event should be delivered asynchronously.
+     *
+     * @return <code>true</code> to deliver asynchronously; otherwise <code>false</code>
+     */
+    public boolean isAsync() {
+        /*
+         * Asynchronous delivery if either non-immediate delivery or async
+         */
+        return !immediateDelivery || async;
+    }
+
     public long getDelay(final TimeUnit unit) {
         return immediateDelivery ? 0L : unit.convert(EventPool.MSEC_DELAY - (System.currentTimeMillis() - stamp), TimeUnit.MILLISECONDS);
     }
 
     public int compareTo(final Delayed o) {
-        final long thisStamp = this.stamp;
+        final long thisStamp = stamp;
         final long otherStamp = ((PooledEvent) o).stamp;
         return (thisStamp < otherStamp ? -1 : (thisStamp == otherStamp ? 0 : 1));
     }
 
     /**
      * Gets the topic for this event.
-     * 
+     *
      * @return The topic
      */
     public String getTopic() {
@@ -159,7 +188,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets this pooled notification's last-accessed time stamp.
-     * 
+     *
      * @return The last-accessed time stamp.
      */
     public long lastAccessed() {
@@ -168,7 +197,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Checks if this pooled events matches specified user ID and context ID.
-     * 
+     *
      * @param userId The user ID
      * @param contextId The context ID
      * @return <code>true</code> this pooled events matches; otherwise <code>false</code>
@@ -222,7 +251,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets the context ID.
-     * 
+     *
      * @return The context ID
      */
     public int getContextId() {
@@ -231,7 +260,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets the user ID.
-     * 
+     *
      * @return The user ID
      */
     public int getUserId() {
@@ -240,7 +269,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets the account ID.
-     * 
+     *
      * @return The account ID
      */
     public int getAccountId() {
@@ -249,7 +278,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets the fullname
-     * 
+     *
      * @return The fullname
      */
     public String getFullname() {
@@ -258,7 +287,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Gets the session
-     * 
+     *
      * @return The session
      */
     public Session getSession() {
@@ -267,7 +296,7 @@ public final class PooledEvent implements Delayed {
 
     /**
      * Checks for a content-related event.
-     * 
+     *
      * @return <code>true</code> for a content-related event; otherwise <code>false</code>
      */
     public boolean isContentRelated() {
