@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,9 @@
 
 package com.openexchange.mail.json.parser;
 
+import java.util.List;
+
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
@@ -57,21 +60,21 @@ import com.openexchange.mail.dataobjects.compose.TextBodyMailPart;
 
 /**
  * {@link IAttachmentHandler} - Tracks mail parts when parsing a mail.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-interface IAttachmentHandler {
+public interface IAttachmentHandler {
 
     /**
      * Sets the text part which may be modified.
-     * 
+     *
      * @param textBodyPart The text part to set
      */
     public void setTextPart(TextBodyMailPart textBodyPart);
 
     /**
      * Adds specified attachment.
-     * 
+     *
      * @param attachment The attachment to add
      * @throws MailException Depending on implementation it may indicate an exceeded quota, but other errors as well
      */
@@ -79,10 +82,10 @@ interface IAttachmentHandler {
 
     /**
      * Generates composed mails.
-     * 
+     *
      * @param source The source composed mail
      * @return The resulting composed mails
      * @throws MailException If an error occurs while filling mail
      */
-    public ComposedMailMessage[] generateComposedMails(ComposedMailMessage source) throws MailException;
+    public ComposedMailMessage[] generateComposedMails(ComposedMailMessage source, List<AbstractOXException> warnings) throws MailException;
 }
