@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.mail.json.parser;
 
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.parseAddressList;
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.quotePersonal;
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.shouldRetry;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
@@ -63,8 +64,11 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 import java.util.TimeZone;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import org.json.JSONArray;
@@ -81,12 +85,15 @@ import com.openexchange.conversion.SimpleData;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileException;
 import com.openexchange.filemanagement.ManagedFileManagement;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.groupware.upload.impl.UploadEvent;
-import com.openexchange.groupware.upload.impl.UploadFile;
+import com.openexchange.groupware.upload.impl.UploadFileImpl;
+import com.openexchange.html.HTMLService;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailJSONField;
@@ -106,12 +113,11 @@ import com.openexchange.mail.dataobjects.compose.UploadFileMailPart;
 import com.openexchange.mail.mime.HeaderCollection;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.ManagedMimeMessage;
 import com.openexchange.mail.mime.QuotedInternetAddress;
+import com.openexchange.mail.mime.utils.ImageMatcher;
 import com.openexchange.mail.parser.MailMessageParser;
 import com.openexchange.mail.parser.handlers.MultipleMailPartHandler;
-import com.openexchange.mail.text.HTMLProcessing;
-import com.openexchange.mail.text.parser.HTMLParser;
-import com.openexchange.mail.text.parser.handler.HTML2TextHandler;
 import com.openexchange.mail.transport.TransportProvider;
 import com.openexchange.mail.transport.TransportProviderRegistry;
 import com.openexchange.mail.transport.config.TransportProperties;
@@ -126,13 +132,13 @@ import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link MessageParser} - Parses instances of {@link JSONObject} to instances of {@link MailMessage}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a> - {@link #parseBasics(JSONObject, MailMessage, TimeZone)}
  */
 public final class MessageParser {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MessageParser.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MessageParser.class));
 
     /**
      * No instantiation
@@ -151,39 +157,41 @@ public final class MessageParser {
      * Completely parses given instance of {@link JSONObject} and given instance of {@link UploadEvent} to a corresponding
      * {@link ComposedMailMessage} object dedicated for being saved as a draft message. Moreover the user's quota limitations are
      * considered.
-     * 
+     *
      * @param jsonObj The JSON object
      * @param uploadEvent The upload event containing the uploaded files to attach
      * @param session The session
      * @param accountId The account ID
+     * @param warnings 
      * @return A corresponding instance of {@link ComposedMailMessage}
      * @throws MailException If parsing fails
      */
-    public static ComposedMailMessage parse4Draft(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId) throws MailException {
-        return parse(jsonObj, uploadEvent, session, accountId, null, null, false)[0];
+    public static ComposedMailMessage parse4Draft(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId, final List<AbstractOXException> warnings) throws MailException {
+        return parse(jsonObj, uploadEvent, session, accountId, null, null, false, warnings)[0];
     }
 
     /**
      * Completely parses given instance of {@link JSONObject} and given instance of {@link UploadEvent} to corresponding
      * {@link ComposedMailMessage} objects dedicated for being sent. Moreover the user's quota limitations are considered.
-     * 
+     *
      * @param jsonObj The JSON object
      * @param uploadEvent The upload event containing the uploaded files to attach
      * @param session The session
      * @param accountId The account ID
      * @param protocol The server's protocol
+     * @param warnings 
      * @param hostname The server's host name
      * @return The corresponding instances of {@link ComposedMailMessage}
      * @throws MailException If parsing fails
      */
-    public static ComposedMailMessage[] parse4Transport(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId, final String protocol, final String hostName) throws MailException {
-        return parse(jsonObj, uploadEvent, session, accountId, protocol, hostName, true);
+    public static ComposedMailMessage[] parse4Transport(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId, final String protocol, final String hostName, final List<AbstractOXException> warnings) throws MailException {
+        return parse(jsonObj, uploadEvent, session, accountId, protocol, hostName, true, warnings);
     }
 
     /**
      * Completely parses given instance of {@link JSONObject} and given instance of {@link UploadEvent} to corresponding
      * {@link ComposedMailMessage} objects. Moreover the user's quota limitations are considered.
-     * 
+     *
      * @param jsonObj The JSON object
      * @param uploadEvent The upload event containing the uploaded files to attach
      * @param session The session
@@ -192,14 +200,16 @@ public final class MessageParser {
      * @param hostname The server's host name
      * @param prepare4Transport <code>true</code> to parse with the intention to transport returned mail later on; otherwise
      *            <code>false</code>
+     * @param warnings 
      * @return The corresponding instances of {@link ComposedMailMessage}
      * @throws MailException If parsing fails
      */
-    private static ComposedMailMessage[] parse(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId, final String protocol, final String hostName, final boolean prepare4Transport) throws MailException {
+    private static ComposedMailMessage[] parse(final JSONObject jsonObj, final UploadEvent uploadEvent, final Session session, final int accountId, final String protocol, final String hostName, final boolean prepare4Transport, final List<AbstractOXException> warnings) throws MailException {
         try {
             final TransportProvider provider = TransportProviderRegistry.getTransportProviderBySession(session, accountId);
             final Context ctx = ContextStorage.getStorageContext(session.getContextId());
             final ComposedMailMessage composedMail = provider.getNewComposedMailMessage(session, ctx);
+            composedMail.setAccountId(accountId);
             /*
              * Select appropriate handler
              */
@@ -289,14 +299,20 @@ public final class MessageParser {
                 final JSONArray ja = jsonObj.getJSONArray(MailJSONField.INFOSTORE_IDS.getKey());
                 final int length = ja.length();
                 for (int i = 0; i < length; i++) {
-                    final InfostoreDocumentMailPart part = provider.getNewDocumentPart(ja.getInt(i), session);
+                    final InfostoreDocumentMailPart part = provider.getNewDocumentPart(ja.getString(i), session);
                     attachmentHandler.addAttachment(part);
                 }
             }
             /*
              * Fill composed mail
              */
-            return attachmentHandler.generateComposedMails(composedMail);
+            final ComposedMailMessage[] ret = attachmentHandler.generateComposedMails(composedMail, warnings);
+            for (final ComposedMailMessage mail : ret) {
+                if (!mail.containsAccountId()) {
+                    mail.setAccountId(accountId);
+                }
+            }
+            return ret;
         } catch (final JSONException e) {
             throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
         } catch (final ContextException e) {
@@ -308,17 +324,33 @@ public final class MessageParser {
         if (!json.hasAndNotNull(JSON_ARGS)) {
             return DataArguments.EMPTY_ARGS;
         }
-        final JSONArray jsonArray = json.getJSONArray(JSON_ARGS);
-        final int len = jsonArray.length();
-        final DataArguments dataArguments = new DataArguments(len);
-        for (int i = 0; i < len; i++) {
-            final JSONObject elem = jsonArray.getJSONObject(i);
-            if (elem.length() == 1) {
-                final String key = elem.keys().next();
-                dataArguments.put(key, elem.getString(key));
-            } else {
-                LOG.warn("Corrupt data argument in JSON object: " + elem.toString());
+        final Object args = json.get(JSON_ARGS);
+        if (args instanceof JSONArray) {
+            /*
+             * Handle as JSON array
+             */
+            final JSONArray jsonArray = (JSONArray) args;
+            final int len = jsonArray.length();
+            final DataArguments dataArguments = new DataArguments(len);
+            for (int i = 0; i < len; i++) {
+                final JSONObject elem = jsonArray.getJSONObject(i);
+                if (elem.length() == 1) {
+                    final String key = elem.keys().next();
+                    dataArguments.put(key, elem.getString(key));
+                } else {
+                    LOG.warn("Corrupt data argument in JSON object: " + elem.toString());
+                }
             }
+            return dataArguments;
+        }
+        /*
+         * Expect JSON object
+         */
+        final JSONObject argsObject = (JSONObject) args;
+        final int len = argsObject.length();
+        final DataArguments dataArguments = new DataArguments(len);
+        for (final Entry<String, Object> entry : argsObject.entrySet()) {
+            dataArguments.put(entry.getKey(), entry.getValue().toString());
         }
         return dataArguments;
     }
@@ -344,7 +376,7 @@ public final class MessageParser {
     /**
      * Parses given instance of {@link JSONObject} to given instance of {@link MailMessage}. Moreover the user's quota limitations are
      * considered.
-     * 
+     *
      * @param jsonObj The JSON object (source)
      * @param mail The mail(target), which should be empty
      * @param session The session
@@ -364,7 +396,7 @@ public final class MessageParser {
     /**
      * Parses given instance of {@link JSONObject} to given instance of {@link MailMessage}. Moreover the user's quota limitations are
      * considered.
-     * 
+     *
      * @param jsonObj The JSON object (source)
      * @param mail The mail(target), which should be empty
      * @param timeZone The user time zone
@@ -402,15 +434,24 @@ public final class MessageParser {
                      * Parse body text
                      */
                     final JSONObject tmp = attachmentArray.getJSONObject(0);
-                    final TextBodyMailPart part = provider.getNewTextBodyPart(tmp.getString(MailJSONField.CONTENT.getKey()));
-                    part.setContentType(parseContentType(tmp.getString(MailJSONField.CONTENT_TYPE.getKey())));
+                    final String sContent = tmp.getString(MailJSONField.CONTENT.getKey());
+                    final TextBodyMailPart part = provider.getNewTextBodyPart(sContent);
+                    final String contentType = parseContentType(tmp.getString(MailJSONField.CONTENT_TYPE.getKey()));
+                    part.setContentType(contentType);
+                    if (contentType.startsWith("text/plain") && tmp.hasAndNotNull("raw") && tmp.getBoolean("raw")) {
+                        part.setPlainText(sContent);
+                    }
                     transportMail.setContentType(part.getContentType());
                     // Add text part
                     attachmentHandler.setTextPart(part);
                     /*
                      * Parse referenced parts
                      */
-                    parseReferencedParts(provider, session, accountId, transportMail.getMsgref(), attachmentHandler, attachmentArray);
+                    final int len = attachmentArray.length();
+                    if (len > 1) {
+                        final Set<String> contentIds = extractContentIds(sContent);
+                        parseReferencedParts(provider, session, accountId, transportMail.getMsgref(), attachmentHandler, attachmentArray, contentIds, prepare4Transport);
+                    }
                 } else {
                     final TextBodyMailPart part = provider.getNewTextBodyPart("");
                     part.setContentType(MIMETypes.MIME_DEFAULT);
@@ -429,10 +470,28 @@ public final class MessageParser {
         }
     }
 
+    private static final Pattern PATTERN_ID_ATTRIBUTE = Pattern.compile("id=\"((?:\\\\\\\"|[^\"])+?)\"");
+
+    private static Set<String> extractContentIds(final String htmlContent) {
+        final ImageMatcher m = ImageMatcher.matcher(htmlContent);
+        if (!m.find()) {
+            return Collections.emptySet();
+        }
+        final Set<String> set = new HashSet<String>(4);
+        do {
+            final String imageTag = m.group();
+            final Matcher tmp = PATTERN_ID_ATTRIBUTE.matcher(imageTag);
+            if (tmp.find()) {
+                set.add(tmp.group(1));
+            }
+        } while (m.find());
+        return set;
+    }
+
     /**
      * Takes a mail as jsonObj and extracts the values into a given MailMessage object. Handles all basic values that do not need
      * information about the session, like attachments.
-     * 
+     *
      * @param jsonObj
      * @param mail
      * @param timeZone
@@ -479,7 +538,7 @@ public final class MessageParser {
             final Iterator<String> iter = obj.keys();
             for (int i = 0; i < size; i++) {
                 final String key = iter.next();
-                if (isCustomHeader(key)) {
+                if (isCustomHeader(key) && !key.equalsIgnoreCase("x-original-headers")) {
                     headers.addHeader(key, obj.getString(key));
                 }
             }
@@ -488,7 +547,21 @@ public final class MessageParser {
         /*
          * From Only mandatory if non-draft message
          */
-        mail.addFrom(parseAddressKey(MailJSONField.FROM.getKey(), jsonObj, prepare4Transport));
+        final String fromKey = MailJSONField.FROM.getKey();
+        if (jsonObj.hasAndNotNull(fromKey)) {
+            try {
+                String value = jsonObj.getString(fromKey);
+                final int endPos;
+                if ('[' == value.charAt(0) && (endPos = value.indexOf(']', 1)) < value.length()) {
+                    value = new StringBuilder(32).append("\"[").append(value.substring(1, endPos)).append("]\"").append(value.substring(endPos+1)).toString();
+                }
+                mail.addFrom(parseAddressList(value, true, true));
+            } catch (final AddressException e) {
+                mail.addFrom(parseAddressKey(fromKey, jsonObj, prepare4Transport));
+            }
+        } else if (prepare4Transport) {
+            throw new MailException(MailException.Code.MISSING_FIELD, fromKey);
+        }
         /*
          * To Only mandatory if non-draft message
          */
@@ -501,6 +574,15 @@ public final class MessageParser {
          * Bcc
          */
         mail.addBcc(parseAddressKey(MailJSONField.RECIPIENT_BCC.getKey(), jsonObj, prepare4Transport));
+        /*
+         * Optional Reply-To
+         */
+        {
+            final InternetAddress[] addrs = parseAddressKey("reply_to", jsonObj, false);
+            if (null != addrs && addrs.length > 0) {
+                mail.setHeader("Reply-To", addrs[0].toString());
+            }
+        }
         /*
          * Disposition notification
          */
@@ -578,11 +660,15 @@ public final class MessageParser {
             final int offset = timeZone.getOffset(date.getTime());
             mail.setReceivedDate(new Date(jsonObj.getLong(MailJSONField.RECEIVED_DATE.getKey()) - offset));
         }
+        /*
+         * Drop special "x-original-headers" header
+         */
+        mail.removeHeader("x-original-headers");
     }
 
     /**
      * Checks if specified header name is a custom header that is it starts ignore-case with <code>"X-"</code>.
-     * 
+     *
      * @param headerName The header name to check
      * @return <code>true</code> if specified header name is a custom header; otherwise <code>false</code>
      */
@@ -598,19 +684,13 @@ public final class MessageParser {
 
     private static final String FILE_PREFIX = "file://";
 
-    private static void parseReferencedParts(final TransportProvider provider, final Session session, final int accountId, final MailPath transportMailMsgref, final IAttachmentHandler attachmentHandler, final JSONArray attachmentArray) throws MailException, JSONException {
+    private static void parseReferencedParts(final TransportProvider provider, final Session session, final int accountId, final MailPath transportMailMsgref, final IAttachmentHandler attachmentHandler, final JSONArray attachmentArray, final Set<String> contentIds, final boolean prepare4Transport) throws MailException, JSONException {
         final int len = attachmentArray.length();
-        if (len <= 1) {
-            /*
-             * We start at index 1 to skip the body part, so no attachment available
-             */
-            return;
-        }
         /*
          * Group referenced parts by referenced mails' paths
          */
         final Map<String, ReferencedMailPart> groupedReferencedParts =
-            groupReferencedParts(provider, session, transportMailMsgref, attachmentArray);
+            groupReferencedParts(provider, session, transportMailMsgref, attachmentArray, contentIds, prepare4Transport);
         /*
          * Iterate attachments array
          */
@@ -633,14 +713,12 @@ public final class MessageParser {
                          * UI delivers HTML content in any case. Generate well-formed HTML for further processing dependent on given content
                          * type.
                          */
-                        final String validHtml =
-                            HTMLProcessing.getConformHTML(attachment.getString(MailJSONField.CONTENT.getKey()), "US-ASCII");
+                        final HTMLService htmlService = ServerServiceRegistry.getInstance().getService(HTMLService.class);
+                        final String conformHTML = htmlService.getConformHTML(attachment.getString(MailJSONField.CONTENT.getKey()), "US-ASCII");
                         if (MIMETypes.MIME_TEXT_PLAIN.equals(contentType)) {
-                            final HTML2TextHandler html2textHandler = new HTML2TextHandler(4096, true);
-                            HTMLParser.parse(validHtml, html2textHandler);
-                            content = html2textHandler.getText().getBytes(charsetName);
+                            content = htmlService.html2text(conformHTML, true).getBytes(charsetName);
                         } else {
-                            content = validHtml.getBytes(charsetName);
+                            content = conformHTML.getBytes(charsetName);
                         }
 
                     } catch (final UnsupportedEncodingException e) {
@@ -693,17 +771,31 @@ public final class MessageParser {
                          * The mail itself
                          */
                         if (null == access) {
-                            access = MailAccess.getInstance(session);
+                            access = MailAccess.getInstance(session, msgref.getAccountId());
                             access.connect();
                         }
-                        final MailMessage referencedMail =
+                        MailMessage referencedMail =
                             access.getMessageStorage().getMessage(msgref.getFolder(), msgref.getMailID(), false);
+                        if (null == referencedMail) {
+                            throw new MailException(MailException.Code.REFERENCED_MAIL_NOT_FOUND, msgref.getMailID(), msgref.getFolder());
+                        }
+                        referencedMail.setAccountId(access.getAccountId());
+                        referencedMail = ManagedMimeMessage.clone(referencedMail);
                         referencedMailPart = provider.getNewReferencedMail(referencedMail, session);
                     } else {
-                        referencedMailPart = groupedReferencedParts.get(seqId);
+                        ReferencedMailPart tmp = groupedReferencedParts.get(seqId);
+                        if (null != tmp && tmp.containsContentId()) {
+                            final String contentId = tmp.getContentId();
+                            if (null != contentId && contentIds.contains('<' == contentId.charAt(0) ? contentId.substring(1, contentId.length()-1) : contentId)) {
+                                tmp = null;
+                            }
+                        }
+                        referencedMailPart = tmp;
+                    }
+                    if (null != referencedMailPart) {
+                        referencedMailPart.setMsgref(msgref);
+                        attachmentHandler.addAttachment(referencedMailPart);
                     }
-                    referencedMailPart.setMsgref(msgref);
-                    attachmentHandler.addAttachment(referencedMailPart);
                 }
             }
         } finally {
@@ -713,12 +805,12 @@ public final class MessageParser {
         }
     }
 
-    private static Map<String, ReferencedMailPart> groupReferencedParts(final TransportProvider provider, final Session session, final MailPath parentMsgRef, final JSONArray attachmentArray) throws MailException, JSONException {
+    private static Map<String, ReferencedMailPart> groupReferencedParts(final TransportProvider provider, final Session session, final MailPath parentMsgRef, final JSONArray attachmentArray, final Set<String> contentIds, final boolean prepare4Transport) throws MailException, JSONException {
         if (null == parentMsgRef) {
             return Collections.emptyMap();
         }
         final int len = attachmentArray.length();
-        final Set<String> groupedSeqIDs = new HashSet<String>(len);
+        final Map<String, String> groupedSeqIDs = new HashMap<String, String>(len);
         NextAttachment: for (int i = 1; i < len; i++) {
             final JSONObject attachment = attachmentArray.getJSONObject(i);
             final String seqId =
@@ -733,7 +825,8 @@ public final class MessageParser {
              * If MSGREF is defined in attachment itself, the MSGREF's mail is meant to be attached and not a nested attachment
              */
             if (!attachment.hasAndNotNull(MailJSONField.MSGREF.getKey())) {
-                groupedSeqIDs.add(seqId);
+                final Object cid = attachment.opt(MailJSONField.CID.getKey());
+                groupedSeqIDs.put(seqId, null == cid ? "" : cid.toString());
             }
         }
         /*
@@ -742,28 +835,54 @@ public final class MessageParser {
         if (groupedSeqIDs.isEmpty()) {
             return Collections.emptyMap();
         }
-        final Map<String, ReferencedMailPart> retval = new HashMap<String, ReferencedMailPart>(len);
-        final MailAccess<?, ?> access = MailAccess.getInstance(session, parentMsgRef.getAccountId());
-        access.connect();
+        Map<String, ReferencedMailPart> retval = null;
+        MailAccess<?, ?> access = null;
         try {
-            final MailMessage referencedMail =
-                access.getMessageStorage().getMessage(parentMsgRef.getFolder(), parentMsgRef.getMailID(), false);
-            if (null == referencedMail) {
-                throw new MailException(MailException.Code.REFERENCED_MAIL_NOT_FOUND, parentMsgRef.getMailID(), parentMsgRef.getFolder());
-            }
-            // Get attachments out of referenced mail
-            final MultipleMailPartHandler handler = new MultipleMailPartHandler(groupedSeqIDs, true);
-            new MailMessageParser().parseMailMessage(referencedMail, handler);
-            final Set<Map.Entry<String, MailPart>> results = handler.getMailParts().entrySet();
-            for (final Map.Entry<String, MailPart> e : results) {
-                retval.put(e.getKey(), provider.getNewReferencedPart(e.getValue(), session));
+            access = MailAccess.getInstance(session, parentMsgRef.getAccountId());
+            access.connect();
+            retval = new HashMap<String, ReferencedMailPart>(len);
+            handleMultipleRefs(provider, session, parentMsgRef, contentIds, prepare4Transport, groupedSeqIDs, retval, access);
+        } catch (final MailException me) {
+            if (null == access || !shouldRetry(me)) {
+                throw me;
             }
+            access = MailAccess.reconnect(access);
+            retval = new HashMap<String, ReferencedMailPart>(len);
+            handleMultipleRefs(provider, session, parentMsgRef, contentIds, prepare4Transport, groupedSeqIDs, retval, access);
         } finally {
-            access.close(true);
+            if (null != access) {
+                access.close(true);
+            }
         }
         return retval;
     }
 
+    private static void handleMultipleRefs(final TransportProvider provider, final Session session, final MailPath parentMsgRef, final Set<String> contentIds, final boolean prepare4Transport, final Map<String, String> groupedSeqIDs, final Map<String, ReferencedMailPart> retval, final MailAccess<?, ?> access) throws MailException {
+        MailMessage referencedMail =
+            access.getMessageStorage().getMessage(parentMsgRef.getFolder(), parentMsgRef.getMailID(), false);
+        if (null == referencedMail) {
+            throw new MailException(MailException.Code.REFERENCED_MAIL_NOT_FOUND, parentMsgRef.getMailID(), parentMsgRef.getFolder());
+        }
+        referencedMail.setAccountId(access.getAccountId());
+        referencedMail = ManagedMimeMessage.clone(referencedMail);
+        // Get attachments out of referenced mail
+        final Set<String> remaining = new HashSet<String>(groupedSeqIDs.keySet());
+        final MultipleMailPartHandler handler = new MultipleMailPartHandler(groupedSeqIDs.keySet(), false);
+        new MailMessageParser().parseMailMessage(referencedMail, handler);
+        for (final Map.Entry<String, MailPart> e : handler.getMailParts().entrySet()) {
+            final String seqId = e.getKey();
+            retval.put(seqId, provider.getNewReferencedPart(e.getValue(), session));
+            remaining.remove(seqId);
+        }
+        if (prepare4Transport && !remaining.isEmpty()) {
+            for (final String seqId : remaining) {
+                if (!contentIds.contains(seqId)) {
+                    throw new MailException(MailException.Code.ATTACHMENT_NOT_FOUND, seqId, Long.valueOf(referencedMail.getMailId()), referencedMail.getFolder());
+                }
+            }
+        }
+    }
+
     private static void processReferencedUploadFile(final TransportProvider provider, final ManagedFileManagement management, final String seqId, final IAttachmentHandler attachmentHandler) throws MailException {
         /*
          * A file reference
@@ -776,7 +895,7 @@ public final class MessageParser {
             return;
         }
         // Create wrapping upload file
-        final UploadFile wrapper = new UploadFile();
+        final UploadFile wrapper = new UploadFileImpl();
         wrapper.setContentType(managedFile.getContentType());
         wrapper.setFileName(managedFile.getFileName());
         wrapper.setSize(managedFile.getSize());
@@ -800,7 +919,7 @@ public final class MessageParser {
 
     /**
      * Parses "From" field out of passed JSON object.
-     * 
+     *
      * @param jo The JSON object
      * @return The parsed "From" address
      * @throws AddressException If parsing the address fails
@@ -812,7 +931,7 @@ public final class MessageParser {
 
     /**
      * Parses address field out of passed JSON object.
-     * 
+     *
      * @param key The key of the address field
      * @param jo The JSON object
      * @return The parsed address(es)
@@ -827,7 +946,7 @@ public final class MessageParser {
 
     /**
      * Parses address field out of passed JSON object.
-     * 
+     *
      * @param key The key of the address field
      * @param jo The JSON object
      * @return The parsed address(es)
@@ -858,16 +977,16 @@ public final class MessageParser {
                 value = jo.getString(key);
             }
         }
-        return parseAddressList(value, false, true);
+        return parseAddressList(value, true, true);
     }
 
     /**
      * Expects the specified JSON array to be an array of arrays. Each inner array conforms to pattern:
-     * 
+     *
      * <pre>
      * [&quot;&lt;personal&gt;&quot;, &quot;&lt;email-address&gt;&quot;]
      * </pre>
-     * 
+     *
      * @param jsonArray The JSON array
      * @return Parsed address list combined in a {@link String} object
      * @throws JSONException If a JSON error occurs
