@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,6 @@ import static com.openexchange.groupware.upload.impl.UploadUtility.getSize;
 import static com.openexchange.mail.mime.converters.MIMEMessageConverter.convertPart;
 import static com.openexchange.mail.text.HTMLProcessing.getConformHTML;
 import static com.openexchange.mail.text.HTMLProcessing.htmlFormat;
-
 import java.io.IOException;
 import java.io.InputStream;
 import java.text.DateFormat;
@@ -68,23 +67,24 @@ import java.util.Map;
 import java.util.Set;
 import java.util.regex.Pattern;
 import javax.mail.MessagingException;
+import javax.mail.internet.IDNA;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeBodyPart;
-import com.openexchange.ajax.Infostore;
-import com.openexchange.api2.OXException;
+import com.openexchange.file.storage.DefaultFile;
+import com.openexchange.file.storage.File;
+import com.openexchange.file.storage.FileStorageException;
+import com.openexchange.file.storage.FileStorageFileAccess;
+import com.openexchange.file.storage.composition.IDBasedFileAccess;
+import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.i18n.MailStrings;
-import com.openexchange.groupware.infostore.DocumentMetadata;
-import com.openexchange.groupware.infostore.InfostoreException;
-import com.openexchange.groupware.infostore.InfostoreFacade;
-import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
-import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailSessionParameterNames;
@@ -93,7 +93,6 @@ import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.dataobjects.compose.TextBodyMailPart;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MessageHeaders;
-import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.transport.TransportProvider;
 import com.openexchange.mail.transport.config.TransportProperties;
@@ -106,18 +105,18 @@ import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
-import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tx.TransactionException;
 import com.openexchange.user.UserService;
 
 /**
  * {@link PublishAttachmentHandler} - An {@link IAttachmentHandler attachment handler} that publishes attachments on exceeded quota (either
  * overall or per-file quota).
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-final class PublishAttachmentHandler extends AbstractAttachmentHandler {
+public final class PublishAttachmentHandler extends AbstractAttachmentHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PublishAttachmentHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PublishAttachmentHandler.class));
 
     private final Session session;
 
@@ -127,7 +126,9 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
 
     private final String hostName;
 
-    private boolean exceeded;
+    private final IDBasedFileAccessFactory fileAccessFactory;
+
+    private boolean exceeded = false;
 
     private TextBodyMailPart textPart;
 
@@ -135,7 +136,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
 
     /**
      * Initializes a new {@link PublishAttachmentHandler}.
-     * 
+     *
      * @param session The session providing needed user information
      * @param transportProvider The transport provider
      * @param protocol The server's protocol
@@ -148,6 +149,11 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
         this.hostName = hostName;
         this.transportProvider = transportProvider;
         this.session = session;
+        try {
+            fileAccessFactory = ServerServiceRegistry.getInstance().getService(IDBasedFileAccessFactory.class, true);
+        } catch (final ServiceException e) {
+            throw new MailException(e);
+        }
     }
 
     public void setTextPart(final TextBodyMailPart textPart) {
@@ -169,8 +175,10 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                             Long.valueOf(uploadQuotaPerFile),
                             null == fileName ? "" : fileName,
                             Long.valueOf(size));
-                    LOG.debug(new StringBuilder(64).append("Per-file quota (").append(getSize(uploadQuotaPerFile, 2, false, true)).append(
-                        ") exceeded. Message is going to be sent with links to publishing infostore folder.").toString(), e);
+                    LOG.debug(
+                        new StringBuilder(64).append("Per-file quota (").append(getSize(uploadQuotaPerFile, 2, false, true)).append(
+                            ") exceeded. Message is going to be sent with links to publishing infostore folder.").toString(),
+                        e);
                 }
                 exceeded = true;
             } else {
@@ -181,8 +189,10 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                 if (uploadQuota > 0 && consumed > uploadQuota) {
                     if (LOG.isDebugEnabled()) {
                         final MailException e = new MailException(MailException.Code.UPLOAD_QUOTA_EXCEEDED, Long.valueOf(uploadQuota));
-                        LOG.debug(new StringBuilder(64).append("Overall quota (").append(getSize(uploadQuota, 2, false, true)).append(
-                            ") exceeded. Message is going to be sent with links to publishing infostore folder.").toString(), e);
+                        LOG.debug(
+                            new StringBuilder(64).append("Overall quota (").append(getSize(uploadQuota, 2, false, true)).append(
+                                ") exceeded. Message is going to be sent with links to publishing infostore folder.").toString(),
+                            e);
                     }
                     exceeded = true;
                 }
@@ -190,8 +200,10 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
         }
         attachments.add(attachment);
     }
-
-    public ComposedMailMessage[] generateComposedMails(final ComposedMailMessage source) throws MailException {
+    
+   public ComposedMailMessage[] generateComposedMails(
+		ComposedMailMessage source, List<AbstractOXException> warnings)
+		throws MailException {
         if (!exceeded) {
             /*
              * No quota exceeded, return prepared source
@@ -242,18 +254,19 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
             throw new MailException(e);
         }
         try {
+        	warnings.add (new MailException(MailException.Code.USED_PUBLISHING_FEATURE));
             return generateComposedMails0(source, publications, folderId, target, publisher, ctx);
         } catch (final MailException e) {
             /*
              * Rollback of publications
              */
-            rollbackPublications(publications, publisher, ctx);
+            rollbackPublications(publications, publisher);
             /*
              * Re-throw exception
              */
             throw e;
         }
-    }
+	}
 
     private ComposedMailMessage[] generateComposedMails0(final ComposedMailMessage source, final List<PublicationAndInfostoreID> publications, final int folderId, final PublicationTarget target, final PublicationService publisher, final Context ctx) throws MailException {
         final List<LinkAndNamePair> links = new ArrayList<LinkAndNamePair>(attachments.size());
@@ -271,7 +284,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                  * Add to list
                  */
                 linkBuilder.setLength(0);
-                links.add(new LinkAndNamePair(attachment.getFileName(), linkBuilder.append(protocol).append("://").append(hostName).append(
+                links.add(new LinkAndNamePair(attachment.getFileName(), linkBuilder.append(protocol).append(hostName).append(
                     path).toString()));
             }
         } catch (final PublicationException e) {
@@ -290,7 +303,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
          * Iterate recipients and split them to internal vs. external recipients
          */
         Date elapsedDate = null;
-        if(TransportProperties.getInstance().publishedDocumentsExpire()) {
+        if (TransportProperties.getInstance().publishedDocumentsExpire()) {
             elapsedDate = new Date(System.currentTimeMillis() + TransportProperties.getInstance().getPublishedDocumentTimeToLive());
         }
         final UserService userService = ServerServiceRegistry.getInstance().getService(UserService.class);
@@ -299,7 +312,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
         for (final InternetAddress address : addresses) {
             User user = null;
             try {
-                user = userService.searchUser(address.getAddress(), ctx);
+                user = userService.searchUser(IDNA.toIDN(address.getAddress()), ctx);
             } catch (final UserException e) {
                 /*
                  * Unfortunately UserService.searchUser() throws an exception if no user could be found matching given email address.
@@ -312,7 +325,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                  * Retry
                  */
                 try {
-                    user = userService.searchUser(QuotedInternetAddress.toIDN(address.getAddress()), ctx);
+                    user = userService.searchUser(IDNA.toIDN(address.getAddress()), ctx);
                 } catch (final UserException inner) {
                     if (LdapException.Code.NO_USER_BY_MAIL.getDetailNumber() != inner.getDetailNumber()) {
                         throw new MailException(inner);
@@ -399,7 +412,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
     private ComposedMailMessage generateInternalVersion(final ComposedMailMessage source, final Context ctx, final List<LinkAndNamePair> links, final boolean appendLinksAsAttachment, final Date elapsedDate, final Locale locale) throws MailException {
         final ComposedMailMessage internalVersion = copyOf(source, ctx);
         final TextBodyMailPart textPart = this.textPart.copy();
-        final StringHelper stringHelper = new StringHelper(locale);
+        final StringHelper stringHelper = StringHelper.valueOf(locale);
         if (appendLinksAsAttachment) {
             // Apply text part as it is
             internalVersion.setBodyPart(textPart);
@@ -413,7 +426,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
             final StringBuilder textBuilder = new StringBuilder(text.length() + 512);
             textBuilder.append(htmlFormat(stringHelper.getString(MailStrings.PUBLISHED_ATTACHMENTS_PREFIX))).append("<br />");
             appendLinks(links, textBuilder);
-            if(elapsedDate != null) {
+            if (elapsedDate != null) {
                 textBuilder.append(
                     htmlFormat(PATTERN_DATE.matcher(stringHelper.getString(MailStrings.PUBLISHED_ATTACHMENTS_APPENDIX)).replaceFirst(
                         DateFormat.getDateInstance(DateFormat.LONG, locale).format(elapsedDate)))).append("<br /><br />");
@@ -434,8 +447,11 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                 externalVersion.addEnclosedPart(attachment);
             }
         } else {
-            final Locale locale = TransportProperties.getInstance().getExternalRecipientsLocale();
-            final StringHelper stringHelper = new StringHelper(locale);
+            Locale locale = TransportProperties.getInstance().getExternalRecipientsLocale();
+            if (null == locale) {
+                locale = getSessionUserLocale();
+            }
+            final StringHelper stringHelper = StringHelper.valueOf(locale);
             if (appendLinksAsAttachment) {
                 // Apply text part as it is
                 externalVersion.setBodyPart(textPart);
@@ -449,7 +465,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                 final StringBuilder textBuilder = new StringBuilder(text.length() + 512);
                 textBuilder.append(htmlFormat(stringHelper.getString(MailStrings.PUBLISHED_ATTACHMENTS_PREFIX))).append("<br />");
                 appendLinks(links, textBuilder);
-                if(elapsedDate != null) {
+                if (elapsedDate != null) {
                     textBuilder.append(
                         htmlFormat(PATTERN_DATE.matcher(stringHelper.getString(MailStrings.PUBLISHED_ATTACHMENTS_APPENDIX)).replaceFirst(
                             DateFormat.getDateInstance(DateFormat.LONG, locale).format(elapsedDate)))).append("<br /><br />");
@@ -462,6 +478,18 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
         return externalVersion;
     }
 
+    private Locale getSessionUserLocale() throws MailException {
+        if (session instanceof ServerSession) {
+            return ((ServerSession) session).getUser().getLocale();
+        }
+        try {
+            final Context context = ContextStorage.getStorageContext(session.getContextId());
+            return UserStorage.getStorageUser(session.getUserId(), context).getLocale();
+        } catch (final ContextException e) {
+            throw new MailException(e);
+        }
+    }
+
     private ComposedMailMessage copyOf(final ComposedMailMessage source, final Context ctx) throws MailException {
         final ComposedMailMessage composedMail = transportProvider.getNewComposedMailMessage(session, ctx);
         if (source.containsFlags()) {
@@ -550,25 +578,19 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
          * Create document meta data for current attachment
          */
         String name = attachment.getFileName();
-        if(name == null) {
-            name = "attachment"; 
+        if (name == null) {
+            name = "attachment";
         }
-        final DocumentMetadata documentMetadata = new DocumentMetadataImpl();
-        documentMetadata.setId(InfostoreFacade.NEW);
-        documentMetadata.setFolderId(folderId);
-        documentMetadata.setFileName(name);
-        documentMetadata.setFileMIMEType(attachment.getContentType().toString());
-        documentMetadata.setTitle(name);
+        final File file = new DefaultFile();
+        file.setId(FileStorageFileAccess.NEW);
+        file.setFolderId(String.valueOf(folderId));
+        file.setFileName(name);
+        file.setFileMIMEType(attachment.getContentType().toString());
+        file.setTitle(name);
         /*
          * Put attachment's document to dedicated infostore folder
          */
-        final InfostoreFacade infostoreFacade = Infostore.FACADE;
-        final ServerSession serverSession;
-        if (session instanceof ServerSession) {
-            serverSession = (ServerSession) session;
-        } else {
-            serverSession = new ServerSessionAdapter(session, ctx);
-        }
+        final IDBasedFileAccess fileAccess = fileAccessFactory.createAccess(session);
         boolean retry = true;
         int count = 1;
         final StringBuilder hlp = new StringBuilder(16);
@@ -581,13 +603,13 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                 /*
                  * Start InfoStore transaction
                  */
-                infostoreFacade.startTransaction();
+                fileAccess.startTransaction();
                 try {
-                    infostoreFacade.saveDocument(documentMetadata, in, Long.MAX_VALUE, serverSession);
-                    infostoreFacade.commit();
+                    fileAccess.saveDocument(file, in, FileStorageFileAccess.DISTANT_FUTURE);
+                    fileAccess.commit();
                     retry = false;
-                } catch (final InfostoreException x) {
-                    infostoreFacade.rollback();
+                } catch (final FileStorageException x) {
+                    fileAccess.rollback();
                     if (441 != x.getDetailNumber()) {
                         throw new MailException(x);
                     }
@@ -598,20 +620,21 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
                     final int pos = name.lastIndexOf('.');
                     final String newName;
                     if (pos >= 0) {
-                        newName = hlp.append(name.substring(0, pos)).append("_(").append(++count).append(')').append(name.substring(pos)).toString();
+                        newName =
+                            hlp.append(name.substring(0, pos)).append("_(").append(++count).append(')').append(name.substring(pos)).toString();
                     } else {
                         newName = hlp.append(name).append("_(").append(++count).append(')').toString();
                     }
-                    documentMetadata.setFileName(newName);
-                    documentMetadata.setTitle(newName);
-                } catch (final OXException x) {
-                    infostoreFacade.rollback();
-                    throw new MailException(x);
+                    file.setFileName(newName);
+                    file.setTitle(newName);
+                } catch (final TransactionException e) {
+                    fileAccess.rollback();
+                    throw e;
                 } catch (final Exception e) {
-                    infostoreFacade.rollback();
+                    fileAccess.rollback();
                     throw new MailException(MailException.Code.UNEXPECTED_ERROR, e, e.getMessage());
                 } finally {
-                    infostoreFacade.finish();
+                    fileAccess.finish();
                 }
             } finally {
                 try {
@@ -626,7 +649,7 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
          */
         final Publication publication = new Publication();
         publication.setModule("infostore/object");
-        publication.setEntityId(String.valueOf(documentMetadata.getId()));
+        publication.setEntityId(String.valueOf(file.getId()));
         publication.setContext(ctx);
         publication.setUserId(session.getUserId());
         /*
@@ -640,49 +663,43 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
         /*
          * Remember publication in provided list
          */
-        publications.add(new PublicationAndInfostoreID(publication, documentMetadata.getId()));
+        publications.add(new PublicationAndInfostoreID(publication, file.getId()));
         /*
          * Return URL
          */
         return (String) publication.getConfiguration().get("url");
     } // End of publishAttachmentAndGetPath()
 
-    private void rollbackPublications(final List<PublicationAndInfostoreID> publications, final PublicationService publisher, final Context ctx) {
-        /*
-         * Remove publication one-by-one
-         */
-        final InfostoreFacade infostoreFacade = Infostore.FACADE;
-        final ServerSession serverSession;
-        if (session instanceof ServerSession) {
-            serverSession = (ServerSession) session;
-        } else {
-            serverSession = new ServerSessionAdapter(session, ctx);
-        }
+    private void rollbackPublications(final List<PublicationAndInfostoreID> publications, final PublicationService publisher) {
+        final IDBasedFileAccess fileAccess = fileAccessFactory.createAccess(session);
         final long timestamp = System.currentTimeMillis();
-        final int[] arr = new int[1];
+        final List<String> arr = new ArrayList<String>(1);
         for (final PublicationAndInfostoreID publication : publications) {
             try {
                 publisher.delete(publication.publication);
             } catch (final PublicationException e) {
-                LOG.error(new StringBuilder("Publication with ID \"").append(publication.publication.getId()).append(
-                    " could not be roll-backed.").toString(), e);
+                LOG.error(
+                    new StringBuilder("Publication with ID \"").append(publication.publication.getId()).append(" could not be roll-backed.").toString(),
+                    e);
             }
             try {
-                infostoreFacade.startTransaction();
+                fileAccess.startTransaction();
                 try {
-                    arr[0] = publication.infostoreId;
-                    infostoreFacade.removeDocument(arr, timestamp, serverSession);
-                    infostoreFacade.commit();
-                } catch (final OXException x) {
-                    infostoreFacade.rollback();
+                    arr.set(0, publication.infostoreId);
+                    fileAccess.removeDocument(arr, timestamp);
+                    fileAccess.commit();
+                } catch (final FileStorageException x) {
+                    fileAccess.rollback();
                     throw x;
                 } finally {
-                    infostoreFacade.finish();
+                    fileAccess.finish();
                 }
             } catch (final TransactionException e) {
-                LOG.error(new StringBuilder("Transaction error while deleting infostore document with ID \"").append(
-                    publication.infostoreId).append("\" failed.").toString(), e);
-            } catch (final OXException e) {
+                LOG.error(
+                    new StringBuilder("Transaction error while deleting infostore document with ID \"").append(publication.infostoreId).append(
+                        "\" failed.").toString(),
+                    e);
+            } catch (final FileStorageException e) {
                 LOG.error(
                     new StringBuilder("Deleting infostore document with ID \"").append(publication.infostoreId).append("\" failed.").toString(),
                     e);
@@ -765,9 +782,9 @@ final class PublishAttachmentHandler extends AbstractAttachmentHandler {
 
         final Publication publication;
 
-        final int infostoreId;
+        final String infostoreId;
 
-        public PublicationAndInfostoreID(final Publication publication, final int infostoreId) {
+        public PublicationAndInfostoreID(final Publication publication, final String infostoreId) {
             super();
             this.publication = publication;
             this.infostoreId = infostoreId;
