@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.html.HTMLService;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailJSONField;
 import com.openexchange.mail.MailListField;
@@ -69,17 +70,15 @@ import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.text.Enriched2HtmlConverter;
 import com.openexchange.mail.text.HTMLProcessing;
 import com.openexchange.mail.text.RTF2HTMLConverter;
-import com.openexchange.mail.text.parser.HTMLParser;
-import com.openexchange.mail.text.parser.handler.HTML2TextHandler;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.DisplayMode;
-import com.openexchange.mail.utils.MailFolderUtility;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link JSONObjectConverter} - Converts a raw JSON mail representation into a user-sensitive JSON mail representation.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class JSONObjectConverter {
@@ -100,13 +99,11 @@ public final class JSONObjectConverter {
 
     // private Html2TextConverter converter;
 
-    private HTML2TextHandler html2textHandler;
-
     private final boolean[] modified;
 
     /**
      * Initializes a new {@link JSONObjectConverter}.
-     * 
+     *
      * @param rawJSONMailObject The raw JSON mail representation to convert
      * @param displayMode The request-specific display mode
      * @param session The session providing needed user information
@@ -141,28 +138,9 @@ public final class JSONObjectConverter {
         return timeZone;
     }
 
-    private HTML2TextHandler getHandler() {
-        if (html2textHandler == null) {
-            html2textHandler = new HTML2TextHandler(4096, true);
-            /*
-             * Add debugging information
-             */
-            if (rawJSONMailObject.hasAndNotNull(FolderChildFields.FOLDER_ID)) {
-                html2textHandler.setMailFolderPath(MailFolderUtility.prepareMailFolderParam(
-                    rawJSONMailObject.optString(FolderChildFields.FOLDER_ID)).getFullname());
-            }
-            if (rawJSONMailObject.hasAndNotNull(DataFields.ID)) {
-                html2textHandler.setMailId(rawJSONMailObject.optLong(DataFields.ID));
-            }
-            html2textHandler.setContextId(session.getContextId());
-            html2textHandler.setUserId(session.getUserId());
-        }
-        return html2textHandler;
-    }
-
     /**
      * Converts this converter's raw JSON mail representation into a user-sensitive JSON mail representation.
-     * 
+     *
      * @return The user-sensitive JSON mail representation
      * @throws MailException If conversion fails
      */
@@ -181,6 +159,7 @@ public final class JSONObjectConverter {
             copyValue(FolderChildFields.FOLDER_ID, rawJSONMailObject, jsonObject);
             copyValue(MailJSONField.UNREAD.getKey(), rawJSONMailObject, jsonObject);
             copyValue(MailJSONField.ACCOUNT_NAME.getKey(), rawJSONMailObject, jsonObject);
+            copyValue(MailJSONField.ACCOUNT_ID.getKey(), rawJSONMailObject, jsonObject);
             raw2JsonMail0(rawJSONMailObject, jsonObject);
             return jsonObject;
         } catch (final JSONException e) {
@@ -456,8 +435,12 @@ public final class JSONObjectConverter {
             /*
              * Try to convert the given html to regular text
              */
-            HTMLParser.parse(HTMLProcessing.getConformHTML(htmlContent, (String) null), getHandler().reset());
-            final String content = HTMLProcessing.formatTextForDisplay(getHandler().getText(), usm, displayMode);
+            final String content;
+            {
+                final HTMLService htmlService = ServerServiceRegistry.getInstance().getService(HTMLService.class);
+                final String plainText = htmlService.html2text(htmlService.getConformHTML(htmlContent, (String) null), true);
+                content = HTMLProcessing.formatTextForDisplay(plainText, usm, displayMode);
+            }
             jsonObject.put(MailJSONField.DISPOSITION.getKey(), Part.INLINE);
             copyValue(MailJSONField.SIZE.getKey(), htmlObject, jsonObject);
             jsonObject.put(MailJSONField.CONTENT.getKey(), content);
@@ -526,7 +509,7 @@ public final class JSONObjectConverter {
 
     /**
      * Checks if specified string starts with either of passed prefixes.
-     * 
+     *
      * @param s The string to check
      * @param prefixes The prefixes
      * @return <code>true</code> if specified string starts with either of passed prefixes; otherwise <code>false</code>
@@ -541,7 +524,7 @@ public final class JSONObjectConverter {
 
     /**
      * Creates a dummy JSON object for an empty plain text mail body.
-     * 
+     *
      * @return A dummy JSON object for an empty plain text mail body
      * @throws JSONException If a JSON error occurs
      */
@@ -557,7 +540,7 @@ public final class JSONObjectConverter {
     /**
      * (Shallow) Copies the value associated with given key from source JSON object to destination JSON object if present and not
      * {@link JSONObject#NULL NULL}.
-     * 
+     *
      * @param key The key
      * @param src The source JSON object
      * @param dst The destination JSON object
