@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,11 @@
 package com.openexchange.mail.json.writer;
 
 import static com.openexchange.mail.mime.QuotedInternetAddress.toIDN;
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.decodeMultiEncodedHeader;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
+import java.util.Collection;
 import java.util.EnumMap;
+import java.util.List;
 import java.util.TimeZone;
 import javax.mail.internet.InternetAddress;
 import org.json.JSONArray;
@@ -60,6 +63,7 @@ import org.json.JSONObject;
 import org.json.JSONValue;
 import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.UserStorage;
@@ -70,12 +74,13 @@ import com.openexchange.mail.MailListField;
 import com.openexchange.mail.MailPath;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailMessage;
+import com.openexchange.mail.mime.MimeFilter;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.parser.MailMessageParser;
 import com.openexchange.mail.parser.handlers.JSONMessageHandler;
 import com.openexchange.mail.parser.handlers.RawJSONMessageHandler;
 import com.openexchange.mail.structure.StructureMailMessageParser;
-import com.openexchange.mail.structure.parser.MIMEStructureHandler;
+import com.openexchange.mail.structure.handler.MIMEStructureHandler;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mail.utils.DisplayMode;
@@ -84,12 +89,12 @@ import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link MessageWriter} - Writes {@link MailMessage} instances as JSON strings
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessageWriter {
 
-    // private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MessageWriter.class);
+    // private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MessageWriter.class));
 
     /**
      * No instantiation
@@ -109,7 +114,7 @@ public final class MessageWriter {
      * <li>Address headers are delivered as JSON objects with a <code>"personal"</code> and an <code>"address"</code> field</li>
      * <li>Parameterized headers are delivered as JSON objects with a <code>"type"</code> and a <code>"params"</code> field</li>
      * </ol>
-     * 
+     *
      * @param accountId The mail's account ID
      * @param mail The mail to write
      * @param maxSize The allowed max. size
@@ -118,23 +123,63 @@ public final class MessageWriter {
      */
     public static JSONObject writeStructure(final int accountId, final MailMessage mail, final long maxSize) throws MailException {
         final MIMEStructureHandler handler = new MIMEStructureHandler(maxSize);
-        new StructureMailMessageParser().parseMailMessage(mail, handler);
+        new StructureMailMessageParser().setParseTNEFParts(true).parseMailMessage(mail, handler);
         return handler.getJSONMailObject();
     }
 
     /**
      * Writes whole mail as a JSON object.
-     * 
+     *
      * @param accountId The account ID
      * @param mail The mail to write
      * @param displayMode The display mode
      * @param session The session
      * @param settings The user's mail settings used for writing message; if <code>null</code> the settings are going to be fetched from
      *            storage, thus no request-specific preparations will take place.
+     * @param warnings A container for possible warnings
      * @return The written JSON object
      * @throws MailException If writing message fails
      */
     public static JSONObject writeMailMessage(final int accountId, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail settings) throws MailException {
+        return writeMailMessage(accountId, mail, displayMode, session, settings, null, false, -1);
+    }
+
+    /**
+     * Writes whole mail as a JSON object.
+     *
+     * @param accountId The account ID
+     * @param mail The mail to write
+     * @param displayMode The display mode
+     * @param session The session
+     * @param settings The user's mail settings used for writing message; if <code>null</code> the settings are going to be fetched from
+     *            storage, thus no request-specific preparations will take place.
+     * @param warnings A container for possible warnings
+     * @param tokenTimeout
+     * @token <code>true</code> to add attachment tokens
+     * @return The written JSON object
+     * @throws MailException If writing message fails
+     */
+    public static JSONObject writeMailMessage(final int accountId, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail settings, final Collection<AbstractOXException> warnings, final boolean token, final int tokenTimeout) throws MailException {
+        return writeMailMessage(accountId, mail, displayMode, session, settings, warnings, token, tokenTimeout, null);
+    }
+
+    /**
+     * Writes whole mail as a JSON object.
+     *
+     * @param accountId The account ID
+     * @param mail The mail to write
+     * @param displayMode The display mode
+     * @param session The session
+     * @param settings The user's mail settings used for writing message; if <code>null</code> the settings are going to be fetched from
+     *            storage, thus no request-specific preparations will take place.
+     * @param warnings A container for possible warnings
+     * @param tokenTimeout
+     * @param mimeFilter The MIME filter
+     * @token <code>true</code> to add attachment tokens
+     * @return The written JSON object
+     * @throws MailException If writing message fails
+     */
+    public static JSONObject writeMailMessage(final int accountId, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail settings, final Collection<AbstractOXException> warnings, final boolean token, final int tokenTimeout, final MimeFilter mimeFilter) throws MailException {
         final MailPath mailPath;
         if (mail.getFolder() != null && mail.getMailId() != null) {
             mailPath = new MailPath(accountId, mail.getFolder(), mail.getMailId());
@@ -150,14 +195,36 @@ public final class MessageWriter {
         } catch (final UserConfigurationException e) {
             throw new MailException(e);
         }
-        final JSONMessageHandler handler = new JSONMessageHandler(accountId, mailPath, mail, displayMode, session, usm);
-        new MailMessageParser().parseMailMessage(mail, handler);
-        return handler.getJSONObject();
+        final JSONMessageHandler handler = new JSONMessageHandler(accountId, mailPath, mail, displayMode, session, usm, token, tokenTimeout);
+        final MailMessageParser parser = new MailMessageParser().addMimeFilter(mimeFilter);
+        parser.parseMailMessage(mail, handler);
+        if (null != warnings) {
+            final List<AbstractOXException> list = parser.getWarnings();
+            if (!list.isEmpty()) {
+                warnings.addAll(list);
+            }
+        }
+        if (!mail.isDraft()) {
+            return handler.getJSONObject();
+        }
+        /*
+         * Ensure "msgref" is present in draft mail
+         */
+        final JSONObject jsonObject = handler.getJSONObject();
+        final String key = MailJSONField.MSGREF.getKey();
+        if (!jsonObject.has(key) && null != mailPath) {
+            try {
+                jsonObject.put(key, mailPath.toString());
+            } catch (final JSONException e) {
+                throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+            }
+        }
+        return jsonObject;
     }
 
     /**
      * Writes raw mail as a JSON object.
-     * 
+     *
      * @param accountId The account ID
      * @param mail The mail to write
      * @return The written JSON object or <code>null</code> if message's text body parts exceed max. size
@@ -328,15 +395,19 @@ public final class MessageWriter {
 
             public void writeField(final JSONValue jsonContainer, final MailMessage mail, final int level, final boolean withKey, final int accountId, final int user, final int cid) throws MailException {
                 try {
-                    final String subject = mail.getSubject();
+                    String subject = mail.getSubject();
                     if (withKey) {
                         if (subject != null) {
-                            ((JSONObject) jsonContainer).put(
-                                MailJSONField.SUBJECT.getKey(),
-                                MIMEMessageUtility.decodeMultiEncodedHeader(subject.trim()));
+                            subject = decodeMultiEncodedHeader(subject);
+                            ((JSONObject) jsonContainer).put(MailJSONField.SUBJECT.getKey(), subject.trim());
                         }
                     } else {
-                        ((JSONArray) jsonContainer).put(subject == null ? JSONObject.NULL : MIMEMessageUtility.decodeMultiEncodedHeader(subject.trim()));
+                        if (subject == null) {
+                            ((JSONArray) jsonContainer).put(JSONObject.NULL);
+                        } else {
+                            subject = decodeMultiEncodedHeader(subject);
+                            ((JSONArray) jsonContainer).put(subject.trim());
+                        }
                     }
                 } catch (final JSONException e) {
                     throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
@@ -575,7 +646,9 @@ public final class MessageWriter {
             public void writeField(final JSONValue jsonContainer, final MailMessage mail, final int level, final boolean withKey, final int accountId, final int user, final int cid) throws MailException {
                 try {
                     if (withKey) {
-                        ((JSONObject) jsonContainer).put(MailJSONField.ACCOUNT_NAME.getKey(), mail.getAccountName());
+                        final JSONObject jsonObject = (JSONObject) jsonContainer;
+                        jsonObject.put(MailJSONField.ACCOUNT_NAME.getKey(), mail.getAccountName());
+                        jsonObject.put(MailJSONField.ACCOUNT_ID.getKey(), mail.getAccountName());
                     } else {
                         ((JSONArray) jsonContainer).put(mail.getAccountName());
                     }
@@ -584,6 +657,22 @@ public final class MessageWriter {
                 }
             }
         });
+        WRITERS.put(MailListField.ACCOUNT_ID, new MailFieldWriter() {
+
+            public void writeField(final JSONValue jsonContainer, final MailMessage mail, final int level, final boolean withKey, final int accountId, final int user, final int cid) throws MailException {
+                try {
+                    if (withKey) {
+                        final JSONObject jsonObject = (JSONObject) jsonContainer;
+                        jsonObject.put(MailJSONField.ACCOUNT_NAME.getKey(), mail.getAccountName());
+                        jsonObject.put(MailJSONField.ACCOUNT_ID.getKey(), mail.getAccountName());
+                    } else {
+                        ((JSONArray) jsonContainer).put(mail.getAccountId());
+                    }
+                } catch (final JSONException e) {
+                    throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+                }
+            }
+        });
     }
 
     private static final MailFieldWriter UNKNOWN = new MailFieldWriter() {
@@ -603,7 +692,7 @@ public final class MessageWriter {
 
     /**
      * Generates appropriate field writers for given mail fields
-     * 
+     *
      * @param fields The mail fields to write
      * @return Appropriate field writers as an array of {@link MailFieldWriter}
      */
@@ -622,7 +711,7 @@ public final class MessageWriter {
 
     /**
      * Gets writers for specified header names.
-     * 
+     *
      * @param headers The header names
      * @return The writers for specified header names
      */
@@ -639,7 +728,7 @@ public final class MessageWriter {
 
     /**
      * Adds the user time zone offset to given date time
-     * 
+     *
      * @param time The date time
      * @param timeZone The time zone
      * @return The time with added time zone offset
@@ -652,7 +741,7 @@ public final class MessageWriter {
 
     /**
      * Convert an array of <code>InternetAddress</code> instances into a JSON-Array conforming to:
-     * 
+     *
      * <pre>
      * [[&quot;The Personal&quot;, &quot;someone@somewhere.com&quot;], ...]
      * </pre>
@@ -686,7 +775,7 @@ public final class MessageWriter {
     // private static final Pattern PATTERN_QUOTE = Pattern.compile("[.,:;<>\"]");
 
     private static String preparePersonal(final String personal) {
-        return MIMEMessageUtility.quotePhrase(MIMEMessageUtility.decodeMultiEncodedHeader(personal), false);
+        return MIMEMessageUtility.quotePhrase(personal, false);
     }
 
     private static final String DUMMY_DOMAIN = "@unspecified-domain";
