@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.mail.mime;
 
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.decodeMultiEncodedHeader;
 import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -57,7 +58,7 @@ import com.openexchange.mail.MailException;
 
 /**
  * {@link ContentDisposition}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ContentDisposition extends ParameterizedHeader {
@@ -66,7 +67,9 @@ public final class ContentDisposition extends ParameterizedHeader {
 
     private static final Pattern PATTERN_CONTENT_DISP = Pattern.compile("(?:inline|attachment)", Pattern.CASE_INSENSITIVE);
 
-    private static final String DEFAULT_CONTENT_DISP = Part.INLINE.toUpperCase(Locale.ENGLISH);
+    private static final String INLINE = Part.INLINE;
+
+    private static final String ATTACHMENT = Part.ATTACHMENT;
 
     private static final String PARAM_FILENAME = "filename";
 
@@ -77,13 +80,13 @@ public final class ContentDisposition extends ParameterizedHeader {
      */
     public ContentDisposition() {
         super();
-        disposition = DEFAULT_CONTENT_DISP;
+        disposition = INLINE;
         parameterList = new ParameterList();
     }
 
     /**
      * Initializes a new {@link ContentDisposition}
-     * 
+     *
      * @param contentDisp The content disposition
      * @throws MailException If content disposition cannot be parsed
      */
@@ -110,7 +113,7 @@ public final class ContentDisposition extends ParameterizedHeader {
     public int hashCode() {
         final int prime = 31;
         int result = super.hashCode();
-        result = prime * result + ((disposition == null) ? 0 : disposition.toLowerCase(Locale.ENGLISH).hashCode());
+        result = prime * result + ((disposition == null) ? 0 : disposition.toLowerCase(Locale.US).hashCode());
         return result;
     }
 
@@ -145,29 +148,33 @@ public final class ContentDisposition extends ParameterizedHeader {
             /*
              * Nothing to parse
              */
-            disposition = DEFAULT_CONTENT_DISP;
+            disposition = INLINE;
             parameterList = new ParameterList();
             return;
         }
-        final String contentDisp = prepareParameterizedHeader(contentDispArg);
+        final String contentDisp = decodeMultiEncodedHeader(prepareParameterizedHeader(contentDispArg));
         final Matcher cdMatcher = PATTERN_CONTENT_DISP.matcher(contentDisp);
         if (!cdMatcher.find()) {
-            disposition = DEFAULT_CONTENT_DISP;
+            disposition = INLINE;
             parameterList = new ParameterList();
             return;
         }
         if (cdMatcher.start() != 0) {
             throw new MailException(MailException.Code.INVALID_CONTENT_DISPOSITION, contentDispArg);
         }
-        disposition = cdMatcher.group().toUpperCase(Locale.ENGLISH);
+        disposition = cdMatcher.group().toLowerCase(Locale.US);
         if (paramList) {
-            parameterList = new ParameterList(contentDisp.substring(cdMatcher.end()));
+            try {
+                parameterList = new ParameterList(contentDisp.substring(cdMatcher.end()));
+            } catch (final RuntimeException e) {
+                throw new MailException(MailException.Code.INVALID_CONTENT_DISPOSITION, e, contentDispArg);
+            }
         }
     }
 
     /**
      * Applies given content disposition to this content disposition
-     * 
+     *
      * @param contentDisp The content disposition to apply
      */
     public void setContentDisposition(final ContentDisposition contentDisp) {
@@ -192,6 +199,20 @@ public final class ContentDisposition extends ParameterizedHeader {
         this.disposition = disposition;
     }
 
+    /**
+     * Sets the disposition to <code>"inline"</code>.
+     */
+    public void setInline() {
+        disposition = INLINE;
+    }
+
+    /**
+     * Sets the disposition to <code>"attachment"</code>.
+     */
+    public void setAttachment() {
+        disposition = ATTACHMENT;
+    }
+
     /**
      * Sets filename parameter
      */
@@ -222,7 +243,7 @@ public final class ContentDisposition extends ParameterizedHeader {
 
     /**
      * Checks if disposition is inline
-     * 
+     *
      * @return <code>true</code> if disposition is inline; otherwise <code>false</code>
      */
     public boolean isInline() {
@@ -231,7 +252,7 @@ public final class ContentDisposition extends ParameterizedHeader {
 
     /**
      * Checks if disposition is attachment
-     * 
+     *
      * @return <code>true</code> if disposition is attachment; otherwise <code>false</code>
      */
     public boolean isAttachment() {
@@ -245,7 +266,7 @@ public final class ContentDisposition extends ParameterizedHeader {
 
     /**
      * Returns a RFC2045 style (ASCII-only) string representation of this content disposition.
-     * 
+     *
      * @param skipEmptyParams <code>true</code> to skip empty parameters; otherwise <code>false</code>
      * @return A RFC2045 style (ASCII-only) string representation of this content disposition
      */
