@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,20 @@
 
 package com.openexchange.mail.mime;
 
+import static com.openexchange.mail.mime.utils.MIMEMessageUtility.decodeMultiEncodedHeader;
 import java.util.Iterator;
 import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.tools.Collections;
 
 /**
  * {@link ContentType} - Parses value of MIME header <code>Content-Type</code>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class ContentType extends ParameterizedHeader {
@@ -74,13 +77,13 @@ public class ContentType extends ParameterizedHeader {
      */
     public static final class UnmodifiableContentType extends ContentType {
 
-        private static final long serialVersionUID = 2473639344400699520L;
+        private static final long serialVersionUID = 2473639344400699522L;
 
         private final ContentType contentType;
 
         /**
          * Initializes a new {@link UnmodifiableContentType}.
-         * 
+         *
          * @param contentType The backing content type
          */
         public UnmodifiableContentType(final ContentType contentType) {
@@ -241,16 +244,40 @@ public class ContentType extends ParameterizedHeader {
     /**
      * The regular expression that should match whole content type
      */
-    private static final Pattern PATTERN_CONTENT_TYPE = Pattern.compile("(?:([\\p{ASCII}&&[^/;\\s\"]]+)(?:/([\\p{ASCII}&&[^;\\s\"]]+))?)");
+    // private static final Pattern PATTERN_CONTENT_TYPE = Pattern.compile("(?:\"?([[\\p{L}\\p{ASCII}]&&[^/;\\s\"]]+)(?:/([[\\p{L}\\p{ASCII}]&&[^;\\s\"]]+))?\"?)|(?:/([[\\p{L}\\p{ASCII}]&&[^;\\s\"]]+))");
+    private static final Pattern PATTERN_CONTENT_TYPE = Pattern.compile("(?:\"?([\\p{L}_0-9-]+)(?:/([\\p{L}_0-9-]+))?\"?)|(?:/([\\p{L}_0-9-]+))");
+
+    private static final Pattern PATTERN_TOKEN = Pattern.compile("[\\p{L}_0-9-.+]*");
+
+    private static boolean isInvalidToken(final String token) {
+        if (null == token) {
+            return true;
+        }
+        return !PATTERN_TOKEN.matcher(token).matches();
+    }
+
+    /**
+     * The regular expression capturing whitespace characters.
+     */
+    private static final Pattern PATTERN_WHITESPACE = Pattern.compile("\\s+");
+
+    private static final String EMPTY = "";
+
+    private static String clearWhitespaces(final String str) {
+        if (null == str) {
+            return null;
+        }
+        return PATTERN_WHITESPACE.matcher(str).replaceAll(EMPTY);
+    }
 
     /**
      * The MIME type delimiter
-     * 
+     *
      * @value /
      */
     private static final char DELIMITER = '/';
 
-    // private static final String DEFAULT_PRIMTYPE = "APPLICATION";
+    private static final String DEFAULT_PRIMTYPE = "APPLICATION";
 
     private static final String DEFAULT_SUBTYPE = "OCTET-STREAM";
 
@@ -274,7 +301,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Initializes a new {@link ContentType}
-     * 
+     *
      * @param contentType The content type
      * @throws MailException If content type cannot be parsed
      */
@@ -283,6 +310,16 @@ public class ContentType extends ParameterizedHeader {
         parseContentType(contentType);
     }
 
+    /**
+     * Resets this {@link ContentType} instance.
+     */
+    public void reset() {
+        parameterList = new ParameterList();
+        primaryType = null;
+        subType = null;
+        baseType = null;
+    }
+
     @Override
     public int compareTo(final ParameterizedHeader other) {
         if (this == other) {
@@ -339,33 +376,127 @@ public class ContentType extends ParameterizedHeader {
         parseContentType(contentType, true);
     }
 
-    private void parseContentType(final String contentTypeArg, final boolean paramList) throws MailException {
-        if ((null == contentTypeArg) || (contentTypeArg.length() == 0)) {
+    private void parseContentType(final String contentType, final boolean paramList) throws MailException {
+        if ((null == contentType) || (contentType.length() == 0)) {
             setContentType(DEFAULT_CONTENT_TYPE);
             return;
         }
-        final String contentType = prepareParameterizedHeader(contentTypeArg);
-        final int pos = contentType.indexOf(';');
-        final Matcher ctMatcher = PATTERN_CONTENT_TYPE.matcher(pos < 0 ? contentType : contentType.substring(0, pos));
+        final String cts = prepareParameterizedHeader(contentType);
+        int pos = cts.indexOf(';');
+        final String type = pos < 0 ? cts : cts.substring(0, pos);
+        // Check for '/' character
+        final int slashPos = type.indexOf(DELIMITER);
+        if (slashPos >= 0) {
+            try {
+                // Primary type
+                {
+                    String pt = 0 == slashPos ? DEFAULT_PRIMTYPE : type.substring(0, slashPos).trim();
+                    if (pt.charAt(0) == '"' || pt.charAt(0) == '\'') {
+                        pt = pt.substring(1);
+                    }
+                    if (pt.toLowerCase(Locale.US).startsWith("content-type:")) {
+                        pt = pt.substring(13);
+                        if (pt.charAt(0) == '"' || pt.charAt(0) == '\'') {
+                            pt = pt.substring(1);
+                        }
+                    }
+                    if (isInvalidToken(pt)) {
+                        throw new MailException(MailException.Code.INVALID_CONTENT_TYPE, contentType);
+                    }
+                    primaryType = pt.length() <= 0 ? DEFAULT_PRIMTYPE : pt;
+                }
+                // Subtype
+                {
+                    String st = slashPos < type.length() ? type.substring(slashPos + 1).trim() : DEFAULT_SUBTYPE;
+                    final int mlen = st.length() - 1;
+                    if (mlen > 0 && (st.charAt(mlen) == '"' || st.charAt(mlen) == '\'')) {
+                        st = st.substring(0, mlen);
+                    }
+                    if (isInvalidToken(st)) {
+                        throw new MailException(MailException.Code.INVALID_CONTENT_TYPE, contentType);
+                    }
+                    if (st.trim().length() <= 0) {
+                        if ("multipart".equals(primaryType)) {
+                            subType = "mixed";
+                        } else if ("text".equals(primaryType)) {
+                            subType = "plain";
+                        } else {
+                            subType = DEFAULT_SUBTYPE;
+                        }
+                    } else {
+                        subType = st;
+                    }
+                }
+                baseType = new StringBuilder(16).append(primaryType).append(DELIMITER).append(subType).toString();
+                if (paramList) {
+                    if (pos < 0) {
+                        parameterList = new ParameterList();
+                    } else {
+                        try {
+                            parameterList = pos >= 0 && pos < cts.length() ? new ParameterList(cts.substring(pos + 1)) : new ParameterList();
+                        } catch (final RuntimeException e) {
+                            throw new MailException(MailException.Code.INVALID_CONTENT_TYPE, e, contentType);
+                        }
+                    }
+                }
+                return;
+            } catch (final MailException e) {
+                // Content-Type could not be parsed the simple way
+                final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContentType.class));
+                logger.debug(e.getMessage(), e);
+            }
+        }
+        // Try with regex-based parsing
+        final Matcher ctMatcher = PATTERN_CONTENT_TYPE.matcher(pos < 0 ? cts : cts.substring(0, pos));
         if (ctMatcher.find()) {
             if (ctMatcher.start() != 0) {
-                throw new MailException(MailException.Code.INVALID_CONTENT_TYPE, contentTypeArg);
+                throw new MailException(MailException.Code.INVALID_CONTENT_TYPE, contentType);
             }
-            primaryType = ctMatcher.group(1);
-            subType = ctMatcher.group(2);
-            if ((subType == null) || (subType.length() == 0)) {
-                subType = DEFAULT_SUBTYPE;
+            final String alt = ctMatcher.group(3);
+            if (null != alt) {
+                primaryType = DEFAULT_PRIMTYPE;
+                final String decoded = clearWhitespaces(decodeMultiEncodedHeader(alt));
+                subType = null == decoded ? alt : decoded;
+                if ((subType == null) || (subType.length() == 0)) {
+                    subType = DEFAULT_SUBTYPE;
+                }
+            } else {
+                {
+                    final String pt = ctMatcher.group(1);
+                    final String decoded = clearWhitespaces(decodeMultiEncodedHeader(pt));
+                    primaryType = null == decoded ? pt : decoded;
+                    if ((primaryType == null) || (primaryType.length() == 0)) {
+                        primaryType = DEFAULT_PRIMTYPE;
+                    }
+                }
+                pos = primaryType.indexOf(DELIMITER);
+                if (pos >= 0) {
+                    subType = primaryType.substring(pos + 1);
+                    primaryType = primaryType.substring(0, pos);
+                } else {
+                    {
+                        final String st = ctMatcher.group(2);
+                        final String decoded = clearWhitespaces(decodeMultiEncodedHeader(st));
+                        subType = null == decoded ? st : decoded;
+                    }
+                    if ((subType == null) || (subType.length() == 0)) {
+                        subType = DEFAULT_SUBTYPE;
+                    }
+                }
+                if ((subType == null) || (subType.length() == 0)) {
+                    subType = DEFAULT_SUBTYPE;
+                }
             }
             baseType = new StringBuilder(16).append(primaryType).append(DELIMITER).append(subType).toString();
             if (paramList) {
-                parameterList = new ParameterList(contentType.substring(ctMatcher.end()));
+                parameterList = new ParameterList(cts.substring(ctMatcher.end()));
             }
         } else {
             primaryType = "text";
             subType = "plain";
             baseType = new StringBuilder(16).append(primaryType).append(DELIMITER).append(subType).toString();
             if (paramList) {
-                parameterList = new ParameterList(pos < 0 ? contentType : contentType.substring(pos));
+                parameterList = new ParameterList(pos < 0 ? cts : cts.substring(pos));
                 final String name = parameterList.getParameter("name");
                 if (null != name) {
                     final String byName = MIMEType2ExtMap.getContentType(name);
@@ -392,7 +523,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Applies given content type to this content type
-     * 
+     *
      * @param contentType The content type to apply
      */
     public void setContentType(final ContentType contentType) {
@@ -414,7 +545,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets primary type
-     * 
+     *
      * @return This content type with new primary type applied
      */
     public ContentType setPrimaryType(final String primaryType) {
@@ -432,7 +563,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets sub-type
-     * 
+     *
      * @return This content type with new sub-type applied
      */
     public ContentType setSubType(final String subType) {
@@ -442,7 +573,9 @@ public class ContentType extends ParameterizedHeader {
     }
 
     /**
-     * @return base type (e.g. text/plain)
+     * Gets this content type's base type without any parameters appended; e.g. <code>"text/plain"</code>.
+     *
+     * @return The base type
      */
     public String getBaseType() {
         if (baseType != null) {
@@ -453,7 +586,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets base type (e.g. text/plain)
-     * 
+     *
      * @return This content type with new base type applied
      */
     public ContentType setBaseType(final String baseType) throws MailException {
@@ -463,7 +596,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets <code>"charset"</code> parameter
-     * 
+     *
      * @param charset The charset parameter value; e.g. <code>"UTF-8"</code>
      * @return This content type with new <code>"charset"</code> parameter applied
      */
@@ -488,7 +621,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets <code>"name"</code> parameter
-     * 
+     *
      * @param filename The name parameter
      * @return This content type with new <code>"name"</code> parameter applied
      */
@@ -513,7 +646,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Sets the content type to specified content type string; e.g. "text/plain; charset=US-ASCII"
-     * 
+     *
      * @param contentType The content type string
      * @throws MailException If specified content type string cannot be parsed
      */
@@ -523,7 +656,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Checks if Content-Type's base type matches given wildcard pattern (e.g text/plain, text/* or text/htm*)
-     * 
+     *
      * @return <code>true</code> if Content-Type's base type matches given pattern, <code>false</code> otherwise
      */
     public boolean isMimeType(final String pattern) {
@@ -532,7 +665,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Checks if Content-Type's base type ignore-case starts with specified prefix.
-     * 
+     *
      * @param prefix The prefix
      * @return <code>true</code> if Content-Type's base type ignore-case starts with specified prefix; otherwise <code>false</code>
      * @throws IllegalArgumentException If specified prefix is <code>null</code>
@@ -544,9 +677,29 @@ public class ContentType extends ParameterizedHeader {
         return toLowerCase(getBaseType()).startsWith(toLowerCase(prefix), 0);
     }
 
+    /**
+     * Checks if Content-Type's base type ignore-case starts with any of specified prefixes.
+     *
+     * @param prefixes The prefixes
+     * @return <code>true</code> if Content-Type's base type ignore-case starts with any of specified prefixes; otherwise <code>false</code>
+     * @throws IllegalArgumentException If specified prefixes are <code>null</code>
+     */
+    public boolean startsWithAny(final String... prefixes) {
+        if (null == prefixes) {
+            throw new IllegalArgumentException("Prefixes are null");
+        }
+        final String lowerCase = toLowerCase(getBaseType());
+        for (final String prefix : prefixes) {
+            if (null != prefix && lowerCase.startsWith(toLowerCase(prefix), 0)) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     /**
      * Parses and prepares specified content-type string for being inserted into a MIME part's headers.
-     * 
+     *
      * @param contentType The content-type string to process
      * @return Prepared content-type string ready for being inserted into a MIME part's headers.
      * @throws MailException If parsing content-type string fails
@@ -557,7 +710,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Parses and prepares specified content-type string for being inserted into a MIME part's headers.
-     * 
+     *
      * @param contentType The content-type string to process
      * @param name The optional name parameter to set if no <tt>"name"</tt> parameter is present in specified content-type string; pass
      *            <code>null</code> to ignore
@@ -574,7 +727,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Checks if given MIME type's base type matches given wildcard pattern (e.g text/plain, text/* or text/htm*)
-     * 
+     *
      * @param mimeType The MIME type
      * @param pattern The pattern
      * @return <code>true</code> if pattern matches; otherwise <code>false</code>
@@ -586,7 +739,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Detects the base type of given MIME type
-     * 
+     *
      * @param mimeType The MIME type
      * @return the base type
      * @throws MailException If an invalid MIME type is detected
@@ -613,7 +766,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Converts specified wildcard string to a regular expression
-     * 
+     *
      * @param wildcard The wildcard string to convert
      * @return An appropriate regular expression ready for being used in a {@link Pattern pattern}
      */
@@ -626,7 +779,10 @@ public class ContentType extends ParameterizedHeader {
             if (c == '*') {
                 s.append(".*");
             } else if (c == '?') {
-                s.append('.');
+                s.append(".");
+            } else if (c == '(' || c == ')' || c == '[' || c == ']' || c == '$' || c == '^' || c == '.' || c == '{' || c == '}' || c == '|' || c == '\\') {
+                s.append('\\');
+                s.append(c);
             } else {
                 s.append(c);
             }
@@ -642,7 +798,7 @@ public class ContentType extends ParameterizedHeader {
 
     /**
      * Returns a RFC2045 style (ASCII-only) string representation of this content type.
-     * 
+     *
      * @param skipEmptyParams <code>true</code> to skip empty parameters; otherwise <code>false</code>
      * @return A RFC2045 style (ASCII-only) string representation of this content type
      */
