@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,27 +54,38 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.NoSuchElementException;
 import java.util.Set;
-import java.util.Map.Entry;
 import java.util.regex.Pattern;
+import javax.mail.internet.MimeUtility;
 import org.apache.commons.logging.Log;
 import com.openexchange.mail.MailException;
+import com.openexchange.mail.utils.CharsetDetector;
+import com.openexchange.mail.utils.MessageUtility;
+import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link HeaderCollection} - Represents a collection of <small><b><a href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small>
  * headers.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class HeaderCollection implements Serializable {
 
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(HeaderCollection.class));
+
+    private static final boolean DEBUG = LOG.isDebugEnabled();
+
     private static final String ERR_HEADER_NAME_IS_INVALID = "Header name is invalid";
 
     private static final long serialVersionUID = 6939560514144351286L;
@@ -90,7 +101,58 @@ public class HeaderCollection implements Serializable {
 
     private static final int DEFAULT_CAPACITY = 4096;
 
-    private final HashMap<HeaderName, List<String>> map;
+    private static final HeaderName RETURN_PATH = MessageHeaders.RETURN_PATH;
+
+    private static final HeaderName RECEIVED = MessageHeaders.RECEIVED;
+
+    private static final HeaderName CONTENT_TYPE = MessageHeaders.CONTENT_TYPE;
+
+    private static final Locale ENGLISH = Locale.ENGLISH;
+
+    private static final Map<String, String> CASE_SENSITIVE_LOOKUP;
+
+    static {
+        final Map<String, String> map = new HashMap<String, String>(24);
+        final Locale l = ENGLISH;
+        map.put("Date".toLowerCase(l), "Date");
+        map.put("From".toLowerCase(l), "From");
+        map.put("Sender".toLowerCase(l), "Sender");
+        map.put("Reply-To".toLowerCase(l), "Reply-To");
+        map.put("To".toLowerCase(l), "To");
+        map.put("Cc".toLowerCase(l), "Cc");
+        map.put("Bcc".toLowerCase(l), "Bcc");
+        map.put("Message-ID".toLowerCase(l), "Message-ID");
+        map.put("In-Reply-To".toLowerCase(l), "In-Reply-To");
+        map.put("References".toLowerCase(l), "References");
+        map.put("Subject".toLowerCase(l), "Subject");
+        map.put("Comments".toLowerCase(l), "Comments");
+        map.put("Keywords".toLowerCase(l), "Keywords");
+        map.put("Resent-Date".toLowerCase(l), "Resent-Date");
+        map.put("Resent-From".toLowerCase(l), "Resent-From");
+        map.put("Resent-Sender".toLowerCase(l), "Resent-Sender");
+        map.put("Resent-To".toLowerCase(l), "Resent-To");
+        map.put("Resent-Cc".toLowerCase(l), "Resent-Cc");
+        map.put("Resent-Bcc".toLowerCase(l), "Resent-Bcc");
+        map.put("Resent-Message-ID".toLowerCase(l), "Resent-Message-ID");
+        CASE_SENSITIVE_LOOKUP = Collections.unmodifiableMap(map);
+    }
+
+    /**
+     * Gets the case-sensitive header name as per RFC2822.
+     * 
+     * @param name The header name to check
+     * @return The case-sensitive header name
+     */
+    public static String caseSensitiveHeadreNameFor(final String name) {
+        final String cshn = CASE_SENSITIVE_LOOKUP.get(name.toLowerCase(ENGLISH));
+        return null == cshn ? name : cshn;
+    }
+
+    /*-
+     * ------------------------ Member stuff ---------------------------------
+     */
+
+    private final Map<HeaderName, List<String>> map;
 
     private int count;
 
@@ -103,7 +165,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Initializes a new {@link HeaderCollection}
-     * 
+     *
      * @param initialCapacity The collection's initial capacity
      */
     public HeaderCollection(final int initialCapacity) {
@@ -113,40 +175,43 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Copy constructor for {@link HeaderCollection}
-     * 
+     *
      * @param headers The source headers
      */
     public HeaderCollection(final HeaderCollection headers) {
-        this(headers.map.size());
+        super();
+        map = new LinkedHashMap<HeaderName, List<String>>(headers.map.size());
         addHeaders(headers);
     }
 
     /**
      * Initializes a new {@link HeaderCollection} from specified headers' <small><b><a
      * href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small> source
-     * 
+     *
      * @param headerSrc The headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt" >RFC822</a></b></small> source
      */
     public HeaderCollection(final String headerSrc) {
-        this();
+        super();
+        map = new LinkedHashMap<HeaderName, List<String>>(40);
         load(headerSrc);
     }
 
     /**
      * Initializes a new {@link HeaderCollection} from specified headers' <small><b><a
      * href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small> input stream
-     * 
+     *
      * @param inputStream The headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt" >RFC822</a></b></small> input stream
      * @throws MailException If parsing the header input stream fails
      */
     public HeaderCollection(final InputStream inputStream) throws MailException {
-        this();
+        super();
+        map = new LinkedHashMap<HeaderName, List<String>>(40);
         load(inputStream);
     }
 
     /**
      * Gets a read-only {@link HeaderCollection collection} constructed from this collection's current content
-     * 
+     *
      * @return A read-only {@link HeaderCollection collection}
      */
     public HeaderCollection getReadOnlyCollection() {
@@ -161,7 +226,7 @@ public class HeaderCollection implements Serializable {
      * the existing list of headers, in order.
      * <p>
      * Provided input stream is not going to be closed but is read until <code>EOF</code> or two subsequent <code>CRLF</code>s occur.
-     * 
+     *
      * @param inputStream The headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt" >RFC822</a></b></small> input stream
      * @throws MailException If reading from headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt" >RFC822</a></b></small> input
      *             stream fails
@@ -201,7 +266,7 @@ public class HeaderCollection implements Serializable {
      * <p>
      * Note that the header lines are added, so any existing headers in this object will not be affected. Headers are added to the end of
      * the existing list of headers, in order.
-     * 
+     *
      * @param headerSrc The headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt" >RFC822</a></b></small> source
      */
     public void load(final String headerSrc) {
@@ -289,7 +354,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Returns <code>true</code> if no headers are contained in this collection
-     * 
+     *
      * @return <code>true</code> if no headers are contained in this collection
      */
     public boolean isEmpty() {
@@ -300,7 +365,7 @@ public class HeaderCollection implements Serializable {
      * Gets the number of headers contained in this collection.
      * <p>
      * This method is a constant-time operation.
-     * 
+     *
      * @return The number of headers contained in this collection
      */
     public int size() {
@@ -312,7 +377,7 @@ public class HeaderCollection implements Serializable {
      * <p>
      * Note that the header lines are added, so any existing headers in this object will not be affected. Headers are added to the end of
      * the existing list of headers, in order.
-     * 
+     *
      * @param headers The header collection to add
      */
     public void addHeaders(final HeaderCollection headers) {
@@ -339,7 +404,7 @@ public class HeaderCollection implements Serializable {
      * <p>
      * Note that <small><b><a href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small> headers can only contain
      * <small><b>US-ASCII</b></small> characters.
-     * 
+     *
      * @param name The header name
      * @param value The header value
      * @return This header collection with specified header added
@@ -356,7 +421,7 @@ public class HeaderCollection implements Serializable {
      * <p>
      * Note that <small><b><a href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small> headers can only contain
      * <small><b>US-ASCII</b></small> characters.
-     * 
+     *
      * @param name The header name
      * @param value The header value
      * @return This header collection with specified header set
@@ -369,11 +434,21 @@ public class HeaderCollection implements Serializable {
 
     private final void putHeader(final String name, final String value, final boolean clear) {
         if (isInvalid(name, true)) {
-            throw new IllegalArgumentException(new StringBuilder(ERR_HEADER_NAME_IS_INVALID).append(": ").append(name).toString());
-        } else if (isInvalid(value, false)) {
-            throw new IllegalArgumentException(new StringBuilder(32).append("Header value is invalid: ").append(value).toString());
+            if (DEBUG) {
+                final IllegalArgumentException tmp =
+                    new IllegalArgumentException(new StringBuilder(ERR_HEADER_NAME_IS_INVALID).append(": ").append(name).toString());
+                LOG.debug(tmp.getMessage(), tmp);
+            }
+            // Do nothing...
+            return;
         }
-        final HeaderName headerName = HeaderName.valueOf(name);
+        if (isInvalid(value, false)) {
+            /*
+             * Ignore an empty value
+             */
+            return;
+        }
+        final HeaderName headerName = HeaderName.valueOf(caseSensitiveHeadreNameFor(name));
         List<String> values = map.get(headerName);
         if (values == null) {
             values = new ArrayList<String>(2);
@@ -381,23 +456,23 @@ public class HeaderCollection implements Serializable {
         } else if (clear) {
             values.clear();
         }
-        if (MessageHeaders.RECEIVED.equals(headerName) || MessageHeaders.RETURN_PATH.equals(headerName)) {
+        if (RECEIVED.equals(headerName) || RETURN_PATH.equals(headerName) || CONTENT_TYPE.equals(headerName)) {
             /*
              * Append
              */
-            values.add(value);
+            values.add(checkValue(value));
         } else {
             /*
              * Prepend
              */
-            values.add(0, value);
+            values.add(0, checkValue(value));
         }
         count++;
     }
 
     /**
      * Checks if this header collection contains a header entry for specified header
-     * 
+     *
      * @param name The header name
      * @return <code>true</code> if this header collection contains a header entry for specified header; otherwise <code>false</code>
      */
@@ -410,7 +485,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Return all the values for the specified header. Returns <code>null</code> if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @return An array of header values, or <code>null</code> if none exists
      * @throws IllegalArgumentException If name is invalid
@@ -429,7 +504,7 @@ public class HeaderCollection implements Serializable {
     /**
      * Get all the headers for this header name, returned as a single String, with headers separated by the delimiter. If the delimiter is
      * <code>null</code>, only the first header is returned. Returns <code>null</code> if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @param delimiter The delimiter
      * @return The value fields for all headers with this name, or <code>null</code> if none
@@ -456,7 +531,7 @@ public class HeaderCollection implements Serializable {
     /**
      * Get all the headers for this header name, returned as a single String, with headers separated by the delimiter. If the delimiter is
      * <code>'\0'</code>, only the first header is returned. Returns <code>null</code> if no headers with the specified name exist.
-     * 
+     *
      * @param name The header name
      * @param delimiter The delimiter character
      * @return The value fields for all headers with this name, or <code>null</code> if none
@@ -482,7 +557,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Remove all header entries that match the given name
-     * 
+     *
      * @param name The header name
      * @return This header collection with specified header removed
      */
@@ -499,12 +574,12 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Gets an  instance of {@link Iterator} to iterate all header names.
-     * 
+     *
      * @return An  instance of {@link Iterator} to iterate all header names
      */
     public Iterator<String> getHeaderNames() {
         final List<String> tmp = new ArrayList<String>(map.size());
-        for (HeaderName headerName : map.keySet()) {
+        for (final HeaderName headerName : map.keySet()) {
             tmp.add(headerName.toString());
         }
         return tmp.iterator();
@@ -512,7 +587,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Gets an instance of {@link Iterator} to iterate all headers.
-     * 
+     *
      * @return An instance of {@link Iterator} to iterate all headers
      */
     public Iterator<Map.Entry<String, String>> getAllHeaders() {
@@ -524,7 +599,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Gets the matching headers
-     * 
+     *
      * @param matchingHeaders The matching headers
      * @return The matching headers
      */
@@ -538,7 +613,7 @@ public class HeaderCollection implements Serializable {
 
     /**
      * Gets the non-matching headers
-     * 
+     *
      * @param nonMatchingHeaders The non-matching headers
      * @return The non-matching headers
      */
@@ -564,7 +639,7 @@ public class HeaderCollection implements Serializable {
      * Indicates whether some other object is "equal to" this one. However this method should be used with care since checking a given
      * header collection for equality with this one requires sorting according to header names and then comparing each header one-by-one.
      * Besides this method behaves exactly as stated in {@link Object#equals(Object) equal} method.
-     * 
+     *
      * @param obj The reference object with which to compare.
      * @return <code>true</code> if this object is the same as the object argument; <code>false</code> otherwise.
      */
@@ -785,7 +860,7 @@ public class HeaderCollection implements Serializable {
     /**
      * Specified string is invalid if it is <code>null</code>, empty, its characters are whitespace characters only or contains Non-ASCII 7
      * bit
-     * 
+     *
      * @param str The string to check
      * @param isName <code>true</code> to check a header name; otherwise <code>false</code> to check a header value
      * @return <code>true</code> if string is invalid; otherwise <code>false</code>
@@ -794,49 +869,82 @@ public class HeaderCollection implements Serializable {
         if (str == null) {
             return true;
         }
-        final char[] chars = str.toCharArray();
         if (isName) {
-            if (str.length() == 0) {
+            final int length = str.length();
+            if (length == 0) {
                 return true;
             }
-            for (int i = 0; i < chars.length; i++) {
-                if (Character.isWhitespace(chars[i])) {
+            for (int i = 0; i < length; i++) {
+                final char c = str.charAt(i);
+                if (Character.isWhitespace(c) || (c >= 128)) {
+                    /*
+                     * Whitespace or non-ascii character
+                     */
                     return true;
                 }
             }
-            return !isAscii(str);
-        }
-        if (str.length() == 0) {
+            /*
+             * All fine
+             */
             return false;
         }
-        for (int i = 0; i < chars.length; i++) {
-            if (!Character.isWhitespace(chars[i])) {
-                return false/* !isAscii(str) */;
-            }
-        }
-        return true;
+        /*
+         * A header value must not be empty
+         */
+        return isEmpty(str);
     }
 
     /**
      * Checks whether the specified string's characters are ASCII 7 bit
-     * 
+     *
      * @param s The string to check
      * @return <code>true</code> if string's characters are ASCII 7 bit; otherwise <code>false</code>
      */
     private static final boolean isAscii(final String s) {
-        final char[] chars = s.toCharArray();
+        final int length = s.length();
         boolean isAscci = true;
-        for (int i = 0; (i < chars.length) && isAscci; i++) {
-            isAscci &= (chars[i] < 128);
+        for (int i = 0; (i < length) && isAscci; i++) {
+            isAscci &= (s.charAt(i) < 128);
         }
         return isAscci;
     }
 
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
+    private static String checkValue(final String value) {
+        if (isAscii(value)) {
+            return value;
+        }
+        final int length = value.length();
+        final byte[] bytes = new byte[length];
+        for (int i = 0; i < length; i++) {
+            bytes[i] = (byte) value.charAt(i);
+        }
+        try {
+            final String detectCharset = CharsetDetector.detectCharset(new UnsynchronizedByteArrayInputStream(bytes));
+            final String unicodeVal = MessageUtility.readStream(new UnsynchronizedByteArrayInputStream(bytes), detectCharset);
+            return MimeUtility.encodeWord(unicodeVal, "UTF-8", "Q");
+        } catch (final IOException e) {
+            // Cannot occur
+            return value;
+        }
+    }
+
     /**
      * Simple test method
      */
     public static final void test() {
-        final Log log2 = org.apache.commons.logging.LogFactory.getLog(HeaderCollection.class);
+        final Log log2 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(HeaderCollection.class));
         try {
             final HeaderCollection hc = new HeaderCollection();
 
