@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,8 @@ import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.net.SocketException;
 import java.util.Arrays;
 import java.util.Locale;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import javax.mail.Address;
 import javax.mail.Folder;
 import javax.mail.MessagingException;
@@ -63,6 +65,7 @@ import com.openexchange.groupware.Component;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailConfig;
+import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.session.Session;
 import com.sun.mail.smtp.SMTPSendFailedException;
 
@@ -74,12 +77,12 @@ import com.sun.mail.smtp.SMTPSendFailedException;
  * The detail number range in subclasses generated in mail bundles is supposed to start with 2000 and may go up to 2999.
  * <p>
  * The detail number range in subclasses generated in transport bundles is supposed to start with 3000 and may go up to 3999.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class MIMEMailException extends MailException {
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEMailException.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MIMEMailException.class));
 
     private static final long serialVersionUID = -3401580182929349354L;
 
@@ -128,13 +131,13 @@ public class MIMEMailException extends MailException {
          */
         ILLEGAL_WRITE("Illegal write attempt: %1$s", Category.CODE_ERROR, 1004),
         /**
-         * Invalid method on a expunged message: %1$s
+         * Mail(s) could not be found in folder
          * <p>
          * The exception thrown when an invalid method is invoked on an expunged Message. The only valid methods on an expunged Message are
          * <code>isExpunged()</code> and <code>getMessageNumber()</code>.
          * </p>
          */
-        MESSAGE_REMOVED("Invalid method on an expunged message: %1$s", Category.CODE_ERROR, 1005),
+        MESSAGE_REMOVED(String.format(MailException.Code.MAIL_NOT_FOUND.getMessage(), "", ""), MailException.Code.MAIL_NOT_FOUND.getCategory(), MailException.Code.MAIL_NOT_FOUND.getNumber()),
         /**
          * Method not supported: %1$s
          * <p>
@@ -168,11 +171,11 @@ public class MIMEMailException extends MailException {
         /**
          * Invalid search expression: %1$s
          */
-        SEARCH_ERROR("Invalid search expression: %1$s", Category.CODE_ERROR, 1011),
+        SEARCH_ERROR("Invalid search expression: %1$s", Category.USER_INPUT, 1011),
         /**
          * Message could not be sent because it is too large
          */
-        MESSAGE_TOO_LARGE("Message could not be sent because it is too large", Category.INTERNAL_ERROR, 1012),
+        MESSAGE_TOO_LARGE("Message could not be sent because it is too large", Category.USER_INPUT, 1012),
         /**
          * Message could not be sent to following recipients: %1$s
          * <p>
@@ -182,13 +185,17 @@ public class MIMEMailException extends MailException {
          */
         SEND_FAILED("Message could not be sent to the following recipients: %1$s", Category.USER_INPUT, 1013),
         /**
-         * Store already closed: %1$s
+         * Message could not be sent to following recipients: %1$s %2$s (arbitrary server information)
          */
-        STORE_CLOSED("Store already closed: %1$s", Category.CODE_ERROR, 1014),
+        SEND_FAILED_EXT("Message could not be sent to the following recipients: %1$s %2$s", Category.USER_INPUT, 1013),
         /**
-         * Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s
+         * Lost connection to mail server.
          */
-        STORE_CLOSED_EXT("Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s", STORE_CLOSED.category, STORE_CLOSED.detailNumber),
+        STORE_CLOSED("Lost connection to mail server.", Category.SUBSYSTEM_OR_SERVICE_DOWN, 1014),
+        /**
+         * Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s).
+         */
+        STORE_CLOSED_EXT("Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s).", STORE_CLOSED.category, STORE_CLOSED.detailNumber),
         /**
          * Could not bind mail connection to local port %1$s
          * <p>
@@ -198,7 +205,7 @@ public class MIMEMailException extends MailException {
          */
         BIND_ERROR("Could not bind connection to local port %1$s", Category.SETUP_ERROR, 1015),
         /**
-         * Connect error: Connection was refused or timed out while attempting to connect to remote mail server %1$s for user %2$s.
+         * Connection was refused or timed out while attempting to connect to remote mail server %1$s for user %2$s.
          * <p>
          * An error occurred while attempting to connect to remote mail server. Typically, the connection was refused remotely (e.g., no
          * process is listening on the remote address/port).
@@ -238,9 +245,13 @@ public class MIMEMailException extends MailException {
          */
         MESSAGING_ERROR("Messaging error: %1$s", Category.CODE_ERROR, 1023),
         /**
-         * The quota on mail server is exceeded
+         * The quota on mail server exceeded.
          */
-        QUOTA_EXCEEDED("Mail server's quota is exceeded", Category.EXTERNAL_RESOURCE_FULL, 1024),
+        QUOTA_EXCEEDED("The quota on mail server exceeded.", Category.EXTERNAL_RESOURCE_FULL, 1024),
+        /**
+         * The quota on mail server "%1$s" exceeded with login %2$s (user=%3$s, context=%4$s).
+         */
+        QUOTA_EXCEEDED_EXT("The quota on mail server \"%1$s\" exceeded with login %2$s (user=%3$s, context=%4$s).", QUOTA_EXCEEDED.category, QUOTA_EXCEEDED.detailNumber),
         /**
          * A command to mail server failed. Server response: %1$s
          */
@@ -269,6 +280,10 @@ public class MIMEMailException extends MailException {
          * Message could not be sent: %1$s
          */
         SEND_FAILED_MSG("Message could not be sent: %1$s", Category.CODE_ERROR, 1028),
+        /**
+         * Message could not be sent: %1$s %2$s (arbitrary server information)
+         */
+        SEND_FAILED_MSG_EXT("Message could not be sent: %1$s %2$s", Category.CODE_ERROR, 1028),
         /**
          * Message cannot be displayed.
          */
@@ -280,8 +295,33 @@ public class MIMEMailException extends MailException {
         /**
          * Wrong or missing login data to access mail transport server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail transport server: %5$s
          */
-        TRANSPORT_INVALID_CREDENTIALS_EXT("Wrong or missing login data to access mail transport server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail transport server: %5$s", Category.PERMISSION, TRANSPORT_INVALID_CREDENTIALS.detailNumber);
-        
+        TRANSPORT_INVALID_CREDENTIALS_EXT("Wrong or missing login data to access mail transport server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail transport server: %5$s", Category.PERMISSION, TRANSPORT_INVALID_CREDENTIALS.detailNumber),
+        /**
+         * Error processing mail server response. The administrator has been informed.
+         */
+        PROCESSING_ERROR("Error processing mail server response. The administrator has been informed.", Category.CODE_ERROR, 1031),
+        /**
+         * Error processing %1$s mail server response for login %2$s (user=%3$s, context=%4$s). The administrator has been informed.
+         */
+        PROCESSING_ERROR_EXT("Error processing %1$s mail server response for login %2$s (user=%3$s, context=%4$s). The administrator has been informed.", Category.CODE_ERROR, PROCESSING_ERROR.detailNumber),
+        /**
+         * An I/O error occurred: %1$s
+         */
+        IO_ERROR(MailException.Code.IO_ERROR),
+        /**
+         * I/O error "%1$s" occurred in communication with "%2$s" mail server for login %3$s (user=%4$s, context=%5$s).
+         */
+        IO_ERROR_EXT(MailException.Code.IO_ERROR, "I/O error \"%1$s\" occurred in communication with \"%2$s\" mail server for login %3$s (user=%4$s, context=%5$s)."),
+        /**
+         * Error processing mail server response. The administrator has been informed. Error message: %1$s
+         */
+        PROCESSING_ERROR_WE("Error processing mail server response. The administrator has been informed. Error message: %1$s", Category.CODE_ERROR, PROCESSING_ERROR.detailNumber),
+        /**
+         * Error processing %1$s mail server response for login %2$s (user=%3$s, context=%4$s). The administrator has been informed. Error message: %5$s
+         */
+        PROCESSING_ERROR_WE_EXT("Error processing %1$s mail server response for login %2$s (user=%3$s, context=%4$s). The administrator has been informed. Error message: %5$s", Category.CODE_ERROR, PROCESSING_ERROR_WE.detailNumber),
+        ;
+
         private final String message;
 
         private final int detailNumber;
@@ -294,6 +334,18 @@ public class MIMEMailException extends MailException {
             this.category = category;
         }
 
+        private Code(final MailException.Code code, final String message) {
+            this.message = message;
+            this.detailNumber = code.getNumber();
+            this.category = code.getCategory();
+        }
+
+        private Code(final MailException.Code code) {
+            this.message = code.getMessage();
+            this.detailNumber = code.getNumber();
+            this.category = code.getCategory();
+        }
+
         public Category getCategory() {
             return category;
         }
@@ -335,23 +387,23 @@ public class MIMEMailException extends MailException {
      * <p>
      * This is just a convenience method that simply invokes {@link #handleMessagingException(MessagingException, MailConfig)} with the
      * latter parameter set to <code>null</code>.
-     * 
+     *
      * @param e The messaging exception
      * @return An appropriate instance of {@link MIMEMailException}
      */
     public static MIMEMailException handleMessagingException(final MessagingException e) {
-        return handleMessagingException(e, null);
+        return handleMessagingException(e, null, null);
     }
 
     /**
      * Handles given instance of {@link MessagingException} and creates an appropriate instance of {@link MIMEMailException}
-     * 
+     *
      * @param e The messaging exception
      * @param mailConfig The corresponding mail configuration used to add information like mail server etc.
      * @return An appropriate instance of {@link MIMEMailException}
      */
     public static MIMEMailException handleMessagingException(final MessagingException e, final MailConfig mailConfig) {
-        return handleMessagingException(e, mailConfig, null);
+        return handleMessagingException(e, mailConfig, mailConfig.getSession());
     }
 
     private static final String STR_EMPTY = "";
@@ -371,7 +423,7 @@ public class MIMEMailException extends MailException {
 
     /**
      * Handles given instance of {@link MessagingException} and creates an appropriate instance of {@link MIMEMailException}
-     * 
+     *
      * @param e The messaging exception
      * @param mailConfig The corresponding mail configuration used to add information like mail server etc.
      * @param session The session providing user information
@@ -379,10 +431,11 @@ public class MIMEMailException extends MailException {
      */
     public static MIMEMailException handleMessagingException(final MessagingException e, final MailConfig mailConfig, final Session session) {
         try {
-            if ((e instanceof javax.mail.AuthenticationFailedException) || ((e.getMessage() != null) && (e.getMessage().toLowerCase(Locale.ENGLISH).indexOf(
-                ERR_AUTH_FAILED) != -1))) {
-                final boolean temporary = (e.getMessage() != null) && ERR_TMP.equals(e.getMessage().toLowerCase(Locale.ENGLISH));
-                if (temporary) {
+            if ((e instanceof javax.mail.AuthenticationFailedException) || ((e.getMessage() != null) && (e.getMessage().toLowerCase(Locale.ENGLISH).indexOf(ERR_AUTH_FAILED) != -1))) {
+                if (null != mailConfig && MailAccount.DEFAULT_ID == mailConfig.getAccountId()) {
+                    return new MIMEMailException(MIMEMailException.Code.LOGIN_FAILED, e, mailConfig.getServer(), mailConfig.getLogin());
+                }
+                if ((e.getMessage() != null) && ERR_TMP.equals(e.getMessage().toLowerCase(Locale.ENGLISH))) {
                     return new MIMEMailException(
                         MIMEMailException.Code.LOGIN_FAILED,
                         e,
@@ -440,8 +493,8 @@ public class MIMEMailException extends MailException {
                 return new MIMEMailException(Code.NO_SUCH_PROVIDER, e, e.getMessage());
             } else if (e instanceof javax.mail.internet.ParseException) {
                 if (e instanceof javax.mail.internet.AddressException) {
-                    final String ref = ((AddressException) e).getRef() == null ? STR_EMPTY : ((AddressException) e).getRef();
-                    return new MIMEMailException(Code.INVALID_EMAIL_ADDRESS, e, ref);
+                    final String optRef = ((AddressException) e).getRef();
+                    return new MIMEMailException(Code.INVALID_EMAIL_ADDRESS, e, optRef == null ? STR_EMPTY : optRef);
                 }
                 return new MIMEMailException(Code.PARSE_ERROR, e, e.getMessage());
             } else if (e instanceof javax.mail.ReadOnlyFolderException) {
@@ -474,7 +527,24 @@ public class MIMEMailException extends MailException {
                 if (exc.getMessage().toLowerCase(Locale.ENGLISH).indexOf(ERR_MSG_TOO_LARGE) > -1) {
                     return new MIMEMailException(Code.MESSAGE_TOO_LARGE, exc, new Object[0]);
                 }
-                return new MIMEMailException(Code.SEND_FAILED, exc, Arrays.toString(exc.getInvalidAddresses()));
+                final Exception nextException = exc.getNextException();
+                if (nextException instanceof com.sun.mail.smtp.SMTPSendFailedException) {
+                    final SMTPSendFailedException smtpExc = (SMTPSendFailedException) nextException;
+                    final Address[] invalidAddresses = smtpExc.getInvalidAddresses();
+                    if (null == invalidAddresses || invalidAddresses.length == 0) {
+                        return new MIMEMailException(Code.SEND_FAILED_MSG_EXT, exc, exc.getMessage(), '('+smtpExc.getMessage()+')');
+                    }
+                }
+                String serverInfo = null;
+                if (nextException instanceof com.sun.mail.smtp.SMTPAddressFailedException) {
+                    serverInfo = nextException.getMessage();
+                }
+                final Address[] addrs = exc.getInvalidAddresses();
+                if (null == addrs || addrs.length == 0) {
+                    // No invalid addresses available
+                    return new MIMEMailException(Code.SEND_FAILED_MSG, exc, exc.getMessage());
+                }
+                return new MIMEMailException(Code.SEND_FAILED_EXT, exc, Arrays.toString(addrs), null == serverInfo ? "" : '('+serverInfo+')');
             } else if (e instanceof javax.mail.StoreClosedException) {
                 if (null != mailConfig && null != session) {
                     return new MIMEMailException(
@@ -484,9 +554,9 @@ public class MIMEMailException extends MailException {
                         mailConfig.getLogin(),
                         Integer.valueOf(session.getUserId()),
                         Integer.valueOf(session.getContextId()),
-                        e.getMessage());
+                        EMPTY_ARGS);
                 }
-                return new MIMEMailException(Code.STORE_CLOSED, e, e.getMessage());
+                return new MIMEMailException(Code.STORE_CLOSED, e, EMPTY_ARGS);
             }
             final Exception nextException = e.getNextException();
             if (nextException == null) {
@@ -553,22 +623,34 @@ public class MIMEMailException extends MailException {
                     e,
                     mailConfig == null ? STR_EMPTY : mailConfig.getServer(),
                     mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
+            } else if (nextException instanceof com.openexchange.mail.mime.QuotaExceededException) {
+                if (null != mailConfig && null != session) {
+                    return new MIMEMailException(
+                        Code.QUOTA_EXCEEDED_EXT,
+                        e,
+                        mailConfig.getServer(),
+                        mailConfig.getLogin(),
+                        Integer.valueOf(session.getUserId()),
+                        Integer.valueOf(session.getContextId()),
+                        nextException.getMessage());
+                }
+                return new MIMEMailException(Code.QUOTA_EXCEEDED, e, nextException.getMessage());
             } else if (nextException instanceof com.sun.mail.iap.CommandFailedException) {
                 if (null != mailConfig && null != session) {
                     return new MIMEMailException(
-                        Code.COMMAND_FAILED_EXT,
+                        Code.PROCESSING_ERROR_WE_EXT,
                         e,
                         mailConfig.getServer(),
                         mailConfig.getLogin(),
                         Integer.valueOf(session.getUserId()),
                         Integer.valueOf(session.getContextId()),
-                        nextException.getMessage());
+                        skipTag(nextException.getMessage()));
                 }
-                return new MIMEMailException(Code.COMMAND_FAILED, e, nextException.getMessage());
+                return new MIMEMailException(Code.PROCESSING_ERROR_WE, e, skipTag(nextException.getMessage()));
             } else if (nextException instanceof com.sun.mail.iap.BadCommandException) {
                 if (null != mailConfig && null != session) {
                     return new MIMEMailException(
-                        Code.BAD_COMMAND_EXT,
+                        Code.PROCESSING_ERROR_EXT,
                         e,
                         mailConfig.getServer(),
                         mailConfig.getLogin(),
@@ -576,11 +658,11 @@ public class MIMEMailException extends MailException {
                         Integer.valueOf(session.getContextId()),
                         nextException.getMessage());
                 }
-                return new MIMEMailException(Code.BAD_COMMAND, e, nextException.getMessage());
+                return new MIMEMailException(Code.PROCESSING_ERROR, e, nextException.getMessage());
             } else if (nextException instanceof com.sun.mail.iap.ProtocolException) {
                 if (null != mailConfig && null != session) {
                     return new MIMEMailException(
-                        Code.PROTOCOL_ERROR_EXT,
+                        Code.PROCESSING_ERROR_EXT,
                         e,
                         mailConfig.getServer(),
                         mailConfig.getLogin(),
@@ -588,14 +670,26 @@ public class MIMEMailException extends MailException {
                         Integer.valueOf(session.getContextId()),
                         nextException.getMessage());
                 }
-                return new MIMEMailException(Code.PROTOCOL_ERROR, e, nextException.getMessage());
+                return new MIMEMailException(Code.PROCESSING_ERROR, e, nextException.getMessage());
+            } else if (nextException instanceof java.io.IOException) {
+                if (null != mailConfig && null != session) {
+                    return new MIMEMailException(
+                        Code.IO_ERROR_EXT,
+                        e,
+                        nextException.getMessage(),
+                        mailConfig.getServer(),
+                        mailConfig.getLogin(),
+                        Integer.valueOf(session.getUserId()),
+                        Integer.valueOf(session.getContextId()));
+                }
+                return new MIMEMailException(Code.IO_ERROR, nextException, nextException.getMessage());
             } else if (e.getMessage().toLowerCase(Locale.ENGLISH).indexOf(ERR_QUOTA) != -1) {
                 return new MIMEMailException(Code.QUOTA_EXCEEDED, e, EMPTY_ARGS);
             }
             /*
              * Default case
              */
-            return new MIMEMailException(Code.MESSAGING_ERROR, e, e.getMessage());
+            return new MIMEMailException(Code.MESSAGING_ERROR, nextException, nextException.getMessage());
         } catch (final Throwable t) {
             if (LOG.isWarnEnabled()) {
                 LOG.warn(t.getMessage(), t);
@@ -606,4 +700,18 @@ public class MIMEMailException extends MailException {
             return new MIMEMailException(Code.MESSAGING_ERROR, e, e.getMessage());
         }
     }
+
+    private static final Pattern PATTERN_TAG = Pattern.compile("A[0-9]+ (.+)");
+
+    private static String skipTag(final String serverResponse) {
+        if (null == serverResponse) {
+            return null;
+        }
+        final Matcher m = PATTERN_TAG.matcher(serverResponse);
+        if (m.matches()) {
+            return m.group(1);
+        }
+        return serverResponse;
+    }
+
 }
