@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -78,16 +78,16 @@ import com.openexchange.configuration.SystemConfig;
  * <li>The file or resource named <i>META-INF/mimetypes.default</i>.</li>
  * <li>The file or resource denoted by property <i>MimeTypeFile</i>.</li>
  * </ol>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MIMEType2ExtMap {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEType2ExtMap.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MIMEType2ExtMap.class));
 
-    private static Map<String, String> typeMap;
+    private static volatile Map<String, String> typeMap;
 
-    private static Map<String, List<String>> extMap;
+    private static volatile Map<String, List<String>> extMap;
 
     /**
      * No instance.
@@ -100,12 +100,14 @@ public final class MIMEType2ExtMap {
      * Resets MIME type file map.
      */
     public static void reset() {
-        synchronized (MIMEType2ExtMap.class) {
-            if (null == typeMap) {
-                return;
+        if (null != typeMap) {
+            synchronized (MIMEType2ExtMap.class) {
+                if (null == typeMap) {
+                    return;
+                }
+                typeMap = null;
+                extMap = null;
             }
-            typeMap = null;
-            extMap = null;
         }
     }
 
@@ -113,89 +115,91 @@ public final class MIMEType2ExtMap {
      * Initializes MIME type file map.
      */
     public static void init() {
-        synchronized (MIMEType2ExtMap.class) {
-            if (null != typeMap) {
-                return;
-            }
-            try {
-                typeMap = new HashMap<String, String>();
-                extMap = new HashMap<String, List<String>>();
-                final StringBuilder sb = new StringBuilder(128);
-                {
-                    final String homeDir = System.getProperty("user.home");
-                    if (homeDir != null) {
-                        final File file = new File(sb.append(homeDir).append(File.separatorChar).append(".mime.types").toString());
-                        if (file.exists()) {
-                            if (LOG.isInfoEnabled()) {
-                                sb.setLength(0);
-                                LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
+        if (null == typeMap) {
+            synchronized (MIMEType2ExtMap.class) {
+                if (null != typeMap) {
+                    return;
+                }
+                try {
+                    typeMap = new HashMap<String, String>();
+                    extMap = new HashMap<String, List<String>>();
+                    final StringBuilder sb = new StringBuilder(128);
+                    {
+                        final String homeDir = System.getProperty("user.home");
+                        if (homeDir != null) {
+                            final File file = new File(sb.append(homeDir).append(File.separatorChar).append(".mime.types").toString());
+                            if (file.exists()) {
+                                if (LOG.isInfoEnabled()) {
+                                    sb.setLength(0);
+                                    LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
+                                }
+                                loadInternal(file);
                             }
-                            loadInternal(file);
                         }
                     }
-                }
-                {
-                    final String javaHome = System.getProperty("java.home");
-                    if (javaHome != null) {
-                        sb.setLength(0);
-                        final File file =
-                            new File(sb.append(javaHome).append(File.separatorChar).append("lib").append(File.separator).append(
-                                "mime.types").toString());
-                        if (file.exists()) {
-                            if (LOG.isInfoEnabled()) {
-                                sb.setLength(0);
-                                LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
-                            }
-                            loadInternal(file);
-                        }
-                    }
-                }
-                {
-                    for (final Enumeration<URL> e = ClassLoader.getSystemResources("META-INF/mime.types"); e.hasMoreElements();) {
-                        final URL url = e.nextElement();
-                        if (LOG.isInfoEnabled()) {
+                    {
+                        final String javaHome = System.getProperty("java.home");
+                        if (javaHome != null) {
                             sb.setLength(0);
-                            LOG.info(sb.append("Loading MIME type file \"").append(url.getFile()).append('"').toString());
+                            final File file =
+                                new File(sb.append(javaHome).append(File.separatorChar).append("lib").append(File.separator).append(
+                                    "mime.types").toString());
+                            if (file.exists()) {
+                                if (LOG.isInfoEnabled()) {
+                                    sb.setLength(0);
+                                    LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
+                                }
+                                loadInternal(file);
+                            }
                         }
-                        loadInternal(url);
                     }
-                }
-                {
-                    for (final Enumeration<URL> e = ClassLoader.getSystemResources("META-INF/mimetypes.default"); e.hasMoreElements();) {
-                        final URL url = e.nextElement();
-                        if (LOG.isInfoEnabled()) {
-                            sb.setLength(0);
-                            LOG.info(sb.append("Loading MIME type file \"").append(url.getFile()).append('"').toString());
-                        }
-                        loadInternal(url);
-                    }
-                }
-                {
-                    String mimeTypesFile = SystemConfig.getProperty(SystemConfig.Property.MimeTypeFile);
-                    if ((mimeTypesFile != null) && ((mimeTypesFile = mimeTypesFile.trim()).length() > 0)) {
-                        final File file = new File(mimeTypesFile);
-                        if (file.exists()) {
+                    {
+                        for (final Enumeration<URL> e = ClassLoader.getSystemResources("META-INF/mime.types"); e.hasMoreElements();) {
+                            final URL url = e.nextElement();
                             if (LOG.isInfoEnabled()) {
                                 sb.setLength(0);
-                                LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
+                                LOG.info(sb.append("Loading MIME type file \"").append(url.getFile()).append('"').toString());
                             }
-                            loadInternal(file);
+                            loadInternal(url);
                         }
                     }
+                    {
+                        for (final Enumeration<URL> e = ClassLoader.getSystemResources("META-INF/mimetypes.default"); e.hasMoreElements();) {
+                            final URL url = e.nextElement();
+                            if (LOG.isInfoEnabled()) {
+                                sb.setLength(0);
+                                LOG.info(sb.append("Loading MIME type file \"").append(url.getFile()).append('"').toString());
+                            }
+                            loadInternal(url);
+                        }
+                    }
+                    {
+                        String mimeTypesFile = SystemConfig.getProperty(SystemConfig.Property.MimeTypeFile);
+                        if ((mimeTypesFile != null) && ((mimeTypesFile = mimeTypesFile.trim()).length() > 0)) {
+                            final File file = new File(mimeTypesFile);
+                            if (file.exists()) {
+                                if (LOG.isInfoEnabled()) {
+                                    sb.setLength(0);
+                                    LOG.info(sb.append("Loading MIME type file \"").append(file.getPath()).append('"').toString());
+                                }
+                                loadInternal(file);
+                            }
+                        }
 
+                    }
+                    if (LOG.isInfoEnabled()) {
+                        LOG.info("MIMEType2ExtMap successfully initialized");
+                    }
+                } catch (final IOException e) {
+                    LOG.error(e.getMessage(), e);
                 }
-                if (LOG.isInfoEnabled()) {
-                    LOG.info("MIMEType2ExtMap successfully initialized");
-                }
-            } catch (final IOException e) {
-                LOG.error(e.getMessage(), e);
             }
         }
     }
 
     /**
      * Gets the MIME type associated with given file.
-     * 
+     *
      * @param file The file
      * @return The MIME type associated with given file or <code>application/octet-stream</code> if none found
      */
@@ -205,7 +209,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Gets the MIME type associated with given file name.
-     * 
+     *
      * @param fileName The file name; e.g. <code>"file.html"</code>
      * @return The MIME type associated with given file name or <code>application/octet-stream</code> if none found
      */
@@ -231,7 +235,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Gets the MIME type associated with given file extension.
-     * 
+     *
      * @param extension The file extension; e.g. <code>"txt"</code>
      * @return The MIME type associated with given file extension or <code>application/octet-stream</code> if none found
      */
@@ -257,7 +261,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Gets the file extension for given MIME type.
-     * 
+     *
      * @param mimeType The MIME type
      * @return The file extension for given MIME type or <code>dat</code> if none found
      */
@@ -268,7 +272,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Loads the MIME type file specified through <code>fileStr</code>.
-     * 
+     *
      * @param fileStr The MIME type file to load
      */
     public static void load(final String fileStr) {
@@ -278,7 +282,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Loads the MIME type file specified through given file.
-     * 
+     *
      * @param file The MIME type file to load
      */
     public static void load(final File file) {
@@ -288,7 +292,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Loads the MIME type file specified through given file.
-     * 
+     *
      * @param file The MIME type file to load
      */
     private static void loadInternal(final File file) {
@@ -315,7 +319,7 @@ public final class MIMEType2ExtMap {
 
     /**
      * Loads the MIME type file specified through given URL.
-     * 
+     *
      * @param url The URL to a MIME type file
      */
     private static void loadInternal(final URL url) {
@@ -364,6 +368,8 @@ public final class MIMEType2ExtMap {
         } else if (entry.charAt(0) == '#') {
             return;
         }
+        final Map<String, List<String>> extMap = MIMEType2ExtMap.extMap;
+        final Map<String, String> typeMap = MIMEType2ExtMap.typeMap;
         if (entry.indexOf('=') > 0) {
             final MimeTypeFileLineParser parser = new MimeTypeFileLineParser(entry);
             final String type = parser.getType();
