@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,7 +67,7 @@ import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 
 /**
  * {@link ParameterList} - Represents the parameter list of a parameterized header.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ParameterList implements Cloneable, Serializable, Comparable<ParameterList> {
@@ -77,7 +77,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
      */
     private static final long serialVersionUID = 1085330725813918879L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ParameterList.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ParameterList.class));
 
     /**
      * The regular expression to parse parameters
@@ -91,7 +91,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
     private static final Pattern PATTERN_PARAM_CORRECT;
 
     static {
-        final String paramNameRegex = "([\\p{ASCII}&&[^=\"\\s;]]+)";
+        final String paramNameRegex = "([\\p{L}\\p{ASCII}&&[^=\"\\s;]]+)";
         final String tokenRegex = "(?:[^\"][\\S&&[^\\s,;:\\\\\"/\\[\\]?()<>@]]*)";
         final String quotedStringRegex = "(?:\"(?:(?:\\\\\\\")|[^\"])+?\")"; // Grab '\"' char sequence or any non-quote character
         PATTERN_PARAM_LIST =
@@ -114,7 +114,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Initializes a new parameter list from specified parameter list's string representation.
-     * 
+     *
      * @param parameterList The parameter list's string representation
      */
     public ParameterList(final String parameterList) {
@@ -128,7 +128,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
      * <li>Ensures starting <code>';'</code> character</li>
      * <li>Turns any unquoted strings to quoted strings</li>
      * </ul>
-     * 
+     *
      * @param parameterList The parameter list's string representation to correct
      * @return The corrected parameter list's string representation.
      */
@@ -210,9 +210,30 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
     }
 
     private void parseParameterList(final String parameterList) {
-        final Matcher m = PATTERN_PARAM_LIST.matcher(parameterList);
-        while (m.find()) {
-            parseParameter(m.group(1).toLowerCase(Locale.ENGLISH), m.group(2));
+        try {
+            final Matcher m = PATTERN_PARAM_LIST.matcher(parameterList);
+            while (m.find()) {
+                parseParameter(m.group(1).toLowerCase(Locale.ENGLISH), m.group(2));
+            }
+        } catch (final StackOverflowError regexFailed) {
+            /*
+             * Regex failed for given parameter list. Perform very simple manual parsing.
+             */
+            int pos = parameterList.indexOf(';');
+            while (pos >= 0) {
+                final int delim = parameterList.indexOf('=', pos);
+                if (delim < 0) {
+                    final int pos2 = parameterList.indexOf(';', pos + 1);
+                    final String name = pos2 < 0 ? parameterList.substring(pos + 1).trim() : parameterList.substring(pos + 1, pos2).trim();
+                    parseParameter(name.toLowerCase(Locale.ENGLISH), "");
+                    pos = pos2;
+                } else {
+                    final String name = parameterList.substring(pos + 1, delim).trim();
+                    pos = parameterList.indexOf(';', pos + 1);
+                    final String value = pos < 0 ? parameterList.substring(delim + 1) : parameterList.substring(delim + 1, pos);
+                    parseParameter(name.toLowerCase(Locale.ENGLISH), value);
+                }
+            }
         }
     }
 
@@ -285,7 +306,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Sets the given parameter. Existing value is overwritten.
-     * 
+     *
      * @param name The sole parameter name
      * @param value The parameter value
      */
@@ -300,7 +321,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Adds specified value to given parameter name. If existing, the parameter is treated as a contiguous parameter according to RFC2231.
-     * 
+     *
      * @param name The parameter name
      * @param value The parameter value to add
      */
@@ -324,7 +345,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Gets specified parameter's value
-     * 
+     *
      * @param name The parameter name
      * @return The parameter's value or <code>null</code> if not existing
      */
@@ -341,7 +362,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Removes specified parameter and returns its value
-     * 
+     *
      * @param name The parameter name
      * @return The parameter's value or <code>null</code> if not existing
      */
@@ -358,7 +379,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Checks if parameter is present
-     * 
+     *
      * @param name the parameter name
      * @return <code>true</code> if parameter is present; otherwise <code>false</code>
      */
@@ -375,20 +396,45 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * Gets all parameter names wrapped in an {@link Iterator}
-     * 
+     *
      * @return All parameter names wrapped in an {@link Iterator}
      */
     public Iterator<String> getParameterNames() {
         return parameters.keySet().iterator();
     }
 
-    public void appendUnicodeString(final StringBuilder sb) {
+    /**
+     * Appends the RFC2045 style (ASCII-only) string representation of this parameter list including empty parameters.
+     *
+     * @param sb The string builder to append to
+     * @see #appendRFC2045String(StringBuilder, boolean)
+     */
+    public void appendRFC2045String(final StringBuilder sb) {
+        appendRFC2045String(sb, false);
+    }
+
+    /**
+     * Appends the RFC2045 style (ASCII-only) string representation of this parameter list.
+     *
+     * @param sb The string builder to append to
+     * @param skipEmptyParam <code>true</code> to skip empty parameters; otherwise <code>false</code>
+     */
+    public void appendRFC2045String(final StringBuilder sb, final boolean skipEmptyParam) {
         final int size = parameters.size();
         final List<String> names = new ArrayList<String>(size);
         names.addAll(parameters.keySet());
         Collections.sort(names);
-        for (final String name : names) {
-            parameters.get(name).appendUnicodeString(sb);
+        if (skipEmptyParam) {
+            for (final String name : names) {
+                final Parameter parameter = parameters.get(name);
+                if (!parameter.contiguousValues.isEmpty()) {
+                    parameter.appendRFC2045String(sb);
+                }
+            }
+        } else {
+            for (final String name : names) {
+                parameters.get(name).appendRFC2045String(sb);
+            }
         }
 
         // final Iterator<Parameter> iter = parameters.values().iterator();
@@ -408,7 +454,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
         names.addAll(parameters.keySet());
         Collections.sort(names);
         for (final String name : names) {
-            parameters.get(name).appendUnicodeString(sb);
+            parameters.get(name).appendRFC2045String(sb);
         }
 
         // final Iterator<Parameter> iter = parameters.values().iterator();
@@ -471,12 +517,12 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
     /**
      * {@link Parameter} - Inner class to represent a parameter.
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     private static final class Parameter implements Cloneable, Serializable, Comparable<Parameter> {
 
-        private static final transient org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(Parameter.class);
+        private static final transient org.apache.commons.logging.Log LOG1 = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Parameter.class));
 
         private static final long serialVersionUID = 7978948703870567515L;
 
@@ -494,7 +540,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Initializes a new rfc2231 parameter.
-         * 
+         *
          * @param name The parameter name without asterix characters
          */
         public Parameter(final String name) {
@@ -506,7 +552,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Initializes a new rfc2047 parameter.
-         * 
+         *
          * @param name The parameter name
          * @param value The parameter value
          */
@@ -617,7 +663,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Gets the charset
-         * 
+         *
          * @return the charset
          */
         public String getCharset() {
@@ -626,7 +672,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Sets the charset
-         * 
+         *
          * @param charset the charset to set
          */
         public void setCharset(final String charset) {
@@ -635,7 +681,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Gets the language
-         * 
+         *
          * @return the language
          */
         public String getLanguage() {
@@ -644,7 +690,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
 
         /**
          * Sets the language
-         * 
+         *
          * @param language the language to set
          */
         public void setLanguage(final String language) {
@@ -684,7 +730,7 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
             return value;
         }
 
-        public void appendUnicodeString(final StringBuilder sb) {
+        public void appendRFC2045String(final StringBuilder sb) {
             final int size = contiguousValues.size();
             if (size == 0) {
                 sb.append("; ").append(name);
@@ -820,5 +866,6 @@ public final class ParameterList implements Cloneable, Serializable, Comparable<
             }
         }
 
-    }
+    } // End of class Parameter
+
 }
