@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,9 +53,13 @@ import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
+import java.util.regex.Pattern;
 import javax.mail.internet.AddressException;
+import javax.mail.internet.IDNA;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeUtility;
+import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 
 /**
  * {@link QuotedInternetAddress} - A quoted version of {@link InternetAddress} originally written by <b>Bill Shannon</b> and <b>John
@@ -73,14 +77,14 @@ import javax.mail.internet.MimeUtility;
  * <code>``"M&uuml;ller,&nbsp;Jan"&nbsp;&lt;mj@foo.de&gt;''</code><br>
  * is converted to<br>
  * <code>``=?UTF-8?Q?=22M=C3=BCller=2C_Jan=22?=&nbsp;&lt;mj@foo.de&gt;''</code>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class QuotedInternetAddress extends InternetAddress {
 
     private static final long serialVersionUID = -2523736473507495692L;
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(QuotedInternetAddress.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(QuotedInternetAddress.class));
 
     private static final boolean IGNORE_BOGUS_GROUP_NAME = getBooleanSystemProperty("mail.mime.address.ignorebogusgroupname", true);
 
@@ -90,7 +94,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Converts given array of {@link InternetAddress} to quoted addresses
-     * 
+     *
      * @param addrs The addresses to convert
      * @return The quoted addresses
      * @throws AddressException If conversion fails
@@ -108,7 +112,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Parse the given comma separated sequence of addresses into {@link InternetAddress} objects. Addresses must follow RFC822 syntax.
-     * 
+     *
      * @param addresslist A comma separated address strings
      * @return An array of {@link InternetAddress} objects
      * @exception AddressException If the parse failed
@@ -125,7 +129,7 @@ public final class QuotedInternetAddress extends InternetAddress {
      * <p>
      * Non-strict parsing is typically used when parsing a list of mail addresses entered by a human. Strict parsing is typically used when
      * parsing address headers in mail messages.
-     * 
+     *
      * @param addresslist A comma separated address strings
      * @param strict <code>true</code> to enforce RFC822 syntax; otherwise <code>false</code>
      * @return An array of {@link InternetAddress} objects
@@ -144,7 +148,7 @@ public final class QuotedInternetAddress extends InternetAddress {
      * <code>parse</code> method when the strict flag is false and enforces more rules when the strict flag is true. If the strict flag is
      * false and the parse is successful in separating out an email address or addresses, the syntax of the addresses themselves is not
      * checked.
-     * 
+     *
      * @param addresslist A comma separated address strings
      * @param strict <code>true</code> to enforce RFC822 syntax; otherwise <code>false</code>
      * @return An array of {@link InternetAddress} objects
@@ -622,7 +626,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
         final int len = addr.length();
         if (len == 0) {
-            throw new AddressException("Empty address", addr);
+            throw new AddressException("Empty address", addr.toString());
         }
 
         /*
@@ -634,7 +638,7 @@ public final class QuotedInternetAddress extends InternetAddress {
              */
             for (start = 0; (i = indexOfAny(addr, ",:", start)) >= 0; start = i + 1) {
                 if (addr.charAt(start) != '@') {
-                    throw new AddressException("Illegal route-addr", addr);
+                    throw new AddressException("Illegal route-addr", addr.toString());
                 }
                 if (addr.charAt(i) == ':') {
                     // end of route-addr
@@ -664,12 +668,12 @@ public final class QuotedInternetAddress extends InternetAddress {
                 if (inquote) {
                     // peek ahead, next char must be "@"
                     if (validate && i + 1 < len && addr.charAt(i + 1) != '@') {
-                        throw new AddressException("Quote not at end of local address", addr);
+                        throw new AddressException("Quote not at end of local address", addr.toString());
                     }
                     inquote = false;
                 } else {
                     if (validate && i != 0) {
-                        throw new AddressException("Quote not at start of local address", addr);
+                        throw new AddressException("Quote not at start of local address", addr.toString());
                     }
                     inquote = true;
                 }
@@ -680,19 +684,19 @@ public final class QuotedInternetAddress extends InternetAddress {
             }
             if (c == '@') {
                 if (i == 0) {
-                    throw new AddressException("Missing local name", addr);
+                    throw new AddressException("Missing local name", addr.toString());
                 }
                 break; // done with local part
             }
             if (c <= 040 || c >= 0177) {
-                throw new AddressException("Local address contains control or whitespace", addr);
+                throw new AddressException("Local address contains control or whitespace", addr.toString());
             }
             if (SPECIALS_NO_DOT.indexOf(c) >= 0) {
-                throw new AddressException("Local address contains illegal character", addr);
+                throw new AddressException("Local address contains illegal character", addr.toString());
             }
         }
         if (inquote) {
-            throw new AddressException("Unterminated quote", addr);
+            throw new AddressException("Unterminated quote", addr.toString());
         }
 
         /*
@@ -704,7 +708,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
         if (c != '@') {
             if (validate) {
-                throw new AddressException("Missing final '@domain'", addr);
+                throw new AddressException("Missing final '@domain'", addr.toString());
             }
             return;
         }
@@ -713,11 +717,11 @@ public final class QuotedInternetAddress extends InternetAddress {
 
         start = i + 1;
         if (start >= len) {
-            throw new AddressException("Missing domain", addr);
+            throw new AddressException("Missing domain", addr.toString());
         }
 
         if (addr.charAt(start) == '.') {
-            throw new AddressException("Domain starts with dot", addr);
+            throw new AddressException("Domain starts with dot", addr.toString());
         }
         for (i = start; i < len; i++) {
             c = addr.charAt(i);
@@ -725,18 +729,18 @@ public final class QuotedInternetAddress extends InternetAddress {
                 return; // domain literal, don't validate
             }
             if (c <= 040 || c >= 0177) {
-                throw new AddressException("Domain contains control or whitespace", addr);
+                throw new AddressException("Domain contains control or whitespace", addr.toString());
             }
             if (SPECIALS_NO_DOT.indexOf(c) >= 0) {
-                throw new AddressException("Domain contains illegal character", addr);
+                throw new AddressException("Domain contains illegal character", addr.toString());
             }
             if (c == '.' && lastc == '.') {
-                throw new AddressException("Domain contains dot-dot", addr);
+                throw new AddressException("Domain contains dot-dot", addr.toString());
             }
             lastc = c;
         }
         if (lastc == '.') {
-            throw new AddressException("Domain ends with dot", addr);
+            throw new AddressException("Domain ends with dot", addr.toString());
         }
     }
 
@@ -744,54 +748,44 @@ public final class QuotedInternetAddress extends InternetAddress {
      * Converts a unicode representation of an internet address to ASCII using the procedure in RFC3490 section 4.1. Unassigned characters
      * are not allowed and STD3 ASCII rules are enforced.
      * <p>
+     * This implementation already supports EsZett character. Thanks to <a
+     * href="http://blog.http.net/code/gnu-libidn-eszett-hotfix/">http.net</a>!
+     * <p>
      * <code>"someone@m&uuml;ller.de"</code> is converted to <code>"someone@xn--mller-kva.de"</code>
-     * 
+     *
      * @param idnAddress The unicode representation of an internet address
      * @return The ASCII-encoded (punycode) of given internet address
      * @throws AddressException If ASCII representation of given internet address cannot be created
      */
     public static String toACE(final String idnAddress) throws AddressException {
-        if (null == idnAddress) {
-            return null;
-        }
-        try {
-            final int pos = idnAddress.indexOf('@');
-            if (pos < 0) {
-                return idnAddress;
-            }
-            return new StringBuilder(idnAddress.length() + 8).append(idnAddress.substring(0, pos)).append('@').append(
-                gnu.inet.encoding.IDNA.toASCII(idnAddress.substring(pos + 1))).toString();
-        } catch (final gnu.inet.encoding.IDNAException e) {
-            throw new AddressException(new StringBuilder(e.getMessage()).append(": ").append(idnAddress).toString());
-        }
+        return IDNA.toACE(idnAddress);
     }
 
     /**
      * Converts an ASCII-encoded address to its unicode representation. Unassigned characters are not allowed and STD3 hostnames are
      * enforced.
      * <p>
+     * This implementation already supports EsZett character. Thanks to <a
+     * href="http://blog.http.net/code/gnu-libidn-eszett-hotfix/">http.net</a>!
+     * <p>
      * <code>"someone@xn--mller-kva.de"</code> is converted to <code>"someone@m&uuml;ller.de"</code>
-     * 
+     *
      * @param aceAddress The ASCII-encoded (punycode) address
      * @return The unicode representation of given internet address
+     * @see #getIDNAddress()
      */
     public static String toIDN(final String aceAddress) {
-        if (null == aceAddress) {
-            return null;
-        }
-        final int pos = aceAddress.indexOf('@');
-        if (pos < 0) {
-            return aceAddress;
-        }
-        return new StringBuilder(aceAddress.length()).append(aceAddress.substring(0, pos)).append('@').append(
-            gnu.inet.encoding.IDNA.toUnicode(aceAddress.substring(pos + 1))).toString();
+        return IDNA.toIDN(aceAddress);
     }
 
+    private String jcharset;
+
     /**
      * Initializes a new {@link QuotedInternetAddress}.
      */
     public QuotedInternetAddress() {
         super();
+        jcharset = MailProperties.getInstance().getDefaultMimeCharset();
     }
 
     /**
@@ -799,7 +793,7 @@ public final class QuotedInternetAddress extends InternetAddress {
      */
     private QuotedInternetAddress(final InternetAddress src) throws AddressException {
         this();
-        this.address = toACE(src.getAddress());
+        address = toACE(src.getAddress());
         try {
             setPersonal(getPersonal(), null);
         } catch (final UnsupportedEncodingException e) {
@@ -814,13 +808,14 @@ public final class QuotedInternetAddress extends InternetAddress {
      * Parse the given string and create an InternetAddress. See the parse method for details of the parsing. The address is parsed using
      * "strict" parsing. This constructor does not perform the additional syntax checks that the InternetAddress(String address, boolean
      * strict) constructor does when strict is true. This constructor is equivalent to InternetAddress(address, false).
-     * 
+     *
      * @param address The address in RFC822 format
      * @throws AddressException If parsing the address fails
      */
     public QuotedInternetAddress(final String address) throws AddressException {
         super();
         parseAddress0(address);
+        jcharset = MailProperties.getInstance().getDefaultMimeCharset();
     }
 
     /**
@@ -828,13 +823,13 @@ public final class QuotedInternetAddress extends InternetAddress {
      * <p>
      * Parse the given string and create an InternetAddress. If strict is <code>false</code>, the detailed syntax of the address isn't
      * checked. toACE
-     * 
+     *
      * @param address The address in RFC822 format
      * @param strict <code>true</code> enforce RFC822 syntax; otherwise <code>false</code>
      * @throws AddressException If parsing the address fails
      */
     public QuotedInternetAddress(final String address, final boolean strict) throws AddressException {
-        this(address);
+        this(init(address, true));
         if (strict) {
             if (isGroup()) {
                 getGroup(true); // throw away the result
@@ -844,11 +839,42 @@ public final class QuotedInternetAddress extends InternetAddress {
         }
     }
 
+    /**
+     * Initializes a new {@link QuotedInternetAddress}.
+     * <p>
+     * Parse the given string and create an InternetAddress. If strict is <code>false</code>, the detailed syntax of the address isn't
+     * checked. toACE
+     *
+     * @param address The address in RFC822 format
+     * @param strict <code>true</code> enforce RFC822 syntax; otherwise <code>false</code>
+     * @param suppressControlOrWhitespace Whether to suppress control or whitespace characters possibly contained in given address string
+     * @throws AddressException If parsing the address fails
+     */
+    public QuotedInternetAddress(final String address, final boolean strict, final boolean suppressControlOrWhitespace) throws AddressException {
+        this(init(address, suppressControlOrWhitespace));
+        if (strict) {
+            if (isGroup()) {
+                getGroup(true); // throw away the result
+            } else {
+                checkAddress(this.address, true, true);
+            }
+        }
+    }
+
+    private static final Pattern WHITESPACE_OR_CONTROL = Pattern.compile("[\\p{Space}&&[^ ]]|\\p{Cntrl}|[^\\p{Print}\\p{L}]");
+
+    private static String init(final String address, final boolean suppressControlOrWhitespace) {
+        if (!suppressControlOrWhitespace) {
+            return address;
+        }
+        return WHITESPACE_OR_CONTROL.matcher(address).replaceAll("");
+    }
+
     /**
      * Initializes a new {@link QuotedInternetAddress}.
      * <p>
      * Construct an instance given the address and personal name. The address is assumed to be a syntactically valid RFC822 address.
-     * 
+     *
      * @param address The address in RFC822 format
      * @param personal The personal name
      * @throws AddressException If parsing the address fails
@@ -860,7 +886,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Initializes a new {@link QuotedInternetAddress}.
-     * 
+     *
      * @param address The address in RFC822 format
      * @param personal The personal name
      * @param charset The MIME charset for the name
@@ -870,12 +896,23 @@ public final class QuotedInternetAddress extends InternetAddress {
     public QuotedInternetAddress(final String address, final String personal, final String charset) throws AddressException, UnsupportedEncodingException {
         super();
         this.address = toACE(address);
+        if (charset == null) {
+            // use default charset
+            jcharset = MailProperties.getInstance().getDefaultMimeCharset();
+        } else {
+            // MIME charset -> java charset
+            String javaCharset = MimeUtility.javaCharset(charset);
+            if ("utf8".equalsIgnoreCase(javaCharset)) {
+                javaCharset = "UTF-8";
+            }
+            jcharset = javaCharset;
+        }
         setPersonal(personal, charset);
     }
 
     /**
      * Parses the given string into this {@link QuotedInternetAddress}.
-     * 
+     *
      * @param address The address in RFC822 format
      * @throws AddressException If parsing the address fails
      */
@@ -885,7 +922,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Internal parse routine.
-     * 
+     *
      * @param address The address in RFC822 format
      * @throws AddressException If parsing the address fails
      */
@@ -903,8 +940,39 @@ public final class QuotedInternetAddress extends InternetAddress {
          */
         final QuotedInternetAddress internetAddress = (QuotedInternetAddress) a[0];
         this.address = internetAddress.address;
-        this.personal = internetAddress.personal;
-        this.encodedPersonal = internetAddress.encodedPersonal;
+        personal = internetAddress.personal;
+        encodedPersonal = internetAddress.encodedPersonal;
+    }
+
+    /**
+     * Gets the email address in its internationalized, unicode form.
+     * 
+     * @return The IDN email address
+     * @see #toIDN(String)
+     */
+    public String getIDNAddress() {
+        return toIDN(address);
+    }
+
+    @Override
+    public void setPersonal(String name, String charset) throws UnsupportedEncodingException {
+        personal = name;
+        if (name != null) {
+            if (charset == null) {
+                // use default charset
+                jcharset = MailProperties.getInstance().getDefaultMimeCharset();
+            } else {
+                // MIME charset -> java charset
+                String javaCharset = MimeUtility.javaCharset(charset);
+                if ("utf8".equalsIgnoreCase(javaCharset)) {
+                    javaCharset = "UTF-8";
+                }
+                jcharset = javaCharset;
+            }
+            encodedPersonal = MimeUtility.encodeWord(name, charset, null);
+        } else {
+            encodedPersonal = null;
+        }
     }
 
     /**
@@ -924,24 +992,51 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Gets the email address in Unicode characters.
-     * 
+     *
      * @return The email address in Unicode characters
      */
     public String getUnicodeAddress() {
         return toIDN(address);
     }
 
+    /**
+     * Get the personal name. If the name is encoded as per RFC 2047, it is decoded and converted into Unicode. If the decoding or
+     * conversion fails, the raw data is returned as is.
+     * 
+     * @return personal name
+     */
+    @Override
+    public String getPersonal() {
+        if (personal != null) {
+            return personal;
+        }
+
+        if (encodedPersonal != null) {
+            try {
+                personal = MIMEMessageUtility.decodeMultiEncodedHeader(encodedPersonal);
+                return personal;
+            } catch (final Exception ex) {
+                // 1. ParseException: either its an unencoded string or
+                // it can't be parsed
+                // 2. UnsupportedEncodingException: can't decode it.
+                return encodedPersonal;
+            }
+        }
+        // No personal or encodedPersonal, return null
+        return null;
+    }
+
     /**
      * Convert this address into a RFC 822 / RFC 2047 encoded address. The resulting string contains only US-ASCII characters, and hence is
      * mail-safe.
-     * 
+     *
      * @return possibly encoded address string
      */
     @Override
     public String toString() {
         if (encodedPersonal == null && personal != null) {
             try {
-                encodedPersonal = MimeUtility.encodeWord(personal);
+                encodedPersonal = MimeUtility.encodeWord(personal, jcharset, null);
             } catch (final UnsupportedEncodingException ex) {
                 LOG.error(ex.getMessage(), ex);
             }
@@ -965,7 +1060,7 @@ public final class QuotedInternetAddress extends InternetAddress {
                 }
                 personal = personal.substring(1, personal.length() - 1);
                 try {
-                    encodedPersonal = MimeUtility.encodeWord(personal);
+                    encodedPersonal = MimeUtility.encodeWord(personal, jcharset, null);
                 } catch (final UnsupportedEncodingException ex) {
                     LOG.error(ex.getMessage(), ex);
                 }
@@ -973,7 +1068,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
             if (needQuoting(personal)) {
                 try {
-                    encodedPersonal = MimeUtility.encodeWord(quotePhrase(personal));
+                    encodedPersonal = MimeUtility.encodeWord(quotePhrase(personal), jcharset, null);
                 } catch (final UnsupportedEncodingException e) {
                     LOG.error(e.getMessage(), e);
                 }
@@ -981,7 +1076,7 @@ public final class QuotedInternetAddress extends InternetAddress {
             return new StringBuilder(32).append(encodedPersonal).append(" <").append(address).append('>').toString();
 
             /*-
-             * 
+             *
             if (encodedPersonal.startsWith("=?", 0)) {
                 return new StringBuilder(32).append('"').append(encodedPersonal).append("\" <").append(address).append('>').toString();
             }
@@ -996,7 +1091,7 @@ public final class QuotedInternetAddress extends InternetAddress {
 
     /**
      * Returns a properly formatted address (RFC 822 syntax) of Unicode characters.
-     * 
+     *
      * @return The Unicode address string
      */
     @Override
@@ -1043,11 +1138,11 @@ public final class QuotedInternetAddress extends InternetAddress {
     /**
      * Return the first index of any of the characters in "any" in "s", or -1 if none are found. This should be a method on String.
      */
-    private static int indexOfAny(final String s, final String any) {
+    private static int indexOfAny(final CharSequence s, final String any) {
         return indexOfAny(s, any, 0);
     }
 
-    private static int indexOfAny(final String s, final String any, final int start) {
+    private static int indexOfAny(final CharSequence s, final String any, final int start) {
         try {
             final int len = s.length();
             for (int i = start; i < len; i++) {
@@ -1123,7 +1218,7 @@ public final class QuotedInternetAddress extends InternetAddress {
         if (length <= 0) {
             return false;
         }
-        return ('"' == s.charAt(0) && '"' == s.charAt(length - 1));
+        return ('"' == s.charAt(0) && length > 1 && '"' == s.charAt(length - 1));
     }
 
     private static boolean checkQuotedPersonal(final String p) {
@@ -1139,7 +1234,8 @@ public final class QuotedInternetAddress extends InternetAddress {
                 valid = i > 1 && '\\' == phrase.charAt(i - 1);
                 i++;
             } else if (c == '\\') {
-                final char c2 = phrase.charAt(i + 1);
+                final int ni = i + 1;
+                final char c2 = ni < len ? phrase.charAt(ni) : '\0';
                 valid = (c2 == '"' || c2 == '\\');
                 i += 2;
             } else {
@@ -1156,6 +1252,9 @@ public final class QuotedInternetAddress extends InternetAddress {
         }
         String s = str;
         int length = s.length();
+        if (1 == length) {
+            return str;
+        }
         if ('"' == s.charAt(0) && '"' == s.charAt(length - 1)) {
             s = s.substring(1, length - 1);
             // check for any escaped characters
