@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.mail.mime.dataobjects;
 
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.io.ByteArrayOutputStream;
+import java.io.Closeable;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -63,28 +64,33 @@ import javax.mail.Part;
 import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
+import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMEDefaultSession;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.ManagedMimeMessage;
 import com.openexchange.mail.mime.MessageHeaders;
+import com.openexchange.mail.mime.MimeCleanUp;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link MIMEMailPart} - Represents a MIME part as per RFC 822.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class MIMEMailPart extends MailPart {
+public final class MIMEMailPart extends MailPart implements MIMERawSource, MimeCleanUp {
 
     private static final long serialVersionUID = -1142595512657302179L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEMailPart.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MIMEMailPart.class));
 
     /**
      * The max. in-memory size in bytes.
@@ -92,6 +98,23 @@ public final class MIMEMailPart extends MailPart {
     // TODO: Make configurable
     private static final int MAX_INMEMORY_SIZE = 131072; // 128KB
 
+    private static volatile Boolean useMimeMultipartMailPart;
+
+    private static boolean useMimeMultipartMailPart() {
+        Boolean tmp = useMimeMultipartMailPart;
+        if (null == tmp) {
+            synchronized (MIMEMailPart.class) {
+                tmp = useMimeMultipartMailPart;
+                if (null == tmp) {
+                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    tmp = Boolean.valueOf(null != service && service.getBoolProperty("com.openexchange.mail.mime.useMimeMultipartMailPart", false));
+                    useMimeMultipartMailPart = tmp;
+                }
+            }
+        }
+        return tmp.booleanValue();
+    }
+
     private static final String ERR_NULL_PART = "Underlying part is null";
 
     /**
@@ -170,7 +193,7 @@ public final class MIMEMailPart extends MailPart {
      * <p>
      * <b>Note</b>: Set only to <code>true</code> if JavaMail property <code>"mail.mime.multipart.allowempty"</code> is set to
      * <code>"false"</code>.
-     * 
+     *
      * @param handleMissingStartBoundary <code>true</code> to handle <i>"Missing start boundary"</i> error; otherwise <code>false</code>
      */
     public void setHandleMissingStartBoundary(final boolean handleMissingStartBoundary) {
@@ -179,7 +202,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Sets this mail part's content.
-     * 
+     *
      * @param part The part
      */
     public void setContent(final Part part) {
@@ -216,13 +239,23 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Gets the {@link Part part}.
-     * 
+     *
      * @return The {@link Part part} or <code>null</code>
      */
     public Part getPart() {
         return part;
     }
 
+    public void cleanUp() {
+        if (part instanceof ManagedMimeMessage) {
+            try {
+                ((ManagedMimeMessage) part).cleanUp();
+            } catch (final Exception e) {
+                com.openexchange.log.Log.valueOf(LogFactory.getLog(MIMEMailPart.class)).warn("Couldn't clean-up MIME resource.", e);
+            }
+        }
+    }
+
     @Override
     public Object getContent() throws MailException {
         if (null == part) {
@@ -247,7 +280,7 @@ public final class MIMEMailPart extends MailPart {
         } catch (final IOException e) {
             throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
         } catch (final MessagingException e) {
-            throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
+            throw MIMEMailException.handleMessagingException(e);
         }
     }
 
@@ -262,7 +295,26 @@ public final class MIMEMailPart extends MailPart {
         try {
             return part.getDataHandler();
         } catch (final MessagingException e) {
-            throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
+            throw MIMEMailException.handleMessagingException(e);
+        }
+    }
+
+    public InputStream getRawInputStream() throws MailException {
+        if (null == part) {
+            throw new IllegalStateException(ERR_NULL_PART);
+        }
+        if (isMulti) {
+            return null;
+        }
+        try {
+            if (part instanceof MimeBodyPart) {
+                return ((MimeBodyPart) part).getRawInputStream();
+            } else if (part instanceof MimeMessage) {
+                return ((MimeMessage) part).getRawInputStream();
+            }
+            throw new MailException(MailException.Code.NO_CONTENT);
+        } catch (final MessagingException e) {
+            throw MIMEMailException.handleMessagingException(e);
         }
     }
 
@@ -279,9 +331,11 @@ public final class MIMEMailPart extends MailPart {
                 return part.getInputStream();
             } catch (final IOException e) {
                 if (LOG.isDebugEnabled()) {
-                    LOG.debug(new StringBuilder(256).append("Part's input stream could not be obtained: ").append(
-                        e.getMessage() == null ? "<no error message given>" : e.getMessage()).append(
-                        ". Trying to read from part's raw input stream instead").toString(), e);
+                    LOG.debug(
+                        new StringBuilder(256).append("Part's input stream could not be obtained: ").append(
+                            e.getMessage() == null ? "<no error message given>" : e.getMessage()).append(
+                            ". Trying to read from part's raw input stream instead").toString(),
+                        e);
                 }
                 try {
                     if (part instanceof MimeBodyPart) {
@@ -296,9 +350,11 @@ public final class MIMEMailPart extends MailPart {
                 throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
             } catch (final MessagingException e) {
                 if (LOG.isDebugEnabled()) {
-                    LOG.debug(new StringBuilder(256).append("Part's input stream could not be obtained: ").append(
-                        e.getMessage() == null ? "<no error message given>" : e.getMessage()).append(
-                        ". Trying to read from part's raw input stream instead").toString(), e);
+                    LOG.debug(
+                        new StringBuilder(256).append("Part's input stream could not be obtained: ").append(
+                            e.getMessage() == null ? "<no error message given>" : e.getMessage()).append(
+                            ". Trying to read from part's raw input stream instead").toString(),
+                        e);
                 }
                 try {
                     if (part instanceof MimeBodyPart) {
@@ -310,10 +366,10 @@ public final class MIMEMailPart extends MailPart {
                     me.setNextException(e);
                     throw me;
                 }
-                throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
+                throw MIMEMailException.handleMessagingException(e);
             }
         } catch (final MessagingException e) {
-            throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
+            throw MIMEMailException.handleMessagingException(e);
         }
     }
 
@@ -454,7 +510,7 @@ public final class MIMEMailPart extends MailPart {
                 contentLoaded = true;
             }
         } catch (final MessagingException e) {
-            throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
+            throw MIMEMailException.handleMessagingException(e);
         } catch (final UnsupportedEncodingException e) {
             LOG.error("Unsupported encoding in a message detected and monitored: \"" + e.getMessage() + '"', e);
             mailInterfaceMonitor.addUnsupportedEncodingExceptions(e.getMessage());
@@ -470,7 +526,7 @@ public final class MIMEMailPart extends MailPart {
      * <code>ObjectOutputStream.defaultWriteObject()</code>. The method does not need to concern itself with the state belonging to its
      * super classes or subclasses. State is saved by writing the individual fields to the ObjectOutputStream using the writeObject method
      * or by using the methods for primitive data types supported by <code>DataOutput</code> .
-     * 
+     *
      * @param out The object output stream
      * @throws IOException If an I/O error occurs
      */
@@ -541,7 +597,7 @@ public final class MIMEMailPart extends MailPart {
      * fields. The method does not need to concern itself with the state belonging to its super classes or subclasses. State is saved by
      * writing the individual fields to the ObjectOutputStream using the writeObject method or by using the methods for primitive data types
      * supported by <code>DataOutput</code>.
-     * 
+     *
      * @param in The object input stream
      * @throws IOException If an I/O error occurs
      * @throws ClassNotFoundException If a casting fails
@@ -593,7 +649,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Compose a new MIME body part with message/rfc822 data.
-     * 
+     *
      * @param data The message/rfc822 data
      * @return A new MIME body part with message/rfc822 data
      * @throws MessagingException If a messaging error occurs
@@ -608,7 +664,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Compose a new MIME body part with multipart/* data.
-     * 
+     *
      * @param data The multipart/* data
      * @param contentType The multipart's content type (containing important boundary parameter)
      * @return A new MIME body part with multipart/* data
@@ -622,7 +678,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Compose a new MIME body part directly from specified data.
-     * 
+     *
      * @param data The part's data
      * @return A new MIME body part
      * @throws MessagingException If a messaging error occurs
@@ -633,7 +689,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Compose a new MIME message directly from specified data.
-     * 
+     *
      * @param data The message's data
      * @return A new MIME message
      * @throws MessagingException If a messaging error occurs
@@ -644,7 +700,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Gets the bytes of specified part's raw data.
-     * 
+     *
      * @param part Either a message or a body part
      * @return The bytes of specified part's raw data (with the optional empty starting line omitted)
      * @throws IOException If an I/O error occurs
@@ -662,7 +718,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Gets the bytes of specified multipart's raw data.
-     * 
+     *
      * @param multipart A multipart object
      * @return The bytes of specified multipart's raw data (with the optional empty starting line omitted)
      * @throws IOException If an I/O error occurs
@@ -680,7 +736,7 @@ public final class MIMEMailPart extends MailPart {
 
     /**
      * Strips the possible empty starting line from specified byte array.
-     * 
+     *
      * @param data The byte array
      * @return The stripped byte array
      */
@@ -707,7 +763,7 @@ public final class MIMEMailPart extends MailPart {
         if (null == multipart) {
             try {
                 final int size = part.getSize();
-                if (size > 0 && size <= MAX_INMEMORY_SIZE) {
+                if (useMimeMultipartMailPart() && (size > 0) && (size <= MAX_INMEMORY_SIZE)) {
                     /*
                      * If size is less than or equal to 1MB, use the in-memory implementation
                      */
@@ -718,7 +774,26 @@ public final class MIMEMailPart extends MailPart {
                     /*
                      * If size is unknown or exceeds 1MB, use the stream-based implementation
                      */
-                    multipart = new JavaMailMultipartWrapper((Multipart) part.getContent());
+                    final Object content = part.getContent();
+                    if (content instanceof Multipart) {
+                        multipart = new JavaMailMultipartWrapper((Multipart) content);
+                    } else {
+                        /*-
+                         * Content object is not a Multipart. Then data is kept in memory regardless of MultipartWrapper implementation.
+                         *
+                         * Since MIMEMultipartMailPart was introduced to provide a faster multipart/* parsing, use the MIMEMultipartWrapper
+                         * implementation to take benefit of improved parsing.
+                         */
+                        if (content instanceof InputStream) {
+                            /*
+                             * Close in case of InputStream
+                             */
+                            closeQuitely((InputStream) content);
+                        }
+                        final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(size);
+                        part.writeTo(out);
+                        multipart = new MIMEMultipartWrapper(new MIMEMultipartMailPart(getContentType(), out.toByteArray()));
+                    }
                 }
             } catch (final MessagingException e) {
                 throw new MailException(MailException.Code.MESSAGING_ERROR, e, e.getMessage());
@@ -785,4 +860,12 @@ public final class MIMEMailPart extends MailPart {
         }
 
     } // End of JavaMailMultipartWrapper
+
+    private static void closeQuitely(final Closeable closeable) {
+        try {
+            closeable.close();
+        } catch (final IOException e) {
+            LOG.trace(e.getMessage(), e);
+        }
+    }
 }
