@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,14 +54,22 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.io.RandomAccessFile;
 import java.io.UnsupportedEncodingException;
+import java.nio.ByteBuffer;
+import java.nio.channels.FileChannel;
 import javax.activation.DataHandler;
 import javax.activation.DataSource;
+import javax.mail.MessagingException;
+import javax.mail.internet.MimeBodyPart;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.mime.ContentType;
+import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
+import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
@@ -69,14 +77,15 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
  * {@link MIMEMultipartMailPart} - An implementation of {@link MailPart} for mail parts of MIME type <code>multipart/*</code>.
  * <p>
  * Parsing of multipart data is based on <b>Knuth&#045;Morris&#045;Pratt (KMP)</b> algorithm.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MIMEMultipartMailPart extends MailPart {
 
     private static final long serialVersionUID = -3130161956976376243L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEMultipartMailPart.class);
+    private static final transient org.apache.commons.logging.Log LOG =
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MIMEMultipartMailPart.class));
 
     private static final int BUFSIZE = 8192; // 8K
 
@@ -86,9 +95,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     private static final String STR_BD_START = "--";
 
-    private byte[] data;
-
-    private DataSource dataSource;
+    private final DataAccess dataAccess;
 
     private byte[] boundaryBytes;
 
@@ -98,7 +105,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
+     *
      * @param dataSource The data source
      * @throws MailException If reading input stream fails
      */
@@ -108,7 +115,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
+     *
      * @param contentType The content type; may be <code>null</code>
      * @param dataSource The data source
      * @throws MailException If reading input stream fails
@@ -124,47 +131,12 @@ public final class MIMEMultipartMailPart extends MailPart {
         } else {
             setContentType(contentType);
         }
-        this.dataSource = dataSource;
+        dataAccess = new DataSourceDataAccess(dataSource);
     }
 
     /**
      * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
-     * @param inputStream The input stream
-     * @throws MailException If reading input stream fails
-     */
-    public MIMEMultipartMailPart(final InputStream inputStream) throws MailException {
-        this(null, inputStream);
-    }
-
-    /**
-     * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
-     * @param contentType The content type; may be <code>null</code>
-     * @param inputStream The input stream
-     * @throws MailException If reading input stream fails
-     */
-    public MIMEMultipartMailPart(final ContentType contentType, final InputStream inputStream) throws MailException {
-        super();
-        if (contentType == null) {
-            try {
-                setContentType(extractHeader(STR_CONTENT_TYPE, inputStream, false));
-            } catch (final IOException e) {
-                throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
-            }
-        } else {
-            setContentType(contentType);
-        }
-        try {
-            data = copyStream(inputStream);
-        } catch (final IOException e) {
-            throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
-        }
-    }
-
-    /**
-     * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
+     *
      * @param inputData The input data
      * @throws MailException If reading input stream fails
      */
@@ -174,7 +146,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Initializes a new {@link MIMEMultipartMailPart}.
-     * 
+     *
      * @param contentType The content type; may be <code>null</code>
      * @param inputData The input data
      * @throws MailException If reading input stream fails
@@ -190,7 +162,7 @@ public final class MIMEMultipartMailPart extends MailPart {
         } else {
             setContentType(contentType);
         }
-        data = inputData;
+        dataAccess = new BytaArrayDataAccess(inputData);
     }
 
     @Override
@@ -211,7 +183,7 @@ public final class MIMEMultipartMailPart extends MailPart {
         final byte[] boundaryBytes = getBoundaryBytes();
         final byte[] dataBytes;
         try {
-            dataBytes = getInputBytes();
+            dataBytes = dataAccess.full();
         } catch (final IOException e) {
             throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
         }
@@ -259,7 +231,7 @@ public final class MIMEMultipartMailPart extends MailPart {
         if (!endingBoundaryFound) {
             if (0 == count) {
                 /*
-                 * No boundary found
+                 * No starting boundary found
                  */
                 if (LOG.isDebugEnabled()) {
                     final StringBuilder sb = new StringBuilder(dataBytes.length + 128);
@@ -274,13 +246,14 @@ public final class MIMEMultipartMailPart extends MailPart {
                 /*
                  * Take complete data as one part
                  */
-                String headerBreak = "\n\r\n";
-                int bodyStart = indexOf(dataBytes, headerBreak.getBytes(), 0, dataBytes.length, null);
-                if (-1 == bodyStart) {
-                    headerBreak = "\n\n";
-                    bodyStart = indexOf(dataBytes, headerBreak.getBytes(), 0, dataBytes.length, null);
+                int hbLen = -1;
+                int bodyStart;
+                if ((bodyStart = indexOf(dataBytes, DELIM1, 0, dataBytes.length)) >= 0) {
+                    hbLen = DELIM1.length;
+                } else if ((bodyStart = indexOf(dataBytes, DELIM2, 0, dataBytes.length)) >= 0) {
+                    hbLen = DELIM2.length;
                 }
-                positions[count++] = -1 == bodyStart ? 0 : bodyStart + headerBreak.length();
+                positions[count++] = bodyStart < 0 ? 0 : bodyStart + hbLen;
                 positions[count] = dataBytes.length;
                 this.boundaryBytes = new byte[0];
             } else {
@@ -309,6 +282,24 @@ public final class MIMEMultipartMailPart extends MailPart {
         return count;
     }
 
+    /**
+     * Sequence: LF LF
+     */
+    private static final byte[] DELIM2 = "\n\n".getBytes();
+
+    /**
+     * Sequence: LF CR LF
+     */
+    private static final byte[] DELIM1 = "\n\r\n".getBytes();
+
+    public static int getHeaderEnd(final byte[] dataBytes) {
+        int headerEnd = indexOf(dataBytes, DELIM1, 0, dataBytes.length);
+        if (-1 == headerEnd) {
+            headerEnd = indexOf(dataBytes, DELIM2, 0, dataBytes.length);
+        }
+        return headerEnd;
+    }
+
     private static boolean isLineBreak(final byte first, final byte second) {
         return ('\n' == first || ('\r' == first && '\n' == second));
     }
@@ -333,47 +324,97 @@ public final class MIMEMultipartMailPart extends MailPart {
         if (index < 0 || index >= count) {
             throw new IndexOutOfBoundsException(String.valueOf(index));
         }
-        final byte[] dataBytes;
         try {
-            dataBytes = getInputBytes();
+            final byte[] subArr;
+            {
+                int i = index;
+                int startIndex = positions[i++];
+                if (startIndex >= dataAccess.length()) {
+                    /*
+                     * Empty (text) body
+                     */
+                    return createTextPart();
+                }
+                if ('\r' == dataAccess.read(startIndex)) {
+                    startIndex += (getBoundaryBytes().length + 1);
+                } else {
+                    startIndex += (getBoundaryBytes().length);
+                }
+                /*
+                 * Omit starting CR?LF
+                 */
+                if ('\r' == dataAccess.read(startIndex) && '\n' == dataAccess.read(startIndex + 1)) {
+                    startIndex += 2;
+                } else if ('\n' == dataAccess.read(startIndex)) {
+                    startIndex++;
+                }
+                final int endIndex = i >= positions.length ? dataAccess.length() : positions[i];
+                final int len = endIndex - startIndex;
+                if (len <= 0) {
+                    /*
+                     * Empty (text) body
+                     */
+                    return createTextPart();
+                }
+                subArr = dataAccess.subarray(startIndex, len);
+            }
+            /*
+             * Has headers?
+             */
+            if (getHeaderEnd(subArr) < 0) {
+                try {
+                    return createTextPart(subArr, CharsetDetector.detectCharset(new UnsynchronizedByteArrayInputStream(subArr)));
+                } catch (final UnsupportedEncodingException e) {
+                    try {
+                        return createTextPart(subArr, "ISO-8859-1");
+                    } catch (final UnsupportedEncodingException e1) {
+                        // Cannot occur
+                        LOG.error(e1.getMessage(), e1);
+                    }
+                }
+            }
+            /*
+             * Get content-type
+             */
+            final ContentType ct = new ContentType(extractHeader(STR_CONTENT_TYPE, new UnsynchronizedByteArrayInputStream(subArr), false));
+            if (ct.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
+                return new MIMEMultipartMailPart(ct, subArr);
+            }
+//            else if (ct.startsWith(MIMETypes.MIME_MESSAGE_RFC822)) {
+//                return MIMEMessageConverter.convertMessage(subArr);
+//            }
+            else {
+                return MIMEMessageConverter.convertPart(subArr);
+            }
         } catch (final IOException e) {
             throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
         }
-        int i = index;
-        int startIndex = positions[i++];
-        if ('\r' == dataBytes[startIndex]) {
-            startIndex += (getBoundaryBytes().length + 1);
-        } else {
-            startIndex += (getBoundaryBytes().length);
-        }
-        /*
-         * Omit starting CR?LF
-         */
-        if ('\n' == dataBytes[startIndex]) {
-            startIndex++;
-        } else if ('\r' == dataBytes[startIndex] && '\n' == dataBytes[startIndex + 1]) {
-            startIndex += 2;
-        }
-        final int endIndex = i >= positions.length ? dataBytes.length : positions[i];
-        final byte[] subArr = new byte[endIndex - startIndex];
-        System.arraycopy(dataBytes, startIndex, subArr, 0, subArr.length);
-        /*
-         * Get content-type
-         */
-        final ContentType ct;
-        try {
-            ct = new ContentType(extractHeader(STR_CONTENT_TYPE, new UnsynchronizedByteArrayInputStream(subArr), false));
-        } catch (final IOException e) {
-            throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
-        }
-        if (ct.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
-            return new MIMEMultipartMailPart(ct, subArr);
-        } else if (ct.startsWith(MIMETypes.MIME_MESSAGE_RFC822)) {
-            return MIMEMessageConverter.convertMessage(subArr);
-        } else {
-            return MIMEMessageConverter.convertPart(subArr);
-        }
+    }
 
+    private static MailPart createTextPart() throws MailException {
+        try {
+            final MimeBodyPart mbp = new MimeBodyPart();
+            mbp.setText("", "US-ASCII");
+            mbp.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
+            mbp.setHeader(MessageHeaders.HDR_CONTENT_TYPE, "text/plain; charset=\"US-ASCII\"");
+            return MIMEMessageConverter.convertPart(mbp);
+        } catch (final MessagingException e) {
+            throw MIMEMailException.handleMessagingException(e);
+        }
+    }
+
+    private static MailPart createTextPart(final byte[] subArr, final String charset) throws UnsupportedEncodingException, MailException {
+        try {
+            final MimeBodyPart mbp = new MimeBodyPart();
+            mbp.setText(new String(subArr, charset), charset);
+            mbp.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
+            mbp.setHeader(
+                MessageHeaders.HDR_CONTENT_TYPE,
+                new StringBuilder("text/plain; charset=\"").append(charset).append('"').toString());
+            return MIMEMessageConverter.convertPart(mbp);
+        } catch (final MessagingException e) {
+            throw MIMEMailException.handleMessagingException(e);
+        }
     }
 
     @Override
@@ -383,12 +424,8 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     @Override
     public void loadContent() throws MailException {
-        if (data != null) {
-            return;
-        }
         try {
-            data = copyStream(dataSource.getInputStream());
-            dataSource = null;
+            dataAccess.load();
         } catch (final IOException e) {
             throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
         }
@@ -396,40 +433,21 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     @Override
     public void prepareForCaching() {
-        dataSource = null;
+        dataAccess.prepareForCaching();
     }
 
     @Override
     public void writeTo(final OutputStream out) throws MailException {
-        final InputStream in;
         try {
-            in = dataSource == null ? (data == null ? null : new UnsynchronizedByteArrayInputStream(data)) : dataSource.getInputStream();
+            dataAccess.writeTo(out);
         } catch (final IOException e) {
             throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
         }
-        if (null == in) {
-            throw new MailException(MailException.Code.NO_CONTENT);
-        }
-        try {
-            final byte[] buf = new byte[8192];
-            int count = -1;
-            while ((count = in.read(buf, 0, buf.length)) != -1) {
-                out.write(buf, 0, count);
-            }
-        } catch (final IOException e) {
-            throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
-        } finally {
-            try {
-                in.close();
-            } catch (final IOException e) {
-                LOG.error(e.getMessage(), e);
-            }
-        }
     }
 
     /**
      * Gets the (starting) boundary bytes by determining the <i>boundary</i> parameter from Content-Type header and prepending <i>--</i>.
-     * 
+     *
      * @return The (starting) boundary bytes
      */
     private byte[] getBoundaryBytes() {
@@ -440,22 +458,13 @@ public final class MIMEMultipartMailPart extends MailPart {
         if (boundary == null || boundary.length() == 0) {
             throw new IllegalStateException("Missing boundary in multipart content-type");
         }
-        return (boundaryBytes = getBytes(new StringBuilder(boundary.length() + 3).append('\n').append(STR_BD_START).append(boundary).toString()));
-    }
-
-    /**
-     * Gets the input bytes either from data source or data array.
-     * 
-     * @return The input bytes either from data source or data array.
-     * @throws IOException If accessing data source's input stream fails
-     */
-    private byte[] getInputBytes() throws IOException {
-        return dataSource == null ? (data == null ? null : data) : copyStream(dataSource.getInputStream());
+        return (boundaryBytes =
+            getBytes(new StringBuilder(boundary.length() + 3).append('\n').append(STR_BD_START).append(boundary).toString()));
     }
 
     /**
      * The readObject method is responsible for reading from the stream and restoring the classes fields.
-     * 
+     *
      * @param in The object input stream
      * @throws IOException If an I/O error occurs
      * @throws ClassNotFoundException If a casting fails
@@ -465,13 +474,12 @@ public final class MIMEMultipartMailPart extends MailPart {
          * Restore common fields
          */
         in.defaultReadObject();
-        dataSource = null;
     }
 
     /**
      * The writeObject method is responsible for writing the state of the object for its particular class so that the corresponding
      * readObject method can restore it.
-     * 
+     *
      * @param out The object output stream
      * @throws IOException If an I/O error occurs
      */
@@ -495,12 +503,12 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Copies given input stream into a newly created byte array.
-     * 
+     *
      * @param inputStream The input stream
      * @return The newly created byte array containing input stream's bytes
      * @throws IOException If reading input stream fails
      */
-    private static byte[] copyStream(final InputStream inputStream) throws IOException {
+    static byte[] copyStream(final InputStream inputStream) throws IOException {
         try {
             final ByteArrayOutputStream baos = new UnsynchronizedByteArrayOutputStream(SIZE);
             final byte[] buf = new byte[BUFSIZE];
@@ -520,7 +528,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Converts given string to a byte array.
-     * 
+     *
      * @param s The string
      * @return The converted string's byte array
      */
@@ -539,17 +547,21 @@ public final class MIMEMultipartMailPart extends MailPart {
      * <p>
      * The sub-array to search in begins at the specified <code>beginIndex</code> and extends to the byte at index <code>endIndex - 1</code>
      * . Thus the length of the sub-array is <code>endIndex-beginIndex</code>.
-     * 
+     *
      * @param data The byte array to search in
      * @param pattern The byte pattern to search for
      * @param beginIndex The beginning index, inclusive.
      * @param endIndex The ending index, exclusive.
-     * @param computedFailures The computed failures where the pattern matches against itself; leave to <code>null</code> to compute from
-     *            within
+     * @param computedFailures The computed failures where the pattern matches against itself
      * @return The index of the first occurrence of the pattern in the byte array starting from given index or <code>-1</code> if none
      *         found.
+     * @throws IndexOutOfBoundsException If <code>beginIndex</code> and/or <code>endIndex</code> is invalid
+     * @throws IllegalArgumentException If given pattern is <code>null</code>
      */
     private static int indexOf(final byte[] data, final byte[] pattern, final int beginIndex, final int endIndex, final int[] computedFailures) {
+        if (null == pattern) {
+            throw new IllegalArgumentException("pattern is null");
+        }
         if ((beginIndex < 0) || (beginIndex > data.length)) {
             throw new IndexOutOfBoundsException(String.valueOf(beginIndex));
         }
@@ -560,14 +572,54 @@ public final class MIMEMultipartMailPart extends MailPart {
             throw new IndexOutOfBoundsException(String.valueOf(endIndex - beginIndex));
         }
 
-        final int[] failure;
-        if (computedFailures == null) {
-            failure = computeFailure(pattern);
-            if (failure == null) {
-                throw new IllegalArgumentException("pattern is null");
+        int j = 0;
+        if (data.length == 0) {
+            return -1;
+        }
+
+        for (int i = beginIndex; i < endIndex; i++) {
+            while (j > 0 && pattern[j] != data[i]) {
+                j = computedFailures[j - 1];
             }
-        } else {
-            failure = computedFailures;
+            if (pattern[j] == data[i]) {
+                j++;
+            }
+            if (j == pattern.length) {
+                return i - pattern.length + 1;
+            }
+        }
+        return -1;
+    }
+
+    /**
+     * Finds the first occurrence of the pattern in the byte (sub-)array using KMP algorithm.
+     * <p>
+     * The sub-array to search in begins at the specified <code>beginIndex</code> and extends to the byte at index <code>endIndex - 1</code>
+     * . Thus the length of the sub-array is <code>endIndex-beginIndex</code>.
+     *
+     * @param data The byte array to search in
+     * @param pattern The byte pattern to search for
+     * @param beginIndex The beginning index, inclusive.
+     * @param endIndex The ending index, exclusive.
+     * @return The index of the first occurrence of the pattern in the byte array starting from given index or <code>-1</code> if none
+     *         found.
+     * @throws IndexOutOfBoundsException If <code>beginIndex</code> and/or <code>endIndex</code> is invalid
+     * @throws IllegalArgumentException If given pattern is <code>null</code>
+     */
+    private static int indexOf(final byte[] data, final byte[] pattern, final int beginIndex, final int endIndex) {
+        if ((beginIndex < 0) || (beginIndex > data.length)) {
+            throw new IndexOutOfBoundsException(String.valueOf(beginIndex));
+        }
+        if ((endIndex < 0) || (endIndex > data.length)) {
+            throw new IndexOutOfBoundsException(String.valueOf(endIndex));
+        }
+        if ((beginIndex > endIndex)) {
+            throw new IndexOutOfBoundsException(String.valueOf(endIndex - beginIndex));
+        }
+
+        final int[] failure = computeFailure(pattern);
+        if (failure == null) {
+            throw new IllegalArgumentException("pattern is null");
         }
 
         int j = 0;
@@ -591,7 +643,7 @@ public final class MIMEMultipartMailPart extends MailPart {
 
     /**
      * Computes the failure function using a boot-strapping process, where the pattern matches against itself.
-     * 
+     *
      * @param pattern The pattern
      * @return The failures
      */
@@ -614,4 +666,188 @@ public final class MIMEMultipartMailPart extends MailPart {
         return failure;
     }
 
+    private interface DataAccess {
+
+        int length() throws IOException;
+
+        int read(int index) throws IOException;
+
+        byte[] subarray(int off, int len) throws IOException;
+
+        byte[] full() throws IOException;
+
+        void load() throws IOException;
+
+        void prepareForCaching();
+
+        void writeTo(final OutputStream out) throws IOException;
+    }
+
+    private static final class BytaArrayDataAccess implements DataAccess {
+
+        private final byte[] data;
+
+        public BytaArrayDataAccess(final byte[] data) {
+            super();
+            this.data = data;
+        }
+
+        public byte[] full() {
+            return data;
+        }
+
+        public int length() {
+            return data.length;
+        }
+
+        public int read(final int index) {
+            return (data[index] & 0xff); // As unsigned integer
+        }
+
+        public byte[] subarray(final int off, final int len) {
+            final byte[] ret = new byte[len];
+            System.arraycopy(data, off, ret, 0, len);
+            return ret;
+        }
+
+        public void load() throws IOException {
+            // Nothing to do
+        }
+
+        public void prepareForCaching() {
+            // Nothing to do
+        }
+
+        public void writeTo(final OutputStream out) throws IOException {
+            out.write(data, 0, data.length);
+        }
+
+    }
+
+    private static final class RandomAccessDataAccess implements DataAccess {
+
+        private RandomAccessFile randomAccess;
+
+        private ByteBuffer roBuf;
+
+        private int length;
+
+        public RandomAccessDataAccess(final RandomAccessFile randomAccess) {
+            super();
+            this.randomAccess = randomAccess;
+            length = -1;
+        }
+
+        public byte[] full() throws IOException {
+            final ByteBuffer roBuf = getByteBuffer();
+            final int size = length();
+            final byte[] bytes = new byte[size];
+            roBuf.get(bytes, 0, size);
+            return bytes;
+        }
+
+        private ByteBuffer getByteBuffer() throws IOException {
+            if (null == roBuf) {
+                final int size = length();
+                roBuf = randomAccess.getChannel().map(FileChannel.MapMode.READ_ONLY, 0, size);
+            }
+            return roBuf;
+        }
+
+        public int length() throws IOException {
+            if (length < 0) {
+                length = (int) randomAccess.length();
+            }
+            return length;
+        }
+
+        public int read(final int index) throws IOException {
+            return (getByteBuffer().get(index) & 0xff); // As unsigned integer
+        }
+
+        public byte[] subarray(final int off, final int len) throws IOException {
+            final byte[] ret = new byte[len];
+            getByteBuffer().get(ret, off, len);
+            return ret;
+        }
+
+        public void load() throws IOException {
+            getByteBuffer();
+        }
+
+        public void prepareForCaching() {
+            randomAccess = null;
+            roBuf = null;
+        }
+
+        public void writeTo(final OutputStream out) throws IOException {
+            out.write(full());
+        }
+
+    }
+
+    private static final class DataSourceDataAccess implements DataAccess {
+
+        private DataSource dataSource;
+
+        private DataAccess delegate;
+
+        public DataSourceDataAccess(final DataSource dataSource) {
+            super();
+            this.dataSource = dataSource;
+        }
+
+        private DataAccess getDelegate() throws IOException {
+            if (null == delegate) {
+                delegate = new BytaArrayDataAccess(copyStream(dataSource.getInputStream()));
+            }
+            return delegate;
+        }
+
+        public byte[] full() throws IOException {
+            return getDelegate().full();
+        }
+
+        public int length() throws IOException {
+            return getDelegate().length();
+        }
+
+        public int read(final int index) throws IOException {
+            return getDelegate().read(index);
+        }
+
+        public byte[] subarray(final int off, final int len) throws IOException {
+            return getDelegate().subarray(off, len);
+        }
+
+        public void load() throws IOException {
+            getDelegate();
+        }
+
+        public void prepareForCaching() {
+            dataSource = null;
+        }
+
+        public void writeTo(final OutputStream out) throws IOException {
+            final InputStream in = dataSource.getInputStream();
+            if (null == in) {
+                return;
+            }
+            try {
+                final byte[] buf = new byte[8192];
+                int count = -1;
+                while ((count = in.read(buf, 0, buf.length)) != -1) {
+                    out.write(buf, 0, count);
+                }
+            } finally {
+                try {
+                    in.close();
+                } catch (final IOException e) {
+                    org.apache.commons.logging.LogFactory.getLog(MIMEMultipartMailPart.DataSourceDataAccess.class).error(e.getMessage(), e);
+                }
+            }
+        }
+
+    }
+
 }
