@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,12 @@
 
 package com.openexchange.mail.mime.processing;
 
+import static java.util.regex.Matcher.quoteReplacement;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.text.DateFormat;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
@@ -72,6 +74,8 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.i18n.MailStrings;
+import com.openexchange.groupware.ldap.LdapException;
+import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.mail.MailException;
@@ -84,6 +88,7 @@ import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMEDefaultSession;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.ManagedMimeMessage;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
@@ -99,17 +104,18 @@ import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.session.Session;
 import com.openexchange.tools.regex.MatcherReplacer;
+import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link MimeForward} - MIME message forward.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MimeForward {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MimeForward.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MimeForward.class));
 
     private static final String PREFIX_FWD = "Fwd: ";
 
@@ -124,7 +130,7 @@ public final class MimeForward {
      * Composes a forward message from specified original messages based on MIME objects from <code>JavaMail</code> API.
      * <p>
      * If multiple messages are given these messages are forwarded as attachments.
-     * 
+     *
      * @param originalMails The referenced original mails
      * @param session The session containing needed user data
      * @param accountID The account ID of the referenced original mails
@@ -139,7 +145,7 @@ public final class MimeForward {
      * Composes a forward message from specified original messages based on MIME objects from <code>JavaMail</code> API.
      * <p>
      * If multiple messages are given these messages are forwarded as attachments.
-     * 
+     *
      * @param originalMails The referenced original mails
      * @param session The session containing needed user data
      * @param accountID The account ID of the referenced original mails
@@ -165,7 +171,7 @@ public final class MimeForward {
      * <code>JavaMail</code> API.
      * <p>
      * If multiple messages are given these messages are forwarded as attachments.
-     * 
+     *
      * @param originalMails The referenced original mails
      * @param session The session containing needed user data
      * @param accountIDs The account IDs of the referenced original mails
@@ -190,7 +196,7 @@ public final class MimeForward {
      * Composes a forward message from specified original messages based on MIME objects from <code>JavaMail</code> API.
      * <p>
      * If multiple messages are given these messages are forwarded as attachments.
-     * 
+     *
      * @param originalMsgs The referenced original messages
      * @param session The session containing needed user data
      * @param userSettingMail The user mail settings to use; leave to <code>null</code> to obtain from specified session
@@ -199,6 +205,10 @@ public final class MimeForward {
      */
     private static MailMessage getFowardMail0(final MailMessage[] originalMsgs, final Session session, final UserSettingMail userSettingMail) throws MailException {
         try {
+            /*
+             * Clone them to ensure consistent data
+             */
+            final MailMessage[] origMsgs = ManagedMimeMessage.clone(originalMsgs);
             /*
              * New MIME message with a dummy session
              */
@@ -211,7 +221,7 @@ public final class MimeForward {
                  * Set its headers. Start with subject constructed from first message.
                  */
                 final String subjectPrefix = PREFIX_FWD;
-                String origSubject = originalMsgs[0].getHeader(MessageHeaders.HDR_SUBJECT, null);
+                String origSubject = MIMEMessageUtility.checkNonAscii(origMsgs[0].getHeader(MessageHeaders.HDR_SUBJECT, null));
                 if (origSubject == null) {
                     forwardMsg.setSubject(subjectPrefix, MailProperties.getInstance().getDefaultMimeCharset());
                 } else {
@@ -233,16 +243,48 @@ public final class MimeForward {
             if (usm.getSendAddr() != null) {
                 forwardMsg.setFrom(new QuotedInternetAddress(usm.getSendAddr(), true));
             }
-            if (usm.isForwardAsAttachment() || originalMsgs.length > 1) {
+            if (usm.isForwardAsAttachment() || origMsgs.length > 1) {
                 /*
                  * Attachment-Forward
                  */
-                return asAttachmentForward(originalMsgs, forwardMsg);
+                if (1 == origMsgs.length) {
+                    final MailMessage originalMsg = origMsgs[0];
+                    final String owner = MimeProcessingUtility.getFolderOwnerIfShared(originalMsg.getFolder(), originalMsg.getAccountId(), session);
+                    if (null != owner) {
+                        try {
+                            final User[] users = UserStorage.getInstance().searchUserByMailLogin(owner, ctx);
+                            if (null != users && users.length > 0) {
+                                final InternetAddress onBehalfOf = new QuotedInternetAddress(users[0].getMail(), true);
+                                forwardMsg.setFrom(onBehalfOf);
+                                final QuotedInternetAddress sender = new QuotedInternetAddress(usm.getSendAddr(), true);
+                                forwardMsg.setSender(sender);
+                            }
+                        } catch (final LdapException e) {
+                            throw new MailException(e);
+                        }
+                    }
+                }
+                return asAttachmentForward(origMsgs, forwardMsg);
             }
             /*
              * Inline-Forward
              */
-            return asInlineForward(originalMsgs[0], session, ctx, usm, forwardMsg);
+            final MailMessage originalMsg = origMsgs[0];
+            final String owner = MimeProcessingUtility.getFolderOwnerIfShared(originalMsg.getFolder(), originalMsg.getAccountId(), session);
+            if (null != owner) {
+                try {
+                    final User[] users = UserStorage.getInstance().searchUserByMailLogin(owner, ctx);
+                    if (null != users && users.length > 0) {
+                        final InternetAddress onBehalfOf = new QuotedInternetAddress(users[0].getMail(), true);
+                        forwardMsg.setFrom(onBehalfOf);
+                        final QuotedInternetAddress sender = new QuotedInternetAddress(usm.getSendAddr(), true);
+                        forwardMsg.setSender(sender);
+                    }
+                } catch (final LdapException e) {
+                    throw new MailException(e);
+                }
+            }
+            return asInlineForward(originalMsg, session, ctx, usm, forwardMsg);
         } catch (final MessagingException e) {
             throw MIMEMailException.handleMessagingException(e);
         } catch (final IOException e) {
@@ -258,6 +300,23 @@ public final class MimeForward {
 
     private static final String TEXT_HTM = "text/htm";
 
+    private static final Pattern PAT_META_CT = Pattern.compile("<meta[^>]*?http-equiv=\"?content-type\"?[^>]*?>", Pattern.CASE_INSENSITIVE);
+
+    private static String replaceMetaEquiv(final String html, final ContentType contentType) {
+        final Matcher m = PAT_META_CT.matcher(html);
+        final MatcherReplacer mr = new MatcherReplacer(m, html);
+        final StringBuilder replaceBuffer = new StringBuilder(html.length());
+        if (m.find()) {
+            replaceBuffer.append("<meta content=\"").append(contentType.getBaseType().toLowerCase(Locale.ENGLISH));
+            replaceBuffer.append("; charset=").append(contentType.getCharsetParameter()).append("\" http-equiv=\"Content-Type\" />");
+            final String replacement = replaceBuffer.toString();
+            replaceBuffer.setLength(0);
+            mr.appendLiteralReplacement(replaceBuffer, replacement);
+        }
+        mr.appendTail(replaceBuffer);
+        return replaceBuffer.toString();
+    }
+
     private static MailMessage asInlineForward(final MailMessage originalMsg, final Session session, final Context ctx, final UserSettingMail usm, final MimeMessage forwardMsg) throws MailException, MessagingException, IOException {
         /*
          * Check for message reference
@@ -267,34 +326,41 @@ public final class MimeForward {
         final MailMessage forwardMail;
         if (originalContentType.startsWith(MULTIPART)) {
             final Multipart multipart = new MimeMultipart();
+            List<String> contentIds = Collections.emptyList();
             {
                 /*
                  * Grab first seen text from original message
                  */
                 final ContentType contentType = new ContentType();
-                final String firstSeenText = getFirstSeenText(originalMsg, contentType, usm);
+                String firstSeenText = getFirstSeenText(originalMsg, contentType, usm);
                 {
                     final String cs = contentType.getCharsetParameter();
                     if (cs == null || "US-ASCII".equalsIgnoreCase(cs)) {
                         contentType.setCharsetParameter(MailProperties.getInstance().getDefaultMimeCharset());
                     }
                 }
+                final boolean isHtml = contentType.startsWith(TEXT_HTM);
+                if (null == firstSeenText) {
+                    firstSeenText = "";
+                } else if (isHtml) {
+                    contentIds = MIMEMessageUtility.getContentIDs(firstSeenText);
+                    contentType.setCharsetParameter("UTF-8");
+                    firstSeenText = replaceMetaEquiv(firstSeenText, contentType);
+                }
                 /*
                  * Add appropriate text part prefixed with forward text
                  */
                 final MimeBodyPart textPart = new MimeBodyPart();
                 textPart.setText(
-                    generateForwardText(
-                        firstSeenText == null ? "" : firstSeenText,
-                        UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
-                        originalMsg,
-                        contentType.startsWith(TEXT_HTM)),
+                    usm.isDropReplyForwardPrefix() ? firstSeenText : generateForwardText(firstSeenText, new LocaleAndTimeZone(getUser(session, ctx)), originalMsg, isHtml),
                     contentType.getCharsetParameter(),
                     contentType.getSubType());
                 textPart.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
                 textPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(contentType.toString()));
                 multipart.addBodyPart(textPart);
                 forwardMsg.setContent(multipart);
+                // Remove generated Message-Id header
+                forwardMsg.removeHeader(MessageHeaders.HDR_MESSAGE_ID);
                 forwardMsg.saveChanges();
             }
             final CompositeMailMessage compositeMail = new CompositeMailMessage(MIMEMessageConverter.convertMessage(forwardMsg));
@@ -302,6 +368,9 @@ public final class MimeForward {
              * Add all non-inline parts through a handler to keep original sequence IDs
              */
             final NonInlineForwardPartHandler handler = new NonInlineForwardPartHandler();
+            if (!contentIds.isEmpty()) {
+                handler.setImageContentIds(contentIds);
+            }
             new MailMessageParser().setInlineDetectorBehavior(true).parseMailMessage(originalMsg, handler);
             final List<MailPart> parts = handler.getNonInlineParts();
             for (final MailPart mailPart : parts) {
@@ -309,7 +378,7 @@ public final class MimeForward {
                 compositeMail.addAdditionalParts(mailPart);
             }
             forwardMail = compositeMail;
-        } else if (originalContentType.startsWith(TEXT)) {
+        } else if (originalContentType.startsWith(TEXT) && !MimeProcessingUtility.isSpecial(originalContentType.getBaseType())) {
             /*
              * Original message is a simple text mail: Add message body prefixed with forward text
              */
@@ -319,15 +388,20 @@ public final class MimeForward {
                     originalContentType.setCharsetParameter(MessageUtility.checkCharset(originalMsg, originalContentType));
                 }
             }
-            final String content = MimeProcessingUtility.readContent(originalMsg, originalContentType.getCharsetParameter());
-            forwardMsg.setText(generateForwardText(
-                content == null ? "" : content,
-                UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
-                originalMsg,
-                originalContentType.startsWith(TEXT_HTM)), originalContentType.getCharsetParameter(), originalContentType.getSubType());
+            String content = MimeProcessingUtility.readContent(originalMsg, originalContentType.getCharsetParameter());
+            if (originalContentType.startsWith(TEXT_HTM)) {
+                originalContentType.setCharsetParameter("UTF-8");
+                content = replaceMetaEquiv(content, originalContentType);
+            }
+            forwardMsg.setText(
+                usm.isDropReplyForwardPrefix() ? (content == null ? "" : content) : generateForwardText(content == null ? "" : content, new LocaleAndTimeZone(getUser(session, ctx)), originalMsg, originalContentType.startsWith(TEXT_HTM)),
+                originalContentType.getCharsetParameter(),
+                originalContentType.getSubType());
             forwardMsg.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
             forwardMsg.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(originalContentType.toString()));
             forwardMsg.saveChanges();
+            // Remove generated Message-Id header
+            forwardMsg.removeHeader(MessageHeaders.HDR_MESSAGE_ID);
             forwardMail = MIMEMessageConverter.convertMessage(forwardMsg);
         } else {
             /*
@@ -341,9 +415,9 @@ public final class MimeForward {
                 final ContentType contentType = new ContentType(MIMETypes.MIME_TEXT_PLAIN);
                 contentType.setCharsetParameter(MailProperties.getInstance().getDefaultMimeCharset());
                 final MimeBodyPart textPart = new MimeBodyPart();
-                textPart.setText(generateForwardText(
+                textPart.setText(usm.isDropReplyForwardPrefix() ? "" : generateForwardText(
                     "",
-                    UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
+                    new LocaleAndTimeZone(getUser(session, ctx)),
                     originalMsg,
                     false), MailProperties.getInstance().getDefaultMimeCharset(), "plain");
                 textPart.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
@@ -351,6 +425,8 @@ public final class MimeForward {
                 multipart.addBodyPart(textPart);
                 forwardMsg.setContent(multipart);
                 forwardMsg.saveChanges();
+                // Remove generated Message-Id header
+                forwardMsg.removeHeader(MessageHeaders.HDR_MESSAGE_ID);
             }
             final CompositeMailMessage compositeMail = new CompositeMailMessage(MIMEMessageConverter.convertMessage(forwardMsg));
             /*
@@ -397,6 +473,13 @@ public final class MimeForward {
         return forwardMail;
     }
 
+    private static User getUser(final Session session, final Context ctx) {
+        if (session instanceof ServerSession) {
+            return ((ServerSession) session).getUser();
+        }
+        return UserStorage.getStorageUser(session.getUserId(), ctx);
+    }
+
     private static MailMessage asAttachmentForward(final MailMessage[] originalMsgs, final MimeMessage forwardMsg) throws MessagingException, MailException {
         final CompositeMailMessage compositeMail;
         {
@@ -413,6 +496,8 @@ public final class MimeForward {
             multipart.addBodyPart(textPart);
             forwardMsg.setContent(multipart);
             forwardMsg.saveChanges();
+            // Remove generated Message-Id header
+            forwardMsg.removeHeader(MessageHeaders.HDR_MESSAGE_ID);
             compositeMail = new CompositeMailMessage(MIMEMessageConverter.convertMessage(forwardMsg));
         }
         /*
@@ -438,7 +523,7 @@ public final class MimeForward {
 
     /**
      * Determines the first seen text in given multipart content with recursive iteration over enclosed multipart contents.
-     * 
+     *
      * @param mp The multipart object
      * @param retvalContentType The return value's content type (gets filled during processing and should therefore be empty)
      * @return The first seen text content
@@ -476,7 +561,7 @@ public final class MimeForward {
         for (int i = 0; i < count; i++) {
             final MailPart part = multipartPart.getEnclosedMailPart(i);
             partContentType.setContentType(part.getContentType());
-            if (partContentType.startsWith(TEXT) && MimeProcessingUtility.isInline(part, partContentType)) {
+            if (partContentType.startsWith(TEXT) && MimeProcessingUtility.isInline(part, partContentType) && !MimeProcessingUtility.isSpecial(contentType.getBaseType())) {
                 final String charset = MessageUtility.checkCharset(part, partContentType);
                 retvalContentType.setContentType(partContentType);
                 retvalContentType.setCharsetParameter(charset);
@@ -510,40 +595,39 @@ public final class MimeForward {
 
     /**
      * Generates the forward text on an inline-forward operation.
-     * 
+     *
      * @param firstSeenText The first seen text from original message
-     * @param locale The locale that determines format of date and time strings
+     * @param ltz The locale that determines format of date and time strings and time zone as well
      * @param msg The original message
      * @param html <code>true</code> if given text is html content; otherwise <code>false</code>
      * @return The forward text
-     * @throws MessagingException
      */
-    private static String generateForwardText(final String firstSeenText, final Locale locale, final MailMessage msg, final boolean html) throws MessagingException {
-        final StringHelper strHelper = new StringHelper(locale);
+    private static String generateForwardText(final String firstSeenText, final LocaleAndTimeZone ltz, final MailMessage msg, final boolean html) {
+        final StringHelper strHelper = StringHelper.valueOf(ltz.locale);
         String forwardPrefix = strHelper.getString(MailStrings.FORWARD_PREFIX);
         {
             final InternetAddress[] from = msg.getFrom();
             forwardPrefix =
-                PATTERN_FROM.matcher(forwardPrefix).replaceFirst(from == null || from.length == 0 ? "" : from[0].toUnicodeString());
+                PATTERN_FROM.matcher(forwardPrefix).replaceFirst(from == null || from.length == 0 ? "" : quoteReplacement(from[0].toUnicodeString()));
         }
         {
             final InternetAddress[] to = msg.getTo();
             forwardPrefix =
-                PATTERN_TO.matcher(forwardPrefix).replaceFirst(to == null || to.length == 0 ? "" : MimeProcessingUtility.addrs2String(to));
+                PATTERN_TO.matcher(forwardPrefix).replaceFirst(to == null || to.length == 0 ? "" : quoteReplacement(MimeProcessingUtility.addrs2String(to)));
         }
         {
             final InternetAddress[] cc = msg.getCc();
             forwardPrefix =
                 PATTERN_CCLINE.matcher(forwardPrefix).replaceFirst(
-                    cc == null || cc.length == 0 ? "" : new StringBuilder(64).append("\nCc: ").append(
-                        MimeProcessingUtility.addrs2String(cc)).toString());
+                    cc == null || cc.length == 0 ? "" : quoteReplacement(new StringBuilder(64).append("\nCc: ").append(
+                        MimeProcessingUtility.addrs2String(cc)).toString()));
         }
         {
             final Date date = msg.getSentDate();
             try {
                 forwardPrefix =
                     PATTERN_DATE.matcher(forwardPrefix).replaceFirst(
-                        date == null ? "" : DateFormat.getDateInstance(DateFormat.LONG, locale).format(date));
+                        date == null ? "" : quoteReplacement(MimeProcessingUtility.getFormattedDate(date, DateFormat.LONG, ltz.locale, ltz.timeZone)));
             } catch (final Exception t) {
                 if (LOG.isWarnEnabled()) {
                     LOG.warn(t.getMessage(), t);
@@ -553,7 +637,7 @@ public final class MimeForward {
             try {
                 forwardPrefix =
                     PATTERN_TIME.matcher(forwardPrefix).replaceFirst(
-                        date == null ? "" : DateFormat.getTimeInstance(DateFormat.SHORT, locale).format(date));
+                        date == null ? "" : quoteReplacement(MimeProcessingUtility.getFormattedTime(date, DateFormat.SHORT, ltz.locale, ltz.timeZone)));
             } catch (final Exception t) {
                 if (LOG.isWarnEnabled()) {
                     LOG.warn(t.getMessage(), t);
@@ -565,7 +649,7 @@ public final class MimeForward {
         {
             final String decodedSubject = MIMEMessageUtility.decodeMultiEncodedHeader(msg.getSubject());
             forwardPrefix =
-                PATTERN_SUBJECT.matcher(forwardPrefix).replaceFirst(decodedSubject == null ? "" : Matcher.quoteReplacement(decodedSubject));
+                PATTERN_SUBJECT.matcher(forwardPrefix).replaceFirst(decodedSubject == null ? "" : quoteReplacement(decodedSubject));
         }
         if (html) {
             forwardPrefix = HTMLProcessing.htmlFormat(forwardPrefix);
@@ -577,19 +661,20 @@ public final class MimeForward {
             final StringBuilder replaceBuffer = new StringBuilder(firstSeenText.length() + 256);
             if (m.find()) {
                 mr.appendLiteralReplacement(replaceBuffer, new StringBuilder(forwardPrefix.length() + 16).append(linebreak).append(
-                    m.group()).append(forwardPrefix).append(linebreak).append(linebreak).toString());
+                    m.group()).append(forwardPrefix).append(linebreak).toString());
             } else {
-                replaceBuffer.append(linebreak).append(forwardPrefix).append(linebreak).append(linebreak);
+                replaceBuffer.append(linebreak).append(forwardPrefix).append(linebreak);
             }
+            replaceBuffer.append("<div style=\"position:relative\">");
             mr.appendTail(replaceBuffer);
+            replaceBuffer.append("</div>");
             return replaceBuffer.toString();
         }
-        return new StringBuilder(firstSeenText.length() + 256).append(linebreak).append(forwardPrefix).append(linebreak).append(linebreak).append(
-            firstSeenText).toString();
+        return new StringBuilder(firstSeenText.length() + 256).append(linebreak).append(forwardPrefix).append(linebreak).append(firstSeenText).toString();
     }
 
     /*-
-     * 
+     *
     private static void addNonInlineParts(final MimeMessage originalMsg, final CompositeMailMessage forwardMail) throws MailException {
         final MailMessage originalMail = MIMEMessageConverter.convertMessage(originalMsg);
         final NonInlineForwardPartHandler handler = new NonInlineForwardPartHandler();
