@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,10 @@
 
 package com.openexchange.mail.mime.processing;
 
+import static com.openexchange.mail.mime.filler.MIMEMessageFiller.setReplyHeaders;
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.parseAddressList;
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.unfold;
+import static java.util.regex.Matcher.quoteReplacement;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -59,20 +61,22 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.HashSet;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import javax.mail.MessagingException;
 import javax.mail.Message.RecipientType;
+import javax.mail.MessagingException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.i18n.MailStrings;
+import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.i18n.tools.StringHelper;
@@ -90,6 +94,7 @@ import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMEDefaultSession;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.MIMETypes;
+import com.openexchange.mail.mime.ManagedMimeMessage;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
@@ -99,6 +104,7 @@ import com.openexchange.mail.parser.handlers.InlineContentHandler;
 import com.openexchange.mail.text.HTMLProcessing;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
+import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.mail.utils.StorageUtility;
 import com.openexchange.session.Session;
@@ -107,12 +113,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link MimeReply} - MIME message reply.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MimeReply {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MimeReply.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MimeReply.class));
 
     private static final String PREFIX_RE = "Re: ";
 
@@ -125,7 +131,7 @@ public final class MimeReply {
 
     /**
      * Composes a reply message from specified original message based on MIME objects from <code>JavaMail</code> API.
-     * 
+     *
      * @param originalMail The referenced original mail
      * @param replyAll <code>true</code> to reply to all; otherwise <code>false</code>
      * @param session The session containing needed user data
@@ -139,7 +145,7 @@ public final class MimeReply {
 
     /**
      * Composes a reply message from specified original message based on MIME objects from <code>JavaMail</code> API.
-     * 
+     *
      * @param originalMail The referenced original mail
      * @param replyAll <code>true</code> to reply to all; otherwise <code>false</code>
      * @param session The session containing needed user data
@@ -185,9 +191,26 @@ public final class MimeReply {
             usm);
     }
 
+    private static final Pattern PAT_META_CT = Pattern.compile("<meta[^>]*?http-equiv=\"?content-type\"?[^>]*?>", Pattern.CASE_INSENSITIVE);
+
+    private static String replaceMetaEquiv(final String html, final ContentType contentType) {
+        final Matcher m = PAT_META_CT.matcher(html);
+        final MatcherReplacer mr = new MatcherReplacer(m, html);
+        final StringBuilder replaceBuffer = new StringBuilder(html.length());
+        if (m.find()) {
+            replaceBuffer.append("<meta content=\"").append(contentType.getBaseType().toLowerCase(Locale.ENGLISH));
+            replaceBuffer.append("; charset=").append(contentType.getCharsetParameter()).append("\" http-equiv=\"Content-Type\" />");
+            final String replacement = replaceBuffer.toString();
+            replaceBuffer.setLength(0);
+            mr.appendLiteralReplacement(replaceBuffer, replacement);
+        }
+        mr.appendTail(replaceBuffer);
+        return replaceBuffer.toString();
+    }
+
     /**
      * Composes a reply message from specified original message based on MIME objects from <code>JavaMail</code> API.
-     * 
+     *
      * @param originalMsg The referenced original message
      * @param msgref The message reference
      * @param replyAll <code>true</code> to reply to all; otherwise <code>false</code>
@@ -201,6 +224,8 @@ public final class MimeReply {
      */
     private static MailMessage getReplyMail(final MailMessage originalMsg, final MailPath msgref, final boolean replyAll, final boolean preferToAsRecipient, final Session session, final int accountId, final javax.mail.Session mailSession, final UserSettingMail userSettingMail) throws MailException {
         try {
+            originalMsg.setAccountId(accountId);
+            final MailMessage origMsg = ManagedMimeMessage.clone(originalMsg);
             final Context ctx = ContextStorage.getStorageContext(session.getContextId());
             final UserSettingMail usm =
                 userSettingMail == null ? UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), ctx) : userSettingMail;
@@ -212,7 +237,7 @@ public final class MimeReply {
              * Set headers of reply message
              */
             final String subjectPrefix = PREFIX_RE;
-            String subjectHdrValue = MIMEMessageUtility.checkNonAscii(originalMsg.getHeader(MessageHeaders.HDR_SUBJECT, null));
+            String subjectHdrValue = MIMEMessageUtility.checkNonAscii(origMsg.getHeader(MessageHeaders.HDR_SUBJECT, null));
             if (subjectHdrValue == null) {
                 subjectHdrValue = "";
             }
@@ -230,25 +255,58 @@ public final class MimeReply {
              */
             final InternetAddress[] recipientAddrs;
             if (preferToAsRecipient) {
-                final String hdrVal = originalMsg.getHeader(MessageHeaders.HDR_TO, MessageHeaders.HDR_ADDR_DELIM);
+                final String hdrVal = origMsg.getHeader(MessageHeaders.HDR_TO, MessageHeaders.HDR_ADDR_DELIM);
                 if (null == hdrVal) {
                     recipientAddrs = new InternetAddress[0];
                 } else {
                     recipientAddrs = parseAddressList(hdrVal, true);
                 }
             } else {
-                final String[] replyTo = originalMsg.getHeader(MessageHeaders.HDR_REPLY_TO);
-                if (MIMEMessageUtility.isEmptyHeader(replyTo)) {
-                    /*
-                     * Set from as recipient
-                     */
-                    recipientAddrs = originalMsg.getFrom();
-                } else {
-                    /*
-                     * Message holds header 'Reply-To'
-                     */
-                    recipientAddrs = QuotedInternetAddress.parseHeader(unfold(replyTo[0]), true);
+                final Set<InternetAddress> tmpSet = new LinkedHashSet<InternetAddress>(4);
+                final boolean fromAdded;
+                try {
+                    final String[] replyTo = origMsg.getHeader(MessageHeaders.HDR_REPLY_TO);
+                    if (MIMEMessageUtility.isEmptyHeader(replyTo)) {
+                        final String owner = MimeProcessingUtility.getFolderOwnerIfShared(msgref.getFolder(), msgref.getAccountId(), session);
+                        if (null != owner) {
+                            final User[] users = UserStorage.getInstance().searchUserByMailLogin(owner, ctx);
+                            if (null != users && users.length > 0) {
+                                final InternetAddress onBehalfOf = new QuotedInternetAddress(users[0].getMail(), true);
+                                replyMsg.setFrom(onBehalfOf);
+                                final QuotedInternetAddress sender = new QuotedInternetAddress(usm.getSendAddr(), true);
+                                replyMsg.setSender(sender);
+                            }
+                        }
+                        /*
+                         * Set from as recipient
+                         */
+                        tmpSet.addAll(Arrays.asList(origMsg.getFrom()));
+                        fromAdded = true;
+                    } else {
+                        /*
+                         * Message holds header 'Reply-To'
+                         */
+                        tmpSet.addAll(Arrays.asList(QuotedInternetAddress.parseHeader(unfold(replyTo[0]), true)));
+                        fromAdded = false;
+                    }
+                } catch (final LdapException e) {
+                    throw new MailException(e);
                 }
+                if (replyAll) {
+                    /*-
+                     * Check 'Sender', too
+                     * 
+                    final String[] hdr = originalMsg.getHeader("Sender");
+                    if (!MIMEMessageUtility.isEmptyHeader(hdr)) {
+                        tmpSet.addAll(Arrays.asList(QuotedInternetAddress.parseHeader(unfold(hdr[0]), true)));
+                    }
+                     * 
+                     */
+                    if (!fromAdded) {
+                        tmpSet.addAll(Arrays.asList(origMsg.getFrom()));
+                    }
+                }
+                recipientAddrs = tmpSet.toArray(new InternetAddress[tmpSet.size()]);
             }
             if (replyAll) {
                 /*
@@ -291,7 +349,7 @@ public final class MimeReply {
                 /*
                  * Add filtered recipients from 'To' field
                  */
-                String hdrVal = originalMsg.getHeader(MessageHeaders.HDR_TO, MessageHeaders.HDR_ADDR_DELIM);
+                String hdrVal = origMsg.getHeader(MessageHeaders.HDR_TO, MessageHeaders.HDR_ADDR_DELIM);
                 InternetAddress[] toAddrs = null;
                 if (hdrVal != null) {
                     filteredAddrs.addAll(filter(filter, (toAddrs = parseAddressList(hdrVal, true))));
@@ -324,7 +382,7 @@ public final class MimeReply {
                  * Filter recipients from 'Cc' field
                  */
                 filteredAddrs.clear();
-                hdrVal = originalMsg.getHeader(MessageHeaders.HDR_CC, MessageHeaders.HDR_ADDR_DELIM);
+                hdrVal = origMsg.getHeader(MessageHeaders.HDR_CC, MessageHeaders.HDR_ADDR_DELIM);
                 if (hdrVal != null) {
                     filteredAddrs.addAll(filter(filter, parseAddressList(unfold(hdrVal), true)));
                 }
@@ -335,7 +393,7 @@ public final class MimeReply {
                  * Filter recipients from 'Bcc' field
                  */
                 filteredAddrs.clear();
-                hdrVal = originalMsg.getHeader(MessageHeaders.HDR_BCC, MessageHeaders.HDR_ADDR_DELIM);
+                hdrVal = origMsg.getHeader(MessageHeaders.HDR_BCC, MessageHeaders.HDR_ADDR_DELIM);
                 if (hdrVal != null) {
                     filteredAddrs.addAll(filter(filter, parseAddressList(unfold(hdrVal), true)));
                 }
@@ -370,14 +428,14 @@ public final class MimeReply {
              * Add reply text
              */
             final ContentType retvalContentType = new ContentType();
-            final String replyText;
+            String replyText;
             {
                 final List<String> list = new ArrayList<String>();
                 {
                     final User user = UserStorage.getStorageUser(session.getUserId(), ctx);
                     final Locale locale = user.getLocale();
                     final LocaleAndTimeZone ltz = new LocaleAndTimeZone(locale, user.getTimeZone());
-                    generateReplyText(originalMsg, retvalContentType, new StringHelper(locale), ltz, usm, mailSession, list);
+                    generateReplyText(origMsg, retvalContentType, StringHelper.valueOf(locale), ltz, usm, mailSession, list);
                 }
                 final StringBuilder replyTextBuilder = new StringBuilder(8192 << 1);
                 for (int i = list.size() - 1; i >= 0; i--) {
@@ -388,7 +446,7 @@ public final class MimeReply {
                 }
                 {
                     final String cs = retvalContentType.getCharsetParameter();
-                    if (cs == null || "US-ASCII".equalsIgnoreCase(cs)) {
+                    if (cs == null || "US-ASCII".equalsIgnoreCase(cs) || !CharsetDetector.isValid(cs)) {
                         // Missing or non-unicode charset
                         retvalContentType.setCharsetParameter(MailProperties.getInstance().getDefaultMimeCharset());
                     }
@@ -401,7 +459,7 @@ public final class MimeReply {
             final MailMessage replyMail;
             /*-
              * Withhold inline images. Those images are inserted through image service framework on message transport
-             * 
+             *
             if (retvalContentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL) && MIMEMessageUtility.hasEmbeddedImages(replyText)) {
                 // Prepare to append inline content
                 final Multipart multiRelated = new MimeMultipart("related");
@@ -429,10 +487,17 @@ public final class MimeReply {
             /*
              * Set message's content directly to reply text
              */
+            if (retvalContentType.startsWith("text/htm")) {
+                retvalContentType.setCharsetParameter("UTF-8");
+                replyText = replaceMetaEquiv(replyText, retvalContentType);
+            }
             replyMsg.setText(replyText, retvalContentType.getCharsetParameter(), retvalContentType.getSubType());
             replyMsg.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
             replyMsg.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(retvalContentType.toString()));
             replyMsg.saveChanges();
+            // Remove generated Message-Id for template message
+            replyMsg.removeHeader(MessageHeaders.HDR_MESSAGE_ID);
+            setReplyHeaders(origMsg, replyMsg);
             replyMail = MIMEMessageConverter.convertMessage(replyMsg);
             if (null != msgref) {
                 replyMail.setMsgref(msgref);
@@ -463,7 +528,7 @@ public final class MimeReply {
     /**
      * Filters given address array against given filter set. All addresses currently contained in filter set are removed from specified
      * <code>addrs</code> and all addresses not contained in filter set are added to filter set for future invocations.
-     * 
+     *
      * @param filter The current address filter
      * @param addrs The address list to filter
      * @return The filtered set of addresses
@@ -496,9 +561,11 @@ public final class MimeReply {
 
     private static final String TEXT_HTM = "text/htm";
 
+    // private static final Pattern PATTERN_BODY = Pattern.compile("<body[^>]*?>", Pattern.CASE_INSENSITIVE);
+
     /**
      * Gathers all text bodies and appends them to given text builder.
-     * 
+     *
      * @param msg The root message
      * @param retvalContentType The return value's content type
      * @param strHelper The i18n string helper
@@ -515,7 +582,7 @@ public final class MimeReply {
             final ParameterContainer pc =
                 new ParameterContainer(retvalContentType, textBuilder, strHelper, usm, mailSession, ltz, replyTexts);
             found |= gatherAllTextContents(msg, contentType, pc);
-        } else if (contentType.startsWith(TEXT)) {
+        } else if (contentType.startsWith(TEXT) && !MimeProcessingUtility.isSpecial(contentType.getBaseType())) {
             if (retvalContentType.getPrimaryType() == null) {
                 final String text = MimeProcessingUtility.handleInlineTextPart(msg, contentType, usm.isDisplayHtmlInlineContent());
                 retvalContentType.setContentType(contentType);
@@ -526,7 +593,7 @@ public final class MimeReply {
             }
             found = true;
         }
-        if (found) {
+        if (found && !usm.isDropReplyForwardPrefix()) {
             final boolean isHtml = retvalContentType.startsWith(TEXT_HTM);
             String replyPrefix = strHelper.getString(MailStrings.REPLY_PREFIX);
             {
@@ -534,7 +601,7 @@ public final class MimeReply {
                 try {
                     replyPrefix =
                         PATTERN_DATE.matcher(replyPrefix).replaceFirst(
-                            date == null ? "" : MimeProcessingUtility.getFormattedDate(date, DateFormat.LONG, ltz.locale, ltz.timeZone));
+                            date == null ? "" : quoteReplacement(MimeProcessingUtility.getFormattedDate(date, DateFormat.LONG, ltz.locale, ltz.timeZone)));
                 } catch (final Exception e) {
                     if (LOG.isWarnEnabled()) {
                         LOG.warn(e.getMessage(), e);
@@ -545,7 +612,7 @@ public final class MimeReply {
                 try {
                     replyPrefix =
                         PATTERN_TIME.matcher(replyPrefix).replaceFirst(
-                            date == null ? "" : MimeProcessingUtility.getFormattedTime(date, DateFormat.SHORT, ltz.locale, ltz.timeZone));
+                            date == null ? "" : quoteReplacement(MimeProcessingUtility.getFormattedTime(date, DateFormat.SHORT, ltz.locale, ltz.timeZone)));
                 } catch (final Exception e) {
                     if (LOG.isWarnEnabled()) {
                         LOG.warn(e.getMessage(), e);
@@ -556,17 +623,16 @@ public final class MimeReply {
             {
                 final InternetAddress[] from = msg.getFrom();
                 replyPrefix =
-                    PATTERN_SENDER.matcher(replyPrefix).replaceFirst(from == null || from.length == 0 ? "" : from[0].toUnicodeString());
+                    PATTERN_SENDER.matcher(replyPrefix).replaceFirst(from == null || from.length == 0 ? "" : quoteReplacement(from[0].toUnicodeString()));
             }
             {
                 final char nextLine = '\n';
                 if (isHtml) {
                     replyPrefix =
-                        HTMLProcessing.htmlFormat(new StringBuilder(replyPrefix.length() + 1).append(nextLine).append(replyPrefix).append(
-                            nextLine).append(nextLine).toString());
+                        HTMLProcessing.htmlFormat(new StringBuilder(replyPrefix.length() + 1).append(nextLine).append(replyPrefix).append(nextLine).toString());
                 } else {
                     replyPrefix =
-                        new StringBuilder(replyPrefix.length() + 1).append(nextLine).append(replyPrefix).append(nextLine).append(nextLine).toString();
+                        new StringBuilder(replyPrefix.length() + 1).append(nextLine).append(replyPrefix).append(nextLine).toString();
                 }
             }
             /*
@@ -574,7 +640,9 @@ public final class MimeReply {
              */
             final String replyTextBody;
             if (isHtml) {
-                replyTextBody = quoteHtml(textBuilder.toString());
+                final String tmp = quoteHtml(textBuilder.toString());
+                textBuilder.setLength(0);
+                replyTextBody = textBuilder.append("<div style=\"position:relative\">").append(tmp).append("</div>").toString();
             } else {
                 replyTextBody = quoteText(textBuilder.toString());
             }
@@ -589,7 +657,7 @@ public final class MimeReply {
 
     /**
      * Gathers all text bodies and appends them to given text builder.
-     * 
+     *
      * @return <code>true</code> if any text was found; otherwise <code>false</code>
      * @throws MailException If a mail error occurs
      * @throws MessagingException If a messaging error occurs
@@ -599,7 +667,7 @@ public final class MimeReply {
         final int count = multipartPart.getEnclosedCount();
         final ContentType partContentType = new ContentType();
         boolean found = false;
-        if (pc.usm.isDisplayHtmlInlineContent() && mpContentType.startsWith(MIMETypes.MIME_MULTIPART_ALTERNATIVE) && count >= 2) {
+        if (pc.usm.isDisplayHtmlInlineContent() && mpContentType.startsWithAny(MIMETypes.MIME_MULTIPART_ALTERNATIVE, MIMETypes.MIME_MULTIPART_RELATED) && count >= 2) {
             /*
              * Prefer HTML content within multipart/alternative part
              */
@@ -645,20 +713,46 @@ public final class MimeReply {
     }
 
     private static boolean getTextContent(final boolean preferHTML, final MailPart multipartPart, final int count, final ContentType partContentType, final ParameterContainer pc) throws MailException, MessagingException, IOException {
+        if (preferHTML) {
+            boolean found = false;
+            for (int i = 0; !found && i < count; i++) {
+                final MailPart part = multipartPart.getEnclosedMailPart(i);
+                partContentType.setContentType(part.getContentType());
+                if (partContentType.startsWith(TEXT_HTM) && MimeProcessingUtility.isInline(part, partContentType) && !MimeProcessingUtility.isSpecial(partContentType.getBaseType())) {
+                    if (pc.retvalContentType.getPrimaryType() == null) {
+                        pc.retvalContentType.setContentType(partContentType);
+                        final String charset = MessageUtility.checkCharset(part, partContentType);
+                        pc.retvalContentType.setCharsetParameter(charset);
+                        final String text = MimeProcessingUtility.readContent(part, charset);
+                        pc.textBuilder.append(text);
+                    } else {
+                        final String charset = MessageUtility.checkCharset(part, partContentType);
+                        partContentType.setCharsetParameter(charset);
+                        final String text =
+                            MimeProcessingUtility.handleInlineTextPart(part, partContentType, pc.usm.isDisplayHtmlInlineContent());
+                        MimeProcessingUtility.appendRightVersion(pc.retvalContentType, partContentType, text, pc.textBuilder);
+                    }
+                    found = true;
+                } else if (partContentType.startsWith(MULTIPART)) {
+                    found |= gatherAllTextContents(part, partContentType, pc);
+                }
+            }
+            return found;
+        }
+        /*
+         * Any text/* part
+         */
         boolean found = false;
-        for (int i = 0; !found && i < count; i++) {
+        for (int i = 0; i < count; i++) {
             final MailPart part = multipartPart.getEnclosedMailPart(i);
             partContentType.setContentType(part.getContentType());
-            if (partContentType.startsWith(preferHTML ? TEXT_HTM : TEXT) && MimeProcessingUtility.isInline(part, partContentType)) {
+            if (partContentType.startsWith(TEXT) && !partContentType.startsWith(TEXT_HTM) && MimeProcessingUtility.isInline(part, partContentType) && !MimeProcessingUtility.isSpecial(partContentType.getBaseType())) {
                 if (pc.retvalContentType.getPrimaryType() == null) {
                     pc.retvalContentType.setContentType(partContentType);
                     final String charset = MessageUtility.checkCharset(part, partContentType);
                     pc.retvalContentType.setCharsetParameter(charset);
                     final String text =
-                        preferHTML ? MimeProcessingUtility.readContent(part, charset) : MimeProcessingUtility.handleInlineTextPart(
-                            part,
-                            pc.retvalContentType,
-                            pc.usm.isDisplayHtmlInlineContent());
+                        MimeProcessingUtility.handleInlineTextPart(part, pc.retvalContentType, pc.usm.isDisplayHtmlInlineContent());
                     pc.textBuilder.append(text);
                 } else {
                     final String charset = MessageUtility.checkCharset(part, partContentType);
