@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,8 +59,8 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import javax.mail.FetchProfile;
-import javax.mail.UIDFolder;
 import javax.mail.FetchProfile.Item;
+import javax.mail.UIDFolder;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.mime.HeaderName;
 import com.openexchange.mail.mime.MessageHeaders;
@@ -69,7 +69,7 @@ import com.sun.mail.imap.protocol.UIDSet;
 
 /**
  * {@link MIMEStorageUtility} - Provides MIME-specific storage utility methods
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MIMEStorageUtility {
@@ -94,6 +94,8 @@ public final class MIMEStorageUtility {
         CACHE_FETCH_PROFILE.add(FetchProfile.Item.CONTENT_INFO);
         CACHE_FETCH_PROFILE.add(UIDFolder.FetchProfileItem.UID);
         CACHE_FETCH_PROFILE.add(IMAPFolder.FetchProfileItem.SIZE);
+        CACHE_FETCH_PROFILE.add(MessageHeaders.HDR_IMPORTANCE);
+        CACHE_FETCH_PROFILE.add(MessageHeaders.HDR_X_PRIORITY);
         // CACHE_FETCH_PROFILE.add(IMAPFolder.FetchProfileItem.HEADERS);
 
         // Cache fields
@@ -105,7 +107,7 @@ public final class MIMEStorageUtility {
 
     /**
      * Clones specified fetch profile:
-     * 
+     *
      * @param toClone The fetch profile to clone
      * @return The clone fetch profile
      */
@@ -125,7 +127,7 @@ public final class MIMEStorageUtility {
 
     /**
      * The corresponding fields to fetch profile obtained by {@link #getCacheFetchProfile()}
-     * 
+     *
      * @return The corresponding fields to the fetch profile obtained by {@link #getCacheFetchProfile()}
      */
     public static Collection<MailField> getCacheFields() {
@@ -134,7 +136,7 @@ public final class MIMEStorageUtility {
 
     /**
      * The corresponding fields to fetch profile obtained by {@link #getCacheFetchProfile()}
-     * 
+     *
      * @return The corresponding fields to the fetch profile obtained by {@link #getCacheFetchProfile()}
      */
     public static MailField[] getCacheFieldsArray() {
@@ -144,7 +146,7 @@ public final class MIMEStorageUtility {
     /**
      * Messages which are pre-filled with the fetch profile returned by this method are completely pre-filles with all data that can occur
      * in a listing. Thus these messages can be put into cache for future list requests
-     * 
+     *
      * @return An appropriate instance of {@link FetchProfile} to pre-fill messages ready for being put into cache
      */
     public static FetchProfile getCacheFetchProfile() {
@@ -171,7 +173,7 @@ public final class MIMEStorageUtility {
 
     /**
      * Creates an appropriate collection of {@link MailField} enumeration constants from given fetch profile
-     * 
+     *
      * @param fetchProfile The fetch profile
      * @return An appropriate collection of {@link MailField} enumeration constants
      */
@@ -234,6 +236,9 @@ public final class MIMEStorageUtility {
             if (fetchProfile.contains(MessageHeaders.HDR_DISP_NOT_TO)) {
                 set.add(MailField.DISPOSITION_NOTIFICATION_TO);
             }
+            if (fetchProfile.contains(MessageHeaders.HDR_IMPORTANCE)) {
+                set.add(MailField.PRIORITY);
+            }
             if (fetchProfile.contains(MessageHeaders.HDR_X_PRIORITY)) {
                 set.add(MailField.PRIORITY);
             }
@@ -244,7 +249,7 @@ public final class MIMEStorageUtility {
     /**
      * Turns given array of <code>long</code> into an array of <code>com.sun.mail.imap.protocol.UIDSet</code> which in turn can be used for
      * a varieties of <code>IMAPProtocol</code> methods.
-     * 
+     *
      * @param uids - the UIDs
      * @return an array of <code>com.sun.mail.imap.protocol.UIDSet</code>
      */
@@ -284,7 +289,7 @@ public final class MIMEStorageUtility {
      * <p>
      * <b>Note</b> that {@link MailField#BODY} and {@link MailField#FULL} are discarded since no corresponding fetch profile item exists and
      * therefore should be handled separately.
-     * 
+     *
      * @param fields The fields
      * @param preferEnvelope <code>true</code> to prefer ENVELOPE instead of single fetch items; otherwise <code>false</code>
      * @return The appropriate IMAP fetch profile
@@ -298,7 +303,7 @@ public final class MIMEStorageUtility {
      * <p>
      * <b>Note</b> that {@link MailField#BODY} and {@link MailField#FULL} are discarded since no corresponding fetch profile item exists and
      * therefore should be handled separately.
-     * 
+     *
      * @param fields The fields
      * @param sortField The sort field
      * @param preferEnvelope <code>true</code> to prefer ENVELOPE instead of single fetch items; otherwise <code>false</code>
@@ -339,7 +344,7 @@ public final class MIMEStorageUtility {
      * <p>
      * <b>Note</b> that {@link MailField#BODY} and {@link MailField#FULL} are discarded since no corresponding fetch profile item exists and
      * therefore should be handled separately.
-     * 
+     *
      * @param fields The fields
      * @param searchFields The search fields
      * @param sortField The sort field
@@ -355,7 +360,7 @@ public final class MIMEStorageUtility {
      * <p>
      * <b>Note</b> that {@link MailField#BODY} and {@link MailField#FULL} are discarded since no corresponding fetch profile item exists and
      * therefore should be handled separately.
-     * 
+     *
      * @param fields The fields
      * @param headerNames The header names
      * @param searchFields The search fields
@@ -459,7 +464,7 @@ public final class MIMEStorageUtility {
 
     private static final EnumMap<MailField, FetchProfile.Item> FIELD2ITEM;
 
-    private static final EnumMap<MailField, String> FIELD2STRING;
+    private static final EnumMap<MailField, List<String>> FIELD2STRING;
 
     static {
         /*
@@ -474,15 +479,15 @@ public final class MIMEStorageUtility {
         /*
          * String map
          */
-        FIELD2STRING = new EnumMap<MailField, String>(MailField.class);
-        FIELD2STRING.put(MailField.FROM, MessageHeaders.HDR_FROM);
-        FIELD2STRING.put(MailField.TO, MessageHeaders.HDR_TO);
-        FIELD2STRING.put(MailField.CC, MessageHeaders.HDR_CC);
-        FIELD2STRING.put(MailField.BCC, MessageHeaders.HDR_BCC);
-        FIELD2STRING.put(MailField.SUBJECT, MessageHeaders.HDR_SUBJECT);
-        FIELD2STRING.put(MailField.SENT_DATE, MessageHeaders.HDR_DATE);
-        FIELD2STRING.put(MailField.DISPOSITION_NOTIFICATION_TO, MessageHeaders.HDR_DISP_NOT_TO);
-        FIELD2STRING.put(MailField.PRIORITY, MessageHeaders.HDR_X_PRIORITY);
+        FIELD2STRING = new EnumMap<MailField, List<String>>(MailField.class);
+        FIELD2STRING.put(MailField.FROM, Collections.singletonList(MessageHeaders.HDR_FROM));
+        FIELD2STRING.put(MailField.TO, Collections.singletonList(MessageHeaders.HDR_TO));
+        FIELD2STRING.put(MailField.CC, Collections.singletonList(MessageHeaders.HDR_CC));
+        FIELD2STRING.put(MailField.BCC, Collections.singletonList(MessageHeaders.HDR_BCC));
+        FIELD2STRING.put(MailField.SUBJECT, Collections.singletonList(MessageHeaders.HDR_SUBJECT));
+        FIELD2STRING.put(MailField.SENT_DATE, Collections.singletonList(MessageHeaders.HDR_DATE));
+        FIELD2STRING.put(MailField.DISPOSITION_NOTIFICATION_TO, Collections.singletonList(MessageHeaders.HDR_DISP_NOT_TO));
+        FIELD2STRING.put(MailField.PRIORITY, Arrays.asList(MessageHeaders.HDR_IMPORTANCE, MessageHeaders.HDR_X_PRIORITY));
     }
 
     private static void addFetchItem(final FetchProfile fp, final MailField field) {
@@ -497,9 +502,11 @@ public final class MIMEStorageUtility {
             fp.add(item);
             return;
         }
-        final String string = FIELD2STRING.get(field);
-        if (null != string) {
-            fp.add(string);
+        final List<String> strings = FIELD2STRING.get(field);
+        if (null != strings) {
+            for (final String string : strings) {
+                fp.add(string);
+            }
         }
     }
 
