@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,18 +58,18 @@ import com.openexchange.mail.api.MailProvider;
 /**
  * {@link MailProviderProxyGenerator} - Generates proxy objects for mail provider which delegate method invocations to the service obtained
  * from a bundle context
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailProviderProxyGenerator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailProviderProxyGenerator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailProviderProxyGenerator.class));
 
     /**
      * TODO: Does not work since {@link MailProvider} is not an interface
      * <p>
      * Create a new proxy object for mail provider which delegates method invocations to the service obtained from bundle context
-     * 
+     *
      * @param mailProviderServiceReference The service reference of a mail provider
      * @param context The bundle context (needed to get/unget the service)
      * @return A new proxy object for mail provider
