@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,19 +73,19 @@ import com.openexchange.mail.uuencode.UUEncodedPart;
 
 /**
  * {@link DumperMessageHandler} - For testing purposes
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class DumperMessageHandler implements MailMessageHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DumperMessageHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DumperMessageHandler.class));
 
     private final boolean bodyOnly;
 
     private final StringBuilder strBuilder;
 
     /**
-	 * 
+	 *
 	 */
     public DumperMessageHandler(final boolean bodyOnly) {
         super();
