@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,12 +74,12 @@ import com.openexchange.mail.uuencode.UUEncodedPart;
 
 /**
  * {@link InlineContentHandler} - Finds matching inline parts to given content IDs
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class InlineContentHandler implements MailMessageHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(InlineContentHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(InlineContentHandler.class));
 
     private final int size;
 
@@ -89,7 +89,7 @@ public final class InlineContentHandler implements MailMessageHandler {
 
     /**
      * Constructor
-     * 
+     *
      * @param cids The content IDs of the inline parts
      */
     public InlineContentHandler(final List<String> cids) {
@@ -101,7 +101,7 @@ public final class InlineContentHandler implements MailMessageHandler {
 
     /**
      * Private constructor for recursive calls
-     * 
+     *
      * @param cids The content IDs of the inline parts
      * @param inlineContents The container for matching mail parts
      */
@@ -115,7 +115,7 @@ public final class InlineContentHandler implements MailMessageHandler {
     /**
      * Gets the found inline contents corresponding to given content IDs. Those inline content which could not be found are set to
      * <code>null</code>.
-     * 
+     *
      * @return The found inline contents
      */
     public Map<String, MailPart> getInlineContents() {
