@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,6 @@ package com.openexchange.mail.parser.handlers;
 import static com.openexchange.mail.mime.utils.MIMEMessageUtility.decodeMultiEncodedHeader;
 import static com.openexchange.mail.parser.MailMessageParser.generateFilename;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
-import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import java.io.File;
 import java.io.InputStream;
 import java.util.Arrays;
@@ -73,14 +72,18 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
+import com.openexchange.data.conversion.ical.ICalParser;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.html.HTMLService;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailJSONField;
 import com.openexchange.mail.MailListField;
 import com.openexchange.mail.MailPath;
+import com.openexchange.mail.attachment.AttachmentToken;
+import com.openexchange.mail.attachment.AttachmentTokenRegistry;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.json.writer.MessageWriter;
@@ -98,22 +101,25 @@ import com.openexchange.mail.parser.MailMessageParser;
 import com.openexchange.mail.text.Enriched2HtmlConverter;
 import com.openexchange.mail.text.HTMLProcessing;
 import com.openexchange.mail.text.RTF2HTMLConverter;
-import com.openexchange.mail.text.parser.HTMLParser;
-import com.openexchange.mail.text.parser.handler.HTML2TextHandler;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.DisplayMode;
 import com.openexchange.mail.uuencode.UUEncodedPart;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.TimeZoneUtils;
+import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link JSONMessageHandler} - Generates a JSON message representation considering user-sensitive data.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class JSONMessageHandler implements MailMessageHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(JSONMessageHandler.class);
+    private static final org.apache.commons.logging.Log LOG =
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JSONMessageHandler.class));
+
+    private static final String VIRTUAL = "___VIRTUAL___";
 
     private static final class PlainTextContent {
 
@@ -150,8 +156,6 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     // private Html2TextConverter converter;
 
-    private HTML2TextHandler html2textHandler;
-
     private JSONArray attachmentsArr;
 
     private JSONArray nestedMsgsArr;
@@ -168,9 +172,19 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     private PlainTextContent plainText;
 
+    private String tokenFolder;
+
+    private String tokenMailId;
+
+    private final boolean token;
+
+    private final int ttlMillis;
+
+    private boolean attachHTMLAlternativePart;
+
     /**
      * Initializes a new {@link JSONMessageHandler}
-     * 
+     *
      * @param accountId The account ID
      * @param mailPath The unique mail path
      * @param displayMode The display mode
@@ -179,8 +193,9 @@ public final class JSONMessageHandler implements MailMessageHandler {
      *            it is ignored.
      * @throws MailException If JSON message handler cannot be initialized
      */
-    public JSONMessageHandler(final int accountId, final String mailPath, final DisplayMode displayMode, final Session session, final UserSettingMail usm) throws MailException {
+    public JSONMessageHandler(final int accountId, final String mailPath, final DisplayMode displayMode, final Session session, final UserSettingMail usm, final boolean token, final int ttlMillis) throws MailException {
         super();
+        attachHTMLAlternativePart = !usm.isSuppressHTMLAlternativePart();
         this.accountId = accountId;
         modified = new boolean[1];
         this.session = session;
@@ -189,11 +204,13 @@ public final class JSONMessageHandler implements MailMessageHandler {
         this.displayMode = displayMode;
         this.mailPath = new MailPath(mailPath);
         jsonObject = new JSONObject();
+        this.token = token;
+        this.ttlMillis = ttlMillis;
     }
 
     /**
      * Initializes a new {@link JSONMessageHandler}
-     * 
+     *
      * @param accountId The account ID
      * @param mailPath The unique mail path
      * @param mail The mail message to add JSON fields not set by message parser traversal
@@ -201,16 +218,21 @@ public final class JSONMessageHandler implements MailMessageHandler {
      * @param session The session providing needed user data
      * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise
      *            it is ignored.
+     * @param token <code>true</code> to add attachment tokens
+     * @param ttlMillis The tokens' timeout
      * @throws MailException If JSON message handler cannot be initialized
      */
-    public JSONMessageHandler(final int accountId, final MailPath mailPath, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail usm) throws MailException {
-        this(accountId, mailPath, mail, displayMode, session, usm, getContext(session));
+    public JSONMessageHandler(final int accountId, final MailPath mailPath, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail usm, final boolean token, final int ttlMillis) throws MailException {
+        this(accountId, mailPath, mail, displayMode, session, usm, getContext(session), token, ttlMillis);
     }
 
     private static Context getContext(final Session session) throws MailException {
+        if (session instanceof ServerSession) {
+            return ((ServerSession) session).getContext();
+        }
         try {
             return ContextStorage.getStorageContext(session.getContextId());
-        } catch (final ContextException e) {
+        } catch (final AbstractOXException e) {
             throw new MailException(e);
         }
     }
@@ -218,8 +240,11 @@ public final class JSONMessageHandler implements MailMessageHandler {
     /**
      * Initializes a new {@link JSONMessageHandler} for internal usage
      */
-    private JSONMessageHandler(final int accountId, final MailPath mailPath, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail usm, final Context ctx) throws MailException {
+    private JSONMessageHandler(final int accountId, final MailPath mailPath, final MailMessage mail, final DisplayMode displayMode, final Session session, final UserSettingMail usm, final Context ctx, final boolean token, final int ttlMillis) throws MailException {
         super();
+        attachHTMLAlternativePart = !usm.isSuppressHTMLAlternativePart();
+        this.ttlMillis = ttlMillis;
+        this.token = token;
         this.accountId = accountId;
         modified = new boolean[1];
         this.session = session;
@@ -236,9 +261,12 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 /*
                  * Add missing fields
                  */
-                if (mail.containsFolder() && mail.getMailId() != null) {
-                    jsonObject.put(FolderChildFields.FOLDER_ID, prepareFullname(accountId, mail.getFolder()));
-                    jsonObject.put(DataFields.ID, mail.getMailId());
+                final String mailId = mail.getMailId();
+                if (mail.containsFolder() && mailId != null) {
+                    tokenFolder = prepareFullname(accountId, mail.getFolder());
+                    jsonObject.put(FolderChildFields.FOLDER_ID, tokenFolder);
+                    tokenMailId = mailId;
+                    jsonObject.put(DataFields.ID, mailId);
                 }
                 jsonObject.put(MailJSONField.UNREAD.getKey(), mail.getUnreadMessages());
                 jsonObject.put(
@@ -248,12 +276,24 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 jsonObject.put(MailJSONField.SIZE.getKey(), mail.getSize());
                 // jsonObject.put(MailJSONField.THREAD_LEVEL.getKey(), mail.getThreadLevel());
                 jsonObject.put(MailJSONField.ACCOUNT_NAME.getKey(), mail.getAccountName());
+                jsonObject.put(MailJSONField.ACCOUNT_ID.getKey(), mail.getAccountId());
             }
         } catch (final JSONException e) {
             throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
         }
     }
 
+    /**
+     * Sets whether the HTML part of a <i>multipart/alternative</i> content shall be attached.
+     * 
+     * @param attachHTMLAlternativePart Whether the HTML part of a <i>multipart/alternative</i> content shall be attached
+     * @return The {@link JSONMessageHandler} with new behavior applied
+     */
+    public JSONMessageHandler setAttachHTMLAlternativePart(final boolean attachHTMLAlternativePart) {
+        this.attachHTMLAlternativePart = attachHTMLAlternativePart;
+        return this;
+    }
+
     private JSONArray getAttachmentsArr() throws JSONException {
         if (attachmentsArr == null) {
             attachmentsArr = new JSONArray();
@@ -270,24 +310,6 @@ public final class JSONMessageHandler implements MailMessageHandler {
         return nestedMsgsArr;
     }
 
-    private HTML2TextHandler getHandler() {
-        if (html2textHandler == null) {
-            html2textHandler = new HTML2TextHandler(4096, true);
-            /*
-             * Add debugging information
-             */
-            if (jsonObject.hasAndNotNull(FolderChildFields.FOLDER_ID)) {
-                html2textHandler.setMailFolderPath(prepareMailFolderParam(jsonObject.optString(FolderChildFields.FOLDER_ID)).getFullname());
-            }
-            if (jsonObject.hasAndNotNull(DataFields.ID)) {
-                html2textHandler.setMailId(jsonObject.optLong(DataFields.ID));
-            }
-            html2textHandler.setContextId(session.getContextId());
-            html2textHandler.setUserId(session.getUserId());
-        }
-        return html2textHandler;
-    }
-
     private TimeZone getTimeZone() {
         if (timeZone == null) {
             timeZone = TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(session.getUserId(), ctx).getTimeZone());
@@ -295,13 +317,34 @@ public final class JSONMessageHandler implements MailMessageHandler {
         return timeZone;
     }
 
+    private void addToken(final JSONObject jsonObject, final String attachmentId) {
+        if (token && null != tokenFolder && null != tokenMailId) {
+            /*
+             * Token
+             */
+            try {
+                final AttachmentToken token = new AttachmentToken(ttlMillis <= 0 ? AttachmentToken.DEFAULT_TIMEOUT : ttlMillis);
+                token.setAccessInfo(accountId, session);
+                token.setAttachmentInfo(tokenFolder, tokenMailId, attachmentId);
+                AttachmentTokenRegistry.getInstance().putToken(token, session);
+                final JSONObject attachmentObject = new JSONObject();
+                attachmentObject.put("id", token.getId());
+                attachmentObject.put("jsessionid", token.getJSessionId());
+                jsonObject.put("token", attachmentObject);
+            } catch (final Exception e) {
+                LOG.warn("Adding attachment token failed.", e);
+            }
+        }
+    }
+
     public boolean handleAttachment(final MailPart part, final boolean isInline, final String baseContentType, final String fileName, final String id) throws MailException {
         try {
             final JSONObject jsonObject = new JSONObject();
             /*
              * Sequence ID
              */
-            jsonObject.put(MailListField.ID.getKey(), part.containsSequenceId() ? part.getSequenceId() : id);
+            final String attachmentId = part.containsSequenceId() ? part.getSequenceId() : id;
+            jsonObject.put(MailListField.ID.getKey(), attachmentId);
             /*
              * Filename
              */
@@ -341,6 +384,10 @@ public final class JSONMessageHandler implements MailMessageHandler {
              * Content
              */
             jsonObject.put(MailJSONField.CONTENT.getKey(), JSONObject.NULL);
+            /*
+             * Add token
+             */
+            addToken(jsonObject, attachmentId);
             // if (isInline &&
             // part.getContentType().isMimeType(MIMETypes.MIME_TEXT_ALL)) {
             // // TODO: Add rtf2html conversion here!
@@ -416,11 +463,10 @@ public final class JSONMessageHandler implements MailMessageHandler {
     /**
      * These headers are covered by fields of {@link MailMessage}
      */
-    private static final Set<HeaderName> COVERED_HEADER_NAMES =
-        new HashSet<HeaderName>(Arrays.asList(new HeaderName[] {
-            MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC,
-            MessageHeaders.CC, MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY,
-            MessageHeaders.SUBJECT, MessageHeaders.TO }));
+    private static final Set<HeaderName> COVERED_HEADER_NAMES = new HashSet<HeaderName>(Arrays.asList(new HeaderName[] {
+        MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC, MessageHeaders.CC,
+        MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY, MessageHeaders.SUBJECT,
+        MessageHeaders.TO }));
 
     public boolean handleHeaders(final int size, final Iterator<Entry<String, String>> iter) throws MailException {
         if (size == 0) {
@@ -502,7 +548,14 @@ public final class JSONMessageHandler implements MailMessageHandler {
                     /*
                      * Add HTML alternative part as attachment
                      */
-                    asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName);
+                    if (attachHTMLAlternativePart) {
+                        try {
+                            final JSONObject attachment = asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName, null);
+                            attachment.put(VIRTUAL, true);
+                        } catch (final JSONException e) {
+                            throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
+                        }
+                    }
                 } else if (DisplayMode.RAW.equals(displayMode)) {
                     /*
                      * Return HTML content as-is
@@ -518,7 +571,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 /*
                  * Add HTML part as attachment
                  */
-                asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName);
+                asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName, null);
             }
         } else {
             /*
@@ -551,7 +604,6 @@ public final class JSONMessageHandler implements MailMessageHandler {
             textAppended = true;
         }
         return true;
-
     }
 
     private static final Enriched2HtmlConverter ENRCONV = new Enriched2HtmlConverter();
@@ -583,7 +635,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
                         /*
                          * Add alternative part as attachment
                          */
-                        asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName);
+                        asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName, null);
                         return true;
                     } else if (DisplayMode.RAW.equals(displayMode)) {
                         /*
@@ -632,7 +684,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 return true;
             }
             /*
-             * Just usual plain text
+             * Just common plain text
              */
             if (textAppended) {
                 if (textWasEmpty) {
@@ -643,7 +695,8 @@ public final class JSONMessageHandler implements MailMessageHandler {
                     /*
                      * A plain text message body has already been detected; append inline text as an attachment, too
                      */
-                    asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName);
+                    final String content = HTMLProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode);
+                    asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName, content);
                 }
             } else {
                 final String content = HTMLProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode);
@@ -737,6 +790,10 @@ public final class JSONMessageHandler implements MailMessageHandler {
             asRawContent(plainText.id, plainText.contentType, plainText.content);
         }
         try {
+            final String headersKey = MailJSONField.HEADERS.getKey();
+            if (!jsonObject.hasAndNotNull(headersKey)) {
+                jsonObject.put(headersKey, new JSONObject());
+            }
             final String attachKey = MailJSONField.ATTACHMENTS.getKey();
             final String dispKey = MailJSONField.DISPOSITION.getKey();
             if (jsonObject.hasAndNotNull(attachKey)) {
@@ -745,8 +802,18 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 for (int i = 0; i < len; i++) {
                     final JSONObject attachment = attachments.getJSONObject(i);
                     if (attachment.hasAndNotNull(dispKey) && Part.ATTACHMENT.equalsIgnoreCase(attachment.getString(dispKey))) {
-                        jsonObject.put(MailJSONField.HAS_ATTACHMENTS.getKey(), true);
-                        i = len;
+                        if (attachment.hasAndNotNull(VIRTUAL) && attachment.getBoolean(VIRTUAL)) {
+                            attachment.remove(VIRTUAL);
+                        } else {
+                            jsonObject.put(MailJSONField.HAS_ATTACHMENTS.getKey(), true);
+                        }
+                        if (token && !attachment.hasAndNotNull("token")) {
+                            try {
+                                addToken(attachment, attachment.getString(MailListField.ID.getKey()));
+                            } catch (final Exception e) {
+                                // Missing field "id"
+                            }
+                        }
                     }
                 }
             }
@@ -808,7 +875,11 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 LOG.error(sb.toString());
                 return true;
             }
-            final JSONMessageHandler msgHandler = new JSONMessageHandler(accountId, null, null, displayMode, session, usm, ctx);
+            final JSONMessageHandler msgHandler =
+                new JSONMessageHandler(accountId, null, null, displayMode, session, usm, ctx, token, ttlMillis);
+            msgHandler.attachHTMLAlternativePart = attachHTMLAlternativePart;
+            msgHandler.tokenFolder = tokenFolder;
+            msgHandler.tokenMailId = tokenMailId;
             new MailMessageParser().parseMailMessage(nestedMail, msgHandler, id);
             final JSONObject nestedObject = msgHandler.getJSONObject();
             /*
@@ -884,7 +955,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     public boolean handleSpecialPart(final MailPart part, final String baseContentType, final String fileName, final String id) throws MailException {
         /*-
-         * 
+         *
         if (false && !textAppended && part.getContentType().isMimeType(MIMETypes.MIME_TEXT_ALL)) {
             String charset = part.getContentType().getCharsetParameter();
             if (null == charset) {
@@ -902,6 +973,26 @@ public final class JSONMessageHandler implements MailMessageHandler {
             }
         }
          */
+        final ContentType contentType = part.getContentType();
+        if (isVCalendar(baseContentType) && !contentType.containsParameter("method")) {
+            /*
+             * Check ICal part for a valid METHOD and its presence in Content-Type header
+             */
+            final ICalParser iCalParser = ServerServiceRegistry.getInstance().getService(ICalParser.class);
+            if (iCalParser != null) {
+                try {
+                    final String method = iCalParser.parseProperty("METHOD", part.getInputStream());
+                    if (null != method) {
+                        /*
+                         * Assume an iTIP response or request
+                         */
+                        contentType.setParameter("method", method.toUpperCase(Locale.US));
+                    }
+                } catch (final RuntimeException e) {
+                    LOG.warn("A runtime error occurred.", e);
+                }
+            }
+        }
         /*
          * When creating a JSON message object from a message we do not distinguish special parts or image parts from "usual" attachments.
          * Therefore invoke the handleAttachment method. Maybe we need a separate handling in the future for vcards.
@@ -909,6 +1000,10 @@ public final class JSONMessageHandler implements MailMessageHandler {
         return handleAttachment(part, false, baseContentType, fileName, id);
     }
 
+    private static boolean isVCalendar(final String baseContentType) {
+        return "text/calendar".equalsIgnoreCase(baseContentType) || "text/x-vcalendar".equalsIgnoreCase(baseContentType);
+    }
+
     public boolean handleSubject(final String subject) throws MailException {
         try {
             jsonObject.put(MailJSONField.SUBJECT.getKey(), subject == null ? JSONObject.NULL : subject.trim());
@@ -977,7 +1072,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     /**
      * Gets the filled instance of {@link JSONObject}
-     * 
+     *
      * @return The filled instance of {@link JSONObject}
      */
     public JSONObject getJSONObject() {
@@ -994,20 +1089,29 @@ public final class JSONMessageHandler implements MailMessageHandler {
         return jsonObject;
     }
 
-    private void asAttachment(final String id, final String baseContentType, final int len, final String fileName) throws MailException {
+    private JSONObject asAttachment(final String id, final String baseContentType, final int len, final String fileName, final String optContent) throws MailException {
         try {
             final JSONObject jsonObject = new JSONObject();
             jsonObject.put(MailListField.ID.getKey(), id);
             jsonObject.put(MailJSONField.CONTENT_TYPE.getKey(), baseContentType);
             jsonObject.put(MailJSONField.SIZE.getKey(), len);
             jsonObject.put(MailJSONField.DISPOSITION.getKey(), Part.ATTACHMENT);
-            jsonObject.put(MailJSONField.CONTENT.getKey(), JSONObject.NULL);
+            if (null == optContent) {
+                jsonObject.put(MailJSONField.CONTENT.getKey(), JSONObject.NULL);
+            } else {
+                jsonObject.put(MailJSONField.CONTENT.getKey(), optContent);
+            }
             if (fileName == null) {
                 jsonObject.put(MailJSONField.ATTACHMENT_FILE_NAME.getKey(), JSONObject.NULL);
             } else {
                 jsonObject.put(MailJSONField.ATTACHMENT_FILE_NAME.getKey(), MIMEMessageUtility.decodeMultiEncodedHeader(fileName));
             }
+            /*
+             * Add token
+             */
+            addToken(jsonObject, id);
             getAttachmentsArr().put(jsonObject);
+            return jsonObject;
         } catch (final JSONException e) {
             throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
         }
@@ -1050,8 +1154,12 @@ public final class JSONMessageHandler implements MailMessageHandler {
             /*
              * Try to convert the given html to regular text
              */
-            HTMLParser.parse(HTMLProcessing.getConformHTML(htmlContent, (String) null), getHandler().reset());
-            final String content = HTMLProcessing.formatTextForDisplay(getHandler().getText(), usm, displayMode);
+            final String content;
+            {
+                final HTMLService htmlService = ServerServiceRegistry.getInstance().getService(HTMLService.class);
+                final String plainText = htmlService.html2text(htmlContent, true);
+                content = HTMLProcessing.formatTextForDisplay(plainText, usm, displayMode);
+            }
             jsonObject.put(MailJSONField.DISPOSITION.getKey(), Part.INLINE);
             jsonObject.put(MailJSONField.SIZE.getKey(), content.length());
             jsonObject.put(MailJSONField.CONTENT.getKey(), content);
