@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,12 +80,12 @@ import com.openexchange.mail.uuencode.UUEncodedPart;
 
 /**
  * {@link MailPartHandler} - Looks for a certain mail part by sequence ID
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailPartHandler implements MailMessageHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailPartHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailPartHandler.class));
 
     private static final class TextMailPart extends MailPart {
 
@@ -176,7 +176,7 @@ public final class MailPartHandler implements MailMessageHandler {
      * Sets sequence ID.
      * <p>
      * Remaining mail part is set to <code>null</code>
-     * 
+     *
      * @param id The sequence ID
      */
     public void setSequenceId(final String id) {
@@ -466,7 +466,7 @@ public final class MailPartHandler implements MailMessageHandler {
 
     /**
      * Gets the identified mail part or <code>null</code> if none found matching given sequence ID
-     * 
+     *
      * @return The identified mail part or <code>null</code> if none found matching given sequence ID
      */
     public MailPart getMailPart() {
