@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,13 @@
 package com.openexchange.mail.parser.handlers;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Date;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map.Entry;
+import java.util.Set;
 import javax.mail.Part;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.mail.MailException;
@@ -77,12 +80,15 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
 
     private final List<MailPart> nonInlineParts;
 
+    private final Set<String> imageContentIds;
+
     /**
      * Initializes a new {@link NonInlineForwardPartHandler}
      */
     public NonInlineForwardPartHandler() {
         super();
         nonInlineParts = new ArrayList<MailPart>();
+        imageContentIds = new HashSet<String>(1);
     }
 
     /**
@@ -93,6 +99,7 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
     public NonInlineForwardPartHandler(final List<MailPart> nonInlineParts) {
         super();
         this.nonInlineParts = nonInlineParts;
+        imageContentIds = new HashSet<String>(1);
     }
 
     /**
@@ -102,6 +109,16 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
         return nonInlineParts;
     }
 
+    /**
+     * Sets the image content IDs.
+     * 
+     * @param imageContentIds The content IDs
+     */
+    public void setImageContentIds(final Collection<String> imageContentIds) {
+        this.imageContentIds.clear();
+        this.imageContentIds.addAll(imageContentIds);
+    }
+
     private static final String APPLICATION = "application/";
 
     public boolean handleAttachment(final MailPart part, final boolean isInline, final String baseContentType, final String fileName, final String id) throws MailException {
@@ -143,10 +160,15 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
     public boolean handleImagePart(final MailPart part, final String imageCID, final String baseContentType, final boolean isInline, final String fileName, final String id) throws MailException {
         if (imageCID == null && (!isInline || part.getContentDisposition().containsFilenameParameter())) {
             nonInlineParts.add(part);
+        } else if (imageCID != null && !imageContentIds.contains(prepareContentId(imageCID))) {
+            /*
+             * Image is not referenced in HTML content
+             */
+            nonInlineParts.add(part);
         }
         /*-
          * Previous code
-         * 
+         *
         if (!isInline || imageCID != null || part.getContentDisposition().containsFilenameParameter()) {
             // Add if disposition is non-inline or a content ID is present
             nonInlineParts.add(part);
@@ -155,6 +177,21 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
         return true;
     }
 
+    private static String prepareContentId(final String contentId) {
+        if (null == contentId) {
+            return null;
+        }
+        String cid = contentId;
+        if (cid.charAt(0) == '<') {
+            cid = cid.substring(1);
+        }
+        final int lastIndex = cid.length() - 1;
+        if (cid.charAt(lastIndex) == '>') {
+            cid = cid.substring(0, lastIndex);
+        }
+        return cid;
+    }
+
     public boolean handleInlineHtml(final String htmlContent, final ContentType contentType, final long size, final String fileName, final String id) throws MailException {
         return true;
     }
@@ -218,10 +255,14 @@ public final class NonInlineForwardPartHandler implements MailMessageHandler {
     }
 
     public boolean handleSpecialPart(final MailPart part, final String baseContentType, final String fileName, final String id) throws MailException {
-        final String disposition =
-            part.getContentDisposition() == null ? (part.getFileName() == null ? Part.INLINE : Part.ATTACHMENT) : part.getContentDisposition().getDisposition();
-        if (!Part.INLINE.equalsIgnoreCase(disposition)) {
+        if (baseContentType.startsWith("text/")) {
             nonInlineParts.add(part);
+        } else {
+            final String disposition =
+                part.getContentDisposition() == null ? (part.getFileName() == null ? Part.INLINE : Part.ATTACHMENT) : part.getContentDisposition().getDisposition();
+            if (!Part.INLINE.equalsIgnoreCase(disposition)) {
+                nonInlineParts.add(part);
+            }
         }
         return true;
     }
