@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -92,12 +92,12 @@ import com.openexchange.mail.uuencode.UUEncodedPart;
 
 /**
  * {@link RawJSONMessageHandler} - Generates a raw JSON message representation without any user-sensitive data.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class RawJSONMessageHandler implements MailMessageHandler {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(RawJSONMessageHandler.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(RawJSONMessageHandler.class));
 
     /**
      * The max. allowed body size of 16 KB.
@@ -128,7 +128,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
 
     /**
      * Initializes a new {@link RawJSONMessageHandler}.
-     * 
+     *
      * @param accountId The account ID
      * @param mailPath The unique mail path
      * @throws MailException If JSON message handler cannot be initialized
@@ -142,7 +142,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
 
     /**
      * Initializes a new {@link RawJSONMessageHandler}.
-     * 
+     *
      * @param accountId The account ID
      * @param mailPath The unique mail path
      * @param mail The mail message to add JSON fields not set by message parser traversal
@@ -169,6 +169,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
                 jsonObject.put(MailJSONField.SIZE.getKey(), mail.getSize());
                 // jsonObject.put(MailJSONField.THREAD_LEVEL.getKey(), mail.getThreadLevel());
                 jsonObject.put(MailJSONField.ACCOUNT_NAME.getKey(), mail.getAccountName());
+                jsonObject.put(MailJSONField.ACCOUNT_ID.getKey(), mail.getAccountId());
             }
         } catch (final JSONException e) {
             throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
@@ -415,7 +416,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
         if (bodyAdded) {
             if (isAlternative) {
                 if (containsContent("text/htm")) {
-                    asAttachment(id, contentType.getBaseType(), size, fileName);
+                    asAttachment(id, contentType.getBaseType(), size, fileName, null);
                 } else {
                     /*
                      * Check size
@@ -427,7 +428,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
                     asRawContent(id, contentType.getBaseType(), htmlContent, fileName);
                 }
             } else {
-                asAttachment(id, contentType.getBaseType(), size, fileName);
+                asAttachment(id, contentType.getBaseType(), size, fileName, null);
             }
         } else {
             /*
@@ -461,7 +462,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
                         replaceEmptyContent(id, contentType.getBaseType(), plainTextContentArg);
                         textWasEmpty = (null == plainTextContentArg || 0 == plainTextContentArg.length());
                     } else {
-                        asAttachment(id, contentType.getBaseType(), size, fileName);
+                        asAttachment(id, contentType.getBaseType(), size, fileName, null);
                     }
                 } else {
                     /*
@@ -486,7 +487,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
                     replaceEmptyContent(id, contentType.getBaseType(), plainTextContentArg);
                     textWasEmpty = (null == plainTextContentArg || 0 == plainTextContentArg.length());
                 } else {
-                    asAttachment(id, contentType.getBaseType(), size, fileName);
+                    asAttachment(id, contentType.getBaseType(), size, fileName, plainTextContentArg);
                 }
             }
         } else {
@@ -690,7 +691,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
 
     public boolean handleSpecialPart(final MailPart part, final String baseContentType, final String fileName, final String id) throws MailException {
         /*-
-         * 
+         *
         if (false && !textAppended && part.getContentType().isMimeType(MIMETypes.MIME_TEXT_ALL)) {
             String charset = part.getContentType().getCharsetParameter();
             if (null == charset) {
@@ -783,7 +784,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
 
     /**
      * Gets the filled instance of {@link JSONObject}
-     * 
+     *
      * @return The filled instance of {@link JSONObject}
      */
     public JSONObject getJSONObject() {
@@ -792,7 +793,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
 
     /**
      * Gets mail path.
-     * 
+     *
      * @return The mail path
      */
     public MailPath getMailPath() {
@@ -842,7 +843,7 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
         }
     }
 
-    private void asAttachment(final String id, final String baseContentType, final long size, final String fileName) throws MailException {
+    private void asAttachment(final String id, final String baseContentType, final long size, final String fileName, final String optContent) throws MailException {
         try {
             final JSONObject jsonObject = new JSONObject();
             /*
@@ -872,7 +873,11 @@ public final class RawJSONMessageHandler implements MailMessageHandler {
             /*
              * Content
              */
-            jsonObject.put(MailJSONField.CONTENT.getKey(), JSONObject.NULL);
+            if (null == optContent) {
+                jsonObject.put(MailJSONField.CONTENT.getKey(), JSONObject.NULL);
+            } else {
+                jsonObject.put(MailJSONField.CONTENT.getKey(), optContent);
+            }
             getAttachmentsArr().put(jsonObject);
         } catch (final JSONException e) {
             throw new MailException(MailException.Code.JSON_ERROR, e, e.getMessage());
