@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import com.openexchange.server.impl.OCLPermission;
  * This depends on if mailing system supports any kind of access control for entities; e.g. for IMAP it is the ACL capability. If no access
  * control is defined by mailing system, {@link DefaultMailPermission} is used which grants full access and therefore bypasses access
  * control.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class MailPermission extends OCLPermission {
@@ -76,11 +76,23 @@ public abstract class MailPermission extends OCLPermission {
         super();
     }
 
+    /**
+     * Checks if permission allows to rename the folder.
+     * <p>
+     * Returns <code>-1</code> if there's no special rename permission. Then rename is granted if {@link #isFolderAdmin()} returns
+     * <code>true</code>. Otherwise <code>1</code> is returned if rename is granted; <code>0</code> means no rename permission.
+     *
+     * @return
+     */
+    public int canRename() {
+        return -1;
+    }
+
     private static final Class<?>[] CONSTRUCTOR_ARGS = new Class[0];
 
     /**
      * Gets a new mail permission instance
-     * 
+     *
      * @param <P> The permission sub-type
      * @param clazz The permission class
      * @return A new mail permission instance
