@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,15 +57,16 @@ import javax.mail.MessagingException;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.search.RecipientStringTerm;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.dataobjects.MailMessage;
-import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.mime.QuotedInternetAddress;
+import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 
 /**
  * {@link BccTerm}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class BccTerm extends SearchTerm<String> {
@@ -80,12 +81,17 @@ public final class BccTerm extends SearchTerm<String> {
     public BccTerm(final String pattern) {
         super();
         try {
-            addr = new QuotedInternetAddress(pattern, true).getAddress();
+            addr = new QuotedInternetAddress(pattern, true).getUnicodeAddress();
         } catch (final AddressException e) {
             addr = pattern;
         }
     }
 
+    @Override
+    public void accept(SearchTermVisitor visitor) {
+        visitor.visit(this);
+    }
+
     /**
      * @return The pattern of the bcc address
      */
@@ -110,13 +116,24 @@ public final class BccTerm extends SearchTerm<String> {
     @Override
     public boolean matches(final Message msg) throws MailException {
         try {
-            if (containsWildcard()) {
-                return toRegex(addr).matcher(getAllAddresses((InternetAddress[]) msg.getRecipients(Message.RecipientType.BCC))).find();
+            /*
+             * Get plain headers
+             */
+            final String[] headers = msg.getHeader("Bcc");
+            if (null == headers || headers.length == 0) {
+                return false;
             }
-            return (getAllAddresses((InternetAddress[]) msg.getRecipients(Message.RecipientType.BCC)).toLowerCase(Locale.ENGLISH).indexOf(
-                addr.toLowerCase(Locale.ENGLISH)) != -1);
+            /*
+             * Parse addresses
+             */
+            final InternetAddress[] addresses = MIMEMessageUtility.parseAddressList(MIMEMessageUtility.decodeMultiEncodedHeader(headers[0]), false, false);
+            if (containsWildcard()) {
+                return toRegex(addr).matcher(getAllAddresses(addresses)).find();
+            }
+            return (getAllAddresses(addresses).toLowerCase(Locale.ENGLISH).indexOf(addr.toLowerCase(Locale.ENGLISH)) != -1);
         } catch (final MessagingException e) {
-            throw MIMEMailException.handleMessagingException(e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(BccTerm.class)).warn("Error during search.", e);
+            return false;
         }
     }
 
@@ -139,4 +156,5 @@ public final class BccTerm extends SearchTerm<String> {
     public boolean containsWildcard() {
         return null == addr ? false : addr.indexOf('*') >= 0 || addr.indexOf('?') >= 0;
     }
+
 }
