@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.mail.dataobjects.MailMessage;
 
 /**
  * {@link BooleanTerm}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class BooleanTerm extends SearchTerm<Boolean> {
@@ -110,6 +110,11 @@ public final class BooleanTerm extends SearchTerm<Boolean> {
         this.value = value;
     }
 
+    @Override
+    public void accept(SearchTermVisitor visitor) {
+        visitor.visit(this);
+    }
+
     /*
      * (non-Javadoc)
      * @see com.openexchange.mail.search.SearchTerm#getPattern()
