@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import com.openexchange.mail.dataobjects.MailMessage;
 
 /**
  * {@link NOTTerm}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class NOTTerm extends SearchTerm<SearchTerm<?>> {
@@ -84,9 +84,14 @@ public final class NOTTerm extends SearchTerm<SearchTerm<?>> {
         this.term = term;
     }
 
+    @Override
+    public void accept(SearchTermVisitor visitor) {
+        visitor.visit(this);
+    }
+
     /**
      * Gets the search terms that should be linked with an OR as an array of {@link SearchTerm} with length <code>2</code>.
-     * 
+     *
      * @return The terms that should be linked with an OR
      */
     @Override
@@ -96,7 +101,7 @@ public final class NOTTerm extends SearchTerm<SearchTerm<?>> {
 
     /**
      * Sets the search term
-     * 
+     *
      * @param term The search term
      */
     public void setTerm(final SearchTerm term) {
