@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,14 +53,14 @@ import java.util.Collection;
 import java.util.Date;
 import javax.mail.Message;
 import javax.mail.MessagingException;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.dataobjects.MailMessage;
-import com.openexchange.mail.mime.MIMEMailException;
 
 /**
  * {@link ReceivedDateTerm}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ReceivedDateTerm extends SearchTerm<ComparablePattern<java.util.Date>> {
@@ -86,6 +86,11 @@ public final class ReceivedDateTerm extends SearchTerm<ComparablePattern<java.ut
         };
     }
 
+    @Override
+    public void accept(SearchTermVisitor visitor) {
+        visitor.visit(this);
+    }
+
     /**
      * @return The sent date to match
      */
@@ -124,7 +129,8 @@ public final class ReceivedDateTerm extends SearchTerm<ComparablePattern<java.ut
         try {
             receivedDate = msg.getReceivedDate();
         } catch (final MessagingException e) {
-            throw MIMEMailException.handleMessagingException(e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ReceivedDateTerm.class)).warn("Error during search.", e);
+            return false;
         }
         if (null == receivedDate) {
             return false;
