@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,7 @@ import com.openexchange.mail.search.ComparisonType;
 import com.openexchange.mail.search.FlagTerm;
 import com.openexchange.mail.search.FromTerm;
 import com.openexchange.mail.search.HeaderTerm;
+import com.openexchange.mail.search.ORTerm;
 import com.openexchange.mail.search.ReceivedDateTerm;
 import com.openexchange.mail.search.SearchTerm;
 import com.openexchange.mail.search.SentDateTerm;
@@ -77,12 +78,12 @@ import com.openexchange.search.SingleSearchTerm.SingleOperation;
 
 /**
  * {@link MailAttributeFetcher} - The attribute fetcher for mail module.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailAttributeFetcher implements SearchAttributeFetcher<MailMessage> {
 
-    static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAttributeFetcher.class);
+    static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAttributeFetcher.class));
 
     private static interface AttributeGetter {
 
@@ -216,7 +217,28 @@ public final class MailAttributeFetcher implements SearchAttributeFetcher<MailMe
                 if (SingleOperation.EQUALS != operation) {
                     throw new IllegalArgumentException("Unsupported operation for header search: " + operation);
                 }
-                return new HeaderTerm(MessageHeaders.HDR_X_PRIORITY, constant.toString());
+                int parsedPrio;
+                final String string = constant.toString();
+                try {
+                    parsedPrio = Integer.parseInt(string);
+                } catch (NumberFormatException e) {
+                    parsedPrio = -1;
+                }
+                final String importance;
+                if (parsedPrio >= 0) {
+                    if (MailMessage.PRIORITY_NORMAL == parsedPrio) {
+                        importance = "Medium";
+                    } else if (parsedPrio > MailMessage.PRIORITY_NORMAL) {
+                        importance = "Low";
+                    } else {
+                        importance = "High";
+                    }
+                } else {
+                    importance = "Medium";
+                }
+                return new ORTerm(new HeaderTerm(MessageHeaders.HDR_IMPORTANCE, importance), new HeaderTerm(
+                    MessageHeaders.HDR_X_PRIORITY,
+                    string));
             }
 
         });
@@ -396,7 +418,7 @@ public final class MailAttributeFetcher implements SearchAttributeFetcher<MailMe
 
     /**
      * Gets the mail attribute fetcher instance.
-     * 
+     *
      * @return The mail attribute fetcher instance.
      */
     public static MailAttributeFetcher getInstance() {
@@ -422,14 +444,13 @@ public final class MailAttributeFetcher implements SearchAttributeFetcher<MailMe
             }
             return null;
         }
-        @SuppressWarnings("unchecked")
-        final T retval = (T) getter.getObject(candidate);
+        @SuppressWarnings("unchecked") final T retval = (T) getter.getObject(candidate);
         return retval;
     }
 
     /**
      * Gets the mail search term for given simple search term identifier
-     * 
+     *
      * @param attributeName The attribute name
      * @param operation The operation
      * @param constant The constant to compare to
