@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.session.Session;
 
 /**
  * {@link MailServiceImpl} - The mail service implementation
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailServiceImpl implements MailService {
@@ -73,6 +73,10 @@ public final class MailServiceImpl implements MailService {
         return MailAccess.getInstance(session, accountId);
     }
 
+    public MailAccess<?, ?> getMailAccess(final int userId, final int contextId, final int accountId) throws MailException {
+        return MailAccess.getInstance(userId, contextId, accountId);
+    }
+
     public MailTransport getMailTransport(final Session session, final int accountId) throws MailException {
         return MailTransport.getInstance(session, accountId);
     }
