@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link Base64JSONString} - A {@link JSONString JSON string} for one-time-retrieval of an input stream's base64-encoded bytes.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Base64JSONString implements JSONString {
@@ -72,7 +72,7 @@ public final class Base64JSONString implements JSONString {
 
     /**
      * Initializes a new {@link Base64JSONString}.
-     * 
+     *
      * @throws MailException If initialization fails
      */
     public Base64JSONString(final InputStream in) throws MailException {
@@ -98,7 +98,7 @@ public final class Base64JSONString implements JSONString {
             try {
                 in.close();
             } catch (final IOException e) {
-                org.apache.commons.logging.LogFactory.getLog(Base64JSONString.class).error(e.getMessage(), e);
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Base64JSONString.class)).error(e.getMessage(), e);
             }
         }
         try {
