@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,8 +55,8 @@ import java.io.IOException;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
-import java.util.NoSuchElementException;
 import java.util.Map.Entry;
+import java.util.NoSuchElementException;
 import javax.activation.DataHandler;
 import javax.activation.DataSource;
 import javax.mail.MessagingException;
@@ -88,24 +88,26 @@ import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.TNEFBodyPart;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
+import com.openexchange.mail.mime.dataobjects.MIMEMultipartMailPart;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.parser.MailMessageHandler;
 import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.mail.uuencode.UUEncodedMultiPart;
+import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * {@link StructureMailMessageParser} - A callback parser to parse instances of {@link MailMessage} by invoking the <code>handleXXX()</code>
  * methods of given {@link MailMessageHandler} object
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class StructureMailMessageParser {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(StructureMailMessageParser.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(StructureMailMessageParser.class));
 
     private static final boolean WARN_ENABLED = LOG.isWarnEnabled();
 
@@ -176,17 +178,32 @@ public final class StructureMailMessageParser {
 
     private InlineDetector inlineDetector;
 
+    private boolean neverTreatMessageAsAttachment;
+
     /**
      * Constructor
      */
     public StructureMailMessageParser() {
         super();
+        parseTNEFParts = true;
+        neverTreatMessageAsAttachment = true;
         inlineDetector = LENIENT_DETECTOR;
     }
 
+    /**
+     * Sets the behavior how to handle a message part.
+     *
+     * @param neverTreatMessageAsAttachment whether to treat a message part as an attachment
+     * @return This parser with new behavior applied
+     */
+    public StructureMailMessageParser setNeverTreatMessageAsAttachment(final boolean neverTreatMessageAsAttachment) {
+        this.neverTreatMessageAsAttachment = neverTreatMessageAsAttachment;
+        return this;
+    }
+
     /**
      * Switches the INLINE detector behavior.
-     * 
+     *
      * @param strict <code>true</code> to perform strict INLINE detector behavior; otherwise <code>false</code>
      * @return This parser with new behavior applied
      */
@@ -197,7 +214,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Sets whether TNEF parts should be parsed or not.
-     * 
+     *
      * @param parseTNEFParts <code>true</code> to parse TNEF parts; otherwise <code>false</code>
      * @return This parser with new behavior applied
      */
@@ -208,7 +225,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Sets whether UUEncoded parts should be parsed or not.
-     * 
+     *
      * @param parseUUEncodedParts <code>true</code> to parse UUEncoded parts; otherwise <code>false</code>
      * @return This parser with new behavior applied
      */
@@ -219,7 +236,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Resets this parser and returns itself
-     * 
+     *
      * @return The parser itself
      */
     public StructureMailMessageParser reset() {
@@ -230,7 +247,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Parses specified mail using given handler as call-back
-     * 
+     *
      * @param mail The mail to parse
      * @param handler The call-back handler
      * @throws MailException If parsing specified mail fails
@@ -242,7 +259,7 @@ public final class StructureMailMessageParser {
     /**
      * Parses specified mail using given handler as call-back and given initial prefix for mail part identifiers; e.g.
      * <code>&quot;1.1&quot;</code>.
-     * 
+     *
      * @param mail The mail to parse
      * @param handler The call-back handler
      * @param prefix The initial prefix for mail part identifiers; e.g. <code>&quot;1.1&quot;</code>
@@ -264,6 +281,10 @@ public final class StructureMailMessageParser {
              * Parse content
              */
             parseMailContent(mail, handler, prefix, 1);
+            /*
+             * Mark end of parsing
+             */
+            handler.handleEnd(mail);
         } catch (final IOException e) {
             throw new MailException(MailException.Code.UNREADBALE_PART_CONTENT, e, Long.valueOf(mail.getMailId()), mail.getFolder());
         }
@@ -285,7 +306,7 @@ public final class StructureMailMessageParser {
         final ContentType contentType =
             mailPart.containsContentType() ? mailPart.getContentType() : new ContentType(MIMETypes.MIME_APPL_OCTET);
         final String lcct = LocaleTools.toLowerCase(contentType.getBaseType());
-        final String filename = getFileName(mailPart.getFileName(), getSequenceId(prefix, partCount), lcct);
+        final String fileName = getFileName(mailPart.getFileName(), getSequenceId(prefix, partCount), lcct);
 
         /*
          * Parse part dependent on its MIME type
@@ -299,8 +320,8 @@ public final class StructureMailMessageParser {
         if (isText(lcct)) {
             if (isInline) {
                 final String content = readContent(mailPart, contentType);
-                final UUEncodedMultiPart uuencodedMP = parseUUEncodedParts ? new UUEncodedMultiPart(content) : null;
-                if (parseUUEncodedParts && uuencodedMP.isUUEncoded()) {
+                final UUEncodedMultiPart uuencodedMP;
+                if (parseUUEncodedParts && (uuencodedMP = new UUEncodedMultiPart(content)).isUUEncoded()) {
                     /*
                      * UUEncoded content detected. Handle normal text.
                      */
@@ -317,7 +338,7 @@ public final class StructureMailMessageParser {
                             uuencodedMP.getCleanText(),
                             contentType,
                             uuencodedMP.getCleanText().length(),
-                            filename,
+                            fileName,
                             getSequenceId(prefix, partCount))) {
                             stop = true;
                             return;
@@ -346,7 +367,7 @@ public final class StructureMailMessageParser {
                             uuencodedMP.getCleanText(),
                             contentType,
                             uuencodedMP.getCleanText().length(),
-                            filename,
+                            fileName,
                             getSequenceId(prefix, partCount))) {
                             stop = true;
                             return;
@@ -381,42 +402,86 @@ public final class StructureMailMessageParser {
             if (count == -1) {
                 throw new MailException(MailException.Code.INVALID_MULTIPART_CONTENT);
             }
-            final String mpId = null == prefix && !multipartDetected ? "" : getSequenceId(prefix, partCount);
+            final boolean rootLevelMultipart = null == prefix && !multipartDetected;
+            final String mpId = rootLevelMultipart ? "" : getSequenceId(prefix, partCount);
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(mpId);
             }
-            if (!handler.handleMultipartStart(mailPart.getContentType(), count, mpId)) {
-                stop = true;
-                return;
-            }
-            final String mpPrefix;
-            if (multipartDetected) {
-                mpPrefix = mpId;
+            if (/*rootLevelMultipart && */isMultipartSigned(lcct)) {
+                /*
+                 * Determine the part which is considered to be the message' text according to
+                 */
+                MailPart part = null;
+                for (int i = 0; null == part && i < count; i++) {
+                    final MailPart enclosedPart = mailPart.getEnclosedMailPart(i);
+                    part = extractTextFrom(enclosedPart, 0);
+                }
+                if (!handler.handleSMIMEBodyText(part)) {
+                    stop = true;
+                    return;
+                }
+                part = null;
+                final ByteArrayOutputStream buf = new UnsynchronizedByteArrayOutputStream(2048);
+                final byte[] bytes;
+                {
+                    mailPart.writeTo(buf);
+                    bytes = buf.toByteArray();
+                    buf.reset();
+                }
+                {
+                    final String version = mailPart.getFirstHeader("MIME-Version");
+                    buf.write(("MIME-Version: " + (null == version ? "1.0" : version) + "\r\n").getBytes("US-ASCII"));
+                }
+                {
+                    final String ct = MIMEMessageUtility.extractHeader("Content-Type", new UnsynchronizedByteArrayInputStream(bytes), false);
+                    buf.write(("Content-Type:" + ct + "\r\n").getBytes("US-ASCII"));
+                }
+                buf.write(extractBodyFrom(bytes));
+                if (!handler.handleSMIMEBodyData(buf.toByteArray())) {
+                    stop = true;
+                    return;
+                }
             } else {
-                mpPrefix = prefix;
-                multipartDetected = true;
-            }
-            for (int i = 0; i < count; i++) {
-                final MailPart enclosedContent = mailPart.getEnclosedMailPart(i);
-                parseMailContent(enclosedContent, handler, mpPrefix, i + 1);
-            }
-            if (!handler.handleMultipartEnd()) {
-                stop = true;
-                return;
+                if (!handler.handleMultipartStart(mailPart.getContentType(), count, mpId)) {
+                    stop = true;
+                    return;
+                }
+                final String mpPrefix;
+                if (multipartDetected) {
+                    mpPrefix = mpId;
+                } else {
+                    mpPrefix = prefix;
+                    multipartDetected = true;
+                }
+                for (int i = 0; i < count; i++) {
+                    final MailPart enclosedPart = mailPart.getEnclosedMailPart(i);
+                    parseMailContent(enclosedPart, handler, mpPrefix, i + 1);
+                }
+                if (!handler.handleMultipartEnd()) {
+                    stop = true;
+                    return;
+                }
             }
         } else if (isMessage(lcct)) {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
-            if (isInline) {
+            if (neverTreatMessageAsAttachment) {
                 if (!handler.handleNestedMessage(mailPart, getSequenceId(prefix, partCount))) {
                     stop = true;
                     return;
                 }
             } else {
-                if (!handler.handleAttachment(mailPart, mailPart.getSequenceId())) {
-                    stop = true;
-                    return;
+                if (isInline) {
+                    if (!handler.handleNestedMessage(mailPart, getSequenceId(prefix, partCount))) {
+                        stop = true;
+                        return;
+                    }
+                } else {
+                    if (!handler.handleAttachment(mailPart, mailPart.getSequenceId())) {
+                        stop = true;
+                        return;
+                    }
                 }
             }
         } else if (parseTNEFParts && TNEFUtils.isTNEFMimeType(lcct)) {
@@ -598,7 +663,7 @@ public final class StructureMailMessageParser {
                         /*
                          * Translate TNEF attributes to MIME
                          */
-                        final String attachFilename = filename;
+                        final String attachFilename = fileName;
                         final DataSource ds = new RawDataSource(messageClass.getRawData(), MIMETypes.MIME_APPL_OCTET);
                         bodyPart.setDataHandler(new DataHandler(ds));
                         bodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, ContentType.prepareContentTypeString(
@@ -649,6 +714,54 @@ public final class StructureMailMessageParser {
         }
     }
 
+    private MailPart extractTextFrom(final MailPart mailPart, final int altLevel) throws MailException {
+        if (!mailPart.containsContentType()) {
+            return null;
+        }
+        final ContentType contentType = mailPart.getContentType();
+        if (contentType.startsWith("text/")) {
+            return (altLevel <= 0) || contentType.startsWith("text/htm") ? mailPart : null;
+        }
+        if (contentType.startsWith("multipart/")) {
+            final boolean isAlternative = contentType.startsWith("multipart/alternative");
+            int alternative = altLevel;
+            if (isAlternative) {
+                alternative++;
+            }
+            final int count = mailPart.getEnclosedCount();
+            MailPart textPart = null;
+            for (int i = 0; i < count; i++) {
+                final MailPart enclosedPart = mailPart.getEnclosedMailPart(i);
+                final MailPart ret = extractTextFrom(enclosedPart, alternative);
+                if (null != ret) {
+                    return ret;
+                }
+                if (isAlternative && null == textPart && enclosedPart.getContentType().startsWith("text/")) {
+                    textPart = enclosedPart;
+                }
+            }
+            if (isAlternative) {
+                alternative--;
+                if (null != textPart) {
+                    return textPart;
+                }
+            }
+        }
+        return null;
+    }
+
+    private byte[] extractBodyFrom(final byte[] bytes) {
+        int pos = MIMEMultipartMailPart.getHeaderEnd(bytes);
+        if (pos <= 0) {
+            return bytes;
+        }
+        pos++; // Advance last LF character
+        final int len = bytes.length - pos;
+        final byte[] body = new byte[len];
+        System.arraycopy(bytes, pos, body, 0, len);
+        return body;
+    }
+
     private void parseEnvelope(final MailMessage mail, final StructureHandler handler) throws MailException {
         /*
          * RECEIVED DATE
@@ -675,7 +788,7 @@ public final class StructureMailMessageParser {
     /**
      * Generates an appropriate filename from either specified <code>rawFileName</code> if not <code>null</code> or generates a filename
      * composed with <code>"Part_" + sequenceId</code>
-     * 
+     *
      * @param rawFileName The raw filename obtained from mail part
      * @param sequenceId The part's sequence ID
      * @param baseMimeType The base MIME type to look up an appropriate file extension, if <code>rawFileName</code> is <code>null</code>
@@ -715,7 +828,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Composes part's sequence ID from given prefix and part's count
-     * 
+     *
      * @param prefix The prefix (may be <code>null</code>)
      * @param partCount The part count
      * @return The sequence ID
@@ -729,7 +842,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Generates a filename consisting of common prefix "Part_" and part's sequence ID appended
-     * 
+     *
      * @param sequenceId Part's sequence ID
      * @param baseMimeType The base MIME type to look up an appropriate file extension if <code>rawFileName</code> is <code>null</code>
      * @return The generated filename
@@ -800,7 +913,7 @@ public final class StructureMailMessageParser {
      * <li><code>text/richtext</code></li>
      * <li><code>text/rtf</code></li>
      * </ul>
-     * 
+     *
      * @param contentType The content type
      * @return <code>true</code> if content type matches text; otherwise <code>false</code>
      */
@@ -820,7 +933,7 @@ public final class StructureMailMessageParser {
 
     /**
      * Checks if content type matches <code>multipart/*</code> content type.
-     * 
+     *
      * @param contentType The content type
      * @return <code>true</code> if content type matches <code>multipart/*</code>; otherwise <code>false</code>
      */
@@ -828,11 +941,23 @@ public final class StructureMailMessageParser {
         return contentType.startsWith(PRIMARY_MULTI, 0);
     }
 
+    private static final String PRIMARY_MULTI_SIGNED = "multipart/signed";
+
+    /**
+     * Checks if content type matches <code>multipart/signed</code> content type.
+     *
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches <code>multipart/signed</code>; otherwise <code>false</code>
+     */
+    private static boolean isMultipartSigned(final String contentType) {
+        return contentType.startsWith(PRIMARY_MULTI_SIGNED, 0);
+    }
+
     private static final String PRIMARY_RFC822 = "message/rfc822";
 
     /**
      * Checks if content type matches <code>message/rfc822</code> content type.
-     * 
+     *
      * @param contentType The content type
      * @return <code>true</code> if content type matches <code>message/rfc822</code>; otherwise <code>false</code>
      */
@@ -840,4 +965,12 @@ public final class StructureMailMessageParser {
         return contentType.startsWith(PRIMARY_RFC822, 0);
     }
 
+    private static boolean isWinmailDat(final String fileName) {
+        if (isEmptyString(fileName)) {
+            return false;
+        }
+        final String toCheck = LocaleTools.toLowerCase(fileName);
+        return toCheck.startsWith("winmail", 0) && toCheck.endsWith(".dat");
+    }
+
 }
