@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,6 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.util.regex.Matcher;
 import javax.swing.text.AttributeSet;
-import javax.swing.text.BadLocationException;
 import javax.swing.text.DefaultStyledDocument;
 import javax.swing.text.Document;
 import javax.swing.text.Element;
@@ -65,12 +64,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 
 /**
  * {@link RTF2HTMLConverter} - Converts RTF to HTML based on <code>javax.swing.text.*</code> package
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class RTF2HTMLConverter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(RTF2HTMLConverter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(RTF2HTMLConverter.class));
 
     private static final class HTMLStateMachine {
 
@@ -362,7 +361,7 @@ public final class RTF2HTMLConverter {
 
     /**
      * Triggers the rtf2html conversion
-     * 
+     *
      * @param rtfContent The RTF content
      * @return The converted HTML content
      */
@@ -376,7 +375,7 @@ public final class RTF2HTMLConverter {
 
     /**
      * Converts a single RTF string to HTML without wrapping returned converted HTML body inside a HTML document.
-     * 
+     *
      * @param rtfString The RTF string
      * @return The converted HTML body
      */
@@ -404,7 +403,7 @@ public final class RTF2HTMLConverter {
         } catch (final IOException e) {
             LOG.error(e.getMessage(), e);
             return;
-        } catch (final BadLocationException e) {
+        } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             return;
         }
@@ -445,7 +444,7 @@ public final class RTF2HTMLConverter {
                 s = hsm.performFirstLineIndent(s);
                 sb.append(s);
             }
-        } catch (final BadLocationException e) {
+        } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             return;
         }
