@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,10 +63,12 @@ import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
+import com.openexchange.caching.CacheKey;
 import com.openexchange.caching.CacheService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException.UserConfigurationCode;
 import com.openexchange.mail.usersetting.UserSettingMail.Signature;
@@ -76,12 +78,12 @@ import com.openexchange.server.services.ServerServiceRegistry;
 /**
  * CachingUserSettingMailStorage - this storage tries to use a cache for instances of <code>{@link UserSettingMail}</code> and falls back to
  * database-based storage if any cache-related errors occur
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CachingUserSettingMailStorage extends UserSettingMailStorage {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CachingUserSettingMailStorage.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CachingUserSettingMailStorage.class));
 
     private static final String CACHE_REGION_NAME = "UserSettingMail";
 
@@ -139,9 +141,11 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
 
     private static final String SQL_UPDATE = "UPDATE user_setting_mail SET bits = ?, send_addr = ?, reply_to_addr = ?, msg_format = ?, display_msg_headers = ?, auto_linebreak = ?, std_trash = ?, std_sent = ?, std_drafts = ?, std_spam = ?, upload_quota = ?, upload_quota_per_file = ?, confirmed_spam = ?, confirmed_ham = ? WHERE cid = ? AND user = ?";
 
+    private static final String SQL_UPDATE_BITS = "UPDATE user_setting_mail SET bits = ? WHERE cid = ? AND user = ?";
+
     /**
      * Saves given user's mail settings to database
-     * 
+     *
      * @param usm the user's mail settings to save
      * @param user the user ID
      * @param ctx the context
@@ -165,7 +169,7 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
             Connection tmpCon = null;
             try {
                 tmpCon = DBPool.pickup(ctx);
-                stmt = tmpCon.prepareStatement(SQL_LOAD);
+                stmt = tmpCon.prepareStatement("SELECT 1 FROM user_setting_mail WHERE cid = ? AND user = ?");
                 stmt.setInt(1, ctx.getContextId());
                 stmt.setInt(2, user);
                 rs = stmt.executeQuery();
@@ -199,7 +203,63 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
                 cacheWriteLock.lock();
                 try {
                     usm.setNoSave(false);
-                    cache.put(cache.newCacheKey(ctx.getContextId(), user), (Serializable) usm.clone());
+                    final CacheKey key = cache.newCacheKey(ctx.getContextId(), user);
+                    if (null != cache.get(key)) {
+                        cache.remove(key);
+                    }
+                    cache.put(key, (Serializable) usm.clone());
+                } catch (final CacheException e) {
+                    LOG.error("UserSettingMail could not be put into cache", e);
+                } finally {
+                    cacheWriteLock.unlock();
+                }
+            }
+        } catch (final SQLException e) {
+            LOG.error(e.getMessage(), e);
+            throw new UserConfigurationException(UserConfigurationCode.SQL_ERROR, e, e.getMessage());
+        } catch (final DBPoolingException e) {
+            LOG.error(e.getMessage(), e);
+            throw new UserConfigurationException(UserConfigurationCode.DBPOOL_ERROR, e);
+        }
+    }
+
+    @Override
+    public void saveUserSettingMailBits(final UserSettingMail usm, final int user, final Context ctx, final Connection writeConArg) throws UserConfigurationException {
+        if (usm.isNoSave()) {
+            /*
+             * Saving to storage denied
+             */
+            return;
+        }
+        try {
+            Connection writeCon = writeConArg;
+            boolean closeCon = false;
+            PreparedStatement stmt = null;
+            final ResultSet rs = null;
+            try {
+                if (writeCon == null) {
+                    writeCon = DBPool.pickupWriteable(ctx);
+                    closeCon = true;
+                }
+                stmt = getUpdateStmtBits(usm, user, ctx, writeCon);
+                stmt.executeUpdate();
+                saveSignatures(usm, user, ctx, writeCon);
+            } finally {
+                closeResources(rs, stmt, closeCon ? writeCon : null, false, ctx);
+            }
+            usm.setModifiedDuringSession(false);
+            if (useCache()) {
+                /*
+                 * Put clone into cache
+                 */
+                cacheWriteLock.lock();
+                try {
+                    usm.setNoSave(false);
+                    final CacheKey key = cache.newCacheKey(ctx.getContextId(), user);
+                    if (null != cache.get(key)) {
+                        cache.remove(key);
+                    }
+                    cache.put(key, (Serializable) usm.clone());
                 } catch (final CacheException e) {
                     LOG.error("UserSettingMail could not be put into cache", e);
                 } finally {
@@ -221,7 +281,7 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
 
     /**
      * Deletes the user's mail settings from database
-     * 
+     *
      * @param user the user ID
      * @param ctx the context
      * @param writeConArg the writable connection; may be <code>null</code>
@@ -283,7 +343,7 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
 
     /**
      * Loads user's mail settings from database
-     * 
+     *
      * @param user the user
      * @param ctx the context
      * @param readConArg the readable connection; may be <code>null</code> to fetch own connection.
@@ -430,19 +490,28 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
         }
         s = null;
         stmt.setInt(6, usm.getAutoLinebreak());
-        stmt.setString(7, usm.getStdTrashName() == null ? UserSettingMail.STD_TRASH : usm.getStdTrashName());
-        stmt.setString(8, usm.getStdSentName() == null ? UserSettingMail.STD_SENT : usm.getStdSentName());
-        stmt.setString(9, usm.getStdDraftsName() == null ? UserSettingMail.STD_DRAFTS : usm.getStdDraftsName());
-        stmt.setString(10, usm.getStdSpamName() == null ? UserSettingMail.STD_SPAM : usm.getStdSpamName());
+        stmt.setString(7, usm.getStdTrashName() == null ? MailStrings.TRASH : usm.getStdTrashName());
+        stmt.setString(8, usm.getStdSentName() == null ? MailStrings.SENT : usm.getStdSentName());
+        stmt.setString(9, usm.getStdDraftsName() == null ? MailStrings.DRAFTS : usm.getStdDraftsName());
+        stmt.setString(10, usm.getStdSpamName() == null ? MailStrings.SPAM : usm.getStdSpamName());
         stmt.setLong(11, usm.getUploadQuota());
         stmt.setLong(12, usm.getUploadQuotaPerFile());
-        stmt.setString(13, usm.getConfirmedSpam() == null ? UserSettingMail.STD_CONFIRMED_SPAM : usm.getConfirmedSpam());
-        stmt.setString(14, usm.getConfirmedHam() == null ? UserSettingMail.STD_CONFIRMED_HAM : usm.getConfirmedHam());
+        stmt.setString(13, usm.getConfirmedSpam() == null ? MailStrings.CONFIRMED_SPAM : usm.getConfirmedSpam());
+        stmt.setString(14, usm.getConfirmedHam() == null ? MailStrings.CONFIRMED_HAM : usm.getConfirmedHam());
         stmt.setInt(15, ctx.getContextId());
         stmt.setInt(16, user);
         return stmt;
     }
 
+    private static PreparedStatement getUpdateStmtBits(final UserSettingMail usm, final int user, final Context ctx, final Connection writeCon) throws SQLException {
+        PreparedStatement stmt;
+        stmt = writeCon.prepareStatement(SQL_UPDATE_BITS);
+        stmt.setInt(1, usm.getBitsValue());
+        stmt.setInt(2, ctx.getContextId());
+        stmt.setInt(3, user);
+        return stmt;
+    }
+
     private static PreparedStatement getInsertStmt(final UserSettingMail usm, final int user, final Context ctx, final Connection writeCon) throws SQLException {
         PreparedStatement stmt;
         stmt = writeCon.prepareStatement(SQL_INSERT);
@@ -460,14 +529,14 @@ public final class CachingUserSettingMailStorage extends UserSettingMailStorage
         }
         s = null;
         stmt.setInt(8, usm.getAutoLinebreak());
-        stmt.setString(9, usm.getStdTrashName() == null ? UserSettingMail.STD_TRASH : usm.getStdTrashName());
-        stmt.setString(10, usm.getStdSentName() == null ? UserSettingMail.STD_SENT : usm.getStdSentName());
-        stmt.setString(11, usm.getStdDraftsName() == null ? UserSettingMail.STD_DRAFTS : usm.getStdDraftsName());
-        stmt.setString(12, usm.getStdSpamName() == null ? UserSettingMail.STD_SPAM : usm.getStdSpamName());
+        stmt.setString(9, usm.getStdTrashName() == null ? MailStrings.TRASH : usm.getStdTrashName());
+        stmt.setString(10, usm.getStdSentName() == null ? MailStrings.SENT : usm.getStdSentName());
+        stmt.setString(11, usm.getStdDraftsName() == null ? MailStrings.DRAFTS : usm.getStdDraftsName());
+        stmt.setString(12, usm.getStdSpamName() == null ? MailStrings.SPAM : usm.getStdSpamName());
         stmt.setLong(13, usm.getUploadQuota());
         stmt.setLong(14, usm.getUploadQuotaPerFile());
-        stmt.setString(15, usm.getConfirmedSpam() == null ? UserSettingMail.STD_CONFIRMED_SPAM : usm.getConfirmedSpam());
-        stmt.setString(16, usm.getConfirmedHam() == null ? UserSettingMail.STD_CONFIRMED_HAM : usm.getConfirmedHam());
+        stmt.setString(15, usm.getConfirmedSpam() == null ? MailStrings.CONFIRMED_SPAM : usm.getConfirmedSpam());
+        stmt.setString(16, usm.getConfirmedHam() == null ? MailStrings.CONFIRMED_HAM : usm.getConfirmedHam());
         return stmt;
     }
 
