@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.mail.usersetting;
 
 import java.io.Serializable;
+import javax.mail.internet.IDNA;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.server.ServiceException;
@@ -58,14 +59,14 @@ import com.openexchange.spamhandler.SpamHandlerRegistry;
 
 /**
  * {@link UserSettingMail} - User's mail settings.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * {@link Signature} - The mail signature.
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     public static final class Signature implements Cloneable, Serializable {
@@ -117,7 +118,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      */
     private static final long serialVersionUID = -5787223065275414178L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UserSettingMail.class);
+    private static final transient org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UserSettingMail.class));
 
     /*-
      * Integer constants for on/off options
@@ -237,18 +238,6 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     public static final int MSG_FORMAT_BOTH = 3;
 
-    public static final String STD_TRASH = "Trash";
-
-    public static final String STD_DRAFTS = "Drafts";
-
-    public static final String STD_SENT = "Sent";
-
-    public static final String STD_SPAM = "Spam";
-
-    public static final String STD_CONFIRMED_SPAM = "Confirmed Spam";
-
-    public static final String STD_CONFIRMED_HAM = "Confirmed Ham";
-
     /*-
      * Member fields
      */
@@ -260,6 +249,8 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     private boolean displayHtmlInlineContent;
 
+    private boolean suppressHTMLAlternativePart;
+
     private boolean useColorQuote;
 
     private boolean showGraphicEmoticons;
@@ -330,9 +321,11 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     private boolean noSave;
 
+    private boolean dropReplyForwardPrefix;
+
     /**
      * Initializes a new {@link UserSettingMail}.
-     * 
+     *
      * @param userId The user ID
      * @param cid The context ID
      */
@@ -367,16 +360,34 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the character count after which a line break is added in <code>text/plain</code> messages
-     * 
+     *
      * @return The character count after which a line break is added
      */
     public int getAutoLinebreak() {
         return autoLinebreak;
     }
+    
+    /**
+     * Gets the dropReplyForwardPrefix.
+     *
+     * @return The dropReplyForwardPrefix
+     */
+    public boolean isDropReplyForwardPrefix() {
+        return dropReplyForwardPrefix;
+    }
+    
+    /**
+     * Sets the dropReplyForwardPrefix.
+     *
+     * @param dropReplyForwardPrefix The dropReplyForwardPrefix to set
+     */
+    public void setDropReplyForwardPrefix(final boolean dropReplyForwardPrefix) {
+        this.dropReplyForwardPrefix = dropReplyForwardPrefix;
+    }
 
     /**
      * Generates a bit pattern from this settings
-     * 
+     *
      * @return a bit pattern from this settings
      */
     public int getBitsValue() {
@@ -412,7 +423,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the confirmed ham folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the confirmed ham folder
      */
     public String getConfirmedHam() {
@@ -423,7 +434,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the confirmed spam folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the confirmed spam folder
      */
     public String getConfirmedSpam() {
@@ -432,7 +443,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Define an array of message headers which shall be displayed for this user in mail's detail view.
-     * 
+     *
      * @return An array of message headers which shall be displayed
      */
     public String[] getDisplayMsgHeaders() {
@@ -449,7 +460,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * <p>
      * The returned <code>int</code> value is one of {@link #MSG_FORMAT_TEXT_ONLY}, {@link #MSG_FORMAT_HTML_ONLY}, and
      * {@link #MSG_FORMAT_BOTH}.
-     * 
+     *
      * @return The desired message format
      */
     public int getMsgFormat() {
@@ -460,7 +471,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * The desired address that shall be set as <code>Reply-To</code> header when sending messages.
      * <p>
      * If returned value is <code>null</code> or empty, the message's <code>From</code> header is used as fallback.
-     * 
+     *
      * @return The desired <code>Reply-To</code> address
      */
     public String getReplyToAddr() {
@@ -469,7 +480,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * The default send address. This address is used to set the <code>From</code> header and the <code>Sender</code> header as well.
-     * 
+     *
      * @return The default send address
      */
     public String getSendAddr() {
@@ -478,7 +489,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the user-defined signatures that are either prepended or appended to a message's body.
-     * 
+     *
      * @return The user-defined signatures
      */
     public Signature[] getSignatures() {
@@ -494,7 +505,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the draft folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the draft folder
      */
     public String getStdDraftsName() {
@@ -505,7 +516,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the sent folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the sent folder
      */
     public String getStdSentName() {
@@ -516,7 +527,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the spam folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the spam folder
      */
     public String getStdSpamName() {
@@ -527,7 +538,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * Gets the name of the trash folder.
      * <p>
      * <b>Note</b>: This is only the name, not its fullname.
-     * 
+     *
      * @return The name of the trash folder
      */
     public String getStdTrashName() {
@@ -536,7 +547,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the overall upload quota limit when uploading several file attachments.
-     * 
+     *
      * @return The overall upload quota limit.
      */
     public long getUploadQuota() {
@@ -545,7 +556,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the upload quota limit per file when uploading several file attachments.
-     * 
+     *
      * @return The upload quota limit per file.
      */
     public long getUploadQuotaPerFile() {
@@ -554,7 +565,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if user's VCard shall be attached to a message on transport
-     * 
+     *
      * @return <code>true</code> if user's VCard shall be attached to a message on transport; otherwise <code>false</code>
      */
     public boolean isAppendVCard() {
@@ -563,7 +574,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if user allows to display inline HTML content of a message.
-     * 
+     *
      * @return <code>true</code> if user allows to display inline HTML content of a message; otherwise <code>false</code>
      */
     public boolean isDisplayHtmlInlineContent() {
@@ -571,8 +582,17 @@ public final class UserSettingMail implements Cloneable, Serializable {
     }
 
     /**
-     * Checks if a forwarded message is supposed to be added as an attachment; otherwise it is added inline.
+     * Whether to suppress HTML parts in text-only mode for <i>multipart/alternative</i>.
      * 
+     * @return <code>true</code> to suppress HTML parts in text-only mode for <i>multipart/alternative</i>; otherwise <code>false</code>
+     */
+    public boolean isSuppressHTMLAlternativePart() {
+        return suppressHTMLAlternativePart;
+    }
+
+    /**
+     * Checks if a forwarded message is supposed to be added as an attachment; otherwise it is added inline.
+     *
      * @return <code>true</code> if a forwarded message is supposed to be added as an attachment; otherwise <code>false</code> if it is
      *         added inline.
      */
@@ -582,7 +602,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if messages are supposed to be deleted permanently or backuped into trash folder.
-     * 
+     *
      * @return <code>true</code> if messages are supposed to be deleted permanently; otherwise <code>false</code> to backup in trash folder
      */
     public boolean isHardDeleteMsgs() {
@@ -591,7 +611,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if original message's content shall be ignored in reply version to the message
-     * 
+     *
      * @return <code>true</code> if original message's content shall be ignored; otherwise <code>false</code> to include.
      */
     public boolean isIgnoreOriginalMailTextOnReply() {
@@ -600,7 +620,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Internal flag to track this mail setting's modified status.
-     * 
+     *
      * @return <code>true</code> if modified during session (and to force a reload); otherwise <code>false</code>
      */
     public boolean isModifiedDuringSession() {
@@ -616,7 +636,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if a sent message shall be copied into sent folder
-     * 
+     *
      * @return <code>true</code> if a sent message shall be copied into sent folder; otherwise <code>false</code>
      */
     public boolean isNoCopyIntoStandardSentFolder() {
@@ -625,7 +645,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if the user will receive notification messages on appointment events (creation, deletion & change).
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on appointment events (creation, deletion & change);
      *         otherwise <code>false</code>
      */
@@ -636,7 +656,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Checks if the user will receive notification messages on appointment events (accept, decline & tentatively accepted) as the
      * appointment's owner.
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on appointment events (accept, decline & tentatively
      *         accepted) as the appointment's owner; otherwise <code>false</code>.
      */
@@ -647,7 +667,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Checks if the user will receive notification messages on appointment events (accept, decline & tentatively accepted) as an
      * appointment's participant.
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on appointment events (accept, decline & tentatively
      *         accepted) as an appointment's participant; otherwise <code>false</code>.
      */
@@ -657,7 +677,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if the user will receive notification messages on task events (accept, decline & tentatively accepted) as the task's owner.
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on task events (accept, decline & tentatively accepted) as
      *         the task's owner; otherwise <code>false</code>.
      */
@@ -668,7 +688,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Checks if the user will receive notification messages on task events (accept, decline & tentatively accepted) as a task's
      * participant.
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on task events (accept, decline & tentatively accepted) as a
      *         task's participant; otherwise <code>false</code>.
      */
@@ -685,7 +705,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if the user will receive notification messages on task events (creation, deletion & change).
-     * 
+     *
      * @return <code>true</code> if the user will receive notification messages on task events (creation, deletion & change); otherwise
      *         <code>false</code>
      */
@@ -695,7 +715,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Indicates if user wants to see graphical emoticons rather than corresponding textual representation
-     * 
+     *
      * @return <code>true</code> if user wants to see graphical emoticons rather than corresponding textual representation; otherwise
      *         <code>false</code>
      */
@@ -706,7 +726,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Checks if user has spam enabled. Spam is enabled if both an appropriate spam handler is defined by user's mail provider
      * <small><b>AND</b></small> its mail settings enable spam.
-     * 
+     *
      * @return <code>true</code> if user has spam enabled; otherwise <code>false</code>
      */
     public boolean isSpamEnabled() {
@@ -731,7 +751,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
      * <p>
      * <b>Note</b>: This method does not check if an appropriate spam handler is defined by user's mail provider. To reliably check full
      * spam support call {@link #isSpamEnabled()}.
-     * 
+     *
      * @return <code>true</code> if user has spam enabled; otherwise <code>false</code>
      */
     public boolean isSpamOptionEnabled() {
@@ -747,7 +767,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Indicates if user allows to display images which appear in HTML content of a message.
-     * 
+     *
      * @return <code>true</code> if user allows to display images; otherwise <code>false</code>
      */
     public boolean isAllowHTMLImages() {
@@ -757,7 +777,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Indicates if the reply-all method will put all recipients except the original sender in the Cc list. Normally, recipients in the To
      * header of the original message will also appear in the To list.
-     * 
+     *
      * @return <code>true</code> if the reply-all method will put all recipients except the original sender in the Cc list; otherwise
      *         <code>false</code>.
      */
@@ -767,7 +787,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Indicates if user wants to see reply quotes inside a message's content indented in a color dependent on quote level.
-     * 
+     *
      * @return <code>true</code> to indent in color; otherwise <code>false</code>
      */
     public boolean isUseColorQuote() {
@@ -776,7 +796,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Checks if this instance of {@link UserSettingMail} is allowed to being saved to storage
-     * 
+     *
      * @return <code>true</code> if this instance of {@link UserSettingMail} is allowed to being saved to storage; otherwise
      *         <code>false</code>
      */
@@ -786,7 +806,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Parses given bit pattern and applies it to this settings
-     * 
+     *
      * @param onOffOptions The bit pattern
      */
     public void parseBits(final int onOffOptions) {
@@ -839,6 +859,15 @@ public final class UserSettingMail implements Cloneable, Serializable {
         modifiedDuringSession = true;
     }
 
+    /**
+     * Sets whether to suppress HTML parts in text-only mode for <i>multipart/alternative</i>.
+     * 
+     * @param suppressHTMLAlternativePart <code>true</code> to suppress HTML parts in text-only mode for <i>multipart/alternative</i>; otherwise <code>false</code>
+     */
+    public void setSuppressHTMLAlternativePart(final boolean suppressHTMLAlternativePart) {
+        this.suppressHTMLAlternativePart = suppressHTMLAlternativePart;
+    }
+
     public void setDisplayMsgHeaders(final String[] displayMsgHeaders) {
         if (displayMsgHeaders == null) {
             this.displayMsgHeaders = null;
@@ -900,12 +929,12 @@ public final class UserSettingMail implements Cloneable, Serializable {
     }
 
     public void setReplyToAddr(final String replyToAddr) {
-        this.replyToAddr = replyToAddr;
+        this.replyToAddr = IDNA.toIDN(replyToAddr);
         modifiedDuringSession = true;
     }
 
     public void setSendAddr(final String sendAddr) {
-        this.sendAddr = sendAddr;
+        this.sendAddr = IDNA.toIDN(sendAddr);
         modifiedDuringSession = true;
     }
 
@@ -963,7 +992,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Sets whether the reply-all method will put all recipients except the original sender in the Cc list. Normally, recipients in the To
      * header of the original message will also appear in the To list.
-     * 
+     *
      * @param replyAllCc <code>true</code> if the reply-all method will put all recipients except the original sender in the Cc list;
      *            otherwise <code>false</code>.
      */
@@ -988,7 +1017,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Sets the notifyAppointmentsConfirmOwner
-     * 
+     *
      * @param notifyAppointmentsConfirmOwner the notifyAppointmentsConfirmOwner to set
      */
     public void setNotifyAppointmentsConfirmOwner(final boolean notifyAppointmentsConfirmOwner) {
@@ -998,7 +1027,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Sets the notifyAppointmentsConfirmParticipant
-     * 
+     *
      * @param notifyAppointmentsConfirmParticipant the notifyAppointmentsConfirmParticipant to set
      */
     public void setNotifyAppointmentsConfirmParticipant(final boolean notifyAppointmentsConfirmParticipant) {
@@ -1008,7 +1037,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Sets the notifyTasksConfirmOwner
-     * 
+     *
      * @param notifyTasksConfirmOwner the notifyTasksConfirmOwner to set
      */
     public void setNotifyTasksConfirmOwner(final boolean notifyTasksConfirmOwner) {
@@ -1018,7 +1047,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Sets the notifyTasksConfirmParticipant
-     * 
+     *
      * @param notifyTasksConfirmParticipant the notifyTasksConfirmParticipant to set
      */
     public void setNotifyTasksConfirmParticipant(final boolean notifyTasksConfirmParticipant) {
@@ -1029,7 +1058,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
     /**
      * Sets the <code>no-save</code> attribute. If set to <code>true</code> this instance of {@link UserSettingMail} cannot be saved to
      * storage.
-     * 
+     *
      * @param noSave <code>true</code> to deny saving this instance of {@link UserSettingMail} to storage; otherwise <code>false</code>
      */
     public void setNoSave(final boolean noSave) {
@@ -1038,7 +1067,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the user ID.
-     * 
+     *
      * @return The user ID
      */
     public int getUserId() {
@@ -1047,7 +1076,7 @@ public final class UserSettingMail implements Cloneable, Serializable {
 
     /**
      * Gets the context ID.
-     * 
+     *
      * @return The context ID
      */
     public int getCid() {
