@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,12 +58,12 @@ import com.openexchange.groupware.userconfiguration.UserConfigurationException;
 
 /**
  * {@link UserSettingMailStorage} - Access to {@link UserSettingMail}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class UserSettingMailStorage implements CacheAvailabilityListener {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(UserSettingMailStorage.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UserSettingMailStorage.class));
 
     private static volatile UserSettingMailStorage singleton;
 
@@ -76,7 +76,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Gets the singleton instance of {@link UserSettingMailStorage}
-     * 
+     *
      * @return The singleton instance of {@link UserSettingMailStorage}
      */
     public static final UserSettingMailStorage getInstance() {
@@ -109,7 +109,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
     /**
      * A convenience method that returns {@link #getUserSettingMail(int, Context, Connection)} with the connection parameter set to
      * <code>null</code>.
-     * 
+     *
      * @param user The user ID
      * @param cid The context ID
      * @return The instance of {@link UserSettingMail} which matches given user ID and context or <code>null</code> on exception
@@ -126,7 +126,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
     /**
      * A convenience method that returns {@link #getUserSettingMail(int, Context, Connection)} with the connection parameter set to
      * <code>null</code>.
-     * 
+     *
      * @param user The user ID
      * @param ctx The context
      * @return The instance of {@link UserSettingMail} which matches given user ID and context or <code>null</code> on exception
@@ -138,7 +138,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
     /**
      * A convenience method that returns {@link #loadUserSettingMail(int, Context, Connection)}. If an exception is thrown in delegated
      * method <code>null</code> is returned.
-     * 
+     *
      * @param user The user ID
      * @param ctx The context
      * @param readCon The readable connection (may be <code>null</code>)
@@ -153,9 +153,32 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
         }
     }
 
+    /**
+     * Saves given user's mail settings bits to database
+     *
+     * @param usm the user's mail settings to save
+     * @param user the user ID
+     * @param ctx the context
+     * @throws UserConfigurationException if user's mail settings could not be saved
+     */
+    public final void saveUserSettingMailBits(final UserSettingMail usm, final int user, final Context ctx) throws UserConfigurationException {
+        saveUserSettingMailBits(usm, user, ctx, null);
+    }
+
+    /**
+     * Saves given user's mail settings bits to database
+     *
+     * @param usm the user's mail settings to save
+     * @param user the user ID
+     * @param ctx the context
+     * @param writeConArg - the writable connection; may be <code>null</code>
+     * @throws UserConfigurationException if user's mail settings could not be saved
+     */
+    public abstract void saveUserSettingMailBits(final UserSettingMail usm, final int user, final Context ctx, final Connection writeConArg) throws UserConfigurationException;
+
     /**
      * Saves given user's mail settings to database
-     * 
+     *
      * @param usm the user's mail settings to save
      * @param user the user ID
      * @param ctx the context
@@ -167,7 +190,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Saves given user's mail settings to database
-     * 
+     *
      * @param usm the user's mail settings to save
      * @param user the user ID
      * @param ctx the context
@@ -178,7 +201,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Deletes the user's mail settings from database
-     * 
+     *
      * @param user the user ID
      * @param ctx the context
      * @throws UserConfigurationException if deletion fails
@@ -189,7 +212,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Deletes the user's mail settings from database
-     * 
+     *
      * @param user the user ID
      * @param ctx the context
      * @param writeConArg the writable connection; may be <code>null</code>
@@ -199,7 +222,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Loads user's mail settings from database
-     * 
+     *
      * @param user the user
      * @param ctx the context
      * @return The instance of {@link UserSettingMail} which matches given user ID and context
@@ -211,7 +234,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Loads user's mail settings from database
-     * 
+     *
      * @param user the user
      * @param ctx the context
      * @param readConArg the readable connection
@@ -222,7 +245,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Removes the user's mail settings from cache if any used
-     * 
+     *
      * @param user the user
      * @param ctx the context
      * @throws UserConfigurationException if cache removal fails
@@ -231,7 +254,7 @@ public abstract class UserSettingMailStorage implements CacheAvailabilityListene
 
     /**
      * Clears this storage's cache if any used
-     * 
+     *
      * @throws UserConfigurationException if cache clearing fails
      */
     public abstract void clearStorage() throws UserConfigurationException;
