@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,15 +64,17 @@ import org.mozilla.intl.chardet.nsPSMDetector;
 
 /**
  * {@link CharsetDetector} - A charset detector based on <a href="http://jchardet.sourceforge.net/">jchardet</a> library.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CharsetDetector {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(CharsetDetector.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CharsetDetector.class));
 
     private static final String STR_US_ASCII = "US-ASCII";
 
+    private static final String FALLBACK = "ISO-8859-1";
+
     /**
      * Initializes a new {@link CharsetDetector}
      */
@@ -83,17 +85,49 @@ public final class CharsetDetector {
     /**
      * Convenience method to check if given name is valid; meaning not <code>null</code>, a legal charset name and supported as indicated by
      * {@link Charset#isSupported(String)}.
-     * 
+     *
      * @param charset The charset name whose validity shall be checked
      * @return <code>true</code> if given name is valid; otherwise <code>false</code>
      */
     public static boolean isValid(final String charset) {
-        return (null != charset && checkName(charset) && Charset.isSupported(charset));
+        try {
+            return (null != charset && checkName(charset) && Charset.isSupported(charset));
+        } catch (final RuntimeException rte) {
+            LOG.warn("RuntimeException while checking charset: " + charset, rte);
+            return false;
+        } catch (final Error e) {
+            handleThrowable(e);
+            LOG.warn("Error while checking charset: " + charset, e);
+            return false;
+        } catch (final Throwable t) {
+            handleThrowable(t);
+            LOG.warn("Unexpected error while checking charset: " + charset, t);
+            return false;
+        }
+    }
+
+    /**
+     * Checks whether the supplied <tt>Throwable</tt> is one that needs to be rethrown and swallows all others.
+     *
+     * @param t The <tt>Throwable</tt> to check
+     */
+    private static void handleThrowable(final Throwable t) {
+        if (t instanceof ThreadDeath) {
+            LOG.fatal(" ---=== /!\\ ===--- Thread death ---=== /!\\ ===--- ", t);
+            throw (ThreadDeath) t;
+        }
+        if (t instanceof VirtualMachineError) {
+            LOG.fatal(
+                " ---=== /!\\ ===--- The Java Virtual Machine is broken or has run out of resources necessary for it to continue operating. ---=== /!\\ ===--- ",
+                t);
+            throw (VirtualMachineError) t;
+        }
+        // All other instances of Throwable will be silently swallowed
     }
 
     /**
      * Checks that the given string is a legal charset name.
-     * 
+     *
      * @param s The charset name
      * @throws NullPointerException If given name is <code>null</code>
      * @return <code>true</code> if the given name is a legal charset name; otherwise <code>false</code>
@@ -137,7 +171,7 @@ public final class CharsetDetector {
 
     /**
      * Detects the charset of specified part.
-     * 
+     *
      * @param p The part whose charset shall be detected
      * @return The detected part's charset
      * @throws MessagingException If an error occurs in part's getter methods
@@ -159,7 +193,7 @@ public final class CharsetDetector {
                  * Neither a MimeBodyPart nor a MimeMessage
                  */
                 LOG.error(e.getMessage(), e);
-                return STR_US_ASCII;
+                return FALLBACK;
             }
             return detectCharset(rawIn);
         }
@@ -169,7 +203,7 @@ public final class CharsetDetector {
      * Detects the charset of specified byte array input stream's data.
      * <p>
      * <b>Note</b>: Specified input stream is going to be closed in this method.
-     * 
+     *
      * @param in The byte array input stream to examine
      * @throws NullPointerException If input stream is <code>null</code>
      * @return The detected charset or <i>US-ASCII</i> if no matching/supported charset could be found
@@ -239,14 +273,14 @@ public final class CharsetDetector {
                 }
             }
         }
-        return null == firstPossibleCharset ? STR_US_ASCII : firstPossibleCharset;
+        return null == firstPossibleCharset ? FALLBACK : firstPossibleCharset;
     }
 
     /**
      * Detects the charset of specified input stream's data.
      * <p>
      * <b>Note</b>: Specified input stream is going to be closed in this method.
-     * 
+     *
      * @param in The input stream to examine
      * @throws NullPointerException If input stream is <code>null</code>
      * @return The detected charset or <i>US-ASCII</i> if no matching/supported charset could be found
@@ -306,18 +340,27 @@ public final class CharsetDetector {
                 final String prob[] = det.getProbableCharsets();
                 String firstPossibleCharset = null;
                 for (int i = 0; i < prob.length; i++) {
-                    if (Charset.isSupported(prob[i])) {
-                        if ("utf-8".equals(prob[i].toLowerCase(Locale.ENGLISH))) {
+                    final String lcs = prob[i].toLowerCase(Locale.US);
+                    if (Charset.isSupported(lcs)) {
+                        if ("utf-8".equals(lcs)) {
                             return prob[i];
-                        } else if ("windows-1252".equals(prob[i].toLowerCase(Locale.ENGLISH))) {
+                        } else if ("windows-1252".equals(lcs)) {
                             return prob[i];
                         }
                         if (null == firstPossibleCharset) {
                             firstPossibleCharset = prob[i];
                         }
+                    } else if ("nomatch".equals(lcs)) {
+                        /*
+                         * Non-ASCII and nomatch
+                         */
+                        return FALLBACK;
                     }
                 }
-                return null == firstPossibleCharset ? STR_US_ASCII : firstPossibleCharset;
+                /*
+                 * Non-ASCII
+                 */
+                return null == firstPossibleCharset ? FALLBACK : firstPossibleCharset;
             } finally {
                 try {
                     in.close();
@@ -327,14 +370,14 @@ public final class CharsetDetector {
             }
         } catch (final IOException e) {
             LOG.error(e.getMessage(), e);
-            return STR_US_ASCII;
+            return FALLBACK;
         }
     }
 
     /**
      * {@link CharsetDetectionObserver} - A charset detection observer according to <a href="http://jchardet.sourceforge.net/">jcharset</a>
      * API
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     private static final class CharsetDetectionObserver implements nsICharsetDetectionObserver {
