@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,12 +59,12 @@ import java.util.regex.Pattern;
 
 /**
  * {@link DateUtils} - Provides some date-related utility constants/methods
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DateUtils {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DateUtils.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DateUtils.class));
 
     private static final DateFormat DATEFORMAT_RFC822 = new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss z", Locale.ENGLISH);
 
@@ -74,7 +74,7 @@ public final class DateUtils {
 
     /**
      * Gets the corresponding instance of {@link Date} from specified RFC822 date string
-     * 
+     *
      * @param string The RFC822 date string
      * @return The corresponding instance of {@link Date}
      * @throws IllegalArgumentException If specified string cannot be parsed to date
@@ -101,7 +101,7 @@ public final class DateUtils {
 
     /**
      * Gets the corresponding RFC822 date string from specified instance of {@link Date}
-     * 
+     *
      * @param d The instance of {@link Date} to convert
      * @return The corresponding RFC822 date string
      */
@@ -111,7 +111,7 @@ public final class DateUtils {
 
     /**
      * Gets the corresponding RFC822 date string from specified instance of {@link Date}
-     * 
+     *
      * @param d The instance of {@link Date} to convert
      * @param tz The time zone
      * @return The corresponding RFC822 date string
