@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,21 +49,16 @@
 
 package com.openexchange.mail.utils;
 
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_CONFIRMED_HAM;
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_CONFIRMED_SPAM;
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_DRAFTS;
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_SENT;
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_SPAM;
-import static com.openexchange.mail.usersetting.UserSettingMail.STD_TRASH;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_CONFIRMED_HAM;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_CONFIRMED_SPAM;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_DRAFTS;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_SENT;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_SPAM;
 import static com.openexchange.mail.utils.StorageUtility.INDEX_TRASH;
-import com.openexchange.mail.FullnameArgument;
+import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.mail.MailException;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.mailaccount.MailAccountDescription;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.server.ServiceException;
@@ -71,13 +66,13 @@ import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link DefaultFolderNamesProvider} - Provides the default folder (full-)names for a certain mail account.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DefaultFolderNamesProvider {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(DefaultFolderNamesProvider.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DefaultFolderNamesProvider.class));
 
     private static final String SWITCH_DEFAULT_FOLDER = "Switching to default value %s";
 
@@ -89,7 +84,7 @@ public final class DefaultFolderNamesProvider {
 
     /**
      * Initializes a new {@link DefaultFolderNamesProvider}.
-     * 
+     *
      * @param accountId The account ID
      * @param user The user ID
      * @param cid The context ID
@@ -113,9 +108,9 @@ public final class DefaultFolderNamesProvider {
     }
 
     /**
-     * Determines the default folder names (<b>not</b> fullnames). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
+     *
      * @param mailAccount The mail account providing the names
      * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
      * @return The default folder names as an array of {@link String}
@@ -132,9 +127,28 @@ public final class DefaultFolderNamesProvider {
     }
 
     /**
-     * Determines the default folder names (<b>not</b> fullnames). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
+     *
+     * @param mailAccount The mail account providing the names
+     * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
+     * @return The default folder names as an array of {@link String}
+     */
+    public String[] getDefaultFolderNames(final MailAccountDescription mailAccount, final boolean isSpamEnabled) {
+        return getDefaultFolderNames(
+            mailAccount.getTrash(),
+            mailAccount.getSent(),
+            mailAccount.getDrafts(),
+            mailAccount.getSpam(),
+            mailAccount.getConfirmedSpam(),
+            mailAccount.getConfirmedHam(),
+            isSpamEnabled);
+    }
+
+    /**
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
+     * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
+     *
      * @param trash The trash name
      * @param sent The sent name
      * @param drafts The drafts name
@@ -149,7 +163,7 @@ public final class DefaultFolderNamesProvider {
         if ((drafts == null) || (drafts.length() == 0)) {
             if (LOG.isWarnEnabled()) {
                 // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_DRAFTS);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_DRAFTS));
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getDrafts()));
             }
             names[INDEX_DRAFTS] = fallbackProvider.getDrafts();
         } else {
@@ -158,7 +172,7 @@ public final class DefaultFolderNamesProvider {
         if ((sent == null) || (sent.length() == 0)) {
             if (LOG.isWarnEnabled()) {
                 // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_SENT);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_SENT));
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getSent()));
             }
             names[INDEX_SENT] = fallbackProvider.getSent();
         } else {
@@ -167,7 +181,7 @@ public final class DefaultFolderNamesProvider {
         if ((spam == null) || (spam.length() == 0)) {
             if (LOG.isWarnEnabled()) {
                 // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_SPAM);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_SPAM));
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getSpam()));
             }
             names[INDEX_SPAM] = fallbackProvider.getSpam();
         } else {
@@ -176,7 +190,7 @@ public final class DefaultFolderNamesProvider {
         if ((trash == null) || (trash.length() == 0)) {
             if (LOG.isWarnEnabled()) {
                 // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_TRASH);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_TRASH));
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getTrash()));
             }
             names[INDEX_TRASH] = fallbackProvider.getTrash();
         } else {
@@ -186,7 +200,7 @@ public final class DefaultFolderNamesProvider {
             if ((confirmedSpam == null) || (confirmedSpam.length() == 0)) {
                 if (LOG.isWarnEnabled()) {
                     // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_CONFIRMED_SPAM);
-                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_CONFIRMED_SPAM));
+                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getConfirmedSpam()));
                 }
                 names[INDEX_CONFIRMED_SPAM] = fallbackProvider.getConfirmedSpam();
             } else {
@@ -195,9 +209,9 @@ public final class DefaultFolderNamesProvider {
             if ((confirmedHam == null) || (confirmedHam.length() == 0)) {
                 if (LOG.isWarnEnabled()) {
                     // final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, STD_CONFIRMED_HAM);
-                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, STD_CONFIRMED_HAM));
+                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, fallbackProvider.getConfirmedHam()));
                 }
-                names[INDEX_CONFIRMED_HAM] = fallbackProvider.getConfirmeHam();
+                names[INDEX_CONFIRMED_HAM] = fallbackProvider.getConfirmedHam();
             } else {
                 names[INDEX_CONFIRMED_HAM] = confirmedHam;
             }
@@ -206,12 +220,12 @@ public final class DefaultFolderNamesProvider {
     }
 
     /**
-     * Determines the default folder fullnames (<b>not</b> names). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder full names (<b>not</b> names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
-     * @param mailAccount The mail account providing the fullnames
+     *
+     * @param mailAccount The mail account providing the full names
      * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
-     * @return The default folder fullnames as an array of {@link String}
+     * @return The default folder full names as an array of {@link String}
      */
     public String[] getDefaultFolderFullnames(final MailAccount mailAccount, final boolean isSpamEnabled) {
         return getDefaultFolderFullnames(
@@ -224,21 +238,39 @@ public final class DefaultFolderNamesProvider {
             isSpamEnabled);
     }
 
-    private static String extractFullname(final String fullnameParameter) {
-        final FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(fullnameParameter);
-        return null == fa ? null : fa.getFullname();
-    }
-
     /**
      * Determines the default folder fullnames (<b>not</b> names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
-     * @param trashFullname The trash fullname
-     * @param sentFullname The sent fullname
-     * @param draftsFullname The drafts fullname
-     * @param spamFullname The spam fullname
-     * @param confirmedSpamFullname The confirmed-spam fullname
-     * @param confirmedHamFullname The confirmed-ham fullname
+     *
+     * @param mailAccount The mail account providing the fullnames
+     * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
+     * @return The default folder fullnames as an array of {@link String}
+     */
+    public String[] getDefaultFolderFullnames(final MailAccountDescription mailAccount, final boolean isSpamEnabled) {
+        return getDefaultFolderFullnames(
+            extractFullname(mailAccount.getTrashFullname()),
+            extractFullname(mailAccount.getSentFullname()),
+            extractFullname(mailAccount.getDraftsFullname()),
+            extractFullname(mailAccount.getSpamFullname()),
+            extractFullname(mailAccount.getConfirmedSpamFullname()),
+            extractFullname(mailAccount.getConfirmedHamFullname()),
+            isSpamEnabled);
+    }
+
+    private static String extractFullname(final String fullnameParameter) {
+        return null == fullnameParameter ? null : MailFolderUtility.prepareMailFolderParam(fullnameParameter).getFullname();
+    }
+
+    /**
+     * Determines the default folder full names (<b>not</b> names). The returned array of {@link String} indexes the names as given through
+     * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
+     *
+     * @param trashFullname The trash full name
+     * @param sentFullname The sent full name
+     * @param draftsFullname The drafts full name
+     * @param spamFullname The spam full name
+     * @param confirmedSpamFullname The confirmed-spam fulln ame
+     * @param confirmedHamFullname The confirmed-ham full name
      * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
      * @return The default folder fullnames as an array of {@link String}
      */
@@ -284,7 +316,10 @@ public final class DefaultFolderNamesProvider {
         return fullnames;
     }
 
-    private static interface FallbackProvider {
+    /**
+     * Provides fall-back values.
+     */
+    public static interface FallbackProvider {
 
         String getTrash();
 
@@ -296,7 +331,7 @@ public final class DefaultFolderNamesProvider {
 
         String getConfirmedSpam();
 
-        String getConfirmeHam();
+        String getConfirmedHam();
     }
 
     private static final class DefaultAccountProvider implements FallbackProvider {
@@ -308,10 +343,10 @@ public final class DefaultFolderNamesProvider {
             this.defaultAccount = defaultAccount;
         }
 
-        public String getConfirmeHam() {
+        public String getConfirmedHam() {
             final String ret = defaultAccount.getConfirmedHam();
             if (ret == null || ret.length() == 0) {
-                return DEFAULT_PROVIDER.getConfirmeHam();
+                return DEFAULT_PROVIDER.getConfirmedHam();
             }
             return ret;
         }
@@ -358,30 +393,33 @@ public final class DefaultFolderNamesProvider {
 
     }
 
-    static final FallbackProvider DEFAULT_PROVIDER = new FallbackProvider() {
+    /**
+     * The fall-back provider.
+     */
+    public static final FallbackProvider DEFAULT_PROVIDER = new FallbackProvider() {
 
-        public String getConfirmeHam() {
-            return STD_CONFIRMED_HAM;
+        public String getConfirmedHam() {
+            return MailStrings.CONFIRMED_HAM;
         }
 
         public String getConfirmedSpam() {
-            return STD_CONFIRMED_HAM;
+            return MailStrings.CONFIRMED_SPAM;
         }
 
         public String getDrafts() {
-            return STD_DRAFTS;
+            return MailStrings.DRAFTS;
         }
 
         public String getSent() {
-            return STD_SENT;
+            return MailStrings.SENT;
         }
 
         public String getSpam() {
-            return STD_SPAM;
+            return MailStrings.SPAM;
         }
 
         public String getTrash() {
-            return STD_TRASH;
+            return MailStrings.TRASH;
         }
     };
 }
