@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,6 +56,7 @@ import java.util.EnumMap;
 import java.util.Locale;
 import javax.mail.Address;
 import javax.mail.MessagingException;
+import javax.mail.internet.IDNA;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.mail.MailSortField;
 import com.openexchange.mail.config.MailProperties;
@@ -64,12 +65,12 @@ import com.openexchange.mail.mime.PlainTextAddress;
 
 /**
  * {@link MailMessageComparator} - A {@link Comparator comparator} for {@link MailMessage messages}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailMessageComparator implements Comparator<MailMessage> {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailMessageComparator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailMessageComparator.class));
 
     private static final String STR_EMPTY = "";
 
@@ -99,7 +100,7 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
 
     /**
      * Initializes a new {@link MailMessageComparator} sorting by header <code>Date</code> (a.k.a. sent date).
-     * 
+     *
      * @param descendingDirection <code>true</code> for descending order; otherwise <code>false</code>
      * @param locale The locale
      */
@@ -109,14 +110,14 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
 
     /**
      * Initializes a new {@link MailMessageComparator}.
-     * 
+     *
      * @param sortField The sort field
      * @param descendingDirection <code>true</code> for descending order; otherwise <code>false</code>
      * @param locale The locale
      */
     public MailMessageComparator(final MailSortField sortField, final boolean descendingDirection, final Locale locale) {
         super();
-        this.descendingDir = descendingDirection;
+        descendingDir = descendingDirection;
         if (MailSortField.COLOR_LABEL.equals(sortField) && !MailProperties.getInstance().isUserFlagsEnabled()) {
             fieldComparer = DUMMY_COMPARER;
         } else {
@@ -145,7 +146,7 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
 
     private static String getCompareStringFromAddress(final Address addr, final Locale locale) {
         if (addr instanceof PlainTextAddress) {
-            return ((PlainTextAddress) addr).getAddress().toLowerCase(Locale.ENGLISH);
+            return ((PlainTextAddress) addr).getAddress().toLowerCase(locale);
         } else if (addr instanceof InternetAddress) {
             final InternetAddress ia1 = (InternetAddress) addr;
             final String personal = ia1.getPersonal();
@@ -155,26 +156,12 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
                  */
                 return (personal.charAt(0) == '\'') || (personal.charAt(0) == '"') ? personal.substring(1).toLowerCase(locale) : personal.toLowerCase(locale);
             }
-            return ia1.getAddress().toLowerCase(Locale.ENGLISH);
+            return IDNA.toIDN(ia1.getAddress()).toLowerCase(locale);
         } else {
             return STR_EMPTY;
         }
     }
 
-    static Integer compareReferences(final Object o1, final Object o2) {
-        if ((o1 == null) && (o2 != null)) {
-            return Integer.valueOf(-1);
-        } else if ((o1 != null) && (o2 == null)) {
-            return Integer.valueOf(1);
-        } else if ((o1 == null) && (o2 == null)) {
-            return Integer.valueOf(0);
-        }
-        /*
-         * Both references are not null
-         */
-        return null;
-    }
-
     private static final EnumMap<MailSortField, FieldComparer> COMPARERS;
 
     static {
@@ -184,8 +171,16 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
             public int compareFields(final MailMessage msg1, final MailMessage msg2) throws MessagingException {
                 final Date d1 = msg1.getSentDate();
                 final Date d2 = msg2.getSentDate();
-                final Integer refComp = compareReferences(d1, d2);
-                return refComp == null ? d1.compareTo(d2) : refComp.intValue();
+                if (null == d1) {
+                    if (null == d2) {
+                        return 0;
+                    }
+                    return -1;
+                } else if (null == d2) {
+                    return 1;
+                } else {
+                    return d1.compareTo(d2);
+                }
             }
         });
         COMPARERS.put(MailSortField.RECEIVED_DATE, new FieldComparer() {
@@ -193,8 +188,16 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
             public int compareFields(final MailMessage msg1, final MailMessage msg2) throws MessagingException {
                 final Date d1 = msg1.getReceivedDate();
                 final Date d2 = msg2.getReceivedDate();
-                final Integer refComp = compareReferences(d1, d2);
-                return refComp == null ? d1.compareTo(d2) : refComp.intValue();
+                if (null == d1) {
+                    if (null == d2) {
+                        return 0;
+                    }
+                    return -1;
+                } else if (null == d2) {
+                    return 1;
+                } else {
+                    return d1.compareTo(d2);
+                }
             }
         });
         COMPARERS.put(MailSortField.FLAG_SEEN, new FieldComparer() {
@@ -251,21 +254,21 @@ public final class MailMessageComparator implements Comparator<MailMessage> {
             return new LocalizedFieldComparer(locale) {
 
                 public int compareFields(final MailMessage msg1, final MailMessage msg2) throws MessagingException {
-                    return compareAddrs(msg1.getFrom(), msg2.getFrom(), this.locale, collator);
+                    return compareAddrs(msg1.getFrom(), msg2.getFrom(), locale, collator);
                 }
             };
         case TO:
             return new LocalizedFieldComparer(locale) {
 
                 public int compareFields(final MailMessage msg1, final MailMessage msg2) throws MessagingException {
-                    return compareAddrs(msg1.getTo(), msg2.getTo(), this.locale, collator);
+                    return compareAddrs(msg1.getTo(), msg2.getTo(), locale, collator);
                 }
             };
         case CC:
             return new LocalizedFieldComparer(locale) {
 
                 public int compareFields(final MailMessage msg1, final MailMessage msg2) throws MessagingException {
-                    return compareAddrs(msg1.getCc(), msg2.getCc(), this.locale, collator);
+                    return compareAddrs(msg1.getCc(), msg2.getCc(), locale, collator);
                 }
             };
         case SUBJECT:
