@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,19 +57,22 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.mail.Message;
 import javax.mail.internet.InternetAddress;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.config.MailConfigException;
 import com.openexchange.mail.mime.HeaderName;
 import com.openexchange.mail.usersetting.UserSettingMail;
+import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link StorageUtility} - Offers utility methods for both folder and message storage
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class StorageUtility {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(StorageUtility.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(StorageUtility.class));
 
     /*
      * Public constants
@@ -101,6 +104,19 @@ public final class StorageUtility {
         super();
     }
 
+    /**
+     * Gets the default max. running millis.
+     *
+     * @return The default max. running millis
+     */
+    public static long getMaxRunningMillis() {
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        if (null == service) {
+            return 60000L;
+        }
+        return service.getIntProperty("AJP_WATCHER_MAX_RUNNING_TIME", 60000);
+    }
+
     public static String getAllAddresses(final InternetAddress[] internetAddrs) {
         if ((internetAddrs == null) || (internetAddrs.length == 0)) {
             return "";
@@ -118,7 +134,7 @@ public final class StorageUtility {
 
     /**
      * Parses specified headers into a map
-     * 
+     *
      * @param headers The headers as raw bytes
      * @return An instance of {@link Map} containing the headers
      */
@@ -138,7 +154,7 @@ public final class StorageUtility {
 
     /**
      * Parses specified headers into a map
-     * 
+     *
      * @param headers The headers as {@link String}
      * @return An instance of {@link Map} containing the headers
      */
@@ -160,9 +176,9 @@ public final class StorageUtility {
     private static final String SWITCH_DEFAULT_FOLDER = "Switching to default value %s";
 
     /**
-     * Determines the default folder names (<b>not</b> fullnames). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
+     *
      * @param accountId The account ID
      * @param usm The user's mail settings
      * @return The default folder names as an array of {@link String}
@@ -173,9 +189,9 @@ public final class StorageUtility {
     }
 
     /**
-     * Determines the default folder names (<b>not</b> fullnames). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
+     *
      * @param accountId The account ID
      * @param usm The user's mail settings
      * @param isSpamEnabled <code>true</code> if spam is enabled for current user; otherwise <code>false</code>
@@ -194,9 +210,9 @@ public final class StorageUtility {
     }
 
     /**
-     * Determines the default folder names (<b>not</b> fullnames). The returned array of {@link String} indexes the names as given through
+     * Determines the default folder names (<b>not</b> full names). The returned array of {@link String} indexes the names as given through
      * constants: {@link StorageUtility#INDEX_DRAFTS}, {@link StorageUtility#INDEX_SENT}, etc.
-     * 
+     *
      * @param trash The trash name
      * @param sent The sent name
      * @param drafts The drafts name
@@ -213,37 +229,37 @@ public final class StorageUtility {
         final String[] names = new String[isSpamEnabled ? 6 : 4];
         if ((drafts == null) || (drafts.length() == 0)) {
             if (LOG.isWarnEnabled()) {
-                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, UserSettingMail.STD_DRAFTS);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_DRAFTS), e);
+                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, MailStrings.DRAFTS);
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.DRAFTS), e);
             }
-            names[INDEX_DRAFTS] = UserSettingMail.STD_DRAFTS;
+            names[INDEX_DRAFTS] = MailStrings.DRAFTS;
         } else {
             names[INDEX_DRAFTS] = drafts;
         }
         if ((sent == null) || (sent.length() == 0)) {
             if (LOG.isWarnEnabled()) {
-                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, UserSettingMail.STD_SENT);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_SENT), e);
+                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, MailStrings.SENT);
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.SENT), e);
             }
-            names[INDEX_SENT] = UserSettingMail.STD_SENT;
+            names[INDEX_SENT] = MailStrings.SENT;
         } else {
             names[INDEX_SENT] = sent;
         }
         if ((spam == null) || (spam.length() == 0)) {
             if (LOG.isWarnEnabled()) {
-                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, UserSettingMail.STD_SPAM);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_SPAM), e);
+                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, MailStrings.SPAM);
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.SPAM), e);
             }
-            names[INDEX_SPAM] = UserSettingMail.STD_SPAM;
+            names[INDEX_SPAM] = MailStrings.SPAM;
         } else {
             names[INDEX_SPAM] = spam;
         }
         if ((trash == null) || (trash.length() == 0)) {
             if (LOG.isWarnEnabled()) {
-                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, UserSettingMail.STD_TRASH);
-                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_TRASH), e);
+                final MailException e = new MailException(MailException.Code.MISSING_DEFAULT_FOLDER_NAME, MailStrings.TRASH);
+                LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.TRASH), e);
             }
-            names[INDEX_TRASH] = UserSettingMail.STD_TRASH;
+            names[INDEX_TRASH] = MailStrings.TRASH;
         } else {
             names[INDEX_TRASH] = trash;
         }
@@ -252,10 +268,10 @@ public final class StorageUtility {
                 if (LOG.isWarnEnabled()) {
                     final MailException e = new MailException(
                         MailException.Code.MISSING_DEFAULT_FOLDER_NAME,
-                        UserSettingMail.STD_CONFIRMED_SPAM);
-                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_CONFIRMED_SPAM), e);
+                        MailStrings.CONFIRMED_SPAM);
+                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.CONFIRMED_SPAM), e);
                 }
-                names[INDEX_CONFIRMED_SPAM] = UserSettingMail.STD_CONFIRMED_SPAM;
+                names[INDEX_CONFIRMED_SPAM] = MailStrings.CONFIRMED_SPAM;
             } else {
                 names[INDEX_CONFIRMED_SPAM] = confirmedSpam;
             }
@@ -263,10 +279,10 @@ public final class StorageUtility {
                 if (LOG.isWarnEnabled()) {
                     final MailException e = new MailException(
                         MailException.Code.MISSING_DEFAULT_FOLDER_NAME,
-                        UserSettingMail.STD_CONFIRMED_HAM);
-                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, UserSettingMail.STD_CONFIRMED_HAM), e);
+                        MailStrings.CONFIRMED_HAM);
+                    LOG.warn(String.format(SWITCH_DEFAULT_FOLDER, MailStrings.CONFIRMED_HAM), e);
                 }
-                names[INDEX_CONFIRMED_HAM] = UserSettingMail.STD_CONFIRMED_HAM;
+                names[INDEX_CONFIRMED_HAM] = MailStrings.CONFIRMED_HAM;
             } else {
                 names[INDEX_CONFIRMED_HAM] = confirmedHam;
             }
