@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,7 +65,7 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 
 /**
  * {@link UUEncodedPart} - UUEncode part containing all needed information about the attachment.
- * 
+ *
  * @author <a href="mailto:stefan.preuss@open-xchange.com">Stefan Preuss</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -99,7 +99,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
 
     /**
      * Return the filename attribute of the UUEncodedPart object
-     * 
+     *
      * @return filename - The filename
      */
     public String getFileName() {
@@ -109,7 +109,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
     /**
      * Return the file size attribute of the UUEncodedPart object. Note: This value may be different from the saved file. This is normal
      * because this is the size of the raw (not encoded) object.
-     * 
+     *
      * @return The file size
      */
     public int getFileSize() {
@@ -122,7 +122,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
 
     /**
      * Return the start position of the attachment within the content.
-     * 
+     *
      * @return beginIndex - The start position
      */
     public int getIndexStart() {
@@ -131,7 +131,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
 
     /**
      * Return the end position of the attachment within the content.
-     * 
+     *
      * @return beginIndex - The start position
      */
     public int getIndexEnd() {
@@ -140,7 +140,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
 
     /**
      * Gets the inputStream attribute of the UUEncodedPart object
-     * 
+     *
      * @return inStreamPart - The inputStream
      */
     public InputStream getInputStream() {
@@ -149,14 +149,14 @@ public class UUEncodedPart extends UUEncodedMultiPart {
             final InputStream inStreamPart = MimeUtility.decode(bStream, "uuencode");
             return (inStreamPart);
         } catch (final Exception e) {
-            org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class)).error(e.getMessage(), e);
             return (null);
         }
     }
 
     /**
      * Creates a data handler for this uuencoded part.
-     * 
+     *
      * @param contentType The content type to apply to data handler
      * @return A data handler for this uuencoded part
      */
@@ -183,7 +183,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
 
     /**
      * Gets the encoded part as StringBuffer
-     * 
+     *
      * @return The part
      */
     public StringBuilder getPart() {
@@ -202,14 +202,14 @@ public class UUEncodedPart extends UUEncodedMultiPart {
                 }
             }
         } catch (final Exception e) {
-            org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class)).error(e.getMessage(), e);
         }
         return (encodedPart);
     }
 
     /**
      * Output an appropriately encoded byte stream to the given OutputStream.
-     * 
+     *
      * @param out - The inputStream
      * @throws java.io.IOException if an error occurs writing to the stream
      */
@@ -223,7 +223,7 @@ public class UUEncodedPart extends UUEncodedMultiPart {
                 bos.write(iChar);
             }
         } catch (final IOException ioe) {
-            org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class).error(ioe.getMessage(), ioe);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(UUEncodedPart.class)).error(ioe.getMessage(), ioe);
             throw ioe;
         } finally {
             if (null != bos) {
