@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,11 +60,12 @@ public interface AttributeSwitch {
     public Object id();
     public Object login();
     public Object password();
-    public Object mailURL();
-    public Object transportURL();
+    public Object mailURL() throws MailAccountException;
+    public Object transportURL() throws MailAccountException;
     public Object name();
     public Object primaryAddress();
     public Object personal();
+    public Object replyTo();
     public Object spamHandler();
     public Object trash();
     public Object sent();
