@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,33 +50,36 @@
 package com.openexchange.mailaccount;
 
 import java.sql.Connection;
+import java.util.Map;
 
 /**
  * {@link MailAccountDeleteListener} - Listener interface for mail account deletion.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface MailAccountDeleteListener {
 
     /**
      * Handles the event <i>before</i> the denoted mail account is deleted.
-     * 
+     *
      * @param id The mail account ID
+     * @param eventProps Optional properties for delete event
      * @param user The user ID
      * @param cid The context ID
      * @param con The used connection <i>in transactional state</i>
      * @throws MailAccountException If a critical error occurs which should abort mail account deletion
      */
-    public void onBeforeMailAccountDeletion(int id, int user, int cid, Connection con) throws MailAccountException;
+    public void onBeforeMailAccountDeletion(int id, Map<String, Object> eventProps, int user, int cid, Connection con) throws MailAccountException;
 
     /**
      * Handles the event <i>after</i> the denoted mail account is deleted.
-     * 
+     *
      * @param id The mail account ID
+     * @param eventProps Optional properties for delete event
      * @param user The user ID
      * @param cid The context ID
      * @param con The used connection <i>in transactional state</i>
      * @throws MailAccountException If a critical error occurs which should abort mail account deletion
      */
-    public void onAfterMailAccountDeletion(int id, int user, int cid, Connection con) throws MailAccountException;
+    public void onAfterMailAccountDeletion(int id, Map<String, Object> eventProps, int user, int cid, Connection con) throws MailAccountException;
 }
