@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,20 +50,25 @@
 package com.openexchange.mailaccount;
 
 import java.io.Serializable;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
-import com.openexchange.mail.api.MailConfig;
-import com.openexchange.mail.transport.config.TransportConfig;
+import javax.mail.internet.IDNA;
+import com.openexchange.tools.net.URIDefaults;
+import com.openexchange.tools.net.URIParser;
+import com.openexchange.tools.net.URITools;
 
 /**
  * {@link MailAccountDescription} - Container object describing a mail account to insert/update.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MailAccountDescription implements Serializable {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountDescription.class);
+    private static final org.apache.commons.logging.Log LOG =
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailAccountDescription.class));
 
     private static final long serialVersionUID = -2443656355399068302L;
 
@@ -150,7 +155,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the ID.
-     * 
+     *
      * @return The ID or <code>-1</code> if not set
      */
     public int getId() {
@@ -159,7 +164,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the login.
-     * 
+     *
      * @return The login
      */
     public String getLogin() {
@@ -168,7 +173,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the account name.
-     * 
+     *
      * @return The account name
      */
     public String getName() {
@@ -177,7 +182,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets clear, non-encrypted password.
-     * 
+     *
      * @return The clear, non-encrypted password.
      */
     public String getPassword() {
@@ -186,7 +191,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the primary email address.
-     * 
+     *
      * @return The primary email address
      */
     public String getPrimaryAddress() {
@@ -195,7 +200,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the personal.
-     * 
+     *
      * @return The personal
      */
     public String getPersonal() {
@@ -204,7 +209,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the ID
-     * 
+     *
      * @return The ID
      */
     public void setId(final int id) {
@@ -213,7 +218,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the login.
-     * 
+     *
      * @param login The login
      */
     public void setLogin(final String login) {
@@ -222,7 +227,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the clear-text password (which is stored encrypted).
-     * 
+     *
      * @param password The clear-text password
      */
     public void setPassword(final String password) {
@@ -234,7 +239,7 @@ public final class MailAccountDescription implements Serializable {
      * <p>
      * The mail server name can either be a machine name, such as "<code>java.sun.com</code>", or a textual representation of its IP
      * address.
-     * 
+     *
      * @return The mail server name
      */
     public String getMailServer() {
@@ -243,7 +248,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the mail server port.
-     * 
+     *
      * @return The mail server port
      */
     public int getMailPort() {
@@ -252,7 +257,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the mail server protocol.
-     * 
+     *
      * @return The mail server protocol
      */
     public String getMailProtocol() {
@@ -261,7 +266,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Checks if a secure connection to mail server shall be established.
-     * 
+     *
      * @return <code>true</code> if a secure connection to mail server shall be established; otherwise <code>false</code>
      */
     public boolean isMailSecure() {
@@ -270,17 +275,17 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the mail server name.
-     * 
+     *
      * @param mailServer The mail server name to set
      */
     public void setMailServer(final String mailServer) {
         mailServerUrl = null;
-        this.mailServer = mailServer;
+        this.mailServer = mailServer == null ? null : IDNA.toUnicode(mailServer);
     }
 
     /**
      * Sets the mail server port.
-     * 
+     *
      * @param mailPort The mail server port to set
      */
     public void setMailPort(final int mailPort) {
@@ -290,7 +295,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the mail server protocol.
-     * 
+     *
      * @param mailProtocol The mail server protocol to set
      */
     public void setMailProtocol(final String mailProtocol) {
@@ -300,7 +305,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets if a secure connection to mail server shall be established.
-     * 
+     *
      * @param mailSecure <code>true</code> if a secure connection to mail server shall be established; otherwise <code>false</code>
      */
     public void setMailSecure(final boolean mailSecure) {
@@ -313,7 +318,7 @@ public final class MailAccountDescription implements Serializable {
      * <p>
      * The transport server name can either be a machine name, such as "<code>java.sun.com</code>", or a textual representation of its IP
      * address.
-     * 
+     *
      * @return The transport server name
      */
     public String getTransportServer() {
@@ -322,7 +327,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the transport server port.
-     * 
+     *
      * @return The transport server port
      */
     public int getTransportPort() {
@@ -331,7 +336,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the transport server protocol.
-     * 
+     *
      * @return The transport server protocol
      */
     public String getTransportProtocol() {
@@ -340,7 +345,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Checks if a secure connection to transport server shall be established.
-     * 
+     *
      * @return <code>true</code> if a secure connection to transport server shall be established; otherwise <code>false</code>
      */
     public boolean isTransportSecure() {
@@ -349,27 +354,27 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the transport server name.
-     * 
+     *
      * @param transportServer The transport server name to set
      */
     public void setTransportServer(final String transportServer) {
         transportUrl = null;
-        this.transportServer = transportServer;
+        this.transportServer = transportServer == null ? null : IDNA.toUnicode(transportServer);
     }
 
     /**
      * Sets the transport server port
-     * 
+     *
      * @param transportPort The transport server port to set
      */
     public void setTransportPort(final int transportPort) {
         transportUrl = null;
-        this.transportPort = transportPort;
+        this.transportPort = checkTransportPort(transportPort);
     }
 
     /**
      * Sets the transport server protocol
-     * 
+     *
      * @param transportProtocol The transport server protocol to set
      */
     public void setTransportProtocol(final String transportProtocol) {
@@ -379,7 +384,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets if a secure connection to transport server shall be established.
-     * 
+     *
      * @param mailSecure <code>true</code> if a secure connection to transport server shall be established; otherwise <code>false</code>
      */
     public void setTransportSecure(final boolean transportSecure) {
@@ -389,102 +394,172 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Generates the mail server URL.
-     * 
+     *
      * @return The generated mail server URL
+     * @throws MailAccountException If mail server URL is invalid
      */
-    public String generateMailServerURL() {
+    public String generateMailServerURL() throws MailAccountException {
         if (null != mailServerUrl) {
             return mailServerUrl;
         }
-        if (null == mailServer) {
+        if (isEmpty(mailServer)) {
             return null;
         }
-        final StringBuilder sb = new StringBuilder(32);
-        sb.append(mailProtocol);
-        if (mailSecure) {
-            sb.append('s');
+        try {
+            return mailServerUrl = URITools.generateURI(mailSecure ? mailProtocol + 's' : mailProtocol, IDNA.toASCII(mailServer), mailPort).toString();
+        } catch (final URISyntaxException e) {
+            final StringBuilder sb = new StringBuilder(32);
+            sb.append(mailProtocol);
+            if (mailSecure) {
+                sb.append('s');
+            }
+            throw MailAccountExceptionFactory.getInstance().create(
+                MailAccountExceptionMessages.INVALID_HOST_NAME,
+                e,
+                sb.append("://").append(mailServer).append(':').append(mailPort).toString());
         }
-        return mailServerUrl = sb.append("://").append(mailServer).append(':').append(mailPort).toString();
     }
 
     /**
      * Parses specified mail server URL
-     * 
+     *
      * @param mailServerURL The mail server URL to parse
+     * @throws MailAccountException If URL cannot be parsed
      */
-    public void parseMailServerURL(final String mailServerURL) {
+    public void parseMailServerURL(final String mailServerURL) throws MailAccountException {
         if (null == mailServerURL) {
-            setMailServer(null);
+            setMailServer((String) null);
             return;
         }
-        final String[] tmp = MailConfig.parseProtocol(mailServerURL);
-        final String prot;
-        final Object[] parsed;
-        if (tmp != null) {
-            prot = tmp[0];
-            parsed = parseServerAndPort(tmp[1], getMailPort());
-        } else {
-            prot = getMailProtocol();
-            parsed = parseServerAndPort(mailServerURL, getMailPort());
+        try {
+            setMailServer(URIParser.parse(IDNA.toASCII(mailServerURL), URIDefaults.IMAP));
+        } catch (final URISyntaxException e) {
+            throw MailAccountExceptionFactory.getInstance().create(MailAccountExceptionMessages.INVALID_HOST_NAME, e, mailServerURL);
+            // TODO method needs to throw the following exception. But that needs a global changing of a mass of code. Doing fallback
+            // instead now.
+            // throw MailAccountExceptionFactory.getInstance().create(MailAccountExceptionMessages.URI_PARSE_FAILED, e, mailServerURL);
+            // final String[] tmp = MailConfig.parseProtocol(mailServerURL);
+            // final String prot;
+            // final Object[] parsed;
+            // if (tmp != null) {
+            // prot = tmp[0];
+            // parsed = parseServerAndPort(tmp[1], getMailPort());
+            // } else {
+            // prot = getMailProtocol();
+            // parsed = parseServerAndPort(mailServerURL, getMailPort());
+            // }
+            // if (prot.endsWith("s")) {
+            // setMailSecure(true);
+            // setMailProtocol(prot.substring(0, prot.length() - 1));
+            // } else {
+            // setMailProtocol(prot);
+            // }
+            // setMailServer(parsed[0].toString());
+            // setMailPort(((Integer) parsed[1]).intValue());
         }
-        if (prot.endsWith("s")) {
-            setMailSecure(true);
-            setMailProtocol(prot.substring(0, prot.length() - 1));
+    }
+
+    public void setMailServer(final URI mailServer) {
+        if (null == mailServer) {
+            // Parse like old parser to prevent problems.
+            setMailServer("");
         } else {
-            setMailProtocol(prot);
+            final String protocol = mailServer.getScheme();
+            if (protocol.endsWith("s")) {
+                setMailSecure(true);
+                setMailProtocol(protocol.substring(0, protocol.length() - 1));
+            } else {
+                setMailSecure(false);
+                setMailProtocol(protocol);
+            }
+            setMailServer(mailServer.getHost());
+            setMailPort(mailServer.getPort());
         }
-        setMailServer(parsed[0].toString());
-        setMailPort(((Integer) parsed[1]).intValue());
     }
 
     /**
      * Parses specified transport server URL
-     * 
+     *
      * @param mailServerURL The transport server URL to parse
+     * @throws MailAccountException If URL cannot be parsed
      */
-    public void parseTransportServerURL(final String transportServerURL) {
+    public void parseTransportServerURL(final String transportServerURL) throws MailAccountException {
         if (null == transportServerURL) {
-            setTransportServer(null);
+            setTransportServer((String) null);
             return;
         }
-        final String[] tmp = TransportConfig.parseProtocol(transportServerURL);
-        final String prot;
-        final Object[] parsed;
-        if (tmp != null) {
-            prot = tmp[0];
-            parsed = parseServerAndPort(tmp[1], getTransportPort());
-        } else {
-            prot = getTransportProtocol();
-            parsed = parseServerAndPort(transportServerURL, getTransportPort());
+        try {
+            setTransportServer(URIParser.parse(IDNA.toASCII(transportServerURL), URIDefaults.SMTP));
+        } catch (final URISyntaxException e) {
+            throw MailAccountExceptionFactory.getInstance().create(MailAccountExceptionMessages.INVALID_HOST_NAME, e, transportServerURL);
         }
-        if (prot.endsWith("s")) {
-            setTransportSecure(true);
-            setTransportProtocol(prot.substring(0, prot.length() - 1));
-        } else {
-            setTransportProtocol(prot);
-        }
-        setTransportServer(parsed[0].toString());
-        setTransportPort(((Integer) parsed[1]).intValue());
     }
 
-    public String generateTransportServerURL() {
+    /**
+     * Sets transport server URI
+     * 
+     * @param transportServer The transport server URI
+     */
+    public void setTransportServer(final URI transportServer) {
+        if (null == transportServer) {
+            // Parse like old parser to prevent problems.
+            setTransportServer("");
+        } else {
+            final String protocol = transportServer.getScheme();
+            if (protocol.endsWith("s")) {
+                setTransportSecure(true);
+                setTransportProtocol(protocol.substring(0, protocol.length() - 1));
+            } else {
+                setTransportSecure(false);
+                setTransportProtocol(protocol);
+            }
+            setTransportServer(URITools.getHost(transportServer));
+            setTransportPort(checkTransportPort(transportServer.getPort()));
+        }
+    }
+
+    private static int checkTransportPort(final int port) {
+        if (URIDefaults.IMAP.getPort() == port) {
+            return URIDefaults.SMTP.getPort();
+        }
+        if (URIDefaults.IMAP.getSSLPort() == port) {
+            return URIDefaults.SMTP.getSSLPort();
+        }
+        return port;
+    }
+
+    /**
+     * Generates transport server URL
+     *
+     * @return The transport server URL
+     * @throws MailAccountException If URL cannot be parsed
+     */
+    public String generateTransportServerURL() throws MailAccountException {
         if (null != transportUrl) {
             return transportUrl;
         }
-        if (null == transportServer) {
+        if (isEmpty(transportServer)) {
             return null;
         }
-        final StringBuilder sb = new StringBuilder(32);
-        sb.append(transportProtocol);
-        if (transportSecure) {
-            sb.append('s');
+        final String protocol = transportSecure ? transportProtocol + 's' : transportProtocol;
+        try {
+            return transportUrl = URITools.generateURI(protocol, IDNA.toASCII(transportServer), transportPort).toString();
+        } catch (final URISyntaxException e) {
+            final StringBuilder sb = new StringBuilder(32);
+            sb.append(transportProtocol);
+            if (transportSecure) {
+                sb.append('s');
+            }
+            throw MailAccountExceptionFactory.getInstance().create(
+                MailAccountExceptionMessages.INVALID_HOST_NAME,
+                e,
+                sb.append("://").append(transportServer).append(':').append(mailPort).toString());
         }
-        return transportUrl = sb.append("://").append(transportServer).append(':').append(transportPort).toString();
     }
 
     /**
      * Sets the account name.
-     * 
+     *
      * @param name The account name.
      */
     public void setName(final String name) {
@@ -493,7 +568,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the primary email address.
-     * 
+     *
      * @param primaryAddress The primary email address
      */
     public void setPrimaryAddress(final String primaryAddress) {
@@ -502,7 +577,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the personal.
-     * 
+     *
      * @param personal The personal
      */
     public void setPersonal(final String personal) {
@@ -511,7 +586,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default drafts folder.
-     * 
+     *
      * @return The name for default drafts folder
      */
     public String getDrafts() {
@@ -520,7 +595,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default sent folder.
-     * 
+     *
      * @return The name for default sent folder
      */
     public String getSent() {
@@ -529,7 +604,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default spam folder.
-     * 
+     *
      * @return The name for default spam folder
      */
     public String getSpam() {
@@ -538,7 +613,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default trash folder.
-     * 
+     *
      * @return The name for default trash folder
      */
     public String getTrash() {
@@ -547,7 +622,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default confirmed-ham folder.
-     * 
+     *
      * @return The name for default confirmed-ham folder
      */
     public String getConfirmedHam() {
@@ -556,7 +631,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the name for default confirmed-spam folder.
-     * 
+     *
      * @return The name for default confirmed-spam folder
      */
     public String getConfirmedSpam() {
@@ -565,7 +640,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the spam handler name.
-     * 
+     *
      * @return The spam handler name
      */
     public String getSpamHandler() {
@@ -574,7 +649,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default trash folder.
-     * 
+     *
      * @param trash The name for default trash folder
      */
     public void setTrash(final String trash) {
@@ -583,7 +658,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default sent folder.
-     * 
+     *
      * @param sent The name for default sent folder
      */
     public void setSent(final String sent) {
@@ -592,7 +667,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default drafts folder.
-     * 
+     *
      * @param drafts The name for default drafts folder
      */
     public void setDrafts(final String drafts) {
@@ -601,7 +676,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default spam folder.
-     * 
+     *
      * @param spam The name for spam trash folder
      */
     public void setSpam(final String spam) {
@@ -610,7 +685,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default confirmed-spam folder.
-     * 
+     *
      * @param confirmedSpam The name for default confirmed-spam folder
      */
     public void setConfirmedSpam(final String confirmedSpam) {
@@ -619,7 +694,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the name for default confirmed-ham folder.
-     * 
+     *
      * @param confirmedHam The name for default confirmed-ham folder
      */
     public void setConfirmedHam(final String confirmedHam) {
@@ -628,7 +703,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the spam handler name.
-     * 
+     *
      * @param spamHandler The spam handler name
      */
     public void setSpamHandler(final String spamHandler) {
@@ -637,7 +712,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Checks if mail account denotes the default mail account.
-     * 
+     *
      * @return <code>true</code> if mail account denotes the default mail account; otherwise <code>false</code>
      */
     public boolean isDefaultFlag() {
@@ -646,7 +721,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets whether mail account denotes the default mail account.
-     * 
+     *
      * @param defaultFlag <code>true</code> if mail account denotes the default mail account; otherwise <code>false</code>
      */
     public void setDefaultFlag(final boolean defaultFlag) {
@@ -655,35 +730,25 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the optional transport login.
-     * <p>
-     * <b>NOTE</b>:&nbsp;{@link #getLogin()} is returned if no separate transport login is available.
-     * 
+     *
      * @return The optional transport login
      */
     public String getTransportLogin() {
-        if (null == transportLogin) {
-            return getLogin();
-        }
         return transportLogin;
     }
 
     /**
      * Gets the optional transport password.
-     * <p>
-     * <b>NOTE</b>:&nbsp;{@link #getPassword()} is returned if no separate transport password is available.
-     * 
+     *
      * @return The optional transport password
      */
     public String getTransportPassword() {
-        if (null == transportPassword) {
-            return getPassword();
-        }
         return transportPassword;
     }
 
     /**
      * Sets the optional transport login.
-     * 
+     *
      * @param transportLogin The optional transport login
      */
     public void setTransportLogin(final String transportLogin) {
@@ -692,7 +757,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the optional transport password.
-     * 
+     *
      * @param transportLogin The optional transport password
      */
     public void setTransportPassword(final String transportPassword) {
@@ -701,7 +766,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Checks if this mail account is enabled for Unified INBOX.
-     * 
+     *
      * @return <code>true</code> if this mail account is enabled for Unified INBOX; otherwise <code>false</code>
      */
     public boolean isUnifiedINBOXEnabled() {
@@ -710,7 +775,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets if this mail account is enabled for Unified INBOX.
-     * 
+     *
      * @param unifiedINBOXEnabled <code>true</code> if this mail account is enabled for Unified INBOX; otherwise <code>false</code>
      */
     public void setUnifiedINBOXEnabled(final boolean unifiedINBOXEnabled) {
@@ -719,7 +784,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the trash fullname
-     * 
+     *
      * @return The trash fullname
      */
     public String getTrashFullname() {
@@ -728,7 +793,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the trash fullname
-     * 
+     *
      * @param trashFullname The trash fullname to set
      */
     public void setTrashFullname(final String trashFullname) {
@@ -737,7 +802,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the sent fullname
-     * 
+     *
      * @return The sent fullname
      */
     public String getSentFullname() {
@@ -746,7 +811,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the sent fullname
-     * 
+     *
      * @param sentFullname The sent fullname to set
      */
     public void setSentFullname(final String sentFullname) {
@@ -755,7 +820,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the drafts fullname
-     * 
+     *
      * @return The drafts fullname
      */
     public String getDraftsFullname() {
@@ -764,7 +829,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the drafts fullname
-     * 
+     *
      * @param draftsFullname The drafts fullname to set
      */
     public void setDraftsFullname(final String draftsFullname) {
@@ -773,7 +838,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the spam fullname
-     * 
+     *
      * @return The spam fullname
      */
     public String getSpamFullname() {
@@ -782,7 +847,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the spam fullname
-     * 
+     *
      * @param spamFullname The spam fullname to set
      */
     public void setSpamFullname(final String spamFullname) {
@@ -791,7 +856,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the confirmed-spam fullname
-     * 
+     *
      * @return The confirmed-spam fullname
      */
     public String getConfirmedSpamFullname() {
@@ -800,7 +865,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the confirmed-spam fullname
-     * 
+     *
      * @param confirmedSpamFullname The confirmed-spam fullname to set
      */
     public void setConfirmedSpamFullname(final String confirmedSpamFullname) {
@@ -809,7 +874,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the confirmed-ham fullname
-     * 
+     *
      * @return The confirmed-ham fullname
      */
     public String getConfirmedHamFullname() {
@@ -818,7 +883,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the confirmed-ham fullname
-     * 
+     *
      * @param confirmedHamFullname The confirmed-ham fullname to set
      */
     public void setConfirmedHamFullname(final String confirmedHamFullname) {
@@ -827,7 +892,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Gets the properties
-     * 
+     *
      * @return The properties
      */
     public Map<String, String> getProperties() {
@@ -841,7 +906,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Sets the properties
-     * 
+     *
      * @param properties The properties to set
      */
     public void setProperties(final Map<String, String> properties) {
@@ -857,7 +922,7 @@ public final class MailAccountDescription implements Serializable {
 
     /**
      * Adds specified name-value-pair to properties.
-     * 
+     *
      * @param name The property name
      * @param value The property value
      */
@@ -883,4 +948,16 @@ public final class MailAccountDescription implements Serializable {
         return new Object[] { server.subSequence(0, pos), Integer.valueOf(port) };
     }
 
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final char[] chars = string.toCharArray();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < chars.length; i++) {
+            isWhitespace = Character.isWhitespace(chars[i]);
+        }
+        return isWhitespace;
+    }
+
 }
