@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,19 +51,32 @@ package com.openexchange.mailaccount;
 
 import java.net.InetSocketAddress;
 import java.sql.Connection;
+import java.util.Collection;
+import java.util.Map;
 import java.util.Set;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.session.Session;
 
 /**
  * {@link MailAccountStorageService} - The storage service for mail accounts.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface MailAccountStorageService {
 
+    /**
+     * Invalidates specified mail account.
+     *
+     * @param id The account ID
+     * @param user The user ID
+     * @param cid The context ID
+     * @throws MailAccountException If invalidation fails
+     */
+    public void invalidateMailAccount(int id, int user, int cid) throws MailAccountException;
+
     /**
      * Gets the mail account identified by specified ID.
-     * 
+     *
      * @param id The mail account ID
      * @param user The user ID
      * @param cid The context ID
@@ -74,7 +87,7 @@ public interface MailAccountStorageService {
 
     /**
      * Gets the mail accounts belonging to specified user in given context.
-     * 
+     *
      * @param user The user ID
      * @param cid The context ID
      * @return The user's mail accounts
@@ -84,7 +97,7 @@ public interface MailAccountStorageService {
 
     /**
      * Gets the mail accounts belonging to specified user in given context.
-     * 
+     *
      * @param user The user ID
      * @param cid The context ID
      * @param con The connection to use
@@ -95,7 +108,7 @@ public interface MailAccountStorageService {
 
     /**
      * Gets the default mail account belonging to specified user in given context.
-     * 
+     *
      * @param user The user ID
      * @param cid The context ID
      * @return The user's default mail account
@@ -105,102 +118,105 @@ public interface MailAccountStorageService {
 
     /**
      * Updates mail account's value taken from specified mail account.
-     * 
+     *
      * @param mailAccount The mail account containing the values to update.
      * @param attributes The attributes to update
      * @param user The user ID
      * @param cid The context ID
-     * @param sessionPassword The session password
+     * @param session The session
      * @throws MailAccountException If the mail account cannot be updated
      */
-    public void updateMailAccount(MailAccountDescription mailAccount, Set<Attribute> attributes, int user, int cid, String sessionPassword) throws MailAccountException;
+    public void updateMailAccount(MailAccountDescription mailAccount, Set<Attribute> attributes, int user, int cid, Session session) throws MailAccountException;
 
     /**
      * Updates mail account's value taken from specified mail account.
-     * 
+     *
      * @param mailAccount The mail account containing the values to update.
      * @param attributes The attributes to update
      * @param user The user ID
      * @param cid The context ID
-     * @param sessionPassword The session password
+     * @param session The session
      * @param con writable database connection.
      * @param changePrimary <code>true</code> to change primary account, too.
      * @throws MailAccountException If the mail account cannot be updated
      */
-    void updateMailAccount(MailAccountDescription mailAccount, Set<Attribute> attributes, int user, int cid, String sessionPassword, Connection con, boolean changePrimary) throws MailAccountException;
+    void updateMailAccount(MailAccountDescription mailAccount, Set<Attribute> attributes, int user, int cid, Session session, Connection con, boolean changePrimary) throws MailAccountException;
 
     /**
      * Updates mail account's value taken from specified mail account.
-     * 
+     *
      * @param mailAccount The mail account containing the values to update.
      * @param user The user ID
      * @param cid The context ID
-     * @param sessionPassword The session password
+     * @param session The session
      * @throws MailAccountException If the mail account cannot be updated
      */
-    public void updateMailAccount(MailAccountDescription mailAccount, int user, int cid, String sessionPassword) throws MailAccountException;
+    public void updateMailAccount(MailAccountDescription mailAccount, int user, int cid, Session session) throws MailAccountException;
 
     /**
      * Inserts mail account's value taken from specified mail account.
-     * 
+     *
      * @param mailAccount The mail account containing the values to update.
      * @param user The user ID
      * @param ctx The context
-     * @param sessionPassword The session password; set to <code>null</code> to insert mail account with an empty password
+     * @param session The session; set to <code>null</code> to insert mail account with an empty password
      * @return The ID of the newly created mail account
      * @throws MailAccountException If the mail account cannot be updated
      */
-    public int insertMailAccount(MailAccountDescription mailAccount, int user, Context ctx, String sessionPassword) throws MailAccountException;
+    public int insertMailAccount(MailAccountDescription mailAccount, int user, Context ctx, Session session) throws MailAccountException;
 
     /**
      * Inserts mail account's value taken from specified mail account.
-     * 
+     *
      * @param mailAccount The mail account containing the values to update.
      * @param user The user ID
      * @param ctx The context
-     * @param sessionPassword The session password; set to <code>null</code> to insert mail account with an empty password
+     * @param session The session; set to <code>null</code> to insert mail account with an empty password
      * @param con writable database connection
      * @return The ID of the newly created mail account
      * @throws MailAccountException If the mail account cannot be updated
      */
-    int insertMailAccount(MailAccountDescription mailAccount, int user, Context ctx, String sessionPassword, Connection con) throws MailAccountException;
+    int insertMailAccount(MailAccountDescription mailAccount, int user, Context ctx, Session session, Connection con) throws MailAccountException;
 
     /**
      * Deletes the mail account identified by specified ID.
-     * 
+     *
      * @param id The mail account ID
+     * @param properties Optional properties for delete event (passed to {@link MailAccountDeleteListener} instances)
      * @param user The user ID
      * @param cid The context ID
      * @throws MailAccountException If the mail account cannot be deleted
      */
-    public void deleteMailAccount(int id, int user, int cid) throws MailAccountException;
+    public void deleteMailAccount(int id, Map<String, Object> properties, int user, int cid) throws MailAccountException;
 
     /**
      * Deletes the mail account identified by specified ID.
-     * 
+     *
      * @param id The mail account ID
+     * @param properties Optional properties for delete event (passed to {@link MailAccountDeleteListener} instances)
      * @param user The user ID
      * @param cid The context ID
      * @param deletePrimary <code>true</code> to delete also the primary mail account if the user is deleted.
      * @throws MailAccountException If the mail account cannot be deleted
      */
-    public void deleteMailAccount(int id, int user, int cid, boolean deletePrimary) throws MailAccountException;
+    public void deleteMailAccount(int id, Map<String, Object> properties, int user, int cid, boolean deletePrimary) throws MailAccountException;
 
     /**
      * Deletes the mail account identified by specified ID.
-     * 
+     *
      * @param id The mail account ID
+     * @param properties Optional properties for delete event (passed to {@link MailAccountDeleteListener} instances)
      * @param user The user ID
      * @param cid The context ID
      * @param deletePrimary <code>true</code> to delete also the primary mail account if the user is deleted.
      * @param con The connection to use
      * @throws MailAccountException If the mail account cannot be deleted
      */
-    public void deleteMailAccount(int id, int user, int cid, boolean deletePrimary, Connection con) throws MailAccountException;
+    public void deleteMailAccount(int id, Map<String, Object> properties, int user, int cid, boolean deletePrimary, Connection con) throws MailAccountException;
 
     /**
      * Gets the mail accounts of the users whose login matches specified login.
-     * 
+     *
      * @param login The login
      * @param cid The context ID
      * @return The mail accounts of the users whose login matches specified login
@@ -210,7 +226,7 @@ public interface MailAccountStorageService {
 
     /**
      * Gets the mail accounts of the users whose login matches specified login on specified server.
-     * 
+     *
      * @param login The login
      * @param server The server's internet address
      * @param cid The context ID
@@ -221,18 +237,17 @@ public interface MailAccountStorageService {
 
     /**
      * Gets the mail accounts of the users whose primary email address matches specified email on specified server.
-     * 
+     *
      * @param primaryAddress The primary email address
-     * @param server The server's internet address
      * @param cid The context ID
      * @return The mail accounts of the users whose login matches specified login on specified server
      * @throws MailAccountException If resolving the primary address fails
      */
-    public MailAccount[] resolvePrimaryAddr(String primaryAddress, InetSocketAddress server, int cid) throws MailAccountException;
+    public MailAccount[] resolvePrimaryAddr(String primaryAddress, int cid) throws MailAccountException;
 
     /**
      * Gets the mail account matching specified primary email address of given user in given context.
-     * 
+     *
      * @param primaryAddress The primary address to look for
      * @param user The user ID
      * @param cid The context ID
@@ -241,9 +256,20 @@ public interface MailAccountStorageService {
      */
     public int getByPrimaryAddress(String primaryAddress, int user, int cid) throws MailAccountException;
 
+    /**
+     * Gets those mail accounts of given user in given context whose host name occurs in specified collection of host names.
+     *
+     * @param hostNames The host names
+     * @param user The user identifier
+     * @param cid The context identifier
+     * @return The binary-sorted identifiers of matching mail accounts
+     * @throws MailAccountException If look-up by host names caused an error
+     */
+    public int[] getByHostNames(Collection<String> hostNames, int user, int cid) throws MailAccountException;
+
     /**
      * Gets the transport account for specified account ID.
-     * 
+     *
      * @param id The account ID
      * @param user The user ID
      * @param cid The context ID
@@ -251,4 +277,20 @@ public interface MailAccountStorageService {
      * @throws MailAccountException If transport look-up fails
      */
     public MailAccount getTransportAccountForID(int id, int user, int cid) throws MailAccountException;
+
+    /**
+     * Decodes stored encrypted strings using the old secret and encode them again using the new secret.
+     *
+     * @param user The user ID
+     * @param cid The context ID
+     * @param oldSecret The secret used for decrypting the stored passwords
+     * @param newSecret The secret to use for encrypting the passwords again
+     * @throws MailAccountException
+     */
+    public void migratePasswords(int user, int cid, String oldSecret, String newSecret) throws MailAccountException;
+
+    /**
+     * Finds out whether the user has items that are encrypted
+     */
+    public boolean hasAccounts(Session session) throws MailAccountException;
 }
