@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,23 +49,30 @@
 
 package com.openexchange.mailaccount.internal;
 
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
-import com.openexchange.mail.api.MailConfig;
+import javax.mail.internet.IDNA;
 import com.openexchange.mail.config.MailProperties;
-import com.openexchange.mail.transport.config.TransportConfig;
 import com.openexchange.mail.transport.config.TransportProperties;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.mailaccount.MailAccountException;
+import com.openexchange.mailaccount.MailAccountExceptionFactory;
+import com.openexchange.mailaccount.MailAccountExceptionMessages;
+import com.openexchange.tools.net.URIDefaults;
+import com.openexchange.tools.net.URIParser;
+import com.openexchange.tools.net.URITools;
 
 /**
  * {@link AbstractMailAccount} - Abstract mail account.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class AbstractMailAccount implements MailAccount {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(AbstractMailAccount.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(AbstractMailAccount.class));
 
     private static final long serialVersionUID = -641194838598605274L;
 
@@ -213,7 +220,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the account ID.
-     * 
+     *
      * @param id The account ID
      */
     public void setId(final int id) {
@@ -222,7 +229,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the login.
-     * 
+     *
      * @param login The login
      */
     public void setLogin(final String login) {
@@ -231,7 +238,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the password.
-     * 
+     *
      * @param password The password
      */
     public void setPassword(final String password) {
@@ -240,7 +247,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the account name.
-     * 
+     *
      * @param name The account name
      */
     public void setName(final String name) {
@@ -249,16 +256,16 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the primary email address.
-     * 
+     *
      * @param primaryAddress The primary email address
      */
     public void setPrimaryAddress(final String primaryAddress) {
-        this.primaryAddress = primaryAddress;
+        this.primaryAddress = primaryAddress == null ? primaryAddress : IDNA.toIDN(primaryAddress);
     }
 
     /**
      * Sets the personal.
-     * 
+     *
      * @param personal The personal
      */
     public void setPersonal(final String personal) {
@@ -267,7 +274,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the user ID.
-     * 
+     *
      * @param userId The user ID
      */
     public void setUserId(final int userId) {
@@ -304,7 +311,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default trash folder's name.
-     * 
+     *
      * @param trash The default trash folder's name
      */
     public void setTrash(final String trash) {
@@ -313,7 +320,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default sent folder's name.
-     * 
+     *
      * @param trash The default sent folder's name
      */
     public void setSent(final String sent) {
@@ -322,7 +329,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default drafts folder's name.
-     * 
+     *
      * @param trash The default drafts folder's name
      */
     public void setDrafts(final String drafts) {
@@ -331,7 +338,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default spam folder's name.
-     * 
+     *
      * @param trash The default spam folder's name
      */
     public void setSpam(final String spam) {
@@ -340,7 +347,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default confirmed-spam folder's name.
-     * 
+     *
      * @param trash The default confirmed-spam folder's name
      */
     public void setConfirmedSpam(final String confirmedSpam) {
@@ -349,7 +356,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the default confirmed-ham folder's name.
-     * 
+     *
      * @param trash The default confirmed-ham folder's name
      */
     public void setConfirmedHam(final String confirmedHam) {
@@ -358,7 +365,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the spam handler name.
-     * 
+     *
      * @param trash The spam handler name
      */
     public void setSpamHandler(final String spamHandler) {
@@ -367,17 +374,17 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the mail server name.
-     * 
+     *
      * @param mailServer The mail server name to set
      */
     public void setMailServer(final String mailServer) {
         mailServerUrl = null;
-        this.mailServer = mailServer;
+        this.mailServer = mailServer == null ? null : IDNA.toUnicode(mailServer);
     }
 
     /**
      * Sets the mail server port.
-     * 
+     *
      * @param mailPort The mail server port to set
      */
     public void setMailPort(final int mailPort) {
@@ -387,7 +394,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the mail server protocol.
-     * 
+     *
      * @param mailProtocol The mail server protocol to set
      */
     public void setMailProtocol(final String mailProtocol) {
@@ -397,7 +404,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets whether to establish a secure connection to mail server.
-     * 
+     *
      * @param mailSecure Whether to establish a secure connection to mail server
      */
     public void setMailSecure(final boolean mailSecure) {
@@ -407,17 +414,17 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the transport server name.
-     * 
+     *
      * @param transportServer The transport server name to set
      */
     public void setTransportServer(final String transportServer) {
         transportServerUrl = null;
-        this.transportServer = transportServer;
+        this.transportServer = transportServer == null ? null : IDNA.toUnicode(transportServer);
     }
 
     /**
      * Sets the transport server port.
-     * 
+     *
      * @param transportPort The transport server port to set
      */
     public void setTransportPort(final int transportPort) {
@@ -427,7 +434,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the transport server protocol
-     * 
+     *
      * @param transportProtocol The transport server protocol to set
      */
     public void setTransportProtocol(final String transportProtocol) {
@@ -437,7 +444,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets whether to establish a secure connection to transport server.
-     * 
+     *
      * @param transportSecure Whether to establish a secure connection to transport server
      */
     public void setTransportSecure(final boolean transportSecure) {
@@ -449,95 +456,119 @@ public abstract class AbstractMailAccount implements MailAccount {
         if (null != mailServerUrl) {
             return mailServerUrl;
         }
-        if (null == mailServer) {
+        if (isEmpty(mailServer)) {
             return null;
         }
-        final StringBuilder sb = new StringBuilder(32);
-        sb.append(mailProtocol);
-        if (mailSecure) {
-            sb.append('s');
+        final String protocol = mailSecure ? mailProtocol + 's' : mailProtocol;
+        try {
+            return mailServerUrl = URITools.generateURI(protocol, IDNA.toASCII(mailServer), mailPort).toString();
+        } catch (final URISyntaxException e) {
+            LOG.error(e.getMessage(), e);
+            // Old implementation is not capable of handling IPv6 addresses.
+            final StringBuilder sb = new StringBuilder(32);
+            sb.append(mailProtocol);
+            if (mailSecure) {
+                sb.append('s');
+            }
+            return mailServerUrl = sb.append("://").append(mailServer).append(':').append(mailPort).toString();
         }
-        return mailServerUrl = sb.append("://").append(mailServer).append(':').append(mailPort).toString();
     }
 
     /**
      * Parses specified mail server URL.
-     * 
+     *
      * @param mailServerURL The mail server URL to parse
+     * @throws MailAccountException if parsing the URL fails.
      */
-    public void parseMailServerURL(final String mailServerURL) {
-        if (null == mailServerURL) {
-            setMailServer(null);
-            return;
+    public void parseMailServerURL(final String mailServerURL) throws MailAccountException {
+        try {
+            setMailServer(URIParser.parse(IDNA.toASCII(mailServerURL), URIDefaults.IMAP));
+        } catch (final URISyntaxException e) {
+            throw MailAccountExceptionFactory.getInstance().create(MailAccountExceptionMessages.URI_PARSE_FAILED, e, mailServerURL);
         }
-        final String[] tmp = MailConfig.parseProtocol(mailServerURL);
-        final String prot;
-        final Object[] parsed;
-        if (tmp != null) {
-            prot = tmp[0];
-            parsed = parseServerAndPort(tmp[1], getMailPort());
+    }
+
+    public void setMailServer(final URI mailServer) {
+        if (null == mailServer) {
+            // Parse like old parser to prevent problems.
+            setMailServer("");
         } else {
-            prot = getMailProtocol();
-            parsed = parseServerAndPort(mailServerURL, getMailPort());
+            final String protocol = mailServer.getScheme();
+            if (protocol.endsWith("s")) {
+                setMailSecure(true);
+                setMailProtocol(protocol.substring(0, protocol.length() - 1));
+            } else {
+                setMailSecure(false);
+                setMailProtocol(protocol);
+            }
+            setMailServer(URITools.getHost(mailServer));
+            setMailPort(mailServer.getPort());
         }
-        if (prot.endsWith("s")) {
-            setMailSecure(true);
-            setMailProtocol(prot.substring(0, prot.length() - 1));
-        } else {
-            setMailProtocol(prot);
-        }
-        setMailServer(parsed[0].toString());
-        setMailPort(((Integer) parsed[1]).intValue());
     }
 
     /**
      * Parses specified transport server URL.
-     * 
+     *
      * @param mailServerURL The transport server URL to parse
+     * @throws MailAccountException if parsing the URL fails.
      */
-    public void parseTransportServerURL(final String transportServerURL) {
+    public void parseTransportServerURL(final String transportServerURL) throws MailAccountException {
         if (null == transportServerURL) {
-            setTransportServer(null);
+            setTransportServer((String) null);
             return;
         }
-        final String[] tmp = TransportConfig.parseProtocol(transportServerURL);
-        final String prot;
-        final Object[] parsed;
-        if (tmp != null) {
-            prot = tmp[0];
-            parsed = parseServerAndPort(tmp[1], getTransportPort());
-        } else {
-            prot = getTransportProtocol();
-            parsed = parseServerAndPort(transportServerURL, getTransportPort());
+        try {
+            setTransportServer(URIParser.parse(IDNA.toASCII(transportServerURL), URIDefaults.SMTP));
+        } catch (final URISyntaxException e) {
+            setTransportServer((String) null);
+            return;
+            //throw MailAccountExceptionFactory.getInstance().create(MailAccountExceptionMessages.URI_PARSE_FAILED, e, transportServerURL);
         }
-        if (prot.endsWith("s")) {
-            setTransportSecure(true);
-            setTransportProtocol(prot.substring(0, prot.length() - 1));
+    }
+
+    public void setTransportServer(final URI transportServer) {
+        if (null == transportServer) {
+            // Parse like old parser to prevent problems.
+            setTransportServer("");
         } else {
-            setTransportProtocol(prot);
+            final String protocol = transportServer.getScheme();
+            if (protocol.endsWith("s")) {
+                setTransportSecure(true);
+                setTransportProtocol(protocol.substring(0, protocol.length() - 1));
+            } else {
+                setTransportSecure(false);
+                setTransportProtocol(protocol);
+            }
+            setTransportServer(URITools.getHost(transportServer));
+            setTransportPort(transportServer.getPort());
         }
-        setTransportServer(parsed[0].toString());
-        setTransportPort(((Integer) parsed[1]).intValue());
     }
 
     public String generateTransportServerURL() {
         if (null != transportServerUrl) {
             return transportServerUrl;
         }
-        if (null == transportServer) {
+        if (isEmpty(transportServer)) {
             return null;
         }
-        final StringBuilder sb = new StringBuilder(32);
-        sb.append(transportProtocol);
-        if (transportSecure) {
-            sb.append('s');
+        final String protocol = transportSecure ? transportProtocol + 's' : transportProtocol;
+        try {
+            return transportServerUrl = URITools.generateURI(protocol, IDNA.toASCII(transportServer), transportPort).toString();
+        } catch (final URISyntaxException e) {
+            LOG.error(e.getMessage(), e);
+            // Old implementation is not capable of handling IPv6 addresses.
+            final StringBuilder sb = new StringBuilder(32);
+            sb.append(transportProtocol);
+            if (transportSecure) {
+                sb.append('s');
+            }
+            return transportServerUrl = sb.append("://").append(transportServer).append(':').append(transportPort).toString();
         }
-        return transportServerUrl = sb.append("://").append(transportServer).append(':').append(transportPort).toString();
     }
 
     /**
      * Gets the optional transport login.
-     * 
+     *
      * @return The optional transport login
      */
     public String getTransportLogin() {
@@ -549,7 +580,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Gets the optional transport password.
-     * 
+     *
      * @return The optional transport password
      */
     public String getTransportPassword() {
@@ -561,7 +592,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the optional transport login.
-     * 
+     *
      * @param transportLogin The optional transport login
      */
     public void setTransportLogin(final String transportLogin) {
@@ -570,7 +601,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the optional transport password.
-     * 
+     *
      * @param transportLogin The optional transport password
      */
     public void setTransportPassword(final String transportPassword) {
@@ -583,7 +614,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets if this mail account is enabled for Unified INBOX.
-     * 
+     *
      * @param unifiedINBOXEnabled <code>true</code> if this mail account is enabled for Unified INBOX; otherwise <code>false</code>
      */
     public void setUnifiedINBOXEnabled(final boolean unifiedINBOXEnabled) {
@@ -596,7 +627,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the trash fullname
-     * 
+     *
      * @param trashFullname The trash fullname to set
      */
     public void setTrashFullname(final String trashFullname) {
@@ -609,7 +640,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the sent fullname
-     * 
+     *
      * @param sentFullname The sent fullname to set
      */
     public void setSentFullname(final String sentFullname) {
@@ -622,7 +653,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the drafts fullname
-     * 
+     *
      * @param draftsFullname The drafts fullname to set
      */
     public void setDraftsFullname(final String draftsFullname) {
@@ -635,7 +666,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the spam fullname
-     * 
+     *
      * @param spamFullname The spam fullname to set
      */
     public void setSpamFullname(final String spamFullname) {
@@ -648,7 +679,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the confirmed-spam fullname
-     * 
+     *
      * @param confirmedSpamFullname The confirmed-spam fullname to set
      */
     public void setConfirmedSpamFullname(final String confirmedSpamFullname) {
@@ -661,7 +692,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the confirmed-ham fullname
-     * 
+     *
      * @param confirmedHamFullname The confirmed-ham fullname to set
      */
     public void setConfirmedHamFullname(final String confirmedHamFullname) {
@@ -679,7 +710,7 @@ public abstract class AbstractMailAccount implements MailAccount {
 
     /**
      * Sets the properties.
-     * 
+     *
      * @param properties The properties to set
      */
     public void setProperties(final Map<String, String> properties) {
@@ -709,18 +740,16 @@ public abstract class AbstractMailAccount implements MailAccount {
         return sb.toString();
     }
 
-    private static Object[] parseServerAndPort(final String server, final int defaultPort) {
-        final int pos = server.indexOf(':');
-        if (pos == -1) {
-            return new Object[] { server, Integer.valueOf(defaultPort) };
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
         }
-        int port;
-        try {
-            port = Integer.parseInt(server.substring(pos + 1));
-        } catch (final NumberFormatException e) {
-            LOG.warn("Unable to parse port out of URL: " + server + ". Using default port instead.", e);
-            port = defaultPort;
+        final char[] chars = string.toCharArray();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < chars.length; i++) {
+            isWhitespace = Character.isWhitespace(chars[i]);
         }
-        return new Object[] { server.subSequence(0, pos), Integer.valueOf(port) };
+        return isWhitespace;
     }
+
 }
