@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,27 +54,35 @@ import java.io.Serializable;
 import java.net.InetSocketAddress;
 import java.sql.Connection;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-import com.openexchange.cache.dynamic.impl.OXObjectFactory;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
 import com.openexchange.caching.CacheKey;
 import com.openexchange.caching.CacheService;
+import com.openexchange.caching.dynamic.OXObjectFactory;
+import com.openexchange.folderstorage.FolderStorage;
+import com.openexchange.folderstorage.cache.memory.FolderMap;
+import com.openexchange.folderstorage.cache.memory.FolderMapManagement;
+import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mailaccount.Attribute;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountDescription;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
 
 /**
  * {@link CachingMailAccountStorage} - The caching implementation of mail account storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class CachingMailAccountStorage implements MailAccountStorageService {
@@ -93,7 +101,7 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
 
     /**
      * Initializes a new {@link CachingMailAccountStorage}.
-     * 
+     *
      * @param delegate The database-backed delegate storage
      */
     CachingMailAccountStorage(final RdbMailAccountStorage delegate) {
@@ -102,34 +110,44 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         cacheLock = new ReentrantLock(true);
     }
 
-    private static CacheKey newCacheKey(final CacheService cacheService, final int id, final int user, final int cid) {
+    RdbMailAccountStorage getDelegate() {
+        return delegate;
+    }
+
+    static CacheKey newCacheKey(final CacheService cacheService, final int id, final int user, final int cid) {
         return cacheService.newCacheKey(cid, Integer.valueOf(id), Integer.valueOf(user));
     }
 
-    private void invalidateMailAccount(final int id, final int user, final int cid) throws MailAccountException {
+    public void invalidateMailAccount(final int id, final int user, final int cid) throws MailAccountException {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
         if (null != cacheService) {
             try {
                 final Cache cache = cacheService.getCache(REGION_NAME);
                 cache.remove(newCacheKey(cacheService, id, user, cid));
+                cache.invalidateGroup(Integer.toString(cid));
             } catch (final CacheException e) {
                 throw new MailAccountException(e);
             }
         }
+        final FolderMap folderMap = FolderMapManagement.getInstance().optFor(user, cid);
+        if (null != folderMap) {
+            folderMap.remove(MailFolder.DEFAULT_FOLDER_ID + id, FolderStorage.REAL_TREE_ID);
+            folderMap.remove(MailFolder.DEFAULT_FOLDER_ID + id, OutlookFolderStorage.OUTLOOK_TREE_ID);
+        }
     }
 
-    public void deleteMailAccount(final int id, final int user, final int cid, final boolean deletePrimary, final Connection con) throws MailAccountException {
-        delegate.deleteMailAccount(id, user, cid, deletePrimary, con);
+    public void deleteMailAccount(final int id, final Map<String, Object> properties, final int user, final int cid, final boolean deletePrimary, final Connection con) throws MailAccountException {
+        delegate.deleteMailAccount(id, properties, user, cid, deletePrimary, con);
         invalidateMailAccount(id, user, cid);
     }
 
-    public void deleteMailAccount(final int id, final int user, final int cid, final boolean deletePrimary) throws MailAccountException {
-        delegate.deleteMailAccount(id, user, cid, deletePrimary);
+    public void deleteMailAccount(final int id, final Map<String, Object> properties, final int user, final int cid, final boolean deletePrimary) throws MailAccountException {
+        delegate.deleteMailAccount(id, properties, user, cid, deletePrimary);
         invalidateMailAccount(id, user, cid);
     }
 
-    public void deleteMailAccount(final int id, final int user, final int cid) throws MailAccountException {
-        delegate.deleteMailAccount(id, user, cid);
+    public void deleteMailAccount(final int id, final Map<String, Object> properties, final int user, final int cid) throws MailAccountException {
+        delegate.deleteMailAccount(id, properties, user, cid);
         invalidateMailAccount(id, user, cid);
     }
 
@@ -138,6 +156,8 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         if (cacheService == null) {
             return delegate.getDefaultMailAccount(user, cid);
         }
+        final RdbMailAccountStorage d = delegate;
+        final Lock l = cacheLock;
         final OXObjectFactory<MailAccount> factory = new OXObjectFactory<MailAccount>() {
 
             public Serializable getKey() {
@@ -145,11 +165,11 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
             }
 
             public MailAccount load() throws MailAccountException {
-                return delegate.getDefaultMailAccount(user, cid);
+                return d.getDefaultMailAccount(user, cid);
             }
 
             public Lock getCacheLock() {
-                return cacheLock;
+                return l;
             }
         };
         try {
@@ -167,6 +187,8 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         if (cacheService == null) {
             return delegate.getMailAccount(id, user, cid);
         }
+        final RdbMailAccountStorage d = delegate;
+        final Lock l = cacheLock;
         final OXObjectFactory<MailAccount> factory = new OXObjectFactory<MailAccount>() {
 
             public Serializable getKey() {
@@ -174,11 +196,11 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
             }
 
             public MailAccount load() throws MailAccountException {
-                return delegate.getMailAccount(id, user, cid);
+                return d.getMailAccount(id, user, cid);
             }
 
             public Lock getCacheLock() {
-                return cacheLock;
+                return l;
             }
         };
         try {
@@ -195,15 +217,70 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return delegate.getByPrimaryAddress(primaryAddress, user, cid);
     }
 
+    public int[] getByHostNames(final Collection<String> hostNames, final int user, final int cid) throws MailAccountException {
+        return delegate.getByHostNames(hostNames, user, cid);
+    }
+
     public MailAccount[] getUserMailAccounts(final int user, final int cid, final Connection con) throws MailAccountException {
         final int[] ids = delegate.getUserMailAccountIDs(user, cid, con);
         final MailAccount[] accounts = new MailAccount[ids.length];
         for (int i = 0; i < accounts.length; i++) {
-            accounts[i] = getMailAccount(ids[i], user, cid);
+            accounts[i] = getMailAccount0(ids[i], user, cid, con);
         }
         return accounts;
     }
 
+    private MailAccount getMailAccount0(final int id, final int user, final int cid, final Connection con) throws MailAccountException {
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (cacheService == null) {
+            return delegate.getMailAccount(id, user, cid);
+        }
+        try {
+            final CacheKey key = newCacheKey(cacheService, id, user, cid);
+            final Cache cache = cacheService.getCache(REGION_NAME);
+            cacheLock.lock();
+            try {
+                if (cache.get(key) == null) {
+                    /*
+                     * Not contained in cache. Load with specified connection
+                     */
+                    final MailAccount mailAccount = delegate.getMailAccount(id, user, cid, con);
+                    cache.put(key, mailAccount);
+                }
+            } finally {
+                cacheLock.unlock();
+            }
+            /*
+             * Return reloading mail account
+             */
+            final RdbMailAccountStorage d = delegate;
+            final Lock l = cacheLock;
+            final OXObjectFactory<MailAccount> factory = new OXObjectFactory<MailAccount>() {
+
+                public Serializable getKey() {
+                    return key;
+                }
+
+                public MailAccount load() throws MailAccountException {
+                    return d.getMailAccount(id, user, cid);
+                }
+
+                public Lock getCacheLock() {
+                    return l;
+                }
+            };
+            return new MailAccountReloader(factory, REGION_NAME);
+
+        } catch (final MailAccountException e) {
+            throw e;
+        } catch (final AbstractOXException e) {
+            if (e instanceof MailAccountException) {
+                throw (MailAccountException) e;
+            }
+            throw new MailAccountException(e);
+        }
+    }
+
     public MailAccount[] getUserMailAccounts(final int user, final int cid) throws MailAccountException {
         final int[] ids = delegate.getUserMailAccountIDs(user, cid);
         final MailAccount[] accounts = new MailAccount[ids.length];
@@ -214,7 +291,12 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
     }
 
     public MailAccount[] resolveLogin(final String login, final int cid) throws MailAccountException {
-        final int[][] idsAndUsers = delegate.resolveLogin2IDs(login, cid);
+        final int[][] idsAndUsers = resolveFromCache(login, cid, new FromDelegate() {
+            public int[][] getFromDelegate(final String pattern, final int contextId) throws MailAccountException {
+                return getDelegate().resolveLogin2IDs(pattern, contextId);
+            }
+            
+        }, CachedResolveType.LOGIN);
         final MailAccount[] accounts = new MailAccount[idsAndUsers.length];
         for (int i = 0; i < accounts.length; i++) {
             final int[] idAndUser = idsAndUsers[i];
@@ -224,10 +306,14 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
     }
 
     public MailAccount[] resolveLogin(final String login, final InetSocketAddress server, final int cid) throws MailAccountException {
-        final int[][] idsAndUsers = delegate.resolveLogin2IDs(login, cid);
+        final int[][] idsAndUsers = resolveFromCache(login, cid, new FromDelegate() {
+            public int[][] getFromDelegate(final String pattern, final int contextId) throws MailAccountException {
+                return getDelegate().resolveLogin2IDs(pattern, contextId);
+            }
+            
+        }, CachedResolveType.LOGIN);
         final List<MailAccount> l = new ArrayList<MailAccount>(idsAndUsers.length);
-        for (int i = 0; i < idsAndUsers.length; i++) {
-            final int[] idAndUser = idsAndUsers[i];
+        for (final int[] idAndUser : idsAndUsers) {
             final MailAccount candidate = getMailAccount(idAndUser[0], idAndUser[1], cid);
             if (server.equals(toSocketAddr(candidate.generateMailServerURL(), 143))) {
                 l.add(candidate);
@@ -236,42 +322,85 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return l.toArray(new MailAccount[l.size()]);
     }
 
-    public void updateMailAccount(final MailAccountDescription mailAccount, final Set<Attribute> attributes, final int user, final int cid, final String sessionPassword) throws MailAccountException {
-        delegate.updateMailAccount(mailAccount, attributes, user, cid, sessionPassword);
+    public void updateMailAccount(final MailAccountDescription mailAccount, final Set<Attribute> attributes, final int user, final int cid, final Session session) throws MailAccountException {
+        delegate.updateMailAccount(mailAccount, attributes, user, cid, session);
         invalidateMailAccount(mailAccount.getId(), user, cid);
     }
 
-    public void updateMailAccount(final MailAccountDescription mailAccount, final Set<Attribute> attributes, final int user, final int cid, final String sessionPassword, final Connection con, final boolean changePrimary) throws MailAccountException {
-        delegate.updateMailAccount(mailAccount, attributes, user, cid, sessionPassword, con, changePrimary);
+    public void updateMailAccount(final MailAccountDescription mailAccount, final Set<Attribute> attributes, final int user, final int cid, final Session session, final Connection con, final boolean changePrimary) throws MailAccountException {
+        delegate.updateMailAccount(mailAccount, attributes, user, cid, session, con, changePrimary);
         invalidateMailAccount(mailAccount.getId(), user, cid);
     }
 
-    public void updateMailAccount(final MailAccountDescription mailAccount, final int user, final int cid, final String sessionPassword) throws MailAccountException {
-        delegate.updateMailAccount(mailAccount, user, cid, sessionPassword);
+    public void updateMailAccount(final MailAccountDescription mailAccount, final int user, final int cid, final Session session) throws MailAccountException {
+        delegate.updateMailAccount(mailAccount, user, cid, session);
         invalidateMailAccount(mailAccount.getId(), user, cid);
     }
 
-    public int insertMailAccount(final MailAccountDescription mailAccount, final int user, final Context ctx, final String sessionPassword) throws MailAccountException {
-        return delegate.insertMailAccount(mailAccount, user, ctx, sessionPassword);
+    public int insertMailAccount(final MailAccountDescription mailAccount, final int user, final Context ctx, final Session session) throws MailAccountException {
+        final int id = delegate.insertMailAccount(mailAccount, user, ctx, session);
+        invalidateMailAccount(id, user, ctx.getContextId());
+        return id;
     }
 
-    public int insertMailAccount(final MailAccountDescription mailAccount, final int user, final Context ctx, final String sessionPassword, final Connection con) throws MailAccountException {
-        return delegate.insertMailAccount(mailAccount, user, ctx, sessionPassword, con);
+    public int insertMailAccount(final MailAccountDescription mailAccount, final int user, final Context ctx, final Session session, final Connection con) throws MailAccountException {
+        final int id = delegate.insertMailAccount(mailAccount, user, ctx, session, con);
+        invalidateMailAccount(id, user, ctx.getContextId());
+        return id;
     }
 
-    public MailAccount[] resolvePrimaryAddr(final String primaryAddress, final InetSocketAddress server, final int cid) throws MailAccountException {
-        final int[][] idsAndUsers = delegate.resolvePrimaryAddr2IDs(primaryAddress, cid);
-        final List<MailAccount> l = new ArrayList<MailAccount>(idsAndUsers.length);
-        for (int i = 0; i < idsAndUsers.length; i++) {
-            final int[] idAndUser = idsAndUsers[i];
-            final MailAccount candidate = getMailAccount(idAndUser[0], idAndUser[1], cid);
-            if (server.equals(toSocketAddr(candidate.generateMailServerURL(), 143))) {
-                l.add(candidate);
+    public MailAccount[] resolvePrimaryAddr(final String primaryAddress, final int cid) throws MailAccountException {
+        final int[][] idsAndUsers = resolveFromCache(primaryAddress, cid, new FromDelegate() {
+            public int[][] getFromDelegate(final String pattern, final int contextId) throws MailAccountException {
+                return getDelegate().resolvePrimaryAddr2IDs(pattern, contextId);
             }
+        }, CachedResolveType.PRIMARY_ADDRESS);
+        final List<MailAccount> l = new ArrayList<MailAccount>(idsAndUsers.length);
+        for (final int[] idAndUser : idsAndUsers) {
+            l.add(getMailAccount(idAndUser[0], idAndUser[1], cid));
         }
         return l.toArray(new MailAccount[l.size()]);
     }
 
+    private static interface FromDelegate {
+        int[][] getFromDelegate(String pattern, int cid) throws MailAccountException;
+    }
+
+    private static int[][] resolveFromCache(final String pattern, final int cid, final FromDelegate delegate, final CachedResolveType type) throws MailAccountException {
+        final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
+        if (null == cacheService) {
+            return delegate.getFromDelegate(pattern, cid);
+        }
+        Cache cache;
+        try {
+            cache = cacheService.getCache(REGION_NAME);
+        } catch (final CacheException e) {
+            cache = null;
+        }
+        if (null == cache) {
+            return delegate.getFromDelegate(pattern, cid);
+        }
+        final int[][] idsAndUsers;
+        final CacheKey key = cacheService.newCacheKey(type.ordinal(), pattern);
+        int[][] tmp;
+        try {
+            tmp = (int[][]) cache.getFromGroup(key, Integer.toString(cid));
+        } catch (final ClassCastException e) {
+            tmp = null;
+        }
+        if (null == tmp) {
+            idsAndUsers = delegate.getFromDelegate(pattern, cid);
+            try {
+                cache.putInGroup(key, Integer.toString(cid), idsAndUsers);
+            } catch (final CacheException e) {
+                throw new MailAccountException(e);
+            }
+        } else {
+            idsAndUsers = tmp;
+        }
+        return idsAndUsers;
+    }
+
     public MailAccount getTransportAccountForID(final int id, final int user, final int cid) throws MailAccountException {
         final MailAccount account = getMailAccount(id, user, cid);
         if (null == account.getTransportServer()) {
@@ -280,4 +409,17 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return account;
     }
 
+    public void migratePasswords(final int user, final int cid, final String oldSecret, final String newSecret) throws MailAccountException {
+        delegate.migratePasswords(user, cid, oldSecret, newSecret);
+        // Invalidate all accounts for the given user
+        final int[] ids = delegate.getUserMailAccountIDs(user, cid);
+        for (final int id : ids) {
+            invalidateMailAccount(id, user, cid);
+        }
+    }
+
+    public boolean hasAccounts(final Session session) throws MailAccountException {
+        return delegate.hasAccounts(session);
+    }
+
 }
