@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,8 +54,10 @@ import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.util.Collections;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.DatabaseService;
 import com.openexchange.databaseold.Database;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
@@ -70,11 +72,12 @@ import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.UnifiedINBOXManagement;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.tools.sql.DBUtils;
 import com.openexchange.user.UserService;
 
 /**
  * {@link UnifiedINBOXManagementImpl} - The Unified INBOX management implementation.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UnifiedINBOXManagementImpl implements UnifiedINBOXManagement {
@@ -99,14 +102,11 @@ public final class UnifiedINBOXManagementImpl implements UnifiedINBOXManagement
             final MailAccountStorageService storageService =
                 ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
             // Check if Unified INBOX account already exists for given user
-            final MailAccount[] existingAccounts = storageService.getUserMailAccounts(userId, contextId, con);
-            for (final MailAccount mailAccount : existingAccounts) {
-                if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(mailAccount.getMailProtocol())) {
-                    // User already has the Unified INBOX account set
-                    throw MailAccountExceptionMessages.DUPLICATE_UNIFIED_INBOX_ACCOUNT.create(
-                        Integer.valueOf(userId),
-                        Integer.valueOf(contextId));
-                }
+            if (exists(userId, contextId, con)) {
+                // User already has the Unified INBOX account set
+                throw MailAccountExceptionMessages.DUPLICATE_UNIFIED_INBOX_ACCOUNT.create(
+                    Integer.valueOf(userId),
+                    Integer.valueOf(contextId));
             }
             final Context ctx;
             {
@@ -137,7 +137,7 @@ public final class UnifiedINBOXManagementImpl implements UnifiedINBOXManagement
             mailAccountDescription.setSpam("spam");
             mailAccountDescription.setSpamHandler("NoSpamHandler");
             // No transport settings
-            mailAccountDescription.setTransportServer(null);
+            mailAccountDescription.setTransportServer((String) null);
             mailAccountDescription.setTrash("trash");
             // Create it
             if (null == con) {
@@ -175,9 +175,9 @@ public final class UnifiedINBOXManagementImpl implements UnifiedINBOXManagement
             // Delete the Unified INBOX account
             if (id >= 0) {
                 if (null == con) {
-                    storageService.deleteMailAccount(id, userId, contextId, false);
+                    storageService.deleteMailAccount(id, Collections.<String, Object> emptyMap(), userId, contextId, false);
                 } else {
-                    storageService.deleteMailAccount(id, userId, contextId, false, con);
+                    storageService.deleteMailAccount(id, Collections.<String, Object> emptyMap(), userId, contextId, false, con);
                 }
             }
         } catch (final ServiceException e) {
@@ -260,24 +260,39 @@ public final class UnifiedINBOXManagementImpl implements UnifiedINBOXManagement
 
     public int getUnifiedINBOXAccountID(final int userId, final int contextId, final Connection con) throws MailAccountException {
         try {
-            final MailAccountStorageService storageService =
-                ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
-            // Look-up the Unified INBOX account for given user
-            final MailAccount[] existingAccounts;
+            final DatabaseService databaseService;
+            final Connection connection;
+            final boolean releaseConnection;
             if (null == con) {
-                existingAccounts = storageService.getUserMailAccounts(userId, contextId);
+                try {
+                    databaseService = ServerServiceRegistry.getInstance().getService(DatabaseService.class, true);
+                    connection = databaseService.getReadOnly(contextId);
+                    releaseConnection = true;
+                } catch (final ServiceException e) {
+                    throw new MailAccountException(e);
+                } catch (final DBPoolingException e) {
+                    throw new MailAccountException(e);
+                }
             } else {
-                existingAccounts = storageService.getUserMailAccounts(userId, contextId, con);
+                databaseService = null;
+                connection = con;
+                releaseConnection = false;
             }
-            for (int i = 0; i < existingAccounts.length; i++) {
-                final MailAccount mailAccount = existingAccounts[i];
-                if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(mailAccount.getMailProtocol())) {
-                    return mailAccount.getId();
+            PreparedStatement stmt = null;
+            ResultSet rs = null;
+            try {
+                stmt = connection.prepareStatement("SELECT id FROM user_mail_account WHERE cid = 1337 AND user = 17 AND url LIKE ?");
+                stmt.setString(1, UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX + '%');
+                rs = stmt.executeQuery();
+                return rs.next() ? rs.getInt(1) : -1;
+            } catch (final SQLException e) {
+                throw MailAccountExceptionMessages.SQL_ERROR.create(e, e.getMessage());
+            } finally {
+                DBUtils.closeSQLStuff(rs, stmt);
+                if (releaseConnection && null != databaseService) {
+                    databaseService.backReadOnly(contextId, connection);
                 }
             }
-            return -1;
-        } catch (final ServiceException e) {
-            throw new MailAccountException(e);
         } catch (final MailAccountException e) {
             throw new MailAccountException(e);
         }
