@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,7 +56,7 @@ import com.openexchange.mailaccount.AttributeSwitch;
 
 /**
  * {@link UpdateTransportAccountBuilder}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class UpdateTransportAccountBuilder implements AttributeSwitch {
@@ -74,7 +74,8 @@ public class UpdateTransportAccountBuilder implements AttributeSwitch {
         Attribute.POP3_EXPUNGE_ON_QUIT_LITERAL,
         Attribute.POP3_PATH_LITERAL,
         Attribute.POP3_REFRESH_RATE_LITERAL,
-        Attribute.POP3_STORAGE_LITERAL);
+        Attribute.POP3_STORAGE_LITERAL,
+        Attribute.REPLY_TO_LITERAL);
 
     public static boolean needsUpdate(final Set<Attribute> attributes) {
         for (final Attribute attribute : attributes) {
@@ -130,6 +131,10 @@ public class UpdateTransportAccountBuilder implements AttributeSwitch {
         return null;
     }
 
+    public Object replyTo() {
+        return null;
+    }
+
     public Object confirmedHam() {
         return null;
     }
