@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.multiple.handlers;
 
+import java.util.Collection;
+import java.util.Collections;
 import java.util.Date;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -61,7 +63,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link ContactsFactoryService} - Factory service for contacts module.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ContactsFactoryService implements MultipleHandlerFactoryService {
@@ -97,19 +99,24 @@ public final class ContactsFactoryService implements MultipleHandlerFactoryServi
             return timestamp;
         }
 
-        public JSONValue performRequest(final String action, final JSONObject jsonObject, final ServerSession session) throws AbstractOXException, JSONException {
+        public JSONValue performRequest(final String action, final JSONObject jsonObject, final ServerSession session, final boolean secure) throws AbstractOXException, JSONException {
             try {
                 final ContactRequest request = new ContactRequest(session);
                 final JSONValue retval = request.action(action, jsonObject);
                 timestamp = request.getTimestamp();
                 return retval;
             } catch (final AbstractOXException e) {
-                final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(ContactsFactoryService.ContactsHandler.class);
+                final org.apache.commons.logging.Log log =
+                    org.apache.commons.logging.LogFactory.getLog(ContactsFactoryService.ContactsHandler.class);
                 log.error(e.getMessage(), e);
                 throw e;
             }
         }
 
+        public Collection<AbstractOXException> getWarnings() {
+            return Collections.<AbstractOXException> emptySet();
+        }
+
     }
 
 }
