@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.multiple.handlers;
 
+import java.util.Collection;
+import java.util.Collections;
 import java.util.Date;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -60,7 +62,7 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link ResourceFactoryService} - Factory service for resource module.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ResourceFactoryService implements MultipleHandlerFactoryService {
@@ -96,13 +98,17 @@ public final class ResourceFactoryService implements MultipleHandlerFactoryServi
             return timestamp;
         }
 
-        public Object performRequest(final String action, final JSONObject jsonObject, final ServerSession session) throws AbstractOXException, JSONException {
+        public Object performRequest(final String action, final JSONObject jsonObject, final ServerSession session, final boolean secure) throws AbstractOXException, JSONException {
             final ResourceRequest request = new ResourceRequest(session);
             final Object retval = request.action(action, jsonObject);
             timestamp = request.getTimestamp();
             return retval;
         }
 
+        public Collection<AbstractOXException> getWarnings() {
+            return Collections.<AbstractOXException> emptySet();
+        }
+
     }
 
 }
