@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,9 +51,12 @@ package com.openexchange.multiple.internal;
 
 import java.util.concurrent.atomic.AtomicBoolean;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.mailaccount.json.multiple.MailAccountMultipleHandlerFactory;
 import com.openexchange.multiple.handlers.AppointmentFactoryService;
+import com.openexchange.multiple.handlers.ConfigFactoryService;
 import com.openexchange.multiple.handlers.ContactsFactoryService;
 import com.openexchange.multiple.handlers.GroupFactoryService;
+import com.openexchange.multiple.handlers.QuotaFactoryService;
 import com.openexchange.multiple.handlers.ReminderFactoryService;
 import com.openexchange.multiple.handlers.ResourceFactoryService;
 import com.openexchange.multiple.handlers.TasksFactoryService;
@@ -64,7 +67,7 @@ import com.openexchange.server.services.ServerServiceRegistry;
  * {@link MultipleHandlerInit} - Initialization for multiple handlers.
  * <p>
  * Should be done in activator if refactored to reside in own package.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MultipleHandlerInit implements Initialization {
@@ -88,12 +91,15 @@ public final class MultipleHandlerInit implements Initialization {
         /*
          * Add known handlers
          */
+        registry.addFactoryService(new QuotaFactoryService());
         registry.addFactoryService(new AppointmentFactoryService());
         registry.addFactoryService(new ContactsFactoryService());
         registry.addFactoryService(new GroupFactoryService());
         registry.addFactoryService(new ReminderFactoryService());
         registry.addFactoryService(new ResourceFactoryService());
         registry.addFactoryService(new TasksFactoryService());
+        registry.addFactoryService(new ConfigFactoryService());
+        registry.addFactoryService(new MailAccountMultipleHandlerFactory());
     }
 
     public void stop() throws AbstractOXException {
