@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,13 +49,14 @@
 
 package com.openexchange.multiple.internal;
 
+import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import com.openexchange.multiple.MultipleHandlerFactoryService;
 
 /**
  * {@link MultipleHandlerRegistryImpl} - Implementation backed by a {@link ConcurrentMap concurrent map}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MultipleHandlerRegistryImpl implements com.openexchange.multiple.internal.MultipleHandlerRegistry {
@@ -79,7 +80,16 @@ public final class MultipleHandlerRegistryImpl implements com.openexchange.multi
     }
 
     public MultipleHandlerFactoryService getFactoryService(final String module) {
-        return registry.get(module);
+        MultipleHandlerFactoryService candidate = registry.get(module);
+        if(candidate == null) {
+            // Maybe prefixed
+            for (Map.Entry<String, MultipleHandlerFactoryService> entry : registry.entrySet()) {
+                if(module.startsWith(entry.getKey())) {
+                    return entry.getValue();
+                }
+            }
+        }
+        return candidate;
     }
 
     public void removeFactoryService(final String module) {
