@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,37 +51,43 @@ package com.openexchange.passwordchange;
 
 import java.io.UnsupportedEncodingException;
 import java.security.NoSuchAlgorithmException;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Map;
 import java.util.regex.Pattern;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventAdmin;
 import com.openexchange.authentication.AuthenticationService;
 import com.openexchange.authentication.LoginException;
 import com.openexchange.authentication.LoginInfo;
 import com.openexchange.authentication.service.Authentication;
+import com.openexchange.caching.Cache;
+import com.openexchange.caching.CacheException;
+import com.openexchange.caching.CacheKey;
+import com.openexchange.caching.CacheService;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.userconfiguration.UserConfigurationException;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.mail.MailException;
-import com.openexchange.mail.cache.MailAccessCache;
+import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mailaccount.MailAccount;
-import com.openexchange.passwordchange.mechs.SHACrypt;
-import com.openexchange.passwordchange.mechs.UnixCrypt;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondException;
 import com.openexchange.sessiond.SessiondService;
-import com.openexchange.sessiond.exception.SessiondException;
 
 /**
  * {@link PasswordChangeService} - Performs changing a user's password
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class PasswordChangeService {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PasswordChangeService.class);
-
-    private static final String MECH_CRYPT = "{CRYPT}";
-
-    private static final String MECH_SHA = "{SHA}";
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PasswordChangeService.class));
 
     /**
      * Initializes a new {@link PasswordChangeService}
@@ -92,7 +98,7 @@ public abstract class PasswordChangeService {
 
     /**
      * Performs the password update.
-     * 
+     *
      * @param event The event containing the session of the user whose password shall be changed, the context, the new password, and the old
      *            password (needed for verification)
      * @throws UserException If password update fails
@@ -106,7 +112,7 @@ public abstract class PasswordChangeService {
 
     /**
      * Checks permission
-     * 
+     *
      * @param event The event containing the session of the user whose password shall be changed, the context, the new password, and the old
      *            password (needed for verification)
      * @throws UserException If permission is denied to update password
@@ -116,8 +122,9 @@ public abstract class PasswordChangeService {
          * At the moment security service is not used for timing reasons but is ought to be used later on
          */
         try {
-            if (!UserConfigurationStorage.getInstance().getUserConfiguration(event.getSession().getUserId(), event.getContext()).isEditPassword()) {
-                throw new UserException(UserException.Code.PERMISSION, Integer.valueOf(event.getContext().getContextId()));
+            final Context context = event.getContext();
+            if (!UserConfigurationStorage.getInstance().getUserConfiguration(event.getSession().getUserId(), context).isEditPassword()) {
+                throw new UserException(UserException.Code.PERMISSION, Integer.valueOf(context.getContextId()));
             }
         } catch (final UserConfigurationException e1) {
             throw new UserException(e1);
@@ -130,7 +137,7 @@ public abstract class PasswordChangeService {
 
     /**
      * Check old password
-     * 
+     *
      * @param event The event containing the session of the user whose password shall be changed, the context, the new password, and the old
      *            password (needed for verification)
      * @throws UserException If old password is invalid
@@ -147,15 +154,28 @@ public abstract class PasswordChangeService {
             /*
              * Loading user also verifies its existence
              */
-            UserStorage.getStorageUser(event.getSession().getUserId(), event.getContext());
-            final String login = event.getSession().getLogin();
-            authenticationService.handleLoginInfo(new _LoginInfo(login, event.getOldPassword()));
+            final Session session = event.getSession();
+            UserStorage.getStorageUser(session.getUserId(), event.getContext());
+            authenticationService.handleLoginInfo(new _LoginInfo(session.getLogin(), event.getOldPassword()));
         } catch (final LoginException e) {
             /*
              * Verification of old password failed
              */
             throw new UserException(e);
         }
+        /*
+         * Check min/max length restrictions
+         */
+        final int len = event.getNewPassword().length();
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        int property = service.getIntProperty("com.openexchange.passwordchange.minLength", 4);
+        if (property > 0 && len < property) {
+            throw new UserException(UserException.Code.INVALID_MIN_LENGTH, Integer.valueOf(property));
+        }
+        property = service.getIntProperty("com.openexchange.passwordchange.maxLength", 0);
+        if (property > 0 && len > property) {
+            throw new UserException(UserException.Code.INVALID_MAX_LENGTH, Integer.valueOf(property));
+        }
         /*
          * No validation of new password since admin daemon does no validation, too
          */
@@ -168,7 +188,7 @@ public abstract class PasswordChangeService {
 
     /**
      * Actually updates the password in affected resources
-     * 
+     *
      * @param event The event containing the session of the user whose password shall be changed, the context, the new password, and the old
      *            password (needed for verification)
      * @see #getEncodedPassword(String, String)
@@ -178,7 +198,7 @@ public abstract class PasswordChangeService {
 
     /**
      * Propagates changed password throughout system: invalidate caches, propagate to sub-systems like mail, etc.
-     * 
+     *
      * @param event The event containing the session of the user whose password shall be changed, the context, the new password, and the old
      *            password (needed for verification)
      * @throws UserException If propagating the password change fails
@@ -187,8 +207,9 @@ public abstract class PasswordChangeService {
         /*
          * Remove possible session-bound cached default mail access
          */
+        final Session session = event.getSession();
         try {
-            MailAccessCache.getInstance().removeMailAccess(event.getSession(), MailAccount.DEFAULT_ID);
+            MailAccess.getMailAccessCache().removeMailAccess(session, MailAccount.DEFAULT_ID);
         } catch (final MailException e) {
             LOG.error("Removing cached mail access failed", e);
             throw new UserException(e);
@@ -196,50 +217,78 @@ public abstract class PasswordChangeService {
         /*
          * Invalidate user cache
          */
-        UserStorage.getInstance().invalidateUser(event.getContext(), event.getSession().getUserId());
+        final int userId = session.getUserId();
+        UserStorage.getInstance().invalidateUser(event.getContext(), userId);
         /*
          * Update password in session
          */
-        final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+        final ServerServiceRegistry serviceRegistry = ServerServiceRegistry.getInstance();
+        final SessiondService sessiondService = serviceRegistry.getService(SessiondService.class);
         if (sessiondService == null) {
             throw new UserException(new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, SessiondService.class.getName()));
         }
         try {
-            sessiondService.changeSessionPassword(event.getSession().getSessionID(), event.getNewPassword());
+            sessiondService.changeSessionPassword(session.getSessionID(), event.getNewPassword());
         } catch (final SessiondException e) {
             LOG.error("Updating password in user session failed", e);
             throw new UserException(e);
         }
+        final EventAdmin eventAdmin = serviceRegistry.getService(EventAdmin.class);
+        final int contextId = session.getContextId();
+        if (null != eventAdmin) {
+            final Map<String, Object> properties = new HashMap<String, Object>(5);
+            properties.put("com.openexchange.passwordchange.contextId", Integer.valueOf(contextId));
+            properties.put("com.openexchange.passwordchange.userId", Integer.valueOf(userId));
+            properties.put("com.openexchange.passwordchange.session", session);
+            properties.put("com.openexchange.passwordchange.oldPassword", event.getOldPassword());
+            properties.put("com.openexchange.passwordchange.newPassword", event.getNewPassword());
+            eventAdmin.postEvent(new Event("com/openexchange/passwordchange", properties));
+        }
+        /*
+         * Invalidate caches manually
+         */
+        final CacheService cacheService = serviceRegistry.getService(CacheService.class);
+        if (null != cacheService) {
+            try {
+                final CacheKey key = cacheService.newCacheKey(contextId, userId);
+                Cache jcs = cacheService.getCache("User");
+                jcs.remove(key);
+
+                jcs = cacheService.getCache("UserConfiguration");
+                jcs.remove(key);
+
+                jcs = cacheService.getCache("UserSettingMail");
+                jcs.remove(key);
+
+                jcs = cacheService.getCache("MailAccount");
+                jcs.invalidateGroup(Integer.toString(contextId));
+            } catch (final CacheException e) {
+                // Ignore
+            }
+        }
     }
 
     /**
      * Utility method to encode given <code>newPassword</code> according to specified encoding mechanism
-     * 
+     *
      * @param mech The encoding mechanism; currently supported values: <code>&quot;{CRYPT}&quot;</code> and <code>&quot;{SHA}&quot;</code>
      * @param newPassword The new password to encode
      * @return The encoded password
      * @throws UserException If encoding the new password fails
      */
     protected static final String getEncodedPassword(final String mech, final String newPassword) throws UserException {
-        if (MECH_CRYPT.equals(mech)) {
-            try {
-                return UnixCrypt.crypt(newPassword);
-            } catch (final UnsupportedEncodingException e) {
-                LOG.error("Error encrypting password according to CRYPT mechanism", e);
-                throw new UserException(UserException.Code.UNSUPPORTED_ENCODING, e, e.getMessage());
+        try {
+            final String cryptedPassword = PasswordMechanism.getEncodedPassword(mech, newPassword);
+            if (null == cryptedPassword) {
+                throw new UserException(UserException.Code.MISSING_PASSWORD_MECH, mech == null ? "" : mech);
             }
-        } else if (MECH_SHA.equals(mech)) {
-            try {
-                return SHACrypt.makeSHAPasswd(newPassword);
-            } catch (final NoSuchAlgorithmException e) {
-                LOG.error("Error encrypting password according to SHA mechanism", e);
-                throw new UserException(UserException.Code.UNSUPPORTED_ENCODING, e, e.getMessage());
-            } catch (final UnsupportedEncodingException e) {
-                LOG.error("Error encrypting password according to SHA mechanism", e);
-                throw new UserException(UserException.Code.UNSUPPORTED_ENCODING, e, e.getMessage());
-            }
-        } else {
-            throw new UserException(UserException.Code.MISSING_PASSWORD_MECH, mech == null ? "" : mech);
+            return cryptedPassword;
+        } catch (final UnsupportedEncodingException e) {
+            LOG.error("Error encrypting password according to CRYPT mechanism", e);
+            throw new UserException(UserException.Code.UNSUPPORTED_ENCODING, e, e.getMessage());
+        } catch (final NoSuchAlgorithmException e) {
+            LOG.error("Error encrypting password according to SHA mechanism", e);
+            throw new UserException(UserException.Code.UNSUPPORTED_ENCODING, e, e.getMessage());
         }
     }
 
@@ -249,7 +298,7 @@ public abstract class PasswordChangeService {
 
     /**
      * {@link _LoginInfo} - Simple class that implements {@link LoginInfo}
-     * 
+     *
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     protected static final class _LoginInfo implements LoginInfo {
@@ -260,7 +309,7 @@ public abstract class PasswordChangeService {
 
         /**
          * Initializes a new {@link _LoginInfo}
-         * 
+         *
          * @param loginInfo The login info
          * @param pw The password
          */
@@ -278,6 +327,10 @@ public abstract class PasswordChangeService {
             return loginInfo;
         }
 
+        public Map<String, Object> getProperties() {
+            return Collections.emptyMap();
+        }
+
     }
 
     /*-
@@ -291,7 +344,7 @@ public abstract class PasswordChangeService {
      * <p>
      * Valid characters are:<br>
      * &quot;<i>&nbsp; abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_ -+.%$@<i>&quot;
-     * 
+     *
      * @param password The password string to check
      * @return <code>true</code> if specified password string only consists of valid characters; otherwise <code>false</code>
      */
