@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,7 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Condition;
 import java.util.concurrent.locks.ReentrantLock;
 import org.apache.commons.logging.Log;
@@ -65,7 +66,7 @@ import org.apache.commons.logging.LogFactory;
  */
 public class ReentrantLockPool<T> implements Pool<T>, Runnable {
 
-    static final Log LOG = LogFactory.getLog(ReentrantLockPool.class);
+    static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ReentrantLockPool.class));
 
     private final int minIdle;
     private final int maxIdle;
@@ -86,6 +87,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
 
     private boolean running = true;
     private int useTimePointer;
+    private final AtomicBoolean brokenCreate = new AtomicBoolean();
 
     /**
      * The longest time an object has been used.
@@ -113,7 +115,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
      * @param lifecycle Implementation of the interface for handling the life cycle of pooled objects.
      * @param config Configuration of the pool parameters.
      */
-    public ReentrantLockPool(PoolableLifecycle<T> lifecycle, Config config) {
+    public ReentrantLockPool(final PoolableLifecycle<T> lifecycle, final Config config) {
         super();
         minIdle = Math.max(0, config.minIdle);
         maxIdle = config.maxIdle;
@@ -129,7 +131,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         this.lifecycle = lifecycle;
         try {
             ensureMinIdle();
-        } catch (PoolingException e) {
+        } catch (final PoolingException e) {
             LOG.error("Problem while creating initial objects.", e);
         }
     }
@@ -138,7 +140,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         return lifecycle;
     }
 
-    public void back(T pooled) throws PoolingException {
+    public void back(final T pooled) throws PoolingException {
         if (null == pooled) {
             throw new PoolingException("A null reference was returned to pool.");
         }
@@ -152,7 +154,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
      * @return if the object has been put to pool.
      * @throws PoolingException if the object does not belong to this pool.
      */
-    private boolean back(T pooled, boolean decrementActive) throws PoolingException {
+    private boolean back(final T pooled, final boolean decrementActive) throws PoolingException {
         final long startTime = System.currentTimeMillis();
         // checks
         final PooledData <T> metaData;
@@ -256,10 +258,10 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                         throw new PoolingException("Pool exhausted.");
                     case BLOCK:
                         final String threadName = Thread.currentThread().getName();
-                        boolean writeWarning = System.currentTimeMillis() > (lastWarning + 60000l);
+                        final boolean writeWarning = System.currentTimeMillis() > (lastWarning + 60000l);
                         if (writeWarning) {
                             lastWarning = System.currentTimeMillis();
-                            PoolingException warn = new PoolingException("Thread " + threadName
+                            final PoolingException warn = new PoolingException("Thread " + threadName
                                 + " is sent to sleep until an object in the pool is available. " + data.numActive()
                                 + " objects are already in use.");
                             LOG.warn(warn.getMessage(), warn);
@@ -272,11 +274,11 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                             } else {
                                 idleAvailable.await();
                             }
-                        } catch (InterruptedException e) {
+                        } catch (final InterruptedException e) {
                             LOG.error("Thread " + threadName + " was interrupted.", e);
                         }
                         if (writeWarning) {
-                            PoolingException warn = new PoolingException("Thread " + threadName + " slept for "
+                            final PoolingException warn = new PoolingException("Thread " + threadName + " slept for "
                                 + (System.currentTimeMillis() - sleepStartTime) + "ms.");
                             LOG.warn(warn.getMessage(), warn);
                         }
@@ -291,6 +293,9 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                     }
                 }
                 if (null == retval) {
+                    if (brokenCreate.get() && data.getCreating() > 0) {
+                        throw new PoolingException("Not trying to create a pooled object in broken create state.");
+                    }
                     data.addCreating();
                 }
             } finally {
@@ -302,7 +307,9 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                 final T pooled;
                 try {
                     pooled = lifecycle.create();
-                } catch (Exception e) {
+                    brokenCreate.set(false);
+                } catch (final Exception e) {
+                    brokenCreate.set(true);
                     lock.lock();
                     try {
                         data.removeCreating();
@@ -358,7 +365,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         throw new PoolingException("Pool has been stopped.");
     }
 
-    private static final long getWaitTime(long startTime) {
+    private static final long getWaitTime(final long startTime) {
         return System.currentTimeMillis() - startTime;
     }
 
@@ -442,12 +449,12 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
     private final Runnable cleaner = new Runnable() {
         public void run() {
             try {
-                Thread thread = Thread.currentThread();
-                String origName = thread.getName();
+                final Thread thread = Thread.currentThread();
+                final String origName = thread.getName();
                 thread.setName("PoolCleaner");
                 ReentrantLockPool.this.run();
                 thread.setName(origName);
-            } catch (Exception e) {
+            } catch (final Exception e) {
                 LOG.error(e.getMessage(), e);
             }
         }
@@ -507,7 +514,9 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         if (LOG.isTraceEnabled()) {
             LOG.trace("Starting cleaner run.");
         }
+        final List<PooledData<T>> toCheck = new ArrayList<PooledData<T>>();
         final List<PooledData<T>> removed = new ArrayList<PooledData<T>>();
+        final List<PooledData<T>> notReturned = new ArrayList<PooledData<T>>();
         lock.lock();
         try {
             int idleSize = data.numIdle();
@@ -519,38 +528,25 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                         maxIdleTime > 0 && metaData.getTimeDiff() > maxIdleTime
                     ) || (
                         maxLifeTime > 0 && metaData.getLiveTime() > maxLifeTime
-                    ) || (
-                        // object not valid anymore
-                        testOnIdle && !(lifecycle.activate(metaData)
-                        && lifecycle.validate(metaData)
-                        && lifecycle.deactivate(metaData))
                     );
                 if (remove) {
                     data.removeIdle(index);
                     idleSize = data.numIdle();
                     removed.add(metaData);
-                    continue;
+                } else if (testOnIdle) {
+                    // Validation check must be done outside lock.
+                    data.removeIdle(index);
+                    idleSize = data.numIdle();
+                    toCheck.add(metaData);
+                } else {
+                    index++;
                 }
-                index++;
             }
             final Iterator<PooledData<T>> iter = data.listActive();
             while (iter.hasNext()) {
                 final PooledData<T> metaData = iter.next();
                 if (metaData.getTimeDiff() > maxIdleTime) {
-                    final StringBuilder sb = new StringBuilder();
-                    sb.append("Object was not returned. Fetched: ");
-                    sb.append(metaData.getTimestamp());
-                    sb.append(", UseTime: ");
-                    sb.append(metaData.getTimeDiff());
-                    sb.append(", ID: ");
-                    sb.append(metaData.getIdentifier());
-                    sb.append(", Object: ");
-                    sb.append(metaData.getPooled());
-                    final PoolingException e = new PoolingException(sb.toString());
-                    if (testThreads && null != metaData.getTrace()) {
-                        e.setStackTrace(metaData.getTrace());
-                    }
-                    LOG.error(e.getMessage(), e);
+                    notReturned.add(metaData);
                     iter.remove();
                     idleAvailable.signal();
                 }
@@ -558,9 +554,37 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         } finally {
             lock.unlock();
         }
+        for (final PooledData<T> metaData : toCheck) {
+            if (!(lifecycle.activate(metaData) && lifecycle.validate(metaData) && lifecycle.deactivate(metaData))) {
+                removed.add(metaData);
+            } else {
+                lock.lock();
+                try {
+                    data.addIdle(metaData);
+                } finally {
+                    lock.unlock();
+                }
+            }
+        }
         for (final PooledData<T> metaData : removed) {
             lifecycle.destroy(metaData.getPooled());
         }
+        for (final PooledData<T> metaData : notReturned) {
+            final StringBuilder sb = new StringBuilder();
+            sb.append("Object was not returned. Fetched: ");
+            sb.append(metaData.getTimestamp());
+            sb.append(", UseTime: ");
+            sb.append(metaData.getTimeDiff());
+            sb.append(", ID: ");
+            sb.append(metaData.getIdentifier());
+            sb.append(", Object: ");
+            sb.append(metaData.getPooled());
+            final PoolingException e = new PoolingException(sb.toString());
+            if (testThreads && null != metaData.getTrace()) {
+                e.setStackTrace(metaData.getTrace());
+            }
+            LOG.error(e.getMessage(), e);
+        }
         try {
             ensureMinIdle();
         } catch (final PoolingException e) {
