@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,9 +52,11 @@ package com.openexchange.pooling;
 import java.util.Iterator;
 import java.util.Timer;
 import java.util.TimerTask;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.threadpool.ThreadPools;
 
 /**
  * Implementation of the object pool.
@@ -68,7 +70,7 @@ public class SynchronizedPool<T> implements Pool<T>, Runnable {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(SynchronizedPool.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(SynchronizedPool.class));
 
     /* --- Constants --- */
 
@@ -471,9 +473,8 @@ public class SynchronizedPool<T> implements Pool<T>, Runnable {
         @Override
         public void run() {
             try {
-                final Thread thread = new Thread(SynchronizedPool.this);
-                thread.setName("PoolCleaner");
-                thread.start();
+                final ThreadPoolService poolService = ServerServiceRegistry.getInstance().getService(ThreadPoolService.class);
+                poolService.submit(ThreadPools.task(SynchronizedPool.this, "PoolCleaner"));
             } catch (final Exception e) {
                 LOG.error(e.getMessage(), e);
             }
@@ -547,7 +548,7 @@ public class SynchronizedPool<T> implements Pool<T>, Runnable {
                     idleSize = data.numIdle();
                     lifecycle.destroy(metaData.getPooled());
                     continue;
-                } 
+                }
                 index++;
             }
             ensureMinIdle();
