@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,34 +49,36 @@
 
 package com.openexchange.preferences;
 
+import static com.openexchange.java.Autoboxing.B;
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.b;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Types;
-import com.openexchange.contactcollector.ContactCollectorService;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
-import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.i18n.FolderStrings;
-import com.openexchange.groupware.ldap.LdapException;
-import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.settings.SettingException;
-import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.server.services.ServerServiceRegistry;
-import com.openexchange.session.Session;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * Interface for accessing configuration settings.
- * 
+ *
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class ServerUserSetting {
 
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServerUserSetting.class));
+
+    private static final boolean DEBUG = LOG.isDebugEnabled();
+
     private static final Attribute<Boolean> CONTACT_COLLECT_ENABLED = new Attribute<Boolean>() {
 
         public Boolean getAttribute(final ResultSet rs) throws SQLException {
@@ -100,8 +102,8 @@ public class ServerUserSetting {
     private static final Attribute<Integer> CONTACT_COLLECT_FOLDER = new Attribute<Integer>() {
 
         public Integer getAttribute(final ResultSet rs) throws SQLException {
-            int retval = rs.getInt(getColumnName());
-            return rs.wasNull() ? null : Integer.valueOf(retval);
+            final int retval = rs.getInt(getColumnName());
+            return rs.wasNull() ? null : I(retval);
         }
 
         public String getColumnName() {
@@ -121,7 +123,8 @@ public class ServerUserSetting {
     private static final Attribute<Boolean> CONTACT_COLLECT_ON_MAIL_ACCESS = new Attribute<Boolean>() {
 
         public Boolean getAttribute(final ResultSet rs) throws SQLException {
-            return Boolean.valueOf(rs.getBoolean(getColumnName()));
+            final boolean b = rs.getBoolean(getColumnName());
+            return rs.wasNull() ? null : Boolean.valueOf(b);
         }
 
         public String getColumnName() {
@@ -141,7 +144,8 @@ public class ServerUserSetting {
     private static final Attribute<Boolean> CONTACT_COLLECT_ON_MAIL_TRANSPORT = new Attribute<Boolean>() {
 
         public Boolean getAttribute(final ResultSet rs) throws SQLException {
-            return Boolean.valueOf(rs.getBoolean(getColumnName()));
+            final boolean b = rs.getBoolean(getColumnName());
+            return rs.wasNull() ? null : Boolean.valueOf(b);
         }
 
         public String getColumnName() {
@@ -161,7 +165,7 @@ public class ServerUserSetting {
     private static final Attribute<Integer> DEFAULT_STATUS_PRIVATE = new Attribute<Integer>() {
 
         public Integer getAttribute(final ResultSet rs) throws SQLException {
-            return Integer.valueOf(rs.getInt(getColumnName()));
+            return I(rs.getInt(getColumnName()));
         }
 
         public String getColumnName() {
@@ -181,7 +185,7 @@ public class ServerUserSetting {
     private static final Attribute<Integer> DEFAULT_STATUS_PUBLIC = new Attribute<Integer>() {
 
         public Integer getAttribute(final ResultSet rs) throws SQLException {
-            return Integer.valueOf(rs.getInt(getColumnName()));
+            return I(rs.getInt(getColumnName()));
         }
 
         public String getColumnName() {
@@ -198,63 +202,46 @@ public class ServerUserSetting {
 
     };
 
+    private static final Attribute<Integer> FOLDER_TREE = new Attribute<Integer>() {
+
+        public Integer getAttribute(final ResultSet rs) throws SQLException {
+            final int tmp = rs.getInt(getColumnName());
+            final Integer retval;
+            if (rs.wasNull()) {
+                retval = null;
+            } else {
+                retval = I(tmp);
+            }
+            return retval;
+        }
+
+        public String getColumnName() {
+            return "folderTree";
+        }
+
+        public void setAttribute(final PreparedStatement pstmt, final Integer value) throws SQLException {
+            if (value == null) {
+                pstmt.setInt(1, 0);
+            } else {
+                pstmt.setInt(1, value.intValue());
+            }
+        }
+    };
+
     private static final ServerUserSetting defaultInstance = new ServerUserSetting();
 
-    /**
-     * Enables/Disables the collection of contacts triggered by mails.
-     * 
-     * @param cid context id
-     * @param user user id
-     */
-    public static void setContactColletion(Context ctx, Session session, final int userId, final boolean enabled) throws SettingException {
-        defaultInstance.setIContactColletion(ctx, session, userId, enabled);
-    }
-
-    /**
-     * Gets the flag for contact collection.
-     * 
-     * @param cid context id
-     * @param user user id
-     * @return <code>true</code> if mails should be collected, <code>false</code> otherwise
-     */
-    public static Boolean isContactCollectionEnabled(final int cid, final int user) throws SettingException {
-        return defaultInstance.isIContactCollectionEnabled(cid, user);
-    }
-
-    /**
-     * Sets the folder used to store collected contacts.
-     * 
-     * @param cid context id
-     * @param user user id
-     * @param folder folder id
-     */
-    public static void setContactCollectionFolder(final int cid, final int user, final int folder) throws SettingException {
-        defaultInstance.setIContactCollectionFolder(cid, user, Integer.valueOf(folder));
-    }
-
-    /**
-     * Returns the folder used to store collected contacts.
-     * 
-     * @param cid context id
-     * @param user user id
-     * @return folder id or <code>null</code> if none found
-     */
-    public static Integer getContactCollectionFolder(final int cid, final int user) throws SettingException {
-        return defaultInstance.getIContactCollectionFolder(cid, user);
-    }
-
     /**
      * Gets the default instance.
-     * 
+     *
      * @return The default instance.
      */
-    public static ServerUserSetting getDefaultInstance() {
+    public static ServerUserSetting getInstance() {
         return defaultInstance;
     }
 
     /**
      * Gets the instance using specified connection.
-     * 
+     *
      * @param connection The connection to use.
      * @return The instance using specified connection.
      */
@@ -277,7 +264,7 @@ public class ServerUserSetting {
 
     /**
      * Initializes a new {@link ServerUserSetting}.
-     * 
+     *
      * @param connection The connection to use.
      */
     private ServerUserSetting(final Connection connection) {
@@ -286,206 +273,203 @@ public class ServerUserSetting {
     }
 
     /**
-     * Enables/Disables the collection of contacts triggered by mails.
-     * 
-     * @param cid context id
-     * @param user user id
-     */
-    public void setIContactColletion(Context ctx, Session session, final int userId, final boolean enabled) throws SettingException {
-        setAttributeInternal(ctx.getContextId(), userId, CONTACT_COLLECT_ENABLED, Boolean.valueOf(enabled), connection);
-        if (enabled && getAttributeInternal(ctx.getContextId(), userId, CONTACT_COLLECT_FOLDER, connection) == null) {
-            ContactCollectorService contactCollectService = ServerServiceRegistry.getInstance().getService(ContactCollectorService.class);
-            User user;
-            try {
-                user = UserStorage.getInstance().getUser(userId, ctx);
-                String folderName = new StringHelper(user.getLocale()).getString(FolderStrings.DEFAULT_CONTACT_COLLECT_FOLDER_NAME);
-                contactCollectService.createCollectFolder(session, ctx, folderName, connection);
-            } catch (LdapException e) {
-                throw new SettingException(SettingException.Code.SUBSYSTEM, e);
-            } catch (AbstractOXException e) {
-                throw new SettingException(SettingException.Code.SUBSYSTEM, e);
-            } catch (SQLException e) {
-                throw new SettingException(SettingException.Code.SQL_ERROR, e);
-            }
-        }
-    }
-
-    /**
-     * Gets the flag for contact collection.
-     * 
+     * Complete feature is enabled if one of its sub switches is enabled.
+     *
      * @param cid context id
      * @param user user id
      * @return The value or <code>false</code> if no entry is found.
      */
-    public Boolean isIContactCollectionEnabled(final int cid, final int user) throws SettingException {
-        final Boolean attribute = getAttributeInternal(cid, user, CONTACT_COLLECT_ENABLED, connection);
-        return null == attribute ? Boolean.FALSE : attribute;
+    public Boolean isContactCollectionEnabled(final int cid, final int user) throws SettingException {
+        return B(b(isContactCollectOnMailAccess(cid, user)) || b(isContactCollectOnMailTransport(cid, user)));
     }
 
     /**
      * Sets the folder used to store collected contacts.
-     * 
+     *
      * @param cid context id
      * @param user user id
      * @param folder folder id
      */
-    public void setIContactCollectionFolder(final int cid, final int user, final Integer folder) throws SettingException {
-        setAttributeInternal(cid, user, CONTACT_COLLECT_FOLDER, folder, connection);
+    public void setContactCollectionFolder(final int cid, final int user, final Integer folder) throws SettingException {
+        setAttribute(cid, user, CONTACT_COLLECT_FOLDER, folder);
     }
 
     /**
      * Returns the folder used to store collected contacts.
-     * 
+     *
      * @param cid The context id
      * @param user The user id
      * @return folder id or <code>null</code> if no entry found.
      */
-    public Integer getIContactCollectionFolder(final int cid, final int user) throws SettingException {
-        return getAttributeInternal(cid, user, CONTACT_COLLECT_FOLDER, connection);
+    public Integer getContactCollectionFolder(final int cid, final int user) throws SettingException {
+        return getAttribute(cid, user, CONTACT_COLLECT_FOLDER);
     }
 
     /**
      * Sets the flag for contact collection on incoming mails.
-     * 
+     *
      * @param cid The context id
      * @param user The user id
      * @param value The flag to set
      * @throws SettingException If a setting error occurs
      */
     public void setContactCollectOnMailAccess(final int cid, final int user, final boolean value) throws SettingException {
-        setAttributeInternal(cid, user, CONTACT_COLLECT_ON_MAIL_ACCESS, Boolean.valueOf(value), connection);
+        setAttribute(cid, user, CONTACT_COLLECT_ON_MAIL_ACCESS, Boolean.valueOf(value));
     }
 
     /**
      * Gets the flag for contact collection on incoming mails. If <code>null</code> default if <code>false</code>.
-     * 
+     *
      * @param cid The context id
      * @param user The user id
      * @return The flag for contact collection on incoming mails or <code>false</code>
      * @throws SettingException If a setting error occurs
      */
     public Boolean isContactCollectOnMailAccess(final int cid, final int user) throws SettingException {
-        final Boolean attribute = getAttributeInternal(cid, user, CONTACT_COLLECT_ON_MAIL_ACCESS, connection);
-        return null == attribute ? Boolean.FALSE : attribute;
+        final Boolean attribute = getAttribute(cid, user, CONTACT_COLLECT_ON_MAIL_ACCESS);
+        if (null != attribute) {
+            return attribute;
+        }
+        /*
+         * Return as configured
+         */
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        return null == service ? Boolean.FALSE : Boolean.valueOf(service.getBoolProperty("com.openexchange.user.contactCollectOnMailAccess", false));
     }
 
     /**
      * Sets the flag for contact collection on outgoing mails.
-     * 
+     *
      * @param cid The context id
      * @param user The user id
      * @param value The flag to set
      * @throws SettingException If a setting error occurs
      */
     public void setContactCollectOnMailTransport(final int cid, final int user, final boolean value) throws SettingException {
-        setAttributeInternal(cid, user, CONTACT_COLLECT_ON_MAIL_TRANSPORT, Boolean.valueOf(value), connection);
+        setAttribute(cid, user, CONTACT_COLLECT_ON_MAIL_TRANSPORT, Boolean.valueOf(value));
     }
 
     /**
      * Gets the flag for contact collection on outgoing mails. If <code>null</code> default if <code>false</code>.
-     * 
+     *
      * @param cid The context id
      * @param user The user id
      * @return The flag for contact collection on outgoing mails or <code>false</code>
      * @throws SettingException If a setting error occurs
      */
     public Boolean isContactCollectOnMailTransport(final int cid, final int user) throws SettingException {
-        final Boolean attribute = getAttributeInternal(cid, user, CONTACT_COLLECT_ON_MAIL_TRANSPORT, connection);
-        return null == attribute ? Boolean.FALSE : attribute;
+        final Boolean attribute = getAttribute(cid, user, CONTACT_COLLECT_ON_MAIL_TRANSPORT);
+        if (null != attribute) {
+            return attribute;
+        }
+        /*
+         * Return as configured
+         */
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        return null == service ? Boolean.FALSE : Boolean.valueOf(service.getBoolProperty("com.openexchange.user.contactCollectOnMailTransport", false));
     }
 
     /**
      * Returns the default confirmation status for private folders. If no value is set this parameter defaults to 0.
-     * 
+     *
      * @param cid
      * @param user
      * @return
      * @throws SettingException If a setting error occurs
      */
     public Integer getDefaultStatusPrivate(final int cid, final int user) throws SettingException {
-        Integer value = getAttributeInternal(cid, user, DEFAULT_STATUS_PRIVATE, connection);
+        Integer value = getAttribute(cid, user, DEFAULT_STATUS_PRIVATE);
         if (value == null) {
-            value = Integer.valueOf(0);
+            value = I(0);
         }
         return value;
     }
 
     /**
      * Sets the default confirmation status for private folders. <code>null</code> will default to 0.
-     * 
+     *
      * @param cid
      * @param user
      * @param status
      * @throws SettingException
      */
     public void setDefaultStatusPrivate(final int cid, final int user, final Integer status) throws SettingException {
-        setAttributeInternal(cid, user, DEFAULT_STATUS_PRIVATE, status, connection);
+        setAttribute(cid, user, DEFAULT_STATUS_PRIVATE, status);
     }
 
     /**
      * Returns the default confirmation status for public folders. If no value is set this parameter defaults to 0.
-     * 
+     *
      * @param cid
      * @param user
      * @return
      * @throws SettingException
      */
     public Integer getDefaultStatusPublic(final int cid, final int user) throws SettingException {
-        Integer value = getAttributeInternal(cid, user, DEFAULT_STATUS_PUBLIC, connection);
+        Integer value = getAttribute(cid, user, DEFAULT_STATUS_PUBLIC);
         if (value == null) {
-            value = Integer.valueOf(0);
+            value = I(0);
         }
         return value;
     }
 
     /**
      * Sets the default confirmation status for public folders. <code>null</code> will default to 0.
-     * 
+     *
      * @param cid
      * @param user
      * @param status
      * @throws SettingException
      */
     public void setDefaultStatusPublic(final int cid, final int user, final Integer status) throws SettingException {
-        setAttributeInternal(cid, user, DEFAULT_STATUS_PUBLIC, status, connection);
+        setAttribute(cid, user, DEFAULT_STATUS_PUBLIC, status);
     }
 
-    private static <T> T getAttributeInternal(final int cid, final int user, final Attribute<T> attribute, final Connection connection) throws SettingException {
+    /**
+     * Get the selected folder tree for the user. Return value may be <code>null</code> if the user does not have selected a folder tree.
+     * @param cid context identifier
+     * @param user user identifier.
+     * @return the selected folder tree or <code>null</code>
+     * @throws SettingException if reading the value from the database fails.
+     */
+    public Integer getFolderTree(final int cid, final int user) throws SettingException {
+        return getAttribute(cid, user, FOLDER_TREE);
+    }
+
+    public void setFolderTree(final int cid, final int user, final Integer value) throws SettingException {
+        setAttribute(cid, user, FOLDER_TREE, value);
+    }
+
+    private <T> T getAttribute(final int cid, final int user, final Attribute<T> attribute) throws SettingException {
         final Connection con;
-        final boolean closeCon;
         if (connection == null) {
             try {
                 con = Database.get(cid, false);
             } catch (final DBPoolingException e) {
                 throw new SettingException(e);
             }
-            closeCon = true;
         } else {
             con = connection;
-            closeCon = false;
         }
         try {
             return getAttribute(cid, user, attribute, con);
         } finally {
-            if (closeCon) {
+            if (null == connection) {
                 Database.back(cid, false, con);
             }
         }
     }
 
-    private static <T> void setAttributeInternal(final int cid, final int user, final Attribute<T> attribute, final T value, final Connection connection) throws SettingException {
+    private <T> void setAttribute(final int cid, final int user, final Attribute<T> attribute, final T value) throws SettingException {
         final Connection con;
-        final boolean closeCon;
         if (connection == null) {
             try {
                 con = Database.get(cid, true);
             } catch (final DBPoolingException e) {
                 throw new SettingException(e);
             }
-            closeCon = true;
         } else {
             con = connection;
-            closeCon = false;
         }
         try {
             if (hasEntry(cid, user, con)) {
@@ -494,28 +478,34 @@ public class ServerUserSetting {
                 insertAttribute(cid, user, attribute, value, con);
             }
         } finally {
-            if (closeCon) {
+            if (null == connection) {
                 Database.back(cid, true, con);
             }
         }
     }
 
-    private static <T> T getAttribute(final int cid, final int user, final Attribute<T> attribute, final Connection connection) throws SettingException {
-        T retval = null;
+    void deleteEntry(final int cid, final int user) throws SettingException {
         final Connection con;
-        final boolean closeCon;
         if (connection == null) {
-            // Use a writable connection to ensure most up-to-date value is read
             try {
                 con = Database.get(cid, true);
             } catch (final DBPoolingException e) {
                 throw new SettingException(e);
             }
-            closeCon = true;
         } else {
             con = connection;
-            closeCon = false;
         }
+        try {
+            deleteEntry(cid, user, con);
+        } finally {
+            if (null == connection) {
+                Database.back(cid, true, con);
+            }
+        }
+    }
+
+    private <T> T getAttribute(final int cid, final int user, final Attribute<T> attribute, final Connection con) throws SettingException {
+        T retval = null;
         final String select = "SELECT " + attribute.getColumnName() + " FROM user_setting_server WHERE cid=? AND user=?";
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -531,14 +521,11 @@ public class ServerUserSetting {
             throw new SettingException(SettingException.Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(rs, stmt);
-            if (closeCon) {
-                Database.back(cid, true, con);
-            }
         }
         return retval;
     }
 
-    private static <T> void updateAttribute(final int cid, final int user, final Attribute<T> attribute, final T value, final Connection con) throws SettingException {
+    private <T> void updateAttribute(final int cid, final int user, final Attribute<T> attribute, final T value, final Connection con) throws SettingException {
         PreparedStatement stmt = null;
         try {
             stmt = con.prepareStatement("UPDATE user_setting_server SET " + attribute.getColumnName() + "=? WHERE cid=? AND user=?");
@@ -553,13 +540,48 @@ public class ServerUserSetting {
         }
     }
 
-    private static <T> void insertAttribute(final int cid, final int user, final Attribute<T> attribute, final T value, final Connection con) throws SettingException {
+    private <T> void insertAttribute(final int cid, final int user, final Attribute<T> attribute, final T value, final Connection con) throws SettingException {
         PreparedStatement stmt = null;
         try {
-            stmt = con.prepareStatement("INSERT INTO user_setting_server (" + attribute.getColumnName() + ",cid,user) VALUES (?,?,?)");
-            attribute.setAttribute(stmt, value);
-            stmt.setInt(2, cid);
-            stmt.setInt(3, user);
+            int pos = 2;
+            {
+                final String start = "INSERT INTO user_setting_server (" + attribute.getColumnName();
+                if (CONTACT_COLLECT_ON_MAIL_ACCESS.equals(attribute)) {
+                    stmt = con.prepareStatement(start + ",contactCollectOnMailTransport,cid,user) VALUES (?,?,?,?)");
+                    attribute.setAttribute(stmt, value);
+                    /*
+                     * As configured
+                     */
+                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    final boolean b = null == service ? false : service.getBoolProperty("com.openexchange.user.contactCollectOnMailTransport", false);
+                    stmt.setBoolean(pos++, b);
+                } else if (CONTACT_COLLECT_ON_MAIL_TRANSPORT.equals(attribute)) {
+                    stmt = con.prepareStatement(start + ",contactCollectOnMailAccess,cid,user) VALUES (?,?,?,?)");
+                    attribute.setAttribute(stmt, value);
+                    /*
+                     * As configured
+                     */
+                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    final boolean b = null == service ? false : service.getBoolProperty("com.openexchange.user.contactCollectOnMailAccess", false);
+                    stmt.setBoolean(pos++, b);
+                } else {
+                    stmt = con.prepareStatement(start + ",contactCollectOnMailAccess,contactCollectOnMailTransport,cid,user) VALUES (?,?,?,?,?)");
+                    attribute.setAttribute(stmt, value);
+                    /*
+                     * As configured
+                     */
+                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    boolean b = null == service ? false : service.getBoolProperty("com.openexchange.user.contactCollectOnMailAccess", false);
+                    stmt.setBoolean(pos++, b);
+                    b = null == service ? false : service.getBoolProperty("com.openexchange.user.contactCollectOnMailTransport", false);
+                    stmt.setBoolean(pos++, b);
+                }
+            }
+            stmt.setInt(pos++, cid);
+            stmt.setInt(pos, user);
+            if (DEBUG) {
+                LOG.debug("INSERTing user settings: " + DBUtils.getStatementString(stmt));
+            }
             stmt.execute();
         } catch (final SQLException e) {
             throw new SettingException(SettingException.Code.SQL_ERROR, e);
@@ -568,7 +590,7 @@ public class ServerUserSetting {
         }
     }
 
-    public static void deleteEntry(final int cid, final int user, final Connection con) throws SettingException {
+    private void deleteEntry(final int cid, final int user, final Connection con) throws SettingException {
         PreparedStatement stmt = null;
         final ResultSet rs = null;
         try {
@@ -583,7 +605,7 @@ public class ServerUserSetting {
         }
     }
 
-    private static boolean hasEntry(final int cid, final int user, final Connection con) throws SettingException {
+    private boolean hasEntry(final int cid, final int user, final Connection con) throws SettingException {
         boolean retval = false;
         PreparedStatement stmt = null;
         ResultSet rs = null;
