@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,7 +74,7 @@ public final class UserSettingServerDeleteListener implements DeleteListener {
     public void deletePerformed(final DeleteEvent event, final Connection readCon, final Connection writeCon) throws DeleteFailedException {
         if (DeleteEvent.TYPE_USER == event.getType()) {
             try {
-                ServerUserSetting.deleteEntry(event.getContext().getContextId(), event.getId(), writeCon);
+                ServerUserSetting.getInstance(writeCon).deleteEntry(event.getContext().getContextId(), event.getId());
             } catch (final SettingException e) {
                 throw new DeleteFailedException(e);
             }
