@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,9 +61,10 @@ import org.apache.commons.logging.LogFactory;
  */
 public final class Constants {
 
-    private static final Log LOG = LogFactory.getLog(Constants.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Constants.class));
 
     public static final ObjectName REPORTING_NAME = initReportingName();
+    public static final ObjectName OXTENDER_MONITOR_NAME = initOxtenderMonitorName();
 
     /**
      * Prevent instantiation.
@@ -83,4 +84,16 @@ public final class Constants {
         }
         return retval;
     }
+
+    private static final ObjectName initOxtenderMonitorName() {
+        ObjectName retval = null;
+        try {
+            retval = new ObjectName("com.openexchange.reporting", "name", "Login Counter");
+        } catch (MalformedObjectNameException e) {
+            LOG.error(e.getMessage(), e);
+        } catch (NullPointerException e) {
+            LOG.error(e.getMessage(), e);
+        }
+        return retval;
+    }
 }
