@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,13 +63,13 @@ import com.openexchange.server.Initialization;
  */
 public class ReportingInit implements Initialization {
 
-    private static final Log LOG = LogFactory.getLog(ReportingInit.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ReportingInit.class));
 
     private final ManagementService managementService;
 
     /**
      * Default constructor.
-     * @param managementService 
+     * @param managementService
      */
     public ReportingInit(ManagementService managementService) {
         super();
@@ -79,6 +79,7 @@ public class ReportingInit implements Initialization {
     public void start() {
         try {
             managementService.registerMBean(Constants.REPORTING_NAME, new ReportingMBean());
+            managementService.registerMBean(Constants.OXTENDER_MONITOR_NAME, new LoginCounter());
         } catch (ManagementException e) {
             LOG.error(e.getMessage(), e);
         }
@@ -87,6 +88,7 @@ public class ReportingInit implements Initialization {
     public void stop() {
         try {
             managementService.unregisterMBean(Constants.REPORTING_NAME);
+            managementService.unregisterMBean(Constants.OXTENDER_MONITOR_NAME);
         } catch (ManagementException e) {
             LOG.error(e.getMessage(), e);
         }
