@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,8 +61,8 @@ import java.util.List;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.LdapException;
-import com.openexchange.groupware.ldap.LdapUtility;
 import com.openexchange.groupware.ldap.LdapException.Code;
+import com.openexchange.groupware.ldap.LdapUtility;
 import com.openexchange.resource.Resource;
 import com.openexchange.resource.ResourceException;
 import com.openexchange.resource.ResourceGroup;
@@ -83,7 +83,7 @@ public class RdbResourceStorage extends ResourceStorage {
 
     /**
      * Default constructor.
-     * 
+     *
      * @param context Context.
      */
     RdbResourceStorage() {
@@ -142,7 +142,7 @@ public class RdbResourceStorage extends ResourceStorage {
 
     /**
      * Reads multiple resource groups from the database.
-     * 
+     *
      * @param groupId array with unique identifier of the resource groups to read.
      * @return an array with the read resource groups.
      * @throws LdapException if an error occurs.
@@ -193,7 +193,7 @@ public class RdbResourceStorage extends ResourceStorage {
 
     /**
      * Reads the member of a resource group.
-     * 
+     *
      * @param con readable database connection.
      * @param groupId unique identifier of the resource group.
      * @return an array with all unique identifier of resource that are member of the resource group.
@@ -240,7 +240,7 @@ public class RdbResourceStorage extends ResourceStorage {
 
     /**
      * Reads multiple resources from the database.
-     * 
+     *
      * @param resourceId array with unique identifier of the resources to read.
      * @return an array with the read resources.
      * @throws LdapException if an error occurs.
@@ -317,7 +317,7 @@ public class RdbResourceStorage extends ResourceStorage {
         return groups.toArray(new ResourceGroup[groups.size()]);
     }
 
-    private static final String SQL_SELECT_RESOURCE2 = "SELECT id,identifier,displayName,mail,available,description,lastModified " + "FROM resource WHERE cid = ? AND (identifier LIKE ? OR displayName LIKE ?)";
+    private static final String SQL_SELECT_RESOURCE2 = "SELECT id,identifier,displayName,mail,available,description,lastModified FROM resource WHERE cid = ? AND (identifier LIKE ? OR displayName LIKE ?)";
 
     @Override
     public Resource[] searchResources(final String pattern, final Context context) throws LdapException {
@@ -348,7 +348,7 @@ public class RdbResourceStorage extends ResourceStorage {
         return resources.toArray(new Resource[resources.size()]);
     }
 
-    private static final String SQL_SELECT_RESOURCE4 = "SELECT id,identifier,displayName,mail,available,description,lastModified " + "FROM resource WHERE cid = ? AND mail LIKE ?";
+    private static final String SQL_SELECT_RESOURCE4 = "SELECT id,identifier,displayName,mail,available,description,lastModified FROM resource WHERE cid = ? AND mail LIKE ?";
 
     @Override
     public Resource[] searchResourcesByMail(final String pattern, final Context context) throws LdapException {
@@ -379,9 +379,19 @@ public class RdbResourceStorage extends ResourceStorage {
     }
 
     private static final String SQL_SELECT_RESOURCE = "SELECT id,identifier,displayName,mail,available,description,lastModified " + "FROM resource WHERE cid = ? AND lastModified > ?";
+    private static final String SQL_SELECT_DELETED_RESOURCE = "SELECT id,identifier,displayName,mail,available,description,lastModified " + "FROM del_resource WHERE cid = ? AND lastModified > ?";
 
     @Override
     public Resource[] listModified(final Date modifiedSince, final Context context) throws LdapException {
+        return listModifiedOrDeleted(modifiedSince, context, SQL_SELECT_RESOURCE);
+    }
+
+    @Override
+    public Resource[] listDeleted(final Date modifiedSince, final Context context) throws LdapException {
+        return listModifiedOrDeleted(modifiedSince, context, SQL_SELECT_DELETED_RESOURCE);
+    }
+
+    private Resource[] listModifiedOrDeleted(final Date modifiedSince, final Context context, String statement) throws LdapException {
         Connection con = null;
         try {
             con = DBPool.pickup(context);
@@ -392,7 +402,7 @@ public class RdbResourceStorage extends ResourceStorage {
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
-            stmt = con.prepareStatement(SQL_SELECT_RESOURCE);
+            stmt = con.prepareStatement(statement);
             stmt.setLong(1, context.getContextId());
             stmt.setLong(2, modifiedSince.getTime());
             result = stmt.executeQuery();
@@ -410,7 +420,7 @@ public class RdbResourceStorage extends ResourceStorage {
 
     /**
      * Creates a newly allocated {@link Resource resource} from current result set's entry.
-     * 
+     *
      * @param result The result set with its cursor properly set
      * @return A newly allocated {@link Resource resource} from current result set's entry
      * @throws SQLException If an SQL error occurs
