@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,7 +60,7 @@ import com.openexchange.resource.storage.ResourceStorage;
 
 /**
  * {@link ResourceServiceImpl}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ResourceServiceImpl implements ResourceService {
@@ -74,7 +74,7 @@ public final class ResourceServiceImpl implements ResourceService {
 
     /**
      * Gets the singleton instance of {@link ResourceServiceImpl}
-     * 
+     *
      * @return The singleton instance of {@link ResourceServiceImpl}
      */
     public static ResourceServiceImpl getInstance() {
@@ -116,6 +116,14 @@ public final class ResourceServiceImpl implements ResourceService {
         }
     }
 
+    public Resource[] listDeleted(final Date modifiedSince, final Context context) throws ResourceException {
+        try {
+            return ResourceStorage.getInstance().listDeleted(modifiedSince, context);
+        } catch (final LdapException e) {
+            throw new ResourceException(e);
+        }
+    }
+
     public Resource[] searchResources(final String pattern, final Context context) throws ResourceException {
         try {
             return ResourceStorage.getInstance().searchResources(pattern, context);
