@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,49 +50,47 @@
 package com.openexchange.resource.internal;
 
 import java.util.concurrent.atomic.AtomicBoolean;
-import com.openexchange.groupware.AbstractOXException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import com.openexchange.resource.ResourceService;
 import com.openexchange.resource.storage.ResourceStorage;
 import com.openexchange.server.Initialization;
+import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * {@link ResourceStorageInit} - The {@link Initialization initialization} for resource storage.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ResourceStorageInit implements Initialization {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ResourceStorageInit.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ResourceStorageInit.class));
 
     private static final ResourceStorageInit SINGLETON = new ResourceStorageInit();
 
     private static final AtomicBoolean initialized = new AtomicBoolean();
 
-    /**
-     * @return The singleton instance.
-     */
     public static ResourceStorageInit getInstance() {
         return SINGLETON;
     }
 
-    /**
-     * Initializes a new {@link ResourceStorageInit}
-     */
     private ResourceStorageInit() {
         super();
     }
 
-    public void start() throws AbstractOXException {
+    public void start() {
         if (!initialized.compareAndSet(false, true)) {
             LOG.warn("Duplicate resource storage start-up");
         }
         ResourceStorage.setInstance(new RdbResourceStorage());
+        ServerServiceRegistry.getInstance().addService(ResourceService.class, ResourceServiceImpl.getInstance());
     }
 
-    public void stop() throws AbstractOXException {
+    public void stop() {
         if (!initialized.compareAndSet(true, false)) {
             LOG.warn("Duplicate resource storage shut-down");
         }
+        ServerServiceRegistry.getInstance().removeService(ResourceService.class);
         ResourceStorage.releaseInstance();
     }
-
 }
