@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,12 +66,12 @@ import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link ResourceUpdate} - Performs update of a {@link Resource resource}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ResourceUpdate {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ResourceUpdate.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ResourceUpdate.class));
 
     private final User user;
 
@@ -87,7 +87,7 @@ public final class ResourceUpdate {
 
     /**
      * Initializes a new {@link ResourceUpdate}
-     * 
+     *
      * @param ctx The context
      * @param resource The resource to update
      * @param clientLastModified The client last-modified timestamp; may be <code>null</code> to omit timestamp comparison
@@ -119,7 +119,7 @@ public final class ResourceUpdate {
      * <li>Then the transaction-bounded update in storage takes place</li>
      * <li>At last, the update is propagated to system (cache invalidation, etc.)</li>
      * </ol>
-     * 
+     *
      * @throws ResourceException If update fails
      */
     void perform() throws ResourceException {
@@ -131,7 +131,7 @@ public final class ResourceUpdate {
 
     /**
      * Checks permission
-     * 
+     *
      * @throws ResourceException If permission is denied
      */
     private void allow() throws ResourceException {
@@ -154,7 +154,7 @@ public final class ResourceUpdate {
     /**
      * Checks permission: Invoke {@link BundleAccessSecurityService#checkPermission(String[], String) checkPermission()} on
      * {@link BundleAccessSecurityService security service}
-     * 
+     *
      * @throws ResourceException If permission is not granted
      */
     // private void checkBySecurityService() throws ResourceException {
@@ -174,7 +174,7 @@ public final class ResourceUpdate {
     // }
     /**
      * This method performs all necessary checks before updating a resource.
-     * 
+     *
      * @throws ResourceException If a problem was detected during checks.
      */
     private void check() throws ResourceException {
@@ -236,7 +236,7 @@ public final class ResourceUpdate {
 
     /**
      * Updates all data for the resource in database.
-     * 
+     *
      * @throws ResourceException
      */
     private void update() throws ResourceException {
@@ -272,7 +272,7 @@ public final class ResourceUpdate {
 
     /**
      * This method calls the plain update methods.
-     * 
+     *
      * @param con writable database connection in transaction or not.
      * @throws ResourceException if some problem occurs.
      */
