@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,13 +54,18 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+
 import com.openexchange.search.internal.terms.EqualsTerm;
+import com.openexchange.search.internal.terms.GreaterOrEqualTerm;
 import com.openexchange.search.internal.terms.GreaterThanTerm;
+import com.openexchange.search.internal.terms.IsNullTerm;
+import com.openexchange.search.internal.terms.LessOrEqualTerm;
 import com.openexchange.search.internal.terms.LessThanTerm;
+import com.openexchange.search.internal.terms.NotEqualTerm;
 
 /**
  * {@link SingleSearchTerm} - A single search term; e.g. <i>equals</i>.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class SingleSearchTerm implements SearchTerm<Operand<?>> {
@@ -78,10 +83,7 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
         /**
          * Equals comparison
          */
-        EQUALS("equals", 2, new InstanceCreator() {
-
-            private static final long serialVersionUID = -7337346107116884060L;
-
+        EQUALS("=", 2, "=", OperationPosition.BETWEEN, "%s=%s", new InstanceCreator() {
             public SingleSearchTerm newInstance() {
                 return new EqualsTerm();
             }
@@ -89,10 +91,7 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
         /**
          * Less-than comparison
          */
-        LESS_THAN("lt", 2, new InstanceCreator() {
-
-            private static final long serialVersionUID = 3045641432242061311L;
-
+        LESS_THAN("<", 2, "<", OperationPosition.BETWEEN, "&(%1$s<=%2$s)(!(%1$s=%2$s))", new InstanceCreator() {
             public SingleSearchTerm newInstance() {
                 return new LessThanTerm();
             }
@@ -100,25 +99,67 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
         /**
          * Greater-than comparison
          */
-        GREATER_THAN("gt", 2, new InstanceCreator() {
-
-            private static final long serialVersionUID = 8960232001776390636L;
-
+        GREATER_THAN(">", 2, ">", OperationPosition.BETWEEN, "&(%1$s>=%2$s)(!(%1$s=%2$s))", new InstanceCreator() {
             public SingleSearchTerm newInstance() {
                 return new GreaterThanTerm();
             }
-        });
+        }),
+        /**
+         * Not-equal comparison
+         */
+        NOT_EQUALS("<>", 2, "<>", OperationPosition.BETWEEN, "!(%s=%s)", new InstanceCreator() {
+            public SingleSearchTerm newInstance() {
+                return new NotEqualTerm();
+            }
+        }),
+        /**
+         * Greater-than or equal comparison
+         */
+        GREATER_OR_EQUAL(">=", 2, ">=", OperationPosition.BETWEEN, "%s>=%s", new InstanceCreator() {
+            public SingleSearchTerm newInstance() {
+                return new GreaterOrEqualTerm();
+            }
+        }),
+        /**
+         * Less-than or equal comparison
+         */
+        LESS_OR_EQUAL("<=", 2, "<=", OperationPosition.BETWEEN, "%s<=%s", new InstanceCreator() {
+            public SingleSearchTerm newInstance() {
+                return new LessOrEqualTerm();
+            }
+        }),
+        /**
+         * is null check
+         */
+        ISNULL("isNull", 1, "IS NULL", OperationPosition.AFTER, "!(%s=*)", new InstanceCreator() {
+          public SingleSearchTerm newInstance() {
+              return new IsNullTerm();
+          }
+      })
+        ;
 
         private final String str;
 
+        private final String sql;
+
+        private String ldap;
+
         private final InstanceCreator creator;
 
         private final int maxOperands;
 
-        private SingleOperation(final String str, final int maxOperands, final InstanceCreator creator) {
+		private OperationPosition sqlPos;
+
+		private OperationPosition ldapPos;
+
+
+        private SingleOperation(final String str, final int maxOperands, final String sql, final OperationPosition sqlPos, final String ldap, final InstanceCreator creator) {
             this.str = str;
             this.maxOperands = maxOperands;
             this.creator = creator;
+            this.sql = sql;
+            this.ldap = ldap;
+            this.sqlPos = sqlPos;
         }
 
         public String getOperation() {
@@ -131,7 +172,7 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
         /**
          * Gets a new single search term for this operation.
-         * 
+         *
          * @return A new single search term for this operation.
          */
         public SingleSearchTerm newInstance() {
@@ -140,13 +181,17 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
         /**
          * Gets the max. number of operands.
-         * 
+         *
          * @return The max. number of operands.
          */
         public int getMaxOperands() {
             return maxOperands;
         }
 
+        public OperationPosition getSqlPosition() {
+        	return sqlPos;
+        }
+
         private static final transient Map<String, SingleOperation> map;
 
         static {
@@ -160,7 +205,7 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
         /**
          * Gets the single operation corresponding to specified operation string.
-         * 
+         *
          * @param operation The operation string.
          * @return The operation corresponding to specified operation string or <code>null</code>.
          */
@@ -180,13 +225,25 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
         /**
          * Checks if specified operation string is a single operation.
-         * 
+         *
          * @param operation The operation string
          * @return <code>true</code> if specified operation string is a single operation; otherwise <code>false</code>
          */
         public static boolean containsOperation(final String operation) {
             return (null != getSingleOperation(operation));
         }
+
+		public String getSqlRepresentation() {
+			return sql;
+		}
+
+		public String getLdapRepresentation() {
+			return ldap;
+		}
+
+		public com.openexchange.search.SearchTerm.OperationPosition getLdapPosition() {
+			return ldapPos;
+		}
     }
 
     /**
@@ -206,20 +263,20 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
     /**
      * Initializes a new {@link SingleSearchTerm} with default capacity (4).
-     * 
+     *
      * @param operation The operation
      */
-    protected SingleSearchTerm(final SingleOperation operation) {
+    public SingleSearchTerm(final SingleOperation operation) {
         this(operation, DEFAULT_CAPACITY);
     }
 
     /**
      * Initializes a new {@link SingleSearchTerm}.
-     * 
+     *
      * @param operation The operation
      * @param initialCapacity The initial capacity
      */
-    protected SingleSearchTerm(final SingleOperation operation, final int initialCapacity) {
+    public SingleSearchTerm(final SingleOperation operation, final int initialCapacity) {
         super();
         this.operation = operation;
         operands = new ArrayList<Operand<?>>(initialCapacity);
@@ -235,7 +292,7 @@ public class SingleSearchTerm implements SearchTerm<Operand<?>> {
 
     /**
      * Adds specified operand to this search term.
-     * 
+     *
      * @param operand The operand to add.
      */
     public void addOperand(final Operand<?> operand) {
