@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import com.openexchange.server.Initialization;
  * {@link Starter} - Starter for <a href="www.open-xchange.com">Open-Xchange</a> server.
  * <p>
  * All necessary initializations for a proper system start-up take place.
- * 
+ *
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -91,14 +91,6 @@ public class Starter implements Initialization {
      * Initialization for custom charset provider
      */
     new com.openexchange.charset.CustomCharsetProviderInit(),
-    /**
-     * Starts AJP server
-     */
-    com.openexchange.groupware.impl.BackendServicesInit.getInstance(),
-    /**
-     * Starts HTTP managers
-     */
-    com.openexchange.tools.servlet.http.HttpManagersInit.getInstance(),
     /**
      * Setup of ContextStorage and LoginInfo.
      */
@@ -172,17 +164,14 @@ public class Starter implements Initialization {
      * Initializes the Link Attachment Listener
      */
     new com.openexchange.groupware.links.LinkInit(),
-    /**
-     * Image registry initialization
-     */
-    new com.openexchange.image.internal.ImageRegistryInit(),
     /**
      * Managed file initialization
      */
     new com.openexchange.filemanagement.internal.ManagedFileInitialization(),
     new com.openexchange.mailaccount.internal.MailAccountStorageInit(),
-    new com.openexchange.mailaccount.servlet.MailAccountServletInit(),
-    new com.openexchange.multiple.internal.MultipleHandlerInit() };
+    new com.openexchange.mailaccount.json.init.MailAccountServletInit(),
+    new com.openexchange.multiple.internal.MultipleHandlerInit(),
+    new com.openexchange.groupware.impl.id.IDGeneratorInit() };
 
     /**
      * This contains the components that must be started if the admin uses APIs of the server.
@@ -250,12 +239,13 @@ public class Starter implements Initialization {
      */
     com.openexchange.groupware.downgrade.DowngradeRegistryInit.getInstance(),
     /**
-     * Image registry initialization
+     * Managed file initialization
      */
-    new com.openexchange.image.internal.ImageRegistryInit(),
-    new com.openexchange.mailaccount.internal.MailAccountStorageInit() };
+    new com.openexchange.filemanagement.internal.ManagedFileInitialization(),
+    new com.openexchange.mailaccount.internal.MailAccountStorageInit(),
+    new com.openexchange.groupware.impl.id.IDGeneratorInit() };
 
-    private static final Log LOG = LogFactory.getLog(Starter.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Starter.class));
 
     private final Stack<Initialization> started;
 
