@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,16 +66,17 @@ import com.openexchange.tools.service.SpecificServiceChooser;
  */
 public abstract class AttachmentPluginsTracker<T> extends ModuleSpecificServiceTracker<T> {
 
-    private static final Log LOG = LogFactory.getLog(AttachmentPluginsTracker.class);
-    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AttachmentPluginsTracker.class));
+
     public AttachmentPluginsTracker(BundleContext context, Class<T> toTrack) {
         super(context, toTrack);
     }
-    
+
+    @Override
     public void removedService(int module, T tracked, ServiceReference reference) {
         Integer contextId = getInt(reference, Constants.OX_OVERRIDE_CONTEXT);
         Integer folderId = getInt(reference, Constants.OX_OVERRIDE_FOLDER);
-    
+
         SpecificServiceChooser<T> chooser = getChooser(module);
         if(chooser == null) {
             LOG.warn("Can't register services for module "+module+" in tracker "+getClass().getName());
@@ -96,8 +97,9 @@ public abstract class AttachmentPluginsTracker<T> extends ModuleSpecificServiceT
             chooser.removeForFolder(tracked, folderId);
         }
     }
-    
 
+
+    @Override
     public void addingService(int module, T tracked, ServiceReference reference) {
         Integer contextId = getInt(reference, Constants.OX_OVERRIDE_CONTEXT);
         Integer folderId = getInt(reference, Constants.OX_OVERRIDE_FOLDER);
@@ -126,20 +128,21 @@ public abstract class AttachmentPluginsTracker<T> extends ModuleSpecificServiceT
             if(folderId != null) {
                 chooser.registerForFolder(tracked, ranking, folderId);
             }
-           
+
         } catch (ServicePriorityConflictException x) {
             LOG.error("Could not register service "+tracked+" with contextId: "+contextId+" for folder: "+folderId+" with ranking: "+ranking+". A conflicting service has already been registered for the combination");
         }
     }
 
+    @Override
     public void modifiedService(int module, T tracked, ServiceReference reference) {
-        
+
     }
 
 
     public abstract SpecificServiceChooser<T> getChooser(int module);
 
-    
+
     protected Integer getInt(ServiceReference reference, String key) {
         Object property = reference.getProperty(key);
         if(property == null) {
