@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,61 +58,38 @@ import com.openexchange.authentication.AuthenticationService;
 import com.openexchange.authentication.service.Authentication;
 
 /**
- * Authentication service tracker putting the service into the static
- * authentication class.
+ * Authentication service tracker putting the service into the static authentication class.
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public class AuthenticationCustomizer implements ServiceTrackerCustomizer {
 
-    /**
-     * Logger.
-     */
-    private static final Log LOG = LogFactory.getLog(AuthenticationCustomizer.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AuthenticationCustomizer.class));
 
-    /**
-     * Reference to the bundle context.
-     */
     private final BundleContext context;
 
-    /**
-     * Default constructor.
-     * @param context the bundle context.
-     */
     public AuthenticationCustomizer(final BundleContext context) {
         super();
         this.context = context;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public Object addingService(final ServiceReference reference) {
-        final AuthenticationService auth = (AuthenticationService) context
-            .getService(reference);
-        if (null == Authentication.getService()) {
-            Authentication.setService(auth);
-        } else {
-            LOG.error("Several authentication services found. Remove all except one!");
+        final AuthenticationService auth = (AuthenticationService) context.getService(reference);
+        if (Authentication.setService(auth)) {
+            return auth;
         }
-        return auth;
+        context.ungetService(reference);
+        LOG.error("Several authentication services found. Remove all except one!");
+        return null;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void modifiedService(final ServiceReference reference,
-        final Object service) {
+    public void modifiedService(final ServiceReference reference, final Object service) {
         // Nothing to do.
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void removedService(final ServiceReference reference,
-        final Object service) {
+    public void removedService(final ServiceReference reference, final Object service) {
         final AuthenticationService auth = (AuthenticationService) service;
-        if (Authentication.getService() == auth) {
-            Authentication.setService(null);
+        if (!Authentication.dropService(auth)) {
+            LOG.error("Removed authentication services was not active!");
         }
         context.ungetService(reference);
     }
