@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,43 +49,39 @@
 
 package com.openexchange.server.osgi;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.openexchange.folderstorage.internal.FolderI18nNamesServiceImpl;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.server.services.I18nServices;
 
 public class I18nServiceListener implements ServiceTrackerCustomizer{
 
-    private static final Log LOG = LogFactory.getLog(I18nServiceListener.class);
-
     private final BundleContext context;
-
     private final I18nServices services = I18nServices.getInstance();
 
-    public I18nServiceListener(BundleContext context) {
+    public I18nServiceListener(final BundleContext context) {
         super();
         this.context = context;
     }
 
-    public Object addingService(ServiceReference reference) {
+    public Object addingService(final ServiceReference reference) {
         final I18nService i18n = (I18nService) context.getService(reference);
-        LOG.info("Adding service I18nService for locale " + i18n.getLocale());
-        services.addService(i18n.getLocale(), i18n);
+        services.addService(i18n);
+        FolderI18nNamesServiceImpl.getInstance().addService(i18n);
         return i18n;
     }
 
-    public void modifiedService(ServiceReference reference, Object service) {
+    public void modifiedService(final ServiceReference reference, final Object service) {
         // Nothing to do.
     }
 
-    public void removedService(ServiceReference reference, Object service) {
+    public void removedService(final ServiceReference reference, final Object service) {
         try {
-            final I18nService i18n = (I18nService) service;
-            LOG.info("Removing service I18nService for locale " + i18n.getLocale());
-            services.removeService(i18n.getLocale(), i18n);
+            final I18nService i18nService = (I18nService) service;
+            services.removeService(i18nService);
+            FolderI18nNamesServiceImpl.getInstance().removeService(i18nService);
         } finally {
             context.ungetService(reference);
         }
