@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,8 +56,6 @@ import javax.management.ObjectName;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.BundleContext;
-import com.openexchange.ajp13.monitoring.AJPv13Monitors;
-import com.openexchange.consistency.ConsistencyInit;
 import com.openexchange.groupware.update.tools.UpdateTaskMBeanInit;
 import com.openexchange.management.ManagementService;
 import com.openexchange.report.internal.ReportingInit;
@@ -67,18 +65,18 @@ import com.openexchange.tools.oxfolder.OXFolderProperties;
 
 /**
  * {@link ManagementServiceTracker}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ManagementServiceTracker extends BundleServiceTracker<ManagementService> {
 
-    private static final Log LOG = LogFactory.getLog(ManagementServiceTracker.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class));
 
     private ObjectName gadObjectName;
 
     /**
      * Initializes a new {@link ManagementServiceTracker}
-     * 
+     *
      * @param context The bundle context
      */
     public ManagementServiceTracker(final BundleContext context) {
@@ -96,14 +94,7 @@ public final class ManagementServiceTracker extends BundleServiceTracker<Managem
              * Add all mbeans since management service is now available
              */
             gadObjectName = OXFolderProperties.registerRestorerMBean(managementService);
-            managementService.registerMBean(
-                getObjectName(AJPv13Monitors.AJP_MONITOR_SERVER_THREADS.getClass().getName(), true),
-                AJPv13Monitors.AJP_MONITOR_SERVER_THREADS);
-            managementService.registerMBean(
-                getObjectName(AJPv13Monitors.getListenerMonitor().getClass().getName(), true),
-                AJPv13Monitors.getListenerMonitor());
             managementService.registerMBean(getObjectName(mailInterfaceMonitor.getClass().getName(), true), mailInterfaceMonitor);
-            new ConsistencyInit().start();
         } catch (final MalformedObjectNameException e) {
             LOG.error(e.getMessage(), e);
         } catch (final NullPointerException e) {
@@ -123,10 +114,7 @@ public final class ManagementServiceTracker extends BundleServiceTracker<Managem
             /*
              * Remove all mbeans since management service now disappears
              */
-            new ConsistencyInit().stop();
             managementService.unregisterMBean(getObjectName(mailInterfaceMonitor.getClass().getName(), true));
-            managementService.unregisterMBean(getObjectName(AJPv13Monitors.getListenerMonitor().getClass().getName(), true));
-            managementService.unregisterMBean(getObjectName(AJPv13Monitors.AJP_MONITOR_SERVER_THREADS.getClass().getName(), true));
             OXFolderProperties.unregisterRestorerMBean(gadObjectName, managementService);
         } catch (final MalformedObjectNameException e) {
             LOG.error(e.getMessage(), e);
