@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,17 +55,23 @@ import java.util.Dictionary;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.concurrent.atomic.AtomicBoolean;
+import javax.servlet.ServletException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.json.JSONObject;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
+import org.osgi.framework.ServiceReference;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.event.EventAdmin;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import org.osgi.service.http.HttpService;
+import org.osgi.service.http.NamespaceException;
 import org.osgi.util.tracker.ServiceTracker;
+import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.openexchange.ajax.Attachment;
 import com.openexchange.ajax.Folder;
 import com.openexchange.ajax.Infostore;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
@@ -78,6 +84,7 @@ import com.openexchange.cache.registry.CacheAvailabilityRegistry;
 import com.openexchange.caching.CacheService;
 import com.openexchange.charset.CustomCharsetProvider;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.configjump.ConfigJumpService;
 import com.openexchange.configjump.client.ConfigJump;
 import com.openexchange.contactcollector.ContactCollectorService;
@@ -85,10 +92,16 @@ import com.openexchange.context.ContextService;
 import com.openexchange.conversion.ConversionService;
 import com.openexchange.conversion.DataHandler;
 import com.openexchange.conversion.DataSource;
+import com.openexchange.counter.MailCounter;
+import com.openexchange.counter.MailIdleCounter;
+import com.openexchange.crypto.CryptoService;
 import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.data.conversion.ical.ICalParser;
 import com.openexchange.database.CreateTableService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.osgiservice.WhiteboardDBProvider;
+import com.openexchange.database.provider.DBPoolProvider;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.dataretention.DataRetentionService;
 import com.openexchange.event.EventFactoryService;
 import com.openexchange.event.impl.EventFactoryServiceImpl;
@@ -96,8 +109,12 @@ import com.openexchange.event.impl.EventQueue;
 import com.openexchange.event.impl.osgi.EventHandlerRegistration;
 import com.openexchange.event.impl.osgi.OSGiEventDispatcher;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
+import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
+import com.openexchange.file.storage.parse.FileMetadataParserService;
+import com.openexchange.file.storage.registry.FileStorageServiceRegistry;
 import com.openexchange.filemanagement.ManagedFileException;
 import com.openexchange.filemanagement.ManagedFileExceptionFactory;
+import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.folder.FolderDeleteListenerService;
 import com.openexchange.folder.FolderService;
 import com.openexchange.folder.internal.FolderDeleteListenerServiceTrackerCustomizer;
@@ -106,6 +123,7 @@ import com.openexchange.folderstorage.osgi.FolderStorageActivator;
 import com.openexchange.group.GroupService;
 import com.openexchange.group.internal.GroupServiceImpl;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.attach.AttachmentBase;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarAdministrationService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
@@ -119,18 +137,21 @@ import com.openexchange.groupware.contact.internal.ContactInterfaceDiscoveryServ
 import com.openexchange.groupware.datahandler.ICalInsertDataHandler;
 import com.openexchange.groupware.datahandler.ICalJSONDataHandler;
 import com.openexchange.groupware.delete.DeleteListener;
+import com.openexchange.groupware.generic.FolderUpdaterRegistry;
+import com.openexchange.groupware.impl.id.CreateIDSequenceTable;
 import com.openexchange.groupware.importexport.importers.ExtraneousSeriesMasterRecoveryParser;
 import com.openexchange.groupware.infostore.InfostoreFacade;
-import com.openexchange.groupware.infostore.osgi.InfostoreActivator;
+import com.openexchange.groupware.infostore.InfostoreSearchEngine;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.groupware.reminder.TargetService;
 import com.openexchange.groupware.settings.PreferencesItemService;
-import com.openexchange.groupware.tx.DBPoolProvider;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.osgi.WhiteboardDBProvider;
+import com.openexchange.html.HTMLService;
 import com.openexchange.i18n.I18nService;
-import com.openexchange.image.ImageService;
+import com.openexchange.id.IDGeneratorService;
+import com.openexchange.image.servlet.ImageServlet;
 import com.openexchange.login.LoginHandlerService;
+import com.openexchange.mail.MailCounterImpl;
+import com.openexchange.mail.MailIdleCounterImpl;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.cache.MailAccessCacheEventListener;
 import com.openexchange.mail.cache.MailSessionEventHandler;
@@ -158,11 +179,11 @@ import com.openexchange.passwordchange.PasswordChangeService;
 import com.openexchange.publish.PublicationTargetDiscoveryService;
 import com.openexchange.report.internal.LastLoginRecorder;
 import com.openexchange.resource.ResourceService;
-import com.openexchange.resource.internal.ResourceServiceImpl;
 import com.openexchange.search.SearchException;
 import com.openexchange.search.SearchExceptionFactory;
 import com.openexchange.search.SearchService;
 import com.openexchange.search.internal.SearchServiceImpl;
+import com.openexchange.secret.SecretEncryptionFactoryService;
 import com.openexchange.secret.SecretService;
 import com.openexchange.secret.osgi.tools.WhiteboardSecretService;
 import com.openexchange.server.impl.Starter;
@@ -173,13 +194,13 @@ import com.openexchange.server.osgiservice.WhiteboardFactoryService;
 import com.openexchange.server.services.ServerRequestHandlerRegistry;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.sessiond.SessiondService;
+import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.osgi.SpamHandlerServiceTracker;
 import com.openexchange.systemname.SystemNameService;
-import com.openexchange.systemname.internal.JVMRouteSystemNameImpl;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
-import com.openexchange.tools.servlet.http.osgi.HttpServiceImpl;
+import com.openexchange.tools.session.SessionHolder;
 import com.openexchange.user.UserService;
 import com.openexchange.userconf.UserConfigurationService;
 import com.openexchange.userconf.internal.UserConfigurationServiceImpl;
@@ -188,12 +209,38 @@ import com.openexchange.xml.spring.SpringParser;
 
 /**
  * {@link ServerActivator} - The activator for server bundle.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ServerActivator extends DeferredActivator {
 
-    private static final Log LOG = LogFactory.getLog(ServerActivator.class);
+	private static final class ServiceAdderTrackerCustomizer implements ServiceTrackerCustomizer {
+
+        private final BundleContext context;
+
+        public ServiceAdderTrackerCustomizer(final BundleContext context) {
+            super();
+            this.context = context;
+        }
+
+        public void removedService(final ServiceReference reference, final Object service) {
+            ServerServiceRegistry.getInstance().removeService(FileMetadataParserService.class);
+            context.ungetService(reference);
+        }
+
+        public void modifiedService(final ServiceReference reference, final Object service) {
+            // Nope
+        }
+
+        public Object addingService(final ServiceReference reference) {
+            final Object service = context.getService(reference);
+            ServerServiceRegistry.getInstance().addService(FileMetadataParserService.class, service);
+            return service;
+        }
+    }
+
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServerActivator.class));
 
     /**
      * Bundle ID of admin.<br>
@@ -208,17 +255,53 @@ public final class ServerActivator extends DeferredActivator {
 
     private static final Class<?>[] NEEDED_SERVICES_ADMIN =
         {
-            ConfigurationService.class, CacheService.class, EventAdmin.class, TimerService.class, ThreadPoolService.class,
-            CalendarAdministrationService.class, CalendarCollectionService.class
+    		AppointmentSqlFactoryService.class,
+    		CacheService.class, 
+    		CalendarAdministrationService.class, 
+    		CalendarCollectionService.class, 
+            ConfigurationService.class, 
+            EventAdmin.class, 
+            ThreadPoolService.class,
+            TimerService.class
         };
 
     private static final Class<?>[] NEEDED_SERVICES_SERVER =
         {
-            ConfigurationService.class, CacheService.class, EventAdmin.class, SessiondService.class, SpringParser.class, JDOMParser.class,
-            TimerService.class, ThreadPoolService.class, CalendarAdministrationService.class, AppointmentSqlFactoryService.class,
-            CalendarCollectionService.class, TargetService.class, MessagingServiceRegistry.class
+	    	AppointmentSqlFactoryService.class,
+    		CacheService.class, 
+    		CalendarAdministrationService.class, 
+    		CalendarCollectionService.class, 
+            ConfigurationService.class, 
+            ConfigViewFactory.class,
+            CryptoService.class, 
+            EventAdmin.class, 
+            FileStorageServiceRegistry.class, 
+            HTMLService.class, 
+            HttpService.class, 
+            IDBasedFileAccessFactory.class,
+            FolderUpdaterRegistry.class, 
+            JDOMParser.class,
+            MessagingServiceRegistry.class, 
+            SessiondService.class,
+            SpringParser.class, 
+            SystemNameService.class, 
+            ThreadPoolService.class, 
+            TimerService.class, 
+            TargetService.class,
+            SecretEncryptionFactoryService.class
         };
 
+    private static volatile BundleContext CONTEXT;
+
+    /**
+     * Gets the bundle context.
+     *
+     * @return The bundle context or <code>null</code> if not started, yet
+     */
+    public static BundleContext getContext() {
+        return CONTEXT;
+    }
+
     private final List<ServiceRegistration> registrationList;
 
     private final List<ServiceTracker> serviceTrackerList;
@@ -303,6 +386,8 @@ public final class ServerActivator extends DeferredActivator {
 
     @Override
     protected void startBundle() throws Exception {
+        CONTEXT = context;
+        JSONObject.setMaxSize(getService(ConfigurationService.class).getIntProperty("com.openexchange.json.maxSize", 2500));
         // get version information from MANIFEST file
         final Dictionary<?, ?> headers = context.getBundle().getHeaders();
         Version.buildnumber = "Rev" + (String) headers.get("OXRevision");
@@ -363,13 +448,13 @@ public final class ServerActivator extends DeferredActivator {
         // ICal Parser
         serviceTrackerList.add(new ServiceTracker(context, ICalParser.class.getName(), new RegistryCustomizer<ICalParser>(
             context,
-            ICalParser.class){ 
-            
+            ICalParser.class){
+
             @Override
             protected ICalParser customize(final ICalParser service) {
                 return new ExtraneousSeriesMasterRecoveryParser(service, ServerServiceRegistry.getInstance());
             }
-            
+
         }));
 
         // ICal Emitter
@@ -392,8 +477,7 @@ public final class ServerActivator extends DeferredActivator {
             context,
             FolderDeleteListenerService.class.getName(),
             new FolderDeleteListenerServiceTrackerCustomizer(context)));
-        
-        
+
         /*
          * Register EventHandler
          */
@@ -466,9 +550,18 @@ public final class ServerActivator extends DeferredActivator {
                 new PublicationTargetDiscoveryServiceTrackerCustomizer(context)));
 
             // Folder Fields
-            
+
             serviceTrackerList.add(new ServiceTracker(context, AdditionalFolderField.class.getName(), new FolderFieldCollector(context, Folder.getAdditionalFields())));
-            
+
+            /*
+             * The FileMetadataParserService needs to be tracked by a separate service tracker instead of just adding the service to
+             * getNeededServices(), because publishing bundle needs the HttpService which is in turn provided by server
+             */
+            serviceTrackerList.add(new ServiceTracker(
+                context,
+                FileMetadataParserService.class.getName(),
+                new ServiceAdderTrackerCustomizer(context)));
+
             // Start up server the usual way
             starter.start();
         }
@@ -478,12 +571,17 @@ public final class ServerActivator extends DeferredActivator {
         }
         // Register server's services
         registrationList.add(context.registerService(CharsetProvider.class.getName(), new CustomCharsetProvider(), null));
-        registrationList.add(context.registerService(HttpService.class.getName(), new HttpServiceImpl(), null));
-        registrationList.add(context.registerService(GroupService.class.getName(), new GroupServiceImpl(), null));
-        registrationList.add(context.registerService(ResourceService.class.getName(), ResourceServiceImpl.getInstance(), null));
-        registrationList.add(context.registerService(UserService.class.getName(), ServerServiceRegistry.getInstance().getService(
-            UserService.class,
-            true), null));
+        final GroupService groupService = new GroupServiceImpl();
+        registrationList.add(context.registerService(GroupService.class.getName(), groupService, null));
+        ServerServiceRegistry.getInstance().addService(GroupService.class, groupService);
+        registrationList.add(context.registerService(
+            ResourceService.class.getName(),
+            ServerServiceRegistry.getInstance().getService(ResourceService.class, true),
+            null));
+        registrationList.add(context.registerService(
+            UserService.class.getName(),
+            ServerServiceRegistry.getInstance().getService(UserService.class, true),
+            null));
         ServerServiceRegistry.getInstance().addService(UserConfigurationService.class, new UserConfigurationServiceImpl());
         registrationList.add(context.registerService(
             UserConfigurationService.class.getName(),
@@ -492,23 +590,28 @@ public final class ServerActivator extends DeferredActivator {
         registrationList.add(context.registerService(ContextService.class.getName(), ServerServiceRegistry.getInstance().getService(
             ContextService.class,
             true), null));
-        registrationList.add(context.registerService(SystemNameService.class.getName(), new JVMRouteSystemNameImpl(), null));
+        registrationList.add(context.registerService(ManagedFileManagement.class.getName(), ServerServiceRegistry.getInstance().getService(
+            ManagedFileManagement.class,
+            true), null));
+        // Register mail stuff
         {
             registrationList.add(context.registerService(MailService.class.getName(), new MailServiceImpl(), null));
-            final Dictionary<Object, Object> serviceProperties = new Hashtable<Object, Object>(1);
+            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
             serviceProperties.put(EventConstants.EVENT_TOPIC, MailSessionEventHandler.getTopics());
             registrationList.add(context.registerService(EventHandler.class.getName(), new MailSessionEventHandler(), serviceProperties));
+            registrationList.add(context.registerService(MailCounter.class.getName(), new MailCounterImpl(), null));
+            registrationList.add(context.registerService(MailIdleCounter.class.getName(), new MailIdleCounterImpl(), null));
         }
-        registrationList.add(context.registerService(ImageService.class.getName(), ServerServiceRegistry.getInstance().getService(
-            ImageService.class), null));
         // TODO: Register search service here until its encapsulated in an own bundle
         registrationList.add(context.registerService(SearchService.class.getName(), new SearchServiceImpl(), null));
         // TODO: Register server's login handler here until its encapsulated in an own bundle
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new MailLoginHandler(), null));
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new TransportLoginHandler(), null));
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new LastLoginRecorder(), null));
+//        registrationList.add(context.registerService(LoginHandlerService.class.getName(), new PasswordCrypter(), null));
         // Register table creation for mail account storage.
         registrationList.add(context.registerService(CreateTableService.class.getName(), new CreateMailAccountTables(), null));
+        registrationList.add(context.registerService(CreateTableService.class.getName(), new CreateIDSequenceTable(), null));
         // TODO: Register server's mail account storage here until its encapsulated in an own bundle
         registrationList.add(context.registerService(
             MailAccountStorageService.class.getName(),
@@ -519,98 +622,119 @@ public final class ServerActivator extends DeferredActivator {
             UnifiedINBOXManagement.class.getName(),
             ServerServiceRegistry.getInstance().getService(UnifiedINBOXManagement.class),
             null));
+        // Register ID generator
+        registrationList.add(context.registerService(
+            IDGeneratorService.class.getName(),
+            ServerServiceRegistry.getInstance().getService(IDGeneratorService.class),
+            null));
         /*
          * Register data sources
          */
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.mail.vcard");
             registrationList.add(context.registerService(DataSource.class.getName(), new VCardMailPartDataSource(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.mail.ical");
             registrationList.add(context.registerService(DataSource.class.getName(), new ICalMailPartDataSource(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.contact");
             registrationList.add(context.registerService(DataSource.class.getName(), new ContactDataSource(), props));
         }
         {
-            final InlineImageDataSource dataSource = new InlineImageDataSource();
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final InlineImageDataSource dataSource = InlineImageDataSource.getInstance();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, dataSource.getRegistrationName());
+            ImageServlet.addMapping(dataSource.getRegistrationName(), dataSource.getAlias());
             registrationList.add(context.registerService(DataSource.class.getName(), dataSource, props));
         }
         {
-            final ContactImageDataSource dataSource = new ContactImageDataSource();
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final ContactImageDataSource dataSource = ContactImageDataSource.getInstance();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, dataSource.getRegistrationName());
+            ImageServlet.addMapping(dataSource.getRegistrationName(), dataSource.getAlias());
             registrationList.add(context.registerService(DataSource.class.getName(), dataSource, props));
         }
         /*
          * Register data handlers
          */
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.contact");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ContactInsertDataHandler(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.contact.json");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ContactJSONDataHandler(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.ical");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ICalInsertDataHandler(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.ical.json");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ICalJSONDataHandler(), props));
         }
         {
-            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
             props.put(STR_IDENTIFIER, "com.openexchange.mail.vcard");
             registrationList.add(context.registerService(DataHandler.class.getName(), new VCardAttachMailDataHandler(), props));
         }
 
         // Register DBProvider
-
         registrationList.add(context.registerService(DBProvider.class.getName(), new DBPoolProvider(), null));
         registrationList.add(context.registerService(WhiteboardFactoryService.class.getName(), new WhiteboardDBProvider.Factory(), null));
 
         // Register Infostore
-
         registrationList.add(context.registerService(InfostoreFacade.class.getName(), Infostore.FACADE, null));
+        registrationList.add(context.registerService(InfostoreSearchEngine.class.getName(), Infostore.SEARCH_ENGINE, null));
+
+        // Register AttachmentBase
+        registrationList.add(context.registerService(AttachmentBase.class.getName(), Attachment.ATTACHMENT_BASE, null));
 
         // Register ContactSQL
-
         registrationList.add(context.registerService(ContactInterfaceFactory.class.getName(), new RdbContactInterfaceFactory(), null));
 
         // Register event factory service
         registrationList.add(context.registerService(EventFactoryService.class.getName(), new EventFactoryServiceImpl(), null));
 
         // Register folder service
-        registrationList.add(context.registerService(FolderService.class.getName(), new FolderServiceImpl(), null));
+        final FolderService folderService = new FolderServiceImpl();
+        registrationList.add(context.registerService(FolderService.class.getName(), folderService, null));
+        ServerServiceRegistry.getInstance().addService(FolderService.class, folderService);
 
         // Register contact interface discovery service
         final ContactInterfaceDiscoveryService cids = ContactInterfaceDiscoveryServiceImpl.getInstance();
         registrationList.add(context.registerService(ContactInterfaceDiscoveryService.class.getName(), cids, null));
         ServerServiceRegistry.getInstance().addService(ContactInterfaceDiscoveryService.class, cids);
-        
+
+        // Register SessionHolder
+        registrationList.add(context.registerService(SessionHolder.class.getName(), ThreadLocalSessionHolder.getInstance(), null));
+        ServerServiceRegistry.getInstance().addService(SessionHolder.class, ThreadLocalSessionHolder.getInstance());
+
         // Fake bundle start
         activators.add(new FolderStorageActivator());
         for (final BundleActivator activator : activators) {
             activator.start(context);
         }
-        
+
         ServerServiceRegistry.getInstance().addService(SecretService.class, secretService = new WhiteboardSecretService(context));
         secretService.open();
-        
+
+        /*
+         * Register servlets
+         */
+        if (!adminBundleInstalled.booleanValue()) {
+            registerServlets(getService(HttpService.class));
+        }
+
         /*
          * Register components
          */
@@ -678,17 +802,21 @@ public final class ServerActivator extends DeferredActivator {
              * Clear service registry
              */
             ServerServiceRegistry.getInstance().clearRegistry();
-            secretService.close();
+            if (null != secretService) {
+                secretService.close();
+                secretService = null;
+            }
         } finally {
             started.set(false);
             adminBundleInstalled = null;
+            CONTEXT = null;
         }
     }
 
     /**
      * Determines if admin bundle is installed by iterating context's bundles whose status is set to {@link Bundle#INSTALLED} or
      * {@link Bundle#ACTIVE} and whose symbolic name equals {@value #BUNDLE_ID_ADMIN}.
-     * 
+     *
      * @param context The bundle context
      * @return <code>true</code> if admin bundle is installed; otherwise <code>false</code>
      */
@@ -701,4 +829,38 @@ public final class ServerActivator extends DeferredActivator {
         return false;
     }
 
+    private void registerServlets(final HttpService http) throws ServletException, NamespaceException {
+        http.registerServlet("/infostore", new com.openexchange.webdav.Infostore(), null, null);
+        http.registerServlet("/servlet/webdav.ical", new com.openexchange.webdav.ical(), null, null);
+        http.registerServlet("/servlet/webdav.vcard", new com.openexchange.webdav.vcard(), null, null);
+        http.registerServlet("/servlet/webdav.version", new com.openexchange.webdav.version(), null, null);
+        http.registerServlet("/servlet/webdav.folders", new com.openexchange.webdav.folders(), null, null);
+        http.registerServlet("/servlet/webdav.calendar", new com.openexchange.webdav.calendar(), null, null);
+        http.registerServlet("/servlet/webdav.contacts", new com.openexchange.webdav.contacts(), null, null);
+        http.registerServlet("/servlet/webdav.tasks", new com.openexchange.webdav.tasks(), null, null);
+        http.registerServlet("/servlet/webdav.groupuser", new com.openexchange.webdav.groupuser(), null, null);
+        http.registerServlet("/servlet/webdav.attachments", new com.openexchange.webdav.attachments(), null, null);
+        http.registerServlet("/servlet/webdav.infostore", new com.openexchange.webdav.Infostore(), null, null);
+        http.registerServlet("/servlet/webdav.freebusy", new com.openexchange.webdav.freebusy(), null, null);
+        http.registerServlet("/ajax/tasks", new com.openexchange.ajax.Tasks(), null, null);
+        http.registerServlet("/ajax/contacts", new com.openexchange.ajax.Contact(), null, null);
+        http.registerServlet("/ajax/mail", new com.openexchange.ajax.Mail(), null, null);
+        http.registerServlet("/ajax/mail.attachment", new com.openexchange.ajax.MailAttachment(), null, null);
+        http.registerServlet("/ajax/calendar", new com.openexchange.ajax.Appointment(), null, null);
+        http.registerServlet("/ajax/config", new com.openexchange.ajax.ConfigMenu(), null, null);
+        http.registerServlet("/ajax/attachment", new com.openexchange.ajax.Attachment(), null, null);
+        http.registerServlet("/ajax/reminder", new com.openexchange.ajax.Reminder(), null, null);
+        http.registerServlet("/ajax/group", new com.openexchange.ajax.Group(), null, null);
+        http.registerServlet("/ajax/resource", new com.openexchange.ajax.Resource(), null, null);
+        http.registerServlet("/ajax/link", new com.openexchange.ajax.Link(), null, null);
+        http.registerServlet("/ajax/multiple", new com.openexchange.ajax.Multiple(), null, null);
+        http.registerServlet("/ajax/quota", new com.openexchange.ajax.Quota(), null, null);
+        http.registerServlet("/ajax/control", new com.openexchange.ajax.ConfigJump(), null, null);
+        http.registerServlet("/ajax/file", new com.openexchange.ajax.AJAXFile(), null, null);
+        http.registerServlet("/ajax/import", new com.openexchange.ajax.ImportServlet(), null, null);
+        http.registerServlet("/ajax/export", new com.openexchange.ajax.ExportServlet(), null, null);
+        http.registerServlet("/ajax/image", new com.openexchange.image.servlet.ImageServlet(), null, null);
+        http.registerServlet("/ajax/sync", new com.openexchange.ajax.SyncServlet(), null, null);
+    }
+
 }
