@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,17 +51,20 @@ package com.openexchange.sessiond.impl;
 
 import java.util.Date;
 import java.util.Map;
+import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
-import javax.mail.Session;
-import com.openexchange.groupware.ldap.Credentials;
+import java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.locks.ReentrantLock;
+import com.openexchange.java.util.UUIDs;
+import com.openexchange.session.Session;
 
 /**
  * {@link SessionObject} - Implements {@link com.openexchange.session.Session}.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.org">Sebastian Kauss</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public class SessionObject implements com.openexchange.session.Session {
+public class SessionObject implements Session {
 
     private final String sessionid;
 
@@ -91,21 +94,27 @@ public class SessionObject implements com.openexchange.session.Session {
 
     private int contextId;
 
-    private Credentials cred;
-
-    private Session mailSession;
-
     private String login;
 
     private String authId;
-    
+
     private String hash;
 
+    private String client;
+
     private final Map<String, Object> parameters;
 
-    public SessionObject(final String sessionid) {
-        this.sessionid = sessionid;
+    /**
+     * Initializes a new {@link SessionObject}.
+     *
+     * @param sessionId The session identifier
+     */
+    public SessionObject(final String sessionId) {
+        this.sessionid = sessionId;
         parameters = new ConcurrentHashMap<String, Object>();
+        parameters.put(PARAM_LOCK, new ReentrantLock());
+        parameters.put(PARAM_COUNTER, new AtomicInteger());
+        parameters.put(PARAM_ALTERNATIVE_ID, UUIDs.getUnformattedString(UUID.randomUUID()));
     }
 
     public void setUsername(final String username) {
@@ -196,14 +205,6 @@ public class SessionObject implements com.openexchange.session.Session {
         return contextId;
     }
 
-    public void setCredentials(final Credentials cred) {
-        this.cred = cred;
-    }
-
-    public Credentials getCredentials() {
-        return cred;
-    }
-
     public void setLoginName(final String loginName) {
         this.loginName = loginName;
     }
@@ -220,14 +221,6 @@ public class SessionObject implements com.openexchange.session.Session {
         return randomToken;
     }
 
-    public Session getMailSession() {
-        return mailSession;
-    }
-
-    public void setMailSession(final Session mailSession) {
-        this.mailSession = mailSession;
-    }
-
     public String getSecret() {
         return secret;
     }
@@ -245,6 +238,9 @@ public class SessionObject implements com.openexchange.session.Session {
     }
 
     public void setParameter(final String name, final Object value) {
+        if (PARAM_LOCK.equals(name)) {
+            return;
+        }
         if (null == value) {
             parameters.remove(name);
         } else {
@@ -268,16 +264,23 @@ public class SessionObject implements com.openexchange.session.Session {
         return authId;
     }
 
-    public void setAuthId(String authId) {
+    public void setAuthId(final String authId) {
         this.authId = authId;
     }
-    
-    
-    public void setHash(String hash) {
+
+    public void setHash(final String hash) {
         this.hash = hash;
     }
-    
+
     public String getHash() {
         return hash;
     }
+
+    public String getClient() {
+        return client;
+    }
+
+    public void setClient(final String client) {
+        this.client = client;
+    }
 }
