@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,12 +65,12 @@ import org.apache.commons.codec.binary.Base64;
  * {@link PasswordUtil} - Utility class to encrypt/decrypt passwords with a key aka password based encryption (PBE).
  * <p>
  * PBE is a form of symmetric encryption where the same key or password is used to encrypt and decrypt the file.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class PasswordUtil {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PasswordUtil.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PasswordUtil.class));
 
     /**
      * The key length.
@@ -94,7 +94,7 @@ public class PasswordUtil {
 
     /**
      * Encrypts specified password with given key.
-     * 
+     *
      * @param password The password
      * @param key The key
      * @return The encrypted password as Base64 encoded string
@@ -106,7 +106,7 @@ public class PasswordUtil {
 
     /**
      * Decrypts specified encrypted password with given key.
-     * 
+     *
      * @param encryptedPassword The Base64 encoded encrypted password
      * @param key The key
      * @return The decrypted password
@@ -118,7 +118,7 @@ public class PasswordUtil {
 
     /**
      * Encrypts specified password with given key.
-     * 
+     *
      * @param password The password to encrypt
      * @param key The key
      * @return The encrypted password as Base64 encoded string
@@ -133,11 +133,11 @@ public class PasswordUtil {
             /*-
              * It's safe to use "US-ASCII" to turn bytes into a Base64 encoded encrypted password string.
              * Taken from RFC 2045 Section 6.8. "Base64 Content-Transfer-Encoding":
-             * 
+             *
              * A 65-character subset of US-ASCII is used, enabling 6 bits to be
              * represented per printable character. (The extra 65th character, "=",
              * is used to signify a special processing function.)
-             * 
+             *
              * NOTE: This subset has the important property that it is represented
              * identically in all versions of ISO 646, including US-ASCII, and all
              * characters in the subset are also represented identically in all
@@ -146,7 +146,7 @@ public class PasswordUtil {
              * the base85 encoding specified as part of Level 2 PostScript, do not
              * share these properties, and thus do not fulfill the portability
              * requirements a binary transport encoding for mail must meet.
-             * 
+             *
              */
             return new String(Base64.encodeBase64(outputBytes), "US-ASCII");
         } catch (final UnsupportedEncodingException e) {
@@ -158,7 +158,7 @@ public class PasswordUtil {
 
     /**
      * Decrypts specified encrypted password with given key.
-     * 
+     *
      * @param encryptedPassword The Base64 encoded encrypted password
      * @param key The key
      * @return The decrypted password
@@ -170,11 +170,11 @@ public class PasswordUtil {
             /*-
              * It's safe to use "US-ASCII" to turn Base64 encoded encrypted password string into bytes.
              * Taken from RFC 2045 Section 6.8. "Base64 Content-Transfer-Encoding":
-             * 
+             *
              * A 65-character subset of US-ASCII is used, enabling 6 bits to be
              * represented per printable character. (The extra 65th character, "=",
              * is used to signify a special processing function.)
-             * 
+             *
              * NOTE: This subset has the important property that it is represented
              * identically in all versions of ISO 646, including US-ASCII, and all
              * characters in the subset are also represented identically in all
@@ -183,7 +183,7 @@ public class PasswordUtil {
              * the base85 encoding specified as part of Level 2 PostScript, do not
              * share these properties, and thus do not fulfill the portability
              * requirements a binary transport encoding for mail must meet.
-             * 
+             *
              */
             encrypted = Base64.decodeBase64(encryptedPassword.getBytes("US-ASCII"));
         } catch (final UnsupportedEncodingException e) {
@@ -217,7 +217,7 @@ public class PasswordUtil {
 
     /**
      * Generates a secret key from specified key string.
-     * 
+     *
      * @param key The key string
      * @return A secret key generated from specified key string
      * @throws GeneralSecurityException If generating secret key fails
@@ -251,7 +251,7 @@ public class PasswordUtil {
 
     /*-
      * Encode a secret key as a string that can be stored for later use.
-     * 
+     *
      * @param key
      * @return
     public static String encodeKey(final Key key) {
@@ -262,7 +262,7 @@ public class PasswordUtil {
 
     /*-
      * Reconstruct a secret key from a string representation.
-     * 
+     *
      * @param encodedKey
      * @return
      * @throws IOException
