@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import java.util.concurrent.ConcurrentMap;
 
 /**
  * Class for storing character sets.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class Charsets {
@@ -69,10 +69,12 @@ public final class Charsets {
      */
     public static final Charset US_ASCII = Charset.forName("US-ASCII");
 
+    public static final String UTF_8_NAME = "UTF-8";
+
     /**
      * UTF-8 character set.
      */
-    public static final Charset UTF_8 = Charset.forName("UTF-8");
+    public static final Charset UTF_8 = Charset.forName(UTF_8_NAME);
 
     /**
      * The charset cache.
@@ -88,7 +90,7 @@ public final class Charsets {
 
     /**
      * Gets a {@link Charset charset} object for the named charset.
-     * 
+     *
      * @param charsetName The name of the requested charset; may be either a canonical name or an alias
      * @return The {@link Charset charset} object for the named charset
      * @throws IllegalCharsetNameException If the given charset name is illegal
@@ -106,14 +108,30 @@ public final class Charsets {
         return cs;
     }
 
+    /**
+     * Constructs a new <tt>String</tt> by decoding the specified array of bytes using the specified charset. The length of the new
+     * <tt>String</tt> is a function of the charset, and hence may not be equal to the length of the byte array.
+     *
+     * @param bytes The bytes to construct the <tt>String</tt> from
+     * @param charset The charset
+     * @return The new <tt>String</tt>
+     */
     public static String toString(final byte[] bytes, final Charset charset) {
         return charset.decode(ByteBuffer.wrap(bytes)).toString();
     }
 
+    /**
+     * Encodes specified <tt>String</tt> into a sequence of bytes using the given charset, storing the result into a new byte array.
+     *
+     * @param source The string
+     * @param charset The charset
+     * @return The resulting bytes
+     */
     public static byte[] getBytes(final String source, final Charset charset) {
         final ByteBuffer buf = charset.encode(CharBuffer.wrap(source));
         final byte[] retval = new byte[buf.limit()];
         buf.get(retval);
         return retval;
     }
+
 }
