@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,13 +51,13 @@ package com.openexchange.tools.encoding;
 
 /**
  * QuotedPrintable
- * 
- * @author <a href="mailto:martin.kauss@netline-is.de">Martin Kauss</a>
+ *
+ * @author <a href="mailto:martin.kauss@open-xchange.com">Martin Kauss</a>
  */
 
 public final class QuotedPrintable {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(QuotedPrintable.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(QuotedPrintable.class));
 
     private QuotedPrintable() {
         super();
