@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,12 +59,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * URL encoding and decoding. RFC 2396
- * 
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein </a>
  */
 public final class URLCoder {
 
-    private static final Log LOG = LogFactory.getLog(URLCoder.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(URLCoder.class));
 
     private URLCoder() {
         super();
@@ -76,7 +76,7 @@ public final class URLCoder {
 
     /**
      * Decodes an URL using the charset UTF-8.
-     * 
+     *
      * @param url URL to decode.
      * @return the decoded URL.
      */
