@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,9 +50,9 @@
 package com.openexchange.tools.file;
 
 import java.io.InputStream;
-import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.tx.AbstractUndoable;
-import com.openexchange.groupware.tx.UndoableAction;
+import com.openexchange.tools.file.external.FileStorageException;
+import com.openexchange.tx.AbstractUndoable;
+import com.openexchange.tx.UndoableAction;
 
 public class SaveFileAction extends AbstractUndoable implements UndoableAction {
 
@@ -63,15 +63,15 @@ public class SaveFileAction extends AbstractUndoable implements UndoableAction {
     private String id;
 
     public SaveFileAction() {
-
+        super();
     }
 
     @Override
-    protected void undoAction() throws AbstractOXException {
+    protected void undoAction() throws FileStorageException {
         storage.deleteFile(id);
     }
 
-    public void perform() throws AbstractOXException {
+    public void perform() throws FileStorageException {
         id = storage.saveNewFile(in);
     }
 
