@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,9 @@
 package com.openexchange.tools.file;
 
 import java.io.InputStream;
-import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.tx.UndoableAction;
+import com.openexchange.tools.file.external.FileStorageException;
 
-public class SaveFileWithQuotaAction extends SaveFileAction implements UndoableAction {
+public class SaveFileWithQuotaAction extends SaveFileAction {
 
     private QuotaFileStorage storage;
 
@@ -64,12 +63,12 @@ public class SaveFileWithQuotaAction extends SaveFileAction implements UndoableA
     private String id;
 
     @Override
-    protected void undoAction() throws AbstractOXException {
+    protected void undoAction() throws FileStorageException {
         storage.deleteFile(id);
     }
 
     @Override
-    public void perform() throws AbstractOXException {
+    public void perform() throws FileStorageException {
         id = storage.saveNewFile(in, sizeHint);
     }
 
