@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,6 +63,8 @@ import java.util.Set;
 import java.util.SortedSet;
 import java.util.StringTokenizer;
 import java.util.TreeSet;
+import java.util.concurrent.locks.Lock;
+import java.util.concurrent.locks.ReentrantLock;
 import javax.activation.MimetypesFileTypeMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -107,6 +109,11 @@ public class LocalFileStorage implements FileStorage {
      */
     private final File storage;
 
+    /**
+     * Whether the path to this filestorage has already been created
+     */
+	private boolean alreadyInitialized;
+
     /**
      * Default buffer size.
      */
@@ -128,17 +135,22 @@ public class LocalFileStorage implements FileStorage {
     protected static final Set<String> SPECIAL_FILENAMES;
 
     static {
-        Set<String> tmp = new HashSet<String>();
+        final Set<String> tmp = new HashSet<String>();
         tmp.add(LOCK_FILENAME);
         tmp.add(STATEFILENAME);
         SPECIAL_FILENAMES = Collections.unmodifiableSet(tmp);
     }
-    
-    private static final Log LOG = LogFactory.getLog(LocalFileStorage.class);
+
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(LocalFileStorage.class));
+
+    /**
+     * This lock is used to avoid threads from creating a filestore dir simultaneously.
+     */
+    private static final Lock LOCK = new ReentrantLock();
 
     /**
      * Constructor with more detailed parameters. This file storage can store entries ^ depth files.
-     * 
+     *
      * @param depth depth of sub directories for storing files.
      * @param entries number of entries per sub directory.
      * @throws FileStorageException if a problem occurs while creating the file storage.
@@ -146,21 +158,9 @@ public class LocalFileStorage implements FileStorage {
     public LocalFileStorage(final URI uri) throws FileStorageException {
         super();
         storage = new File(uri);
-        if (!storage.exists() && !mkdirs(storage)) {
-            throw new FileStorageException(FileStorageException.Code.CREATE_DIR_FAILED, storage.getAbsolutePath());
-        }
-        lock(LOCK_TIMEOUT);
-        try {
-            if (!exists(STATEFILENAME)) {
-                if (LOG.isInfoEnabled()) {
-                    LOG.info("Repairing.");
-                }
-                final State state = repairState();
-                saveState(state);
-            }
-        } finally {
-            unlock();
-        }
+
+       	alreadyInitialized = storage.exists();
+
     }
 
     /**
@@ -168,12 +168,22 @@ public class LocalFileStorage implements FileStorage {
      */
     protected LocalFileStorage() {
         super();
-        storage = null;
+        storage = assignStorage();
     }
 
+    //Ugly workaround because someone insisted to make storage final:
+	private File assignStorage() {
+		try {
+        	return File.createTempFile("test-storage", "tmp");
+		} catch (IOException e) {
+			e.printStackTrace();
+			return null;
+		}
+	}
+
     /**
      * Checks, if Statefile is correct. Especially if nextEntry is right and all Files really exist.
-     * 
+     *
      * @author Steffen Templin
      * @return True if Statefile is correct
      * @throws FileStorageException
@@ -235,7 +245,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Calculates the Entrypath of the file that is previous to identifier
-     * 
+     *
      * @param identifier
      * @return String of the previous File
      * @throws FileStorageException
@@ -288,7 +298,7 @@ public class LocalFileStorage implements FileStorage {
         }
 
         // Forms the Output String
-        StringBuilder retval = new StringBuilder();
+        final StringBuilder retval = new StringBuilder();
         for (int j = 0; j < vals.length; j++) {
             retval.append("/");
             retval.append(vals[j]);
@@ -309,12 +319,13 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Stores a new file in the file storage.
-     * 
+     *
      * @param input the files data will be written from this input stream.
      * @return the identifier of the newly created file.
      * @throws FileStorageException if an error occurs while storing the file.
      */
     public String saveNewFile(final InputStream input) throws FileStorageException {
+    	initialize();
         String nextentry = null;
         State state = null;
         lock(LOCK_TIMEOUT);
@@ -378,12 +389,13 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Gets a file from the file storage.
-     * 
+     *
      * @param identifier identifier of the file.
      * @return an inputstream from that the file can be read once.
      * @throws FileStorageException if an error occurs.
      */
     public InputStream getFile(final String identifier) throws FileStorageException {
+
         return load(identifier);
     }
 
@@ -418,7 +430,7 @@ public class LocalFileStorage implements FileStorage {
     }
 
     public long getFileSize(final String name) throws FileStorageException {
-        File dataFile = new File(storage, name);
+        final File dataFile = new File(storage, name);
         if (!dataFile.exists()) {
             throw new FileStorageException(Code.FILE_NOT_FOUND, dataFile.getAbsoluteFile().getAbsolutePath());
         }
@@ -432,7 +444,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Deletes a file in the FileStorage.
-     * 
+     *
      * @param identifier identifier of the file to delete.
      * @return true if the file has been deleted successfully.
      * @throws FileStorageException if an error occurs.
@@ -454,7 +466,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Deletes a set of files in the FileStorage.
-     * 
+     *
      * @param identifier identifier of the files to delete.
      * @return a set of identifiers that could not be deleted.
      * @throws FileStorageException if an error occurs.
@@ -480,10 +492,14 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * This method removes the complete FileStorage and its elements.
-     * 
+     *
      * @throws FileStorageException if removing fails.
      */
     public void remove() throws FileStorageException {
+        // Already initialized?
+        if (!alreadyInitialized || !storage.exists()) {
+            return;
+        }
         lock(LOCK_TIMEOUT);
         eliminate();
         // no unlock here because everything is removed.
@@ -491,7 +507,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Recreates the state file of a storage no matter if it exists or not
-     * 
+     *
      * @throws FileStorageException if an error occurs.
      */
     public void recreateStateFile() throws FileStorageException {
@@ -509,7 +525,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Calculates the next free Entry of the Storage
-     * 
+     *
      * @param identifier last used Entry in the Storage
      * @return Path of the next free Entry as String
      * @throws FileStorageException if an error occurs while calculating the next free Entry
@@ -551,7 +567,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Scans the whole Storage and creates a list of unused Entries
-     * 
+     *
      * @return Set of free Entries
      * @throws FileStorageException if an error occurs while scanning
      */
@@ -569,7 +585,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Calculates the very first Entry in the Store based on the depth
-     * 
+     *
      * @return Path to the first Entry as String
      */
     protected String computeFirstEntry() {
@@ -584,7 +600,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Checks if File or Folder exists
-     * 
+     *
      * @param name Name of the file that has to be checked
      * @return true if File or Folder exists
      * @throws FileStorageException
@@ -595,7 +611,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Saves the Inputfile in the Storage
-     * 
+     *
      * @param name Name of the Inputfile
      * @param input The Inputfile
      * @throws FileStorageException
@@ -603,9 +619,18 @@ public class LocalFileStorage implements FileStorage {
     protected void save(final String name, final InputStream input) throws FileStorageException {
         final File file = new File(storage, name);
         final File parentDir = file.getParentFile();
-        if (!parentDir.exists() && !mkdirs(parentDir)) {
-            throw new FileStorageException(FileStorageException.Code.CREATE_DIR_FAILED, parentDir.getAbsolutePath());
+
+        if (!parentDir.exists()) {
+            try {
+                LOCK.lock();
+                if (!parentDir.exists() && !mkdirs(parentDir)) {
+                    throw new FileStorageException(FileStorageException.Code.CREATE_DIR_FAILED, parentDir.getAbsolutePath());
+                }
+            } finally {
+                LOCK.unlock();
+            }
         }
+
         FileOutputStream fos = null;
         try {
             fos = new FileOutputStream(file);
@@ -634,7 +659,7 @@ public class LocalFileStorage implements FileStorage {
         final long lastModified = lock.lastModified();
         if (lastModified > 0 && lastModified + maxLifeTime < System.currentTimeMillis()) {
             unlock();
-            LOG.error("Deleting a very old stale lock file here " + lock.getAbsolutePath() + ". Assuming it has not been removed by a crashed/restartet application.");
+            LOG.error("Deleting a very old stale lock file here " + lock.getAbsolutePath() + ". Assuming it has not been removed by a crashed/restarted application.");
         }
         final long failTime = System.currentTimeMillis() + timeout;
         boolean created = false;
@@ -665,7 +690,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Deletes the lock
-     * 
+     *
      * @throws FileStorageException
      */
     protected void unlock() throws FileStorageException {
@@ -680,7 +705,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Loads the state file.
-     * 
+     *
      * @return a successfully loaded state file.
      * @throws FileStorageException if the state file cannot be loaded.
      */
@@ -695,7 +720,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Saves the state file.
-     * 
+     *
      * @param state state file to save.
      * @throws FileStorageException if the saving fails.
      */
@@ -710,16 +735,20 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Loads the File
-     * 
+     *
      * @param name Name of the File
      * @return File as FileInputStream
      * @throws FileStorageException
      */
     protected InputStream load(final String name) throws FileStorageException {
+        final File dataFile = new File(storage, name);
+        if (!dataFile.exists()) {
+            throw new FileStorageException(Code.FILE_NOT_FOUND, dataFile.getAbsoluteFile().getAbsolutePath());
+        }
         try {
             return new FileInputStream(new File(storage, name));
         } catch (final FileNotFoundException e) {
-            throw new FileStorageException(FileStorageException.Code.IOERROR, e, e.getMessage());
+            throw new FileStorageException(Code.IOERROR, e, e.getMessage());
         }
     }
 
@@ -730,7 +759,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Formats the entry name as a string. Names will bein the range 0 till (entries - 1).
-     * 
+     *
      * @param entry to format
      * @return formated entry name
      */
@@ -748,7 +777,7 @@ public class LocalFileStorage implements FileStorage {
     /**
      * This method eliminates the complete storage of files including state files and parent directory. Before eliminating the storage, it
      * will be locked to exclude other instances throwing ugly errors.
-     * 
+     *
      * @throws FileStorageException if eliminating fails.
      */
     protected void eliminate() throws FileStorageException {
@@ -772,7 +801,7 @@ public class LocalFileStorage implements FileStorage {
 
     /**
      * Deletes a set of Files
-     * 
+     *
      * @param names The Filenames
      * @return Set of Files that could not be deleted
      */
@@ -789,7 +818,7 @@ public class LocalFileStorage implements FileStorage {
     /**
      * Tries to recreate the state file. This is only a fast restore because it determines only the next free slot in the FileStorage. This
      * method doesn't care about empty (deleted) slots.
-     * 
+     *
      * @return a fastly repaired state object.
      * @throws FileStorageException if checking for existing files throws an IOException.
      */
@@ -809,14 +838,45 @@ public class LocalFileStorage implements FileStorage {
         return state;
     }
 
-    private boolean mkdirs(File directory) {
+    private boolean mkdirs(final File directory) {
         if (directory.exists()) {
             return true;
         }
-        File parent = directory.getParentFile();
+        final File parent = directory.getParentFile();
         if (!mkdirs(parent)) {
             return false;
         }
         return directory.mkdir();
     }
+
+    private void initialize() throws FileStorageException{
+    	if(alreadyInitialized) {
+            return;
+        }
+
+        try {
+            LOCK.lock();
+            if (!storage.exists() && !mkdirs(storage)) {
+                throw new FileStorageException(FileStorageException.Code.CREATE_DIR_FAILED, storage.getAbsolutePath());
+            }
+        } finally {
+            LOCK.unlock();
+        }
+
+        lock(LOCK_TIMEOUT);
+        try {
+            if (!exists(STATEFILENAME)) {
+                if (LOG.isInfoEnabled()) {
+                    LOG.info("Repairing.");
+                }
+                final State state = repairState();
+                saveState(state);
+            }
+        } finally {
+            unlock();
+        }
+        alreadyInitialized = true;
+
+
+    }
 }
