@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,12 +62,12 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
  * SpamAssassin - Offers methods for spam detection and learning.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class SpamAssassin {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(SpamAssassin.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(SpamAssassin.class));
 
     private static final String STR_SPAMASSASSIN = "SpamAssassin result: ";
 
@@ -127,7 +127,7 @@ public class SpamAssassin {
 
     /**
      * Check if message is spam or non-spam
-     * 
+     *
      * @return <code>true</code> if message is treated as spam, <code>false</code> otherwise
      */
     public static final boolean scoreMessage(final Message msg) {
@@ -170,7 +170,7 @@ public class SpamAssassin {
 
     /**
      * Adds given message to SpamAssassin's learn rules as <b>spam</b> in a separate thread
-     * 
+     *
      * @param msg - the message
      */
     public static final void trainMessageAsSpam(final Message msg) {
@@ -179,7 +179,7 @@ public class SpamAssassin {
 
     /**
      * Adds given message to SpamAssassin's learn rules as <b>ham</b> in a separate thread
-     * 
+     *
      * @param msg - the message
      */
     public static final void trainMessageAsHam(final Message msg) {
