@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,7 @@ public final class GABRestorerMBeanImpl extends StandardMBean implements GABRest
 
     /**
      * Initializes a new {@link GABRestorerMBeanImpl}.
-     * 
+     *
      * @throws NotCompliantMBeanException
      */
     public GABRestorerMBeanImpl() throws NotCompliantMBeanException {
@@ -76,7 +76,7 @@ public final class GABRestorerMBeanImpl extends StandardMBean implements GABRest
             new OXFolderAdminHelper().restoreDefaultGlobalAddressBookPermissions(cid, OXFolderProperties.isEnableInternalUsersEdit());
         } catch (final OXException e) {
             final String message = e.getMessage();
-            org.apache.commons.logging.LogFactory.getLog(GABRestorerMBeanImpl.class).error(message, e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(GABRestorerMBeanImpl.class)).error(message, e);
             final Exception wrapMe = new Exception(message);
             wrapMe.setStackTrace(e.getStackTrace());
             throw new MBeanException(wrapMe, message);
