@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,6 +62,8 @@ import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBPoolProvider;
+import com.openexchange.database.provider.StaticDBPoolProvider;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.contact.Contacts;
@@ -71,8 +73,6 @@ import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.infostore.facade.impl.InfostoreFacadeImpl;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.tasks.Tasks;
-import com.openexchange.groupware.tx.DBPoolProvider;
-import com.openexchange.groupware.tx.StaticDBPoolProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.server.impl.DBPool;
@@ -81,10 +81,11 @@ import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link OXFolderAccess} - Provides access to OX folders.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class OXFolderAccess {
@@ -104,7 +105,7 @@ public class OXFolderAccess {
      * <p>
      * Since the access is created with a connection with "read-only" capability, an appropriate connection is going to be fetched from DB
      * pool every time when needed.
-     * 
+     *
      * @param ctx The context
      */
     public OXFolderAccess(final Context ctx) {
@@ -113,7 +114,7 @@ public class OXFolderAccess {
 
     /**
      * Initializes a new {@link OXFolderAccess}.
-     * 
+     *
      * @param readCon A connection with "read-only" capability or <code>null</code> to let the access fetch an appropriate connection from
      *            DB pool every time when needed
      * @param ctx The context
@@ -126,7 +127,7 @@ public class OXFolderAccess {
 
     /**
      * Tests if the folder associated with specified folder ID exists.
-     * 
+     *
      * @param folderId The folder ID
      * @return <code>true</code> if the folder associated with specified folder ID exists; otherwise <code>false</code>
      * @throws OXException If an error occurs while checking existence
@@ -153,7 +154,7 @@ public class OXFolderAccess {
     /**
      * Loads matching <code>com.openexchange.groupware.container.FolderObject</code> instance either from cache (if enabled) or from
      * underlying storage.
-     * 
+     *
      * @param folderId - the folder ID
      * @return matching <code>com.openexchange.groupware.container.FolderObject</code> instance
      * @throws OXException
@@ -170,7 +171,7 @@ public class OXFolderAccess {
 
     /**
      * Creates a <code>java.util.List</code> of <code>FolderObject</code> instances which match given folder IDs.
-     * 
+     *
      * @param folderIDs - the folder IDs as an <code>int</code> array
      * @return a <code>java.util.List</code> of <code>FolderObject</code> instances
      * @throws OXException
@@ -189,7 +190,7 @@ public class OXFolderAccess {
 
     /**
      * Creates a <code>java.util.List</code> of <code>FolderObject</code> instances fills which match given folder IDs.
-     * 
+     *
      * @param folderIDs - the folder IDs backed by a <code>java.util.Collection</code>
      * @return a <code>java.util.List</code> of <code>FolderObject</code> instances
      * @throws OXException
@@ -211,7 +212,7 @@ public class OXFolderAccess {
     /**
      * Determines folder type. The returned value is either <code>FolderObject.PRIVATE</code>, <code>FolderObject.PUBLIC</code> or
      * <code>FolderObject.SHARED</code>. <b>NOTE:</b> This method assumes that given user has read access!
-     * 
+     *
      * @param folderId - the folder ID
      * @param userId - the user ID
      * @return the folder type
@@ -225,7 +226,7 @@ public class OXFolderAccess {
      * Determines the <b>plain</b> folder type meaning the returned value is either <code>FolderObject.PRIVATE</code> or
      * <code>FolderObject.PUBLIC</code>. <b>NOTE:</b> Do not use this method to check if folder is shared (<code>FolderObject.SHARED</code>
      * ), use {@link #getFolderType(int, int)} instead.
-     * 
+     *
      * @param folderId - the folder ID
      * @return the folder type
      * @throws OXException
@@ -237,7 +238,7 @@ public class OXFolderAccess {
 
     /**
      * Determines folder module.
-     * 
+     *
      * @param folderId - the folder ID
      * @return folder module
      * @throws OXException
@@ -248,7 +249,7 @@ public class OXFolderAccess {
 
     /**
      * Determines folder owner.
-     * 
+     *
      * @param folderId - the folder ID
      * @return folder owner
      * @throws OXException
@@ -259,7 +260,7 @@ public class OXFolderAccess {
 
     /**
      * Determines if folder is shared. <b>NOTE:</b> This method assumes that given user has read access!
-     * 
+     *
      * @param folderId - the folder ID
      * @param userId - the user ID
      * @return <code>true</code> if folder is shared, otherwise <code>false</code>
@@ -271,7 +272,7 @@ public class OXFolderAccess {
 
     /**
      * Determines if folder is an user's default folder.
-     * 
+     *
      * @param folderId - the folder ID
      * @return <code>true</code> if folder is marked as a default folder, otherwise <code>false</code>
      * @throws OXException
@@ -282,7 +283,7 @@ public class OXFolderAccess {
 
     /**
      * Determines given folder's name.
-     * 
+     *
      * @param folderId - the folder ID
      * @return folder name
      * @throws OXException
@@ -293,7 +294,7 @@ public class OXFolderAccess {
 
     /**
      * Determines given folder's parent ID.
-     * 
+     *
      * @param folderId - the folder ID
      * @return folder parent ID
      * @throws OXException
@@ -304,7 +305,7 @@ public class OXFolderAccess {
 
     /**
      * Determines given folder's last modifies date.
-     * 
+     *
      * @param folderId
      * @return folder's last modifies date
      * @throws OXException
@@ -315,7 +316,7 @@ public class OXFolderAccess {
 
     /**
      * Determines user's effective permission on the folder matching given folder ID.
-     * 
+     *
      * @param folderId - the folder ID
      * @param userId - the user ID
      * @param userConfig - the user configuration
@@ -335,7 +336,7 @@ public class OXFolderAccess {
 
     /**
      * Determines user's default folder of given module.
-     * 
+     *
      * @param userId - the user ID
      * @param module - the module
      * @return user's default folder of given module
@@ -345,17 +346,43 @@ public class OXFolderAccess {
         try {
             final int folderId = OXFolderSQL.getUserDefaultFolder(userId, module, readCon, ctx);
             if (folderId == -1) {
-                throw new OXFolderException(
-                    FolderCode.NO_DEFAULT_FOLDER_FOUND,
-                    folderModule2String(module),
-                    getUserName(userId, ctx),
-                    Integer.valueOf(ctx.getContextId()));
+                if (FolderObject.INFOSTORE != module) {
+                    throw new OXFolderException(
+                        FolderCode.NO_DEFAULT_FOLDER_FOUND,
+                        folderModule2String(module),
+                        getUserName(userId, ctx),
+                        Integer.valueOf(ctx.getContextId()));
+                }
+                /*
+                 * Re-Create default infostore folder
+                 */
+                final Connection wc = DBPool.pickupWriteable(ctx);
+                try {
+                    wc.setAutoCommit(false);
+                    final String displayName = UserStorage.getStorageUser(userId, ctx).getDisplayName();
+                    final int fuid = new OXFolderAdminHelper().addUserToInfoStore(userId, displayName, ctx.getContextId(), wc);
+                    wc.commit();
+                    return getFolderObject(fuid);
+                } catch (final SQLException e) {
+                    DBUtils.rollback(wc);
+                    throw e;
+                } catch (final Exception e) {
+                    DBUtils.rollback(wc);
+                    throw e;
+                } finally {
+                    DBUtils.autocommit(wc);
+                    DBPool.closeWriterSilent(ctx, wc);
+                }
             }
             return getFolderObject(folderId);
+        } catch (final OXException e) {
+            throw e;
         } catch (final SQLException e) {
             throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
+        } catch (final Exception e) {
+            throw new OXFolderException(FolderCode.RUNTIME_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
     }
 
@@ -364,7 +391,7 @@ public class OXFolderAccess {
      * <p>
      * <b>Note</b>: This method checks only by contained items and does <small><b>NOT</b></small> check by the user's effective folder
      * permission itself. Thus the user is supposed to hold sufficient folder permissions on specified folder.
-     * 
+     *
      * @param fo - the folder object
      * @param session - current user session
      * @param ctx - the context
@@ -412,7 +439,7 @@ public class OXFolderAccess {
 
     /**
      * Checks if given folder contains session-user-foreign objects.
-     * 
+     *
      * @param fo The folder to check
      * @param session The session
      * @param ctx The context
@@ -472,7 +499,7 @@ public class OXFolderAccess {
 
     /**
      * Checks if given folder is empty.
-     * 
+     *
      * @param fo The folder to check
      * @param session The session
      * @param ctx The context
