@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,9 @@ package com.openexchange.tools.oxfolder;
 
 import static com.openexchange.tools.sql.DBUtils.closeResources;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
-import gnu.trove.TIntArrayList;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.list.linked.TIntLinkedList;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.PreparedStatement;
@@ -65,8 +67,15 @@ import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.cache.impl.FolderCacheNotEnabledException;
 import com.openexchange.cache.impl.FolderQueryCacheManager;
+import com.openexchange.caching.Cache;
+import com.openexchange.caching.CacheKey;
+import com.openexchange.caching.CacheService;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
+import com.openexchange.folderstorage.FolderStorage;
+import com.openexchange.folderstorage.cache.CacheFolderStorage;
+import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.calendar.CalendarCache;
@@ -75,23 +84,26 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
+import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.i18n.LocaleTools;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.server.impl.OCLPermission;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link OXFolderAdminHelper} - Helper class for admin.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OXFolderAdminHelper {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXFolderAdminHelper.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXFolderAdminHelper.class));
 
     private static final boolean ADMIN_EDITABLE = false;
 
@@ -133,7 +145,7 @@ public final class OXFolderAdminHelper {
      * Checks if context's admin has administer permission on public folder(s).
      * <p>
      * <b>Note</b>: Succeeds only of specified user ID denotes context's admin
-     * 
+     *
      * @param cid The context ID
      * @param userId The ID of the user for whom the setting shall be checked
      * @param readCon A readable connection
@@ -175,7 +187,7 @@ public final class OXFolderAdminHelper {
      * Sets if context's admin has administer permission on public folder(s).
      * <p>
      * <b>Note</b>: Succeeds only of specified user ID denotes context's admin
-     * 
+     *
      * @param editable <code>true</code> if context's admin has administer permission on public folder(s); otherwise <code>false</code>
      * @param cid The context ID
      * @param userId The ID of the user for whom the option shall be set
@@ -190,9 +202,6 @@ public final class OXFolderAdminHelper {
             LOG.error(e.getMessage(), e);
             return;
         }
-        if (userId != admin) {
-            return;
-        }
         for (final int id : CHANGEABLE_PUBLIC_FOLDERS) {
             try {
                 /*
@@ -208,15 +217,26 @@ public final class OXFolderAdminHelper {
             ResultSet rs = null;
             try {
                 stmt =
-                    writeCon.prepareStatement("SELECT permission_id FROM oxfolder_permissions WHERE cid = ? AND fuid = ? AND permission_id = ?");
+                    writeCon.prepareStatement("SELECT permission_id, admin_flag FROM oxfolder_permissions WHERE cid = ? AND fuid = ? AND permission_id = ?");
                 int pos = 1;
                 stmt.setInt(pos++, cid);
                 stmt.setInt(pos++, id);
-                stmt.setInt(pos++, admin);
+                stmt.setInt(pos++, userId);
                 rs = stmt.executeQuery();
                 final boolean update = rs.next();
+                final boolean prevEditable = update && rs.getInt(2) > 0;
                 DBUtils.closeSQLStuff(rs, stmt);
                 rs = null;
+                /*
+                 * Check user
+                 */
+                if (admin != userId) {
+                    if (prevEditable == editable || !editable) {
+                        // No-op
+                        return;
+                    }
+                    throw new OXFolderException(FolderCode.ADMIN_OP_ONLY, Integer.valueOf(admin), Integer.valueOf(userId));
+                }
                 /*
                  * Insert/Update
                  */
@@ -260,6 +280,7 @@ public final class OXFolderAdminHelper {
                 /*
                  * Update caches
                  */
+                ConditionTreeMapManagement.dropFor(ctx.getContextId());
                 try {
                     if (FolderCacheManager.isEnabled()) {
                         FolderCacheManager.getInstance().removeFolderObject(id, ctx);
@@ -285,7 +306,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Restores default permissions on global address book folder in given context.
-     * 
+     *
      * @param cid The context ID
      * @param enable Whether to enable or disable global address book access for each user
      * @throws OXException If an error occurs
@@ -316,7 +337,7 @@ public final class OXFolderAdminHelper {
             /*
              * Get context's users
              */
-            final TIntArrayList users;
+            final TIntList users;
             {
                 PreparedStatement stmt = null;
                 ResultSet rs = null;
@@ -342,12 +363,12 @@ public final class OXFolderAdminHelper {
                 final Integer admin = Integer.valueOf(getContextAdminID(cid, writeCon));
                 final int size = users.size();
                 for (int i = 1; i < size; i++) {
-                    setGlobalAddressBookDisabled(cid, users.getQuick(i), !enable, writeCon, admin, false);
+                    setGlobalAddressBookDisabled(cid, users.get(i), !enable, writeCon, admin, false);
                 }
                 /*
                  * Propagate with last update
                  */
-                setGlobalAddressBookDisabled(cid, users.getQuick(0), !enable, writeCon, admin, true);
+                setGlobalAddressBookDisabled(cid, users.get(0), !enable, writeCon, admin, true);
             }
         } finally {
             Database.back(cid, true, writeCon);
@@ -356,7 +377,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Checks whether global address book is enabled for specified user.
-     * 
+     *
      * @param cid The context ID
      * @param userId The user ID
      * @param readCon A readable connection
@@ -399,7 +420,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Enables/Disables specified user's global address book permission.
-     * 
+     *
      * @param cid The context ID
      * @param userId The user ID
      * @param disable <code>true</code> to enabled user's global address book permission; otherwise <code>false</code>
@@ -412,7 +433,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Enables/Disables specified user's global address book permission.
-     * 
+     *
      * @param cid The context ID
      * @param userId The user ID
      * @param disable <code>true</code> to enabled user's global address book permission; otherwise <code>false</code>
@@ -454,13 +475,14 @@ public final class OXFolderAdminHelper {
         ResultSet rs = null;
         try {
             stmt =
-                writeCon.prepareStatement("SELECT permission_id FROM oxfolder_permissions WHERE cid = ? AND fuid = ? AND permission_id = ?");
+                writeCon.prepareStatement("SELECT permission_id,system FROM oxfolder_permissions WHERE cid = ? AND fuid = ? AND permission_id = ?");
             int pos = 1;
             stmt.setInt(pos++, cid);
             stmt.setInt(pos++, globalAddressBookId);
             stmt.setInt(pos++, userId);
             rs = stmt.executeQuery();
             final boolean update = rs.next();
+            final int system = (update) ? rs.getInt(2) : 0;
             DBUtils.closeSQLStuff(rs, stmt);
             rs = null;
             /*
@@ -468,7 +490,7 @@ public final class OXFolderAdminHelper {
              */
             if (update) {
                 stmt =
-                    writeCon.prepareStatement("UPDATE oxfolder_permissions SET fp = ?, orp = ?, owp = ?, admin_flag = ?, odp = ? WHERE cid = ? AND fuid = ? AND permission_id = ?");
+                    writeCon.prepareStatement("UPDATE oxfolder_permissions SET fp = ?, orp = ?, owp = ?, admin_flag = ?, odp = ? WHERE cid = ? AND fuid = ? AND permission_id = ? AND system = ?");
                 pos = 1;
                 if (disable) {
                     stmt.setInt(pos++, OCLPermission.NO_PERMISSIONS);
@@ -486,6 +508,7 @@ public final class OXFolderAdminHelper {
                 stmt.setInt(pos++, cid);
                 stmt.setInt(pos++, globalAddressBookId);
                 stmt.setInt(pos++, userId);
+                stmt.setInt(pos++, system);
                 stmt.executeUpdate();
             } else {
                 stmt =
@@ -517,6 +540,7 @@ public final class OXFolderAdminHelper {
              * Update last-modified of folder
              */
             if (propagate) {
+                ConditionTreeMapManagement.dropFor(cid);
                 final ContextImpl ctx = new ContextImpl(cid);
                 ctx.setMailadmin(admin);
                 OXFolderSQL.updateLastModified(globalAddressBookId, System.currentTimeMillis(), admin, writeCon, ctx);
@@ -533,6 +557,16 @@ public final class OXFolderAdminHelper {
                     if (CalendarCache.isInitialized()) {
                         CalendarCache.getInstance().invalidateGroup(cid);
                     }
+                    final CacheService service = ServerServiceRegistry.getInstance().getService(CacheService.class);
+                    if (null != service) {
+                        final Cache cache = service.getCache("GlobalFolderCache");
+                        final String sContextId = Integer.toString(cid);
+                        final String[] trees = new String[] { FolderStorage.REAL_TREE_ID, OutlookFolderStorage.OUTLOOK_TREE_ID, "20" };
+                        for (final String tid : trees) {
+                            final CacheKey cacheKey = service.newCacheKey(1, tid, Integer.toString(globalAddressBookId));
+                            cache.removeFromGroup(cacheKey, sContextId);
+                        }
+                    }
                 } catch (final AbstractOXException e) {
                     LOG.error(e.getMessage(), e);
                 }
@@ -551,7 +585,7 @@ public final class OXFolderAdminHelper {
     /**
      * Creates the standard system folders located in each context for given context in database and creates the default folders for
      * context's admin user by invoking <code>{@link #addUserToOXFolders(int, String, String, int, Connection)}</code>
-     * 
+     *
      * @param cid The context ID
      * @param mailAdminDisplayName The display name of context's admin user
      * @param language The language conforming to syntax rules of locales
@@ -778,7 +812,7 @@ public final class OXFolderAdminHelper {
          */
         /*-
          * Don't grant full access for admin on top level infostore folder
-         * 
+         *
         createSingleUserPermission(
             FolderObject.SYSTEM_INFOSTORE_FOLDER_ID,
             mailAdmin,
@@ -846,7 +880,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates a public system folder with default permission for all-groups-and-users entity.
-     * 
+     *
      * @param cid The context ID
      * @param mailAdmin The context admin
      * @param writeCon A writable connection
@@ -867,7 +901,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates the public folder with default permission for all-groups-and-users entity.
-     * 
+     *
      * @param cid The context ID
      * @param mailAdmin The context admin
      * @param writeCon A writable connection
@@ -900,7 +934,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates the infostore folder with default permission for all-groups-and-users entity.
-     * 
+     *
      * @param cid The context ID
      * @param mailAdmin The context admin
      * @param writeCon A writable connection
@@ -933,7 +967,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates the public infostore folder with default permission for all-groups-and-users entity.
-     * 
+     *
      * @param cid The context ID
      * @param mailAdmin The context admin
      * @param writeCon A writable connection
@@ -966,7 +1000,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Checks permission existence for all-groups-abd-users on GAB folder in given context.
-     * 
+     *
      * @param cid The context ID
      * @param con A connection
      * @return <code>true</code> if a permission exists; otherwise <code>false</code>
@@ -978,7 +1012,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Checks permission existence in given folder in given context for given user.
-     * 
+     *
      * @param cid The context ID
      * @param folderId The folder ID
      * @param userId The user ID
@@ -1002,7 +1036,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Checks permission values for folder, object-read, object-write and object-delete permission.
-     * 
+     *
      * @param cid The context ID
      * @param folderId The folder ID
      * @param entityId The entity ID
@@ -1031,7 +1065,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Checks existence of given folder in given context.
-     * 
+     *
      * @param cid The context ID
      * @param folderId The folder ID
      * @param con A connection
@@ -1052,7 +1086,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates the global address book folder.
-     * 
+     *
      * @param cid The context ID
      * @param mailAdmin The ID of context's admin
      * @param writeCon A writable connection
@@ -1080,10 +1114,10 @@ public final class OXFolderAdminHelper {
     }
 
     private final static String SQL_INSERT_SYSTEM_FOLDER =
-        "INSERT INTO oxfolder_tree " + "(fuid, cid, parent, fname, module, type, creating_date, created_from, changing_date, changed_from, permission_flag, subfolder_flag) " + "VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
+        "INSERT INTO oxfolder_tree (fuid, cid, parent, fname, module, type, creating_date, created_from, changing_date, changed_from, permission_flag, subfolder_flag) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
 
     private static final String SQL_INSERT_SYSTEM_PERMISSION =
-        "INSERT INTO oxfolder_permissions " + "(cid, fuid, permission_id, fp, orp, owp, odp, admin_flag, group_flag) VALUES (?,?,?,?,?,?,?,?,?)";
+        "INSERT INTO oxfolder_permissions (cid, fuid, permission_id, fp, orp, owp, odp, admin_flag, group_flag) VALUES (?,?,?,?,?,?,?,?,?)";
 
     private static final String SQL_INSERT_SPECIAL_FOLDER = "INSERT INTO oxfolder_specialfolders " + "(tag, cid, fuid) VALUES (?,?,?)";
 
@@ -1198,7 +1232,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Deletes all context associated folder in both working and backup tables from database
-     * 
+     *
      * @param cid The context ID
      * @param readCon A readable connection
      * @param writeCon A writeable connection
@@ -1297,7 +1331,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Propagates that a group has been modified throughout affected folders by touching folder's last-modified timestamp.
-     * 
+     *
      * @param group The affected group ID
      * @param readCon A readable connection to database
      * @param writeCon A writable connection to database
@@ -1305,6 +1339,18 @@ public final class OXFolderAdminHelper {
      * @throws SQLException If a SQL related error occurs
      */
     public static void propagateGroupModification(final int group, final Connection readCon, final Connection writeCon, final int cid) throws SQLException {
+        try {
+            final int[] members = GroupStorage.getInstance().getGroup(group, ContextStorage.getStorageContext(cid)).getMember();
+            for (final int member : members) {
+                CacheFolderStorage.getInstance().clearCache(member, cid);
+            }
+        } catch (final Exception e) {
+            // Ignore
+            LOG.error(e.getMessage(), e);
+        }
+        /*
+         * Update last-modified time stamp
+         */
         final long lastModified = System.currentTimeMillis();
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -1320,7 +1366,7 @@ public final class OXFolderAdminHelper {
             stmt.setInt(2, cid);
             stmt.setInt(3, group);
             rs = stmt.executeQuery();
-            final TIntArrayList list = new TIntArrayList();
+            final TIntList list = new TIntLinkedList();
             while (rs.next()) {
                 list.add(rs.getInt(1));
             }
@@ -1330,7 +1376,7 @@ public final class OXFolderAdminHelper {
             if (!list.isEmpty()) {
                 stmt = writeCon.prepareStatement(SQL_UPDATE_FOLDER_TIMESTAMP.replaceFirst("#FT#", STR_OXFOLDERTREE));
                 do {
-                    final int fuid = list.remove(0);
+                    final int fuid = list.removeAt(0);
                     stmt.setLong(1, lastModified);
                     stmt.setInt(2, cid);
                     stmt.setInt(3, fuid);
@@ -1357,7 +1403,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Propagates modifications <b>already</b> performed on an existing user throughout folder module.
-     * 
+     *
      * @param userId The ID of the user who has been modified
      * @param changedFields The changed fields of the user taken from constants defined in {@link Contact}; e.g.
      *            {@link Contact#DISPLAY_NAME}
@@ -1435,7 +1481,7 @@ public final class OXFolderAdminHelper {
     /**
      * Load specified user's display name with given connection (which is possibly in non-auto-commit mode). Thus we obtain most up-to-date
      * data and do not read old value.
-     * 
+     *
      * @param userId The user ID
      * @param cid The context ID
      * @param con The connection
@@ -1473,7 +1519,7 @@ public final class OXFolderAdminHelper {
 
     /**
      * Creates default folders for modules task, calendar, contact, and infostore for given user ID
-     * 
+     *
      * @param userId The user ID
      * @param displayName The display name which is taken as folder name for user's default infostore folder
      * @param language User's language which determines the translation of default folder names
@@ -1484,7 +1530,7 @@ public final class OXFolderAdminHelper {
     public void addUserToOXFolders(final int userId, final String displayName, final String language, final int cid, final Connection writeCon) throws OXException {
         try {
             final Context ctx = new ContextImpl(cid);
-            final StringHelper strHelper = new StringHelper(LocaleTools.getLocale(language));
+            final StringHelper strHelper = StringHelper.valueOf(LocaleTools.getLocale(language));
             /*
              * Check infostore sibling
              */
@@ -1612,9 +1658,64 @@ public final class OXFolderAdminHelper {
         }
     }
 
+    /**
+     * Creates default folders for infostore module for given user ID
+     *
+     * @param userId The user ID
+     * @param displayName The display name which is taken as folder name for user's default infostore folder
+     * @param cid The context ID
+     * @param writeCon A writable connection to (master) database
+     * @return THe folder identifier
+     * @throws OXException If user's default infostore folder could not be created successfully
+     */
+    public int addUserToInfoStore(final int userId, final String displayName, final int cid, final Connection writeCon) throws OXException {
+        try {
+            final Context ctx = new ContextImpl(cid);
+            /*
+             * Check infostore sibling
+             */
+            String folderName = displayName;
+            final int resetLen = folderName.length();
+            int count = 0;
+            while (OXFolderSQL.lookUpFolder(FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID, folderName, FolderObject.INFOSTORE, writeCon, ctx) != -1) {
+                folderName = folderName.substring(0, resetLen) + " (" + String.valueOf(++count) + ')';
+            }
+            /*
+             * Insert default infostore folder
+             */
+            final long creatingTime = System.currentTimeMillis();
+            final OCLPermission defaultPerm = new OCLPermission();
+            defaultPerm.setEntity(userId);
+            defaultPerm.setGroupPermission(false);
+            defaultPerm.setAllPermission(
+                OCLPermission.ADMIN_PERMISSION,
+                OCLPermission.ADMIN_PERMISSION,
+                OCLPermission.ADMIN_PERMISSION,
+                OCLPermission.ADMIN_PERMISSION);
+            defaultPerm.setFolderAdmin(true);
+            final FolderObject fo = new FolderObject();
+            fo.setPermissionsAsArray(new OCLPermission[] { defaultPerm });
+            fo.setDefaultFolder(true);
+            fo.setParentFolderID(FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID);
+            fo.setType(FolderObject.PUBLIC);
+            fo.setFolderName(folderName);
+            fo.setModule(FolderObject.INFOSTORE);
+            final int newFolderId = OXFolderSQL.getNextSerialForAdmin(ctx, writeCon);
+            OXFolderSQL.insertDefaultFolderSQL(newFolderId, userId, fo, creatingTime, ctx, writeCon);
+            if (LOG.isInfoEnabled()) {
+                LOG.info("User's default INFOSTORE folder successfully created");
+            }
+            return newFolderId;
+        } catch (final DBPoolingException e) {
+            throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(cid));
+        } catch (final SQLException e) {
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
+        }
+    }
+
     /**
      * Sets the global address book permission dependent on {@link OXFolderProperties#isEnableInternalUsersEdit()} option.
-     * 
+     *
      * @param p The permission instance whose permissions shall be set
      */
     private static void setGABPermissions(final OCLPermission p) {
@@ -1625,6 +1726,8 @@ public final class OXFolderAdminHelper {
             OCLPermission.NO_PERMISSIONS);
     }
 
+    // NOTE: This is an update without the full primary key in the where clause, so it may lock too many rows.
+    // Since this is never called, I suppose we might as well remove the method
     private void updateGABWritePermission(final int contextId, final boolean enable, final Connection con) throws OXException {
         PreparedStatement ps = null;
         try {
