@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import com.openexchange.groupware.EnumComponent;
 
 /**
  * {@link OXFolderException} - OX-Folder related exceptions
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class OXFolderException extends OXException {
@@ -458,9 +458,9 @@ public class OXFolderException extends OXException {
          */
         SHARE_FORBIDDEN("User %1$s is not allowed to share folder %2$s in context %3$s due to user configuration", Category.USER_CONFIGURATION, 72),
         /**
-         * Defined permissions for folder %1$s in context %2$s are not applicable to user %3$s due to user configuration
+         * The permissions for the user %1$s are limited. It is not possible to grant this user the wanted permissions for the folder %2$s in context %3$s.
          */
-        UNAPPLICABLE_FOLDER_PERM("Defined permissions for folder %1$s in context %2$s are not applicable to user %3$s due to user configuration", Category.USER_CONFIGURATION, 73),
+        UNAPPLICABLE_FOLDER_PERM("The permissions for the user %1$s are limited. It is not possible to grant this user the wanted permissions for the folder %2$s in context %3$s.", Category.USER_CONFIGURATION, 73),
         /**
          * Folder %1$s in context %2$s contains a hidden subfolder. User %3$s has no delete rights for this subfolder and consequently
          * cannot delete its parent folder.
@@ -509,7 +509,27 @@ public class OXFolderException extends OXException {
         /**
          * The module of a default folder must not be changed.
          */
-        NO_DEFAULT_FOLDER_MODULE_UPDATE("The module of a default folder must not be changed.", Category.USER_INPUT, 85);
+        NO_DEFAULT_FOLDER_MODULE_UPDATE("The module of a default folder must not be changed.", Category.USER_INPUT, 85),
+        /**
+         * User %1$s must not rename folder %2$s in context %3$s
+         * <p>
+         * No necessary rename access granted for update operation
+         * </p>
+         */
+        NO_RENAME_ACCESS("User %1$s must not rename folder %2$s in context %3$s", Category.PERMISSION, 86),
+        /**
+         * Failed to create folder. Please retry.
+         */
+        CREATE_FAILED("Failed to create folder. Please retry.", Category.TRY_AGAIN, 87),
+        /**
+         * Delete cannot be performed because of locked documents in folder %1$s in context %2$s.
+         */
+        DELETE_FAILED_LOCKED_DOCUMENTS("Delete cannot be performed because of locked documents in folder %1$s in context %2$s.", Category.PERMISSION, 88),
+        /**
+         * Operation may only be performed for context administrator (%1$s), but not for normal user %2$s.
+         */
+        ADMIN_OP_ONLY("Operation may only be performed for context administrator (%1$s), but not for normal user %2$s.", Category.PERMISSION, 89),
+        ;
 
         /**
          * Message of the exception.
@@ -534,7 +554,7 @@ public class OXFolderException extends OXException {
 
         /**
          * Gets the (detail) number.
-         * 
+         *
          * @return The (detail) number.
          */
         public int getNumber() {
@@ -543,7 +563,7 @@ public class OXFolderException extends OXException {
 
         /**
          * Gets the (unformatted) message.
-         * 
+         *
          * @return The (unformatted) message.
          */
         public String getMessage() {
@@ -552,7 +572,7 @@ public class OXFolderException extends OXException {
 
         /**
          * Gets the category.
-         * 
+         *
          * @return The category.
          */
         public Category getCategory() {
@@ -564,7 +584,7 @@ public class OXFolderException extends OXException {
 
     /**
      * Constructs a new {@link OXFolderException} from specified {@link AbstractOXException init cause}.
-     * 
+     *
      * @param e The init cause
      */
     public OXFolderException(final AbstractOXException e) {
@@ -573,42 +593,42 @@ public class OXFolderException extends OXException {
 
     /**
      * Constructs a new {@link OXFolderException} from specified {@link FolderCode folder error code} only.
-     * 
+     *
      * @param folderCode The folder error code
      */
     public OXFolderException(final FolderCode folderCode) {
-        super(EnumComponent.FOLDER, folderCode.category, folderCode.detailNumber, folderCode.message, null, EMPTY_ARGS);
+        super(EnumComponent.FOLDER, folderCode.getCategory(), folderCode.getNumber(), folderCode.getMessage(), null, EMPTY_ARGS);
     }
 
     /**
      * Constructs a new {@link OXFolderException}
-     * 
+     *
      * @param folderCode The folder error code
      * @param messageArgs The error code's message arguments
      */
     public OXFolderException(final FolderCode folderCode, final Object... messageArgs) {
-        super(EnumComponent.FOLDER, folderCode.category, folderCode.detailNumber, folderCode.message, null, messageArgs);
+        super(EnumComponent.FOLDER, folderCode.getCategory(), folderCode.getNumber(), folderCode.getMessage(), null, messageArgs);
     }
 
     /**
      * Constructs a new {@link OXFolderException}
-     * 
+     *
      * @param folderCode The folder error code
      * @param cause The init cause
      * @param messageArgs The error code's message arguments
      */
     public OXFolderException(final FolderCode folderCode, final Throwable cause, final Object... messageArgs) {
-        super(EnumComponent.FOLDER, folderCode.category, folderCode.detailNumber, folderCode.message, cause, messageArgs);
+        super(EnumComponent.FOLDER, folderCode.getCategory(), folderCode.getNumber(), folderCode.getMessage(), cause, messageArgs);
     }
 
     /**
      * Constructs a new {@link OXFolderException}
-     * 
+     *
      * @param folderCode The folder error code
      * @param category The error's category
      * @param messageArgs The error code's message arguments
      */
     public OXFolderException(final FolderCode folderCode, final Category category, final Object... messageArgs) {
-        super(EnumComponent.FOLDER, category, folderCode.detailNumber, folderCode.message, null, messageArgs);
+        super(EnumComponent.FOLDER, category, folderCode.getNumber(), folderCode.getMessage(), null, messageArgs);
     }
 }
