@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,16 +85,18 @@ import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.threadpool.behavior.CallerRunsBehavior;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
+import com.openexchange.tools.oxfolder.permissionLoader.PermissionLoaderService;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * <tt>OXFolderProperties</tt> contains both folder properties and folder cache properties
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OXFolderProperties implements Initialization, CacheAvailabilityListener {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXFolderProperties.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXFolderProperties.class));
 
     private static OXFolderProperties instance = new OXFolderProperties();
 
@@ -120,6 +122,8 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
 
     private volatile boolean enableInternalUsersEdit = false;
 
+    private boolean enableSharedFolderCaching = true;
+
     private OXFolderProperties() {
         super();
     }
@@ -130,6 +134,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
             return;
         }
         init();
+        PermissionLoaderService.getInstance().startUp();
         final CacheAvailabilityRegistry reg = CacheAvailabilityRegistry.getInstance();
         if (reg != null) {
             reg.registerListener(this);
@@ -138,6 +143,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
             FolderCacheManager.initInstance();
         }
         FolderQueryCacheManager.initInstance();
+        ConditionTreeMapManagement.startInstance();
     }
 
     public void stop() throws AbstractOXException {
@@ -160,8 +166,10 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         if (reg != null) {
             reg.unregisterListener(this);
         }
+        ConditionTreeMapManagement.stopInstance();
         FolderCacheManager.releaseInstance();
         FolderQueryCacheManager.releaseInstance();
+        PermissionLoaderService.dropInstance();
         reset();
     }
 
@@ -188,6 +196,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
     }
 
     private void reset() {
+        enableSharedFolderCaching = true;
         propertyListener = null;
         enableDBGrouping = true;
         enableFolderCache = true;
@@ -201,14 +210,21 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
             LOG.error("Cannot look-up configuration service");
             return;
         }
+        /*
+         * ENABLE_SHARED_FOLDER_CACHING
+         */
+        String value = configurationService.getProperty("ENABLE_SHARED_FOLDER_CACHING");
+        if (null != value) {
+            enableSharedFolderCaching = Boolean.parseBoolean(value.trim());
+        }
         /*
          * ENABLE_DB_GROUPING
          */
-        String value = configurationService.getProperty("ENABLE_DB_GROUPING");
+        value = configurationService.getProperty("ENABLE_DB_GROUPING");
         if (null == value) {
             LOG.warn("Missing property ENABLE_DB_GROUPING.");
         } else {
-            enableDBGrouping = Boolean.parseBoolean(value);
+            enableDBGrouping = Boolean.parseBoolean(value.trim());
         }
         /*
          * ENABLE_FOLDER_CACHE
@@ -217,7 +233,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         if (null == value) {
             LOG.warn("Missing property ENABLE_FOLDER_CACHE");
         } else {
-            enableFolderCache = Boolean.parseBoolean(value);
+            enableFolderCache = Boolean.parseBoolean(value.trim());
         }
         /*
          * IGNORE_SHARED_ADDRESSBOOK
@@ -226,7 +242,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         if (null == value) {
             LOG.warn("Missing property IGNORE_SHARED_ADDRESSBOOK");
         } else {
-            ignoreSharedAddressbook = Boolean.parseBoolean(value);
+            ignoreSharedAddressbook = Boolean.parseBoolean(value.trim());
         }
         /*
          * ENABLE_INTERNAL_USER_EDIT and add listener
@@ -253,14 +269,14 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
                     }
                     enableInternalUsersEdit = false;
                 }
-                final ThreadPoolService pool = ServerServiceRegistry.getInstance().getService(ThreadPoolService.class);
+                final ThreadPoolService pool = ThreadPools.getThreadPool();
                 if (null == pool) {
                     // Run in this thread
                     updatePermissions();
                 } else {
                     // Run in separate thread
                     final Runnable r = new Runnable() {
-                        
+
                         public void run() {
                             updatePermissions();
                         }
@@ -369,7 +385,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         if (null == value) {
             LOG.warn("Missing property ENABLE_INTERNAL_USER_EDIT");
         } else {
-            enableInternalUsersEdit = Boolean.parseBoolean(value);
+            enableInternalUsersEdit = Boolean.parseBoolean(value.trim());
         }
         /*
          * Log info
@@ -381,6 +397,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         if (LOG.isInfoEnabled()) {
             final StringBuilder sb = new StringBuilder(512);
             sb.append("\nFolder Properties & Folder Cache Properties:\n");
+            sb.append("\tENABLE_SHARED_FOLDER_CACHING=").append(enableSharedFolderCaching).append('\n');
             sb.append("\tENABLE_DB_GROUPING=").append(enableDBGrouping).append('\n');
             sb.append("\tENABLE_FOLDER_CACHE=").append(enableFolderCache).append('\n');
             sb.append("\tENABLE_INTERNAL_USER_EDIT=").append(enableInternalUsersEdit).append('\n');
@@ -424,7 +441,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
     /**
      * Context's system folder "<code>Global address book</code>" is created with write permission set to
      * {@link OCLPermission#WRITE_OWN_OBJECTS} if this property is set to <code>true</code>
-     * 
+     *
      * @return <code>true</code> if contacts located in global address book may be edited; otherwise <code>false</code>
      */
     public static boolean isEnableInternalUsersEdit() {
@@ -434,13 +451,25 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
         return instance.enableInternalUsersEdit;
     }
 
+    /**
+     * Checks whether caching for shared folders is enabled or not.
+     * 
+     * @return <code>true</code> if caching for shared folder is enabled; otherwise <code>false</code>
+     */
+    public static boolean isEnableSharedFolderCaching() {
+        if (!instance.started.get()) {
+            LOG.error(WARN_FOLDER_PROPERTIES_INIT, new Throwable());
+        }
+        return instance.enableSharedFolderCaching;
+    }
+
     /*-
      * ############################# MBEAN STUFF #############################
      */
 
     /**
      * Registers the global address book restorer MBean.
-     * 
+     *
      * @param managementService The management service
      * @return The object name of registered MBean
      */
@@ -461,7 +490,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
 
     /**
      * Unregisters the global address book restorer MBean.
-     * 
+     *
      * @param objectName The object name of registered MBean
      * @param managementService The management service
      */
@@ -477,7 +506,7 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
 
     /**
      * Creates an appropriate instance of {@link ObjectName} from specified class name and domain name.
-     * 
+     *
      * @param className The class name to use as object name
      * @param domain The domain name
      * @return An appropriate instance of {@link ObjectName}
