@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,6 +65,7 @@ import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBPoolProvider;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.contact.Contacts;
 import com.openexchange.groupware.container.FolderObject;
@@ -77,7 +78,7 @@ import com.openexchange.groupware.infostore.facade.impl.InfostoreFacadeImpl;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.tasks.Tasks;
-import com.openexchange.groupware.tx.DBPoolProvider;
+import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.i18n.tools.StringHelper;
@@ -87,7 +88,6 @@ import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.StringCollection;
-import com.openexchange.tools.iterator.FolderObjectIterator;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorAdapter;
 import com.openexchange.tools.iterator.SearchIteratorException;
@@ -95,7 +95,7 @@ import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 
 /**
  * OXFolderTools
- * 
+ *
  * @deprecated - use routines available in <code>OXFolderAccess</code>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -202,7 +202,7 @@ public class OXFolderTools {
             userId,
             userConfig,
             ctx,
-            con), getFolderModule(folderId, ctx, con), userConfig);
+            con), getFolderModule(folderId, ctx, con), getFolderOwner(folderId, ctx, con), userConfig);
         retval.setEntity(userId);
         retval.setAllPermission(
             OCLPermission.NO_PERMISSIONS,
@@ -665,7 +665,7 @@ public class OXFolderTools {
             final FolderObject parentFolder = new OXFolderAccess(ctx).getFolderObject(parentFolderId);
             final OCLPermission effectivePerm = parentFolder.getEffectiveUserPermission(userId, userConfig);
             if (effectivePerm.getFolderPermission() < OCLPermission.READ_FOLDER) {
-                return SearchIteratorAdapter.createEmptyIterator();
+                return SearchIteratorAdapter.emptyIterator();
             }
             return getVisibleSubfoldersIterator(parentFolder, userId, groups, userConfig.getAccessibleModules(), ctx, since);
         }
@@ -991,7 +991,7 @@ public class OXFolderTools {
                     if (fo.getCreatedBy() != OCLPermission.ALL_GROUPS_AND_USERS) {
                         throw e;
                     }
-                    final StringHelper strHelper = new StringHelper(locale);
+                    final StringHelper strHelper = StringHelper.valueOf(locale);
                     creatorDisplayName = strHelper.getString(Groups.ALL_USERS);
                 }
                 final FolderObject virtualOwnerFolder = FolderObject.createVirtualFolderObject(
