@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,8 @@
 
 package com.openexchange.tools.oxfolder;
 
-import gnu.trove.TIntArrayList;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.ArrayList;
@@ -78,12 +79,12 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link OXFolderUtility} - Provides utility methods for folder operations.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OXFolderUtility {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXFolderUtility.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXFolderUtility.class));
 
     private static final String STR_EMPTY = "";
 
@@ -96,7 +97,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks for duplicate folder name considering locale-sensitive folder names.
-     * 
+     *
      * @param parentFolderId The parent folder ID
      * @param folderName The folder name to check
      * @param locale The user's locale
@@ -134,7 +135,7 @@ public final class OXFolderUtility {
 
     /**
      * Tests if specified folder contains contains duplicate permissions.
-     * 
+     *
      * @param folder The folder whose permissions shall be checked.
      * @param ctx The context
      * @throws OXFolderException If specified folder contains contains duplicate permissions.
@@ -165,7 +166,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks for similar named shared folder
-     * 
+     *
      * @param userIds The user IDs
      * @param allSharedFolders The shared folders
      * @param folderName The folder name of the folder that shall be shared
@@ -216,7 +217,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks for invalid characters in folder name
-     * 
+     *
      * @param checkMe The folder whose name shall be checked
      * @throws OXFolderException If folder name contains invalid characters
      */
@@ -230,7 +231,7 @@ public final class OXFolderUtility {
     /**
      * Checks if permissions from given folder specify (at least) one folder admin and if creating user is the folder admin for his default
      * folders.
-     * 
+     *
      * @param folderObj The folder
      * @param userId The user ID
      * @param ctx The context
@@ -238,9 +239,9 @@ public final class OXFolderUtility {
      */
     public static void checkFolderPermissions(final FolderObject folderObj, final int userId, final Context ctx) throws OXException {
         final boolean isPrivate = (folderObj.getType() == FolderObject.PRIVATE || folderObj.getType() == FolderObject.SHARED);
-        int adminPermissionCount = 0;
+        final TIntList adminEntities = new TIntArrayList(isPrivate ? 1 : 4);
         final int permissionsSize = folderObj.getPermissions().size();
-        final Iterator<OCLPermission> iter = folderObj.getPermissions().iterator();
+        Iterator<OCLPermission> iter = folderObj.getPermissions().iterator();
         final int creator = folderObj.containsCreatedBy() ? folderObj.getCreatedBy() : userId;
         final boolean isDefaultFolder = folderObj.containsDefaultFolder() ? folderObj.isDefaultFolder() : false;
         boolean creatorIsAdmin = false;
@@ -254,16 +255,43 @@ public final class OXFolderUtility {
                     Integer.valueOf(ctx.getContextId()));
             }
             if (oclPerm.isFolderAdmin()) {
-                adminPermissionCount++;
+                adminEntities.add(oclPerm.getEntity());
                 if (isPrivate && folderObj.getModule() != FolderObject.SYSTEM_MODULE) {
-                    checkPrivateAdminPerm(adminPermissionCount, creator, oclPerm);
+                    checkPrivateAdminPerm(adminEntities.size(), creator, oclPerm);
                 }
                 if (isDefaultFolder && !creatorIsAdmin) {
                     creatorIsAdmin = (oclPerm.getEntity() == creator);
                 }
             }
         }
-        if (adminPermissionCount == 0) {
+        if (!isPrivate && !adminEntities.contains(creator)) {
+            iter = folderObj.getPermissions().iterator();
+            boolean found = false;
+            for (int i = 0; !found && i < permissionsSize; i++) {
+                final OCLPermission oclPerm = iter.next();
+                if (oclPerm.getEntity() == creator) {
+                    oclPerm.setFolderAdmin(true);
+                    found = true;
+                }
+            }
+            if (!found) {
+                final OCLPermission oclPerm = new OCLPermission();
+                oclPerm.setEntity(creator);
+                oclPerm.setGroupPermission(false);
+                oclPerm.setFolderAdmin(true);
+                oclPerm.setAllPermission(
+                    OCLPermission.NO_PERMISSIONS,
+                    OCLPermission.NO_PERMISSIONS,
+                    OCLPermission.NO_PERMISSIONS,
+                    OCLPermission.NO_PERMISSIONS);
+                oclPerm.setSystem(0);
+                final List<OCLPermission> nList = new ArrayList<OCLPermission>(folderObj.getPermissions());
+                nList.add(oclPerm);
+                adminEntities.add(creator);
+                folderObj.setPermissions(nList);
+            }
+        }
+        if (adminEntities.isEmpty()) {
             throw new OXFolderLogicException(OXFolderException.FolderCode.NO_FOLDER_ADMIN);
         } else if (isDefaultFolder && !creatorIsAdmin) {
             throw new OXFolderException(OXFolderException.FolderCode.CREATOR_IS_NOT_ADMIN, getUserName(creator, ctx), getFolderName(
@@ -286,7 +314,7 @@ public final class OXFolderUtility {
 
     /**
      * Ensures that an user who does not hold full shared folder access cannot share one of his private folders
-     * 
+     *
      * @param folderObj The folder object
      * @param sessionUserConfig The session user's configuration
      * @param ctx The context
@@ -319,7 +347,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks system folder permissions.
-     * 
+     *
      * @param folderId The folder ID
      * @param newPerms The update-operation permissions
      * @param ctx The context
@@ -413,7 +441,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the permissions without folder access by comparing specified storage-version permissions with update-operation permissions
-     * 
+     *
      * @param newPerms The update-operation permissions
      * @param storagePerms The storage-version permissions
      * @return The permissions without folder access
@@ -455,7 +483,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks every <b>user permission</b> against user configuration settings
-     * 
+     *
      * @param folderObj The folder object
      * @param ctx The context
      * @throws OXException If a composed permission does not obey user's configuration
@@ -472,9 +500,9 @@ public final class OXFolderUtility {
                 if (!isApplicable(maxApplicablePerm, assignedPerm)) {
                     throw new OXFolderException(
                         OXFolderException.FolderCode.UNAPPLICABLE_FOLDER_PERM,
+                        getUserName(assignedPerm.getEntity(), ctx),
                         getFolderName(folderObj),
-                        Integer.valueOf(ctx.getContextId()),
-                        getUserName(assignedPerm.getEntity(), ctx));
+                        Integer.valueOf(ctx.getContextId()));
                 }
             }
         }
@@ -487,6 +515,7 @@ public final class OXFolderUtility {
                 folderObj.getObjectID(),
                 folderObj.getType(userConfig.getUserId()),
                 folderObj.getModule(),
+                folderObj.getCreatedBy(),
                 userConfig);
         retval.setFolderAdmin(true);
         retval.setAllPermission(
@@ -506,7 +535,7 @@ public final class OXFolderUtility {
 
     /**
      * This routine ensures that owner of parental shared folder gets full access (incl. folder admin) to shared subfolder
-     * 
+     *
      * @param parentOwner The user ID of parent folder owner
      * @param folderObj The shared subfolder
      * @param userId The user ID
@@ -558,7 +587,7 @@ public final class OXFolderUtility {
                 OCLPermission.ADMIN_PERMISSION);
             ocls.add(pownerPerm);
         }
-        folderObj.setPermissions(ocls);
+        folderObj.setPermissionsNoClone(ocls);
     }
 
     private static final int[] SORTED_STD_MODULES =
@@ -566,7 +595,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks specified new folder module against parent folder
-     * 
+     *
      * @param parentId The parent folder ID
      * @param parentModule The parent module
      * @param newFolderModule The new folder module
@@ -595,7 +624,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks specified folder type against parent folder
-     * 
+     *
      * @param parentFolder The parent folder
      * @param newFolderType The folder type
      * @return <code>true</code> if parent allows specified folder type; otherwise <code>false</code>
@@ -609,6 +638,9 @@ public final class OXFolderUtility {
         case FolderObject.SYSTEM_PUBLIC_FOLDER_ID:
             enforcedType = FolderObject.PUBLIC;
             break;
+        case FolderObject.SYSTEM_INFOSTORE_FOLDER_ID:
+            enforcedType = FolderObject.PUBLIC;
+            break;
         case FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID:
             enforcedType = FolderObject.PUBLIC;
             break;
@@ -623,7 +655,7 @@ public final class OXFolderUtility {
 
     /**
      * Checks if specified folder ID is a descendant folder
-     * 
+     *
      * @param parentIDList The parent IDs
      * @param possibleDescendant The ID of possible descendant folder
      * @param readCon A connection with read-only capability
@@ -632,14 +664,14 @@ public final class OXFolderUtility {
      * @throws SQLException If a SQL error occurs
      * @throws DBPoolingException If a pooling error occurs
      */
-    public static boolean isDescendentFolder(final TIntArrayList parentIDList, final int possibleDescendant, final Connection readCon, final Context ctx) throws SQLException, DBPoolingException {
+    public static boolean isDescendentFolder(final TIntList parentIDList, final int possibleDescendant, final Connection readCon, final Context ctx) throws SQLException, DBPoolingException {
         final int size = parentIDList.size();
         boolean isDescendant = false;
         for (int i = 0; i < size && !isDescendant; i++) {
-            final TIntArrayList subfolderIDs = OXFolderSQL.getSubfolderIDs(parentIDList.getQuick(i), readCon, ctx);
+            final TIntList subfolderIDs = OXFolderSQL.getSubfolderIDs(parentIDList.get(i), readCon, ctx);
             final int subsize = subfolderIDs.size();
             for (int j = 0; j < subsize && !isDescendant; j++) {
-                final int current = subfolderIDs.getQuick(j);
+                final int current = subfolderIDs.get(j);
                 isDescendant |= (current == possibleDescendant);
             }
             if (isDescendant) {
@@ -656,10 +688,94 @@ public final class OXFolderUtility {
         return isDescendant;
     }
 
+    /**
+     * Checks if given update object indicates to perform a rename-only operation compared to storage object.
+     *
+     * @param updateObject The update object
+     * @param storageObject The storage object
+     * @return <code>true</code> if given update object indicates to perform a rename-only operation; otherwise <code>false</code>
+     */
+    public static boolean isRenameOnly(final FolderObject updateObject, final FolderObject storageObject) {
+        if (!updateObject.containsFolderName()) {
+            return false;
+        }
+        final String newName = updateObject.getFolderName();
+        if (null == newName || newName.equals(storageObject.getFolderName())) {
+            return false;
+        }
+        /*-
+         * Ok, folder name differs. Check other fields.
+         *
+         * Permissions
+         */
+        if (updateObject.containsPermissions()) {
+            final List<OCLPermission> updateList = Arrays.asList(updateObject.getNonSystemPermissionsAsArray());
+            if (null != updateList && isDifferent(Arrays.asList(storageObject.getNonSystemPermissionsAsArray()), updateList)) {
+                return false;
+            }
+        }
+        /*
+         * Parent
+         */
+        if (updateObject.containsParentFolderID()) {
+            final int updateParent = updateObject.getParentFolderID();
+            if (updateParent > 0 && storageObject.getParentFolderID() != updateParent) {
+                return false;
+            }
+        }
+        /*
+         * Module
+         */
+        if (updateObject.containsModule()) {
+            final int updateModule = updateObject.getModule();
+            if (updateModule > 0 && storageObject.getModule() != updateModule) {
+                return false;
+            }
+        }
+        /*
+         * Rename only
+         */
+        return true;
+    }
+
+    /**
+     * Checks if specified permission lists are different.
+     *
+     * @param storageList The storage-version permissions
+     * @param updateList The update-version permissions
+     * @return <code>true</code> if different; otherwise <code>false</code>
+     */
+    public static boolean isDifferent(final List<OCLPermission> storageList, final List<OCLPermission> updateList) {
+        if (updateList.isEmpty()) {
+            return false;
+        }
+        final int ssize = storageList.size();
+        for (final OCLPermission update : updateList) {
+            boolean found = false;
+            for (int i = 0; i < ssize && !found; i++) {
+                final OCLPermission storage = storageList.get(i);
+                if (storage.getEntity() == update.getEntity()) {
+                    found = true;
+                    if (!update.equalsPermission(storage)) {
+                        return true;
+                    }
+
+                }
+            }
+            if (!found) {
+                return true;
+            }
+        }
+        /*
+         * Same
+         */
+        return false;
+    }
+
     /**
      * Gets those entities which are new or updated in given update list compared to given storage list or whole update list if storage list
      * is <code>null</code>.
-     * 
+     *
      * @param storageList The storage list of permissions (if <code>null</code> whole update list entities are added)
      * @param updateList The update list of permissions
      * @param user The user ID
@@ -703,7 +819,7 @@ public final class OXFolderUtility {
     /**
      * Adds permission-associated user ID or group member IDs to specified set dependent on whether given permission denotes an user or a
      * group permission.
-     * 
+     *
      * @param permission The permission
      * @param users The set of user IDs
      * @param ctx The context (possibly needed to resolve group)
@@ -728,7 +844,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the folder name for logging/messaging purpose
-     * 
+     *
      * @param fo The folder
      * @return The folder name for logging/messaging purpose
      */
@@ -739,7 +855,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the folder name for logging/messaging purpose
-     * 
+     *
      * @param folderId The folder ID
      * @param ctx The context
      * @return The folder name for logging/messaging purpose
@@ -754,7 +870,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the user name for logging/messaging purpose.
-     * 
+     *
      * @param session The session
      * @param u The user
      * @return The user name for logging/messaging purpose.
@@ -772,7 +888,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the user name for logging/messaging purpose.
-     * 
+     *
      * @param userId The user ID
      * @param ctx The context
      * @return The user name for logging/messaging purpose.
@@ -794,7 +910,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the user name for logging/messaging purpose.
-     * 
+     *
      * @param session The server session
      * @return The user name for logging/messaging purpose.
      */
@@ -809,7 +925,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the group name for logging/messaging purpose.
-     * 
+     *
      * @param groupId The group ID
      * @param ctx The context
      * @return The group name for logging/messaging purpose.
@@ -839,7 +955,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the given type's string representation
-     * 
+     *
      * @param type The type
      * @return The type's string representation
      */
@@ -870,7 +986,7 @@ public final class OXFolderUtility {
 
     /**
      * Gets the given module's string representation
-     * 
+     *
      * @param module The module
      * @return The module's string representation
      */
