@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,19 +72,19 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.Groups;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.tools.StringCollection;
-import com.openexchange.tools.iterator.FolderObjectIterator;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 
 /**
  * This class provides SQL related methods to fill instances of <code>com.openexchange.tools.iterator.FolderObjectIterator</code>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OldOXFolderIteratorSQL {
@@ -492,7 +492,7 @@ public final class OldOXFolderIteratorSQL {
 
     /**
      * Gets all visible public folders that are not visible in hierarchic tree-view (because any ancestor folder is not visible)
-     * 
+     *
      * @param userId The user ID
      * @param groups The user's group IDs
      * @param userConfig The user configuration
@@ -507,7 +507,7 @@ public final class OldOXFolderIteratorSQL {
 
     /**
      * Gets all visible public folders that are not visible in hierarchic tree-view (because any ancestor folder is not visible)
-     * 
+     *
      * @param userId The user ID
      * @param groups The user's group IDs
      * @param userConfig The user configuration
@@ -524,7 +524,7 @@ public final class OldOXFolderIteratorSQL {
     /**
      * Gets specified module's visible public folders that are not visible in hierarchic tree-view (because any ancestor folder is not
      * visible)
-     * 
+     *
      * @param module The module whose non-hierarchic-visible folders should be determined
      * @param userId The user ID
      * @param groups The user's group IDs
@@ -687,7 +687,7 @@ public final class OldOXFolderIteratorSQL {
                     if (fo.getCreatedBy() != OCLPermission.ALL_GROUPS_AND_USERS) {
                         throw e;
                     }
-                    final StringHelper strHelper = new StringHelper(locale);
+                    final StringHelper strHelper = StringHelper.valueOf(locale);
                     creatorDisplayName = strHelper.getString(Groups.ALL_USERS);
                 }
                 final FolderObject virtualOwnerFolder = FolderObject.createVirtualFolderObject(
