@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,7 +75,7 @@ import com.openexchange.tools.oxfolder.OXFolderProperties;
 
 /**
  * {@link GABRestorerCLT} - Restores default permissions for global address book (GAB).
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class GABRestorerCLT {
@@ -175,7 +175,7 @@ public class GABRestorerCLT {
 
             } catch (final MalformedObjectNameException e) {
                 // Cannot occur
-                org.apache.commons.logging.LogFactory.getLog(GABRestorerCLT.class).error(e.getMessage(), e);
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(GABRestorerCLT.class)).error(e.getMessage(), e);
             } finally {
                 jmxConnector.close();
             }
