@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -101,7 +101,7 @@ final class JMXAuthenticatorImpl implements JMXAuthenticator {
         try {
             md = MessageDigest.getInstance("SHA-1");
         } catch (final NoSuchAlgorithmException e) {
-            org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class)).error(e.getMessage(), e);
             return raw;
         }
 
@@ -114,16 +114,16 @@ final class JMXAuthenticatorImpl implements JMXAuthenticator {
             /*
              * Cannot occur
              */
-            org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class)).error(e.getMessage(), e);
         }
         md.update(salt);
 
         try {
             return Charset.forName("US-ASCII").decode(ByteBuffer.wrap(Base64.encodeBase64(md.digest()))).toString();
         } catch (final IllegalCharsetNameException e) {
-            org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class)).error(e.getMessage(), e);
         } catch (final UnsupportedCharsetException e) {
-            org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class).error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JMXAuthenticatorImpl.class)).error(e.getMessage(), e);
         }
 
         return null;
