@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,12 +60,12 @@ import com.openexchange.tools.oxfolder.deletelistener.sql.UserPermissionMerger;
 
 /**
  * {@link OXFolderDeleteListenerHelper} - Offers helper method related to {@link OXFolderDeleteListener}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OXFolderDeleteListenerHelper {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXFolderDeleteListenerHelper.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXFolderDeleteListenerHelper.class));
 
     /**
      * Initializes a new {@link OXFolderDeleteListenerHelper}
@@ -76,7 +76,7 @@ public final class OXFolderDeleteListenerHelper {
 
     /**
      * Ensures folder data consistency after user/group delete operation
-     * 
+     *
      * @param ctx The context
      * @throws DeleteFailedException If checking folder data consistency fails
      */
