@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,14 +52,21 @@ package com.openexchange.tools.oxfolder.downgrade;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Collection;
+import java.util.Dictionary;
 import java.util.HashSet;
+import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Set;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventAdmin;
 import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.api2.OXException;
 import com.openexchange.cache.impl.FolderCacheManager;
 import com.openexchange.cache.impl.FolderQueryCacheManager;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBPoolProvider;
+import com.openexchange.database.provider.StaticDBPoolProvider;
+import com.openexchange.folderstorage.FolderEventConstants;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCache;
 import com.openexchange.groupware.contact.Contacts;
@@ -68,11 +75,10 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.downgrade.DowngradeEvent;
 import com.openexchange.groupware.downgrade.DowngradeFailedException;
 import com.openexchange.groupware.downgrade.DowngradeListener;
+import com.openexchange.groupware.infostore.InfostoreException;
 import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.infostore.facade.impl.InfostoreFacadeImpl;
 import com.openexchange.groupware.tasks.Tasks;
-import com.openexchange.groupware.tx.DBPoolProvider;
-import com.openexchange.groupware.tx.StaticDBPoolProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -80,11 +86,13 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderException;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 import com.openexchange.tools.oxfolder.downgrade.sql.OXFolderDowngradeSQL;
+import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tx.TransactionException;
 
 /**
  * {@link OXFolderDowngradeListener} - Performs deletion of unused folder data remaining from a former downgrade.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class OXFolderDowngradeListener extends DowngradeListener {
@@ -93,7 +101,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
 
     private static final String TABLE_PERMISSIONS_WORKING = "oxfolder_permissions";
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXFolderDowngradeListener.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXFolderDowngradeListener.class));
 
     /**
      * Initializes a new {@link OXFolderDowngradeListener}
@@ -111,11 +119,12 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
              */
             try {
                 deleteCalendarFolderData(newUserConfiguration.getUserId(), event);
-            } catch (final OXException e) {
-                throw new DowngradeFailedException(e);
-            }
-            if (LOG.isInfoEnabled()) {
-                LOG.info("All calendar-related folder data removed due to loss of task module access");
+                if (LOG.isInfoEnabled()) {
+                    LOG.info("All calendar-related folder data removed due to loss of calendar module access");
+                }
+            } catch (final Exception e) {
+                LOG.warn("Could not remove all calendar-related folder data caused by loss of calendar module access.");
+                LOG.debug(e.getMessage(), e);
             }
         }
         if (!newUserConfiguration.hasTask()) {
@@ -124,11 +133,12 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
              */
             try {
                 deleteTaskFolderData(newUserConfiguration.getUserId(), event);
-            } catch (final OXException e) {
-                throw new DowngradeFailedException(e);
-            }
-            if (LOG.isInfoEnabled()) {
-                LOG.info("All task-related folder data removed due to loss of task module access");
+                if (LOG.isInfoEnabled()) {
+                    LOG.info("All task-related folder data removed due to loss of task module access");
+                }
+            } catch (final Exception e) {
+                LOG.warn("Could not remove all task-related folder data caused by loss of task module access.");
+                LOG.debug(e.getMessage(), e);
             }
         }
         if (!newUserConfiguration.hasInfostore()) {
@@ -137,11 +147,12 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
              */
             try {
                 deleteInfostoreFolderData(newUserConfiguration.getUserId(), event);
-            } catch (final OXException e) {
-                throw new DowngradeFailedException(e);
-            }
-            if (LOG.isInfoEnabled()) {
-                LOG.info("All infostore-related folder data removed due to loss of task module access");
+                if (LOG.isInfoEnabled()) {
+                    LOG.info("All infostore-related folder data removed due to loss of infostore module access");
+                }
+            } catch (final Exception e) {
+                LOG.warn("Could not remove all infostore-related folder data caused by loss of infostore module access.");
+                LOG.debug(e.getMessage(), e);
             }
         }
         if (!newUserConfiguration.hasFullSharedFolderAccess()) {
@@ -150,11 +161,12 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
              */
             try {
                 deleteSharedFolderData(newUserConfiguration.getUserId(), event);
-            } catch (final OXFolderException e) {
-                throw new DowngradeFailedException(e);
-            }
-            if (LOG.isInfoEnabled()) {
-                LOG.info("All shared folder data removed due to loss of full shared folder access");
+                if (LOG.isInfoEnabled()) {
+                    LOG.info("All shared folder data removed due to loss of full shared folder access");
+                }
+            } catch (final Exception e) {
+                LOG.warn("Could not remove all shared folder data caused by loss of full shared folder access.");
+                LOG.debug(e.getMessage(), e);
             }
         }
         /*
@@ -179,7 +191,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
      * <li>Delete all shared permissions assigned to default calendar folder</li>
      * <li>Delete all public calendar folders' permissions assigned to affected user; reassign to context admin if necessary</li>
      * </ul>
-     * 
+     *
      * @param entity The user's ID
      * @param event The downgrade event
      * @throws OXException If a folder error occurs
@@ -195,7 +207,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
      * <li>Delete all shared permissions assigned to default task folder</li>
      * <li>Delete all public task folders' permissions assigned to affected user; reassign to context admin if necessary</li>
      * </ul>
-     * 
+     *
      * @param entity The user's ID
      * @param event The downgrade event
      * @throws OXException If a folder error occurs
@@ -211,7 +223,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
      * </ul>
      * <p>
      * Folder cache is updated, too
-     * 
+     *
      * @param entity The user's ID
      * @param event The downgrade event
      * @throws OXException If a folder error occurs
@@ -230,7 +242,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
                 TABLE_PERMISSIONS_WORKING,
                 event.getWriteCon());
             if (fuid != -1) {
-                removeFromFolderCache(new int[] { fuid }, event.getContext());
+                removeFromFolderCache(new int[] { fuid }, entity, event.getContext());
             }
             /*
              * Remove subfolders below default folder
@@ -247,7 +259,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
             /*
              * Update cache
              */
-            removeFromFolderCache(fuids, event.getContext());
+            removeFromFolderCache(fuids, entity, event.getContext());
         } catch (final SQLException e) {
             throw new OXFolderException(OXFolderException.FolderCode.SQL_ERROR, e, e.getMessage());
         }
@@ -259,7 +271,7 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
 
     /**
      * Deletes specified module's folder data and updates the folder cache
-     * 
+     *
      * @param entity The entity whose folder data ought to be deleted
      * @param module The module
      * @param event The downgrade event providing needed information
@@ -325,12 +337,12 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
         /*
          * Update cache
          */
-        removeFromFolderCache(ids, event.getContext());
+        removeFromFolderCache(ids, entity, event.getContext());
     }
 
     /**
      * Deletes folders' content
-     * 
+     *
      * @param fuids The folder IDs
      * @param event The downgrade event
      * @throws OXException If deleting contents fails
@@ -367,15 +379,18 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
     }
 
     private static void deleteContainedAppointments(final int folderID, final DowngradeEvent event) throws OXException {
-        final AppointmentSQLInterface cSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(event.getSession());
-        try {
-            if (null == event.getWriteCon()) {
-                cSql.deleteAppointmentsInFolder(folderID);
-            } else {
-                cSql.deleteAppointmentsInFolder(folderID, event.getWriteCon());
+        final AppointmentSqlFactoryService service = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class);
+        if (null != service) {
+            final AppointmentSQLInterface cSql = service.createAppointmentSql(event.getSession());
+            try {
+                if (null == event.getWriteCon()) {
+                    cSql.deleteAppointmentsInFolder(folderID);
+                } else {
+                    cSql.deleteAppointmentsInFolder(folderID, event.getWriteCon());
+                }
+            } catch (final SQLException e) {
+                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
             }
-        } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -426,21 +441,31 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
             db.setCommitsTransaction(false);
         }
         db.setTransactional(true);
-        db.startTransaction();
         try {
+            db.startTransaction();
             db.removeDocument(folderID, System.currentTimeMillis(), new ServerSessionAdapter(event.getSession(), event.getContext()));
             db.commit();
         } catch (final OXException x) {
-            db.rollback();
+            try {
+                db.rollback();
+            } catch (final TransactionException e) {
+                throw new InfostoreException(e);
+            }
             throw x;
+        } catch (final TransactionException e) {
+            throw new InfostoreException(e);
         } finally {
-            db.finish();
+            try {
+                db.finish();
+            } catch (final TransactionException e) {
+                throw new InfostoreException(e);
+            }
         }
     }
 
     /**
      * Deletes the shared folder data and updates cache
-     * 
+     *
      * @param entity The entity
      * @param event The downgrade event
      * @throws OXFolderException If deleting the shared folder data fails
@@ -462,22 +487,23 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
         /*
          * Update cache
          */
-        removeFromFolderCache(set, event.getContext());
+        removeFromFolderCache(set, entity, event.getContext());
     }
 
-    private static void removeFromFolderCache(final Collection<Integer> collection, final Context ctx) {
+    private static void removeFromFolderCache(final Collection<Integer> collection, final int userId, final Context ctx) {
         final int[] ints = new int[collection.size()];
         final Iterator<Integer> iter = collection.iterator();
         for (int i = 0; i < ints.length; i++) {
             ints[i] = iter.next().intValue();
         }
-        removeFromFolderCache(ints, ctx);
+        removeFromFolderCache(ints, userId, ctx);
     }
 
-    private static void removeFromFolderCache(final int[] folderIDs, final Context ctx) {
+    private static void removeFromFolderCache(final int[] folderIDs, final int userId, final Context ctx) {
         /*
          * Remove from cache
          */
+        ConditionTreeMapManagement.dropFor(ctx.getContextId());
         if (FolderCacheManager.isEnabled() && FolderCacheManager.isInitialized()) {
             try {
                 FolderCacheManager.getInstance().removeFolderObjects(folderIDs, ctx);
@@ -485,6 +511,18 @@ public final class OXFolderDowngradeListener extends DowngradeListener {
                 LOG.error(e.getMessage(), e);
             }
         }
+        final EventAdmin eventAdmin = ServerServiceRegistry.getInstance().getService(EventAdmin.class);
+        if (null != eventAdmin) {
+            for (int i = 0; i < folderIDs.length; i++) {
+                final Dictionary<String, Object> props = new Hashtable<String, Object>(1);
+                props.put(FolderEventConstants.PROPERTY_FOLDER, String.valueOf(folderIDs[i]));
+                props.put(FolderEventConstants.PROPERTY_CONTEXT, Integer.valueOf(ctx.getContextId()));
+                props.put(FolderEventConstants.PROPERTY_USER, Integer.valueOf(userId));
+                props.put(FolderEventConstants.PROPERTY_CONTENT_RELATED, Boolean.FALSE);
+                final Event event = new Event(FolderEventConstants.TOPIC_ATTR, props);
+                eventAdmin.postEvent(event);
+            }
+        }
     }
 
     @Override
