@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,7 +50,6 @@
 package com.openexchange.tools.oxfolder.downgrade.sql;
 
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
-
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -61,25 +60,24 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
-
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.tools.Collections.SmartIntArray;
 
 /**
  * {@link OXFolderDowngradeSQL} - Provides several SQL commands in order to
  * delete unused user folder data remaining from a former downgrade.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
+ *
  */
 public final class OXFolderDowngradeSQL {
 
 	/**
 	 * {@link Permission} - Simple container for a permission.
-	 * 
+	 *
 	 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben
 	 *         Betten</a>
-	 * 
+	 *
 	 */
 	private static final class Permission {
 
@@ -101,7 +99,7 @@ public final class OXFolderDowngradeSQL {
 
 		/**
 		 * Initializes a new {@link Permission}
-		 * 
+		 *
 		 * @param entity
 		 *            The entity ID
 		 * @param fuid
@@ -134,7 +132,7 @@ public final class OXFolderDowngradeSQL {
 
 		/**
 		 * Initializes a new {@link Permission} from specified permission
-		 * 
+		 *
 		 * @param The
 		 *            entity ID
 		 * @param src
@@ -154,7 +152,7 @@ public final class OXFolderDowngradeSQL {
 
 		/**
 		 * Initializes a new {@link Permission} from specified permission
-		 * 
+		 *
 		 * @param The
 		 *            entity ID
 		 * @param fuid
@@ -207,7 +205,7 @@ public final class OXFolderDowngradeSQL {
 
 	/**
 	 * Drops all system permissions from public folders of given module
-	 * 
+	 *
 	 * @param module
 	 *            The module
 	 * @param entity
@@ -248,7 +246,7 @@ public final class OXFolderDowngradeSQL {
 	/**
 	 * Gets all user's private folders' IDs of specified module except the
 	 * module's default folder.
-	 * 
+	 *
 	 * @param module
 	 *            The module
 	 * @param owner
@@ -289,7 +287,7 @@ public final class OXFolderDowngradeSQL {
 
 	/**
 	 * Deletes specified folders' permissions from specified permission table.
-	 * 
+	 *
 	 * @param fuids
 	 *            The folder IDs
 	 * @param cid
@@ -324,7 +322,7 @@ public final class OXFolderDowngradeSQL {
 
 	/**
 	 * Deletes specified folders from specified folder table.
-	 * 
+	 *
 	 * @param fuids
 	 *            The folder IDs
 	 * @param cid
@@ -366,7 +364,7 @@ public final class OXFolderDowngradeSQL {
 	/**
 	 * Determines the module's public folders' IDs which hold a permission entry
 	 * for specified entity
-	 * 
+	 *
 	 * @param entity
 	 *            The entity
 	 * @param module
@@ -419,7 +417,7 @@ public final class OXFolderDowngradeSQL {
 	/**
 	 * Removes all shared permissions from module's default folder for specified
 	 * entity
-	 * 
+	 *
 	 * @param entity
 	 *            The entity
 	 * @param module
@@ -475,7 +473,7 @@ public final class OXFolderDowngradeSQL {
 
 	/**
 	 * Handles the affected public folder's permissions
-	 * 
+	 *
 	 * @param entity
 	 *            The entity ID
 	 * @param fuid
@@ -650,7 +648,7 @@ public final class OXFolderDowngradeSQL {
 	/**
 	 * Removes all shared permissions bound to given entity's private folders
 	 * and all shared permissions assigned to given entity by private folders
-	 * 
+	 *
 	 * @param entity
 	 *            The entity ID
 	 * @param cid
@@ -725,7 +723,7 @@ public final class OXFolderDowngradeSQL {
 	}
 
 	private static final String SQL_SEL_SUB_INFO_FLD = "SELECT ot.fuid FROM " + RPL_FOLDER
-			+ " AS ot WHERE ot.parent IN (" + "SELECT ot2.fuid FROM " + RPL_FOLDER
+			+ " AS ot WHERE ot.cid = ? AND ot.module = ? AND ot.parent IN (" + "SELECT ot2.fuid FROM " + RPL_FOLDER
 			+ " AS ot2 WHERE ot2.cid = ? AND ot2.module = ? AND ot2.created_from = ? AND ot2.default_flag = 1)";
 
 	private static final String SQL_SEL_SUB2_INFO_FLD = "SELECT ot.fuid FROM " + RPL_FOLDER
@@ -733,7 +731,7 @@ public final class OXFolderDowngradeSQL {
 
 	/**
 	 * Gathers all subfolders below default infostore folder
-	 * 
+	 *
 	 * @param entity
 	 *            The entity
 	 * @param cid
@@ -760,7 +758,9 @@ public final class OXFolderDowngradeSQL {
 			stmt = writeCon.prepareStatement(SQL_SEL_SUB_INFO_FLD.replaceAll(RPL_FOLDER, folderTable));
 			stmt.setInt(1, cid);
 			stmt.setInt(2, FolderObject.INFOSTORE);
-			stmt.setInt(3, entity);
+			stmt.setInt(3, cid);
+			stmt.setInt(4, FolderObject.INFOSTORE);
+			stmt.setInt(5, entity);
 			rs = stmt.executeQuery();
 			final SmartIntArray sia = new SmartIntArray(128);
 			while (rs.next()) {
