@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,9 +51,14 @@ package com.openexchange.tools.oxfolder.treeconsistency;
 
 import java.sql.Connection;
 import java.util.Arrays;
+import java.util.Dictionary;
+import java.util.Hashtable;
 import java.util.List;
+import org.osgi.service.event.Event;
+import org.osgi.service.event.EventAdmin;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.folderstorage.FolderEventConstants;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
@@ -62,12 +67,12 @@ import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.session.Session;
 import com.openexchange.tools.oxfolder.OXFolderException;
-import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
+import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 
 /**
  * {@link CheckPermission}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 abstract class CheckPermission {
@@ -82,7 +87,7 @@ abstract class CheckPermission {
 
     /**
      * Initializes a new {@link CheckPermission}
-     * 
+     *
      * @param session The session
      * @param writeCon A connection with write capability
      * @param ctx The context
@@ -97,7 +102,7 @@ abstract class CheckPermission {
 
     /**
      * Gets the folder from master database
-     * 
+     *
      * @param folderId The folder ID
      * @return The folder from master database
      * @throws OXException If folder cannot be fetched from master database
@@ -108,7 +113,7 @@ abstract class CheckPermission {
 
     /**
      * Gets the folder from master database with or without subfolder IDs loaded
-     * 
+     *
      * @param folderId The folder ID
      * @param withSubfolders whether to load subfolder IDs, too
      * @return The folder from master database
@@ -140,7 +145,7 @@ abstract class CheckPermission {
 
     /**
      * Gets the effective user permission
-     * 
+     *
      * @param userId The user ID
      * @param userConfig The user's configuration
      * @param folder The folder needed to determine type, module, etc.
@@ -153,6 +158,7 @@ abstract class CheckPermission {
             folder.getObjectID(),
             folder.getType(userId),
             folder.getModule(),
+            folder.getCreatedBy(),
             userConfig);
         maxPerm.setAllPermission(
             OCLPermission.NO_PERMISSIONS,
@@ -193,7 +199,7 @@ abstract class CheckPermission {
 
     /**
      * Checks if specified permissions contain a system-read-folder permission for given entity
-     * 
+     *
      * @param permissions The permissions to check
      * @param entity The entity
      * @return <code>true</code> if specified permissions contain a system-read-folder permission for given entity; otherwise
@@ -207,4 +213,36 @@ abstract class CheckPermission {
         }
         return false;
     }
+
+    /**
+     * Broadcast folder event.
+     *
+     * @param folderId The folder identifier
+     * @param deleted <code>true</code> if deleted; otherwise changed
+     * @param eventAdmin The event admin service reference
+     */
+    protected void broadcastEvent(final int folderId, final boolean deleted, final EventAdmin eventAdmin) {
+        if (null != eventAdmin) {
+            final Dictionary<String, Object> properties = new Hashtable<String, Object>(6);
+            properties.put(FolderEventConstants.PROPERTY_CONTEXT, Integer.valueOf(session.getContextId()));
+            properties.put(FolderEventConstants.PROPERTY_USER, Integer.valueOf(session.getUserId()));
+            properties.put(FolderEventConstants.PROPERTY_SESSION, session);
+            properties.put(FolderEventConstants.PROPERTY_FOLDER, String.valueOf(folderId));
+            properties.put(FolderEventConstants.PROPERTY_CONTENT_RELATED, Boolean.valueOf(!deleted));
+            /*
+             * Create event with push topic
+             */
+            final Event event = new Event(FolderEventConstants.TOPIC, properties);
+            /*
+             * Finally deliver it
+             */
+            eventAdmin.sendEvent(event);
+            final org.apache.commons.logging.Log logger = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(CheckPermission.class));
+            if (logger.isDebugEnabled()) {
+                logger.debug(new StringBuilder(64).append("Notified ").append("content-related").append("-wise changed folder \"").append(
+                    folderId).append(" in context ").append(session.getContextId()).toString());
+            }
+        }
+    }
+
 }
