@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,11 @@
 
 package com.openexchange.tools.service;
 
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Dictionary;
+import java.util.Hashtable;
+import java.util.List;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import org.apache.commons.logging.Log;
@@ -56,6 +61,7 @@ import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.BundleContext;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.server.osgiservice.DeferredRegistryRegistration;
 
 
@@ -67,13 +73,25 @@ import com.openexchange.server.osgiservice.DeferredRegistryRegistration;
  */
 public class ServletRegistration extends DeferredRegistryRegistration<HttpService, HttpServlet> {
 
-    private static final Log LOG = LogFactory.getLog(ServletRegistration.class);
-    
-    private String alias;
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletRegistration.class));
 
-    public ServletRegistration(BundleContext context, HttpServlet item, String alias) {
-        super(context, HttpService.class, item);
+    private static final Class<?>[] NO_SERVICES = new Class<?>[0];
+    private static final Class<?>[] CONFIGURATION_SERVICE = new Class<?>[]{ConfigurationService.class};
+
+    private final String alias;
+
+    private final List<String> configKeys;
+
+    private boolean registered;
+
+    public ServletRegistration(final BundleContext context, final HttpServlet item, final String alias, final String...configKeys) {
+        this(context, item, alias, ((configKeys == null || configKeys.length == 0) ? new ArrayList<String>() : Arrays.asList(configKeys)));
+    }
+
+    public ServletRegistration(final BundleContext context, final HttpServlet item, final String alias, final List<String> configKeys) {
+        super(context, HttpService.class, item, ((configKeys == null || configKeys.isEmpty()) ? NO_SERVICES : CONFIGURATION_SERVICE));
         this.alias = alias;
+        this.configKeys = configKeys;
         if(alias == null) {
             throw new IllegalArgumentException("The alias must not be null");
         }
@@ -81,20 +99,47 @@ public class ServletRegistration extends DeferredRegistryRegistration<HttpServic
     }
 
     @Override
-    public void register(HttpService registry, HttpServlet item) {
+    public void register(final HttpService registry, final HttpServlet item) {
         try {
-            registry.registerServlet(alias, item, null, null);
-        } catch (ServletException e) {
+            final Dictionary<String, String> initParams = new Hashtable<String, String>();
+            final ConfigurationService configurationService = getService(ConfigurationService.class);
+            if (configurationService != null) {
+                for(final String configKey : configKeys) {
+                    final String property = configurationService.getProperty(configKey);
+                    if (null == property) {
+                        /*
+                         * Missing initialization parameter
+                         */
+                        throw new IllegalStateException(new StringBuilder("Missing initialization parameter \"").append(configKey).append(
+                            "\". Aborting registration of servlet \"").append(item.getClass().getName()).append(
+                            "\" into the URI namespace \"").append(alias).append("\".").toString());
+                    }
+                    initParams.put(configKey, property);
+                }
+            }
+            customizeInitParams(initParams);
+            registry.registerServlet(alias, item, initParams, null);
+            registered = true;
+        } catch (final ServletException e) {
             LOG.error(e.getMessage(), e);
-        } catch (NamespaceException e) {
+        } catch (final NamespaceException e) {
+            LOG.error(e.getMessage(), e);
+        } catch (final IllegalStateException e) {
             LOG.error(e.getMessage(), e);
         }
     }
 
 
+    protected void customizeInitParams(final Dictionary<String, String> initParams) {
+        // Can be overridden
+    }
+
     @Override
     public void unregister(HttpService registry, HttpServlet item) {
-        registry.unregister(alias);
+        if (registered && registry != null) {
+            registry.unregister(alias);
+        }
+        registered = false;
     }
 
 
