@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,7 @@ import com.openexchange.groupware.EnumComponent;
 
 /**
  * Exception for problems in servlets.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public class AjaxException extends AbstractOXException {
@@ -66,7 +66,7 @@ public class AjaxException extends AbstractOXException {
 
     /**
      * Initializes a new {@link AjaxException}
-     * 
+     *
      * @param cause The init cause
      */
     public AjaxException(final AbstractOXException cause) {
@@ -75,7 +75,7 @@ public class AjaxException extends AbstractOXException {
 
     /**
      * Initializes a new exception using the information provided by the code.
-     * 
+     *
      * @param code code for the exception.
      * @param cause the cause of the exception.
      * @param messageArgs arguments that will be formatted into the message.
@@ -86,7 +86,7 @@ public class AjaxException extends AbstractOXException {
 
     /**
      * Initializes a new exception using the information provided by the code.
-     * 
+     *
      * @param code code for the exception.
      * @param cause the cause of the exception.
      * @param messageArgs arguments that will be formatted into the message.
@@ -98,7 +98,7 @@ public class AjaxException extends AbstractOXException {
 
     /**
      * Error codes for servlet exceptions.
-     * 
+     *
      * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
      */
     public enum Code {
@@ -107,7 +107,7 @@ public class AjaxException extends AbstractOXException {
          */
         UnknownAction("Unknown AJAX action: %s.", Category.CODE_ERROR, 1),
         /**
-         * Missing the following field: %s
+         * Missing the following request parameter: %s
          */
         MISSING_PARAMETER("Missing the following request parameter: %s", Category.CODE_ERROR, 2),
         /**
@@ -159,11 +159,15 @@ public class AjaxException extends AbstractOXException {
          */
         NonSecureDenied("Action \"%1$s\" on request path \"%2$s\" is not permitted via a non-secure connection.", Category.CODE_ERROR, 14),
         /**
-         * The Action "%1$s" is disabled due to the server configuration
+         * The action "%1$s" is disabled due to server configuration
          */
-        DisabledAction("The Action \"%1$s\" is disabled due to the server configuration", Category.PERMISSION, 15),
+        DisabledAction("The action \"%1$s\" is disabled due to server configuration", Category.PERMISSION, 15),
+        /**
+         * Too many concurrent requests. Please try again later.
+         */
+        TOO_MANY_REQUESTS("Too many concurrent requests. Please try again later.", Category.TRY_AGAIN, 19),
         ;
-        
+
         /**
          * Message of the exception.
          */
@@ -181,7 +185,7 @@ public class AjaxException extends AbstractOXException {
 
         /**
          * Default constructor.
-         * 
+         *
          * @param message message.
          * @param category category.
          * @param detailNumber detail number.
