@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,12 +67,12 @@ import org.osgi.util.tracker.ServiceTracker;
  *
  */
 public class HTTPServletRegistration extends ServiceTracker{
-    
-    private static Log LOG = LogFactory.getLog(HTTPServletRegistration.class);
-    
+
+    private static Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(HTTPServletRegistration.class));
+
     private Servlet servlet;
     private String alias;
-    
+
 
     public HTTPServletRegistration(BundleContext context, String alias, Servlet servlet) {
         super(context, HttpService.class.getName(), null);
@@ -80,7 +80,7 @@ public class HTTPServletRegistration extends ServiceTracker{
         this.servlet = servlet;
         open();
     }
-    
+
     @Override
     public Object addingService(ServiceReference reference) {
         HttpService service = (HttpService) super.addingService(reference);
@@ -93,14 +93,14 @@ public class HTTPServletRegistration extends ServiceTracker{
         }
         return service;
     }
-    
+
     @Override
     public void removedService(ServiceReference reference, Object service) {
         HttpService httpService = (HttpService)service;
         httpService.unregister(alias);
         super.removedService(reference, service);
     }
-    
+
     public void unregister() {
         close();
         if(getService() != null) {
