@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,12 +56,12 @@ import java.util.concurrent.locks.ReentrantLock;
 
 /**
  * {@link Timeout} - A simple timeout
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class Timeout implements Runnable {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(Timeout.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(Timeout.class));
 
     private final Lock lock;
 
@@ -79,7 +79,7 @@ public final class Timeout implements Runnable {
 
     /**
      * Timeout for current thread
-     * 
+     *
      * @param timeoutMillis The timeout in milliseconds
      */
     public Timeout(final long timeoutMillis) {
@@ -88,7 +88,7 @@ public final class Timeout implements Runnable {
 
     /**
      * Timeout for given thread
-     * 
+     *
      * @param target The target thread to kill if timeout elapsed
      * @param timeoutMillis The timeout in milliseconds
      */
@@ -132,7 +132,7 @@ public final class Timeout implements Runnable {
 
     /**
      * Reset
-     * 
+     *
      * @param millis The new timeout in milliseconds
      */
     public void reset(final long timeoutMillis) {
