@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,26 +61,27 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
+import java.util.Set;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.filestore.FilestoreException;
 import com.openexchange.groupware.filestore.FilestoreStorage;
-import com.openexchange.groupware.tx.SimpleDBProvider;
 import com.openexchange.tools.file.FileStorage;
-import com.openexchange.tools.file.FileStorageException;
+import com.openexchange.tools.file.QuotaFileStorage;
+import com.openexchange.tools.file.external.FileStorageException;
 
 /**
  * This class contains some tools to ease update of database.
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class Tools {
@@ -128,7 +129,7 @@ public final class Tools {
         }
         boolean matches = columns.length == foundColumns.size();
         for (int i = 0; matches && i < columns.length; i++) {
-            matches = columns[i].equals(foundColumns.get(i));
+            matches = columns[i].equalsIgnoreCase(foundColumns.get(i));
         }
         return matches;
     }
@@ -174,7 +175,7 @@ public final class Tools {
             }
             boolean matches = true;
             for (int i = 0; matches && i < columns.length; i++) {
-                matches = columns[i].equals(foundColumns.get(i));
+                matches = columns[i].equalsIgnoreCase(foundColumns.get(i));
             }
             if (matches) {
                 foundIndex = entry.getKey();
@@ -209,13 +210,31 @@ public final class Tools {
             closeSQLStuff(result);
         }
         for (final ForeignKey key : keys) {
-            if (key.getPrimaryTable().equals(primaryTable) && key.getForeignTable().equals(foreignTable) && key.matches(primaryColumns, foreignColumns)) {
+            if (key.getPrimaryTable().equalsIgnoreCase(primaryTable) && key.getForeignTable().equalsIgnoreCase(foreignTable) && key.matches(primaryColumns, foreignColumns)) {
                 return key.getName();
             }
         }
         return null;
     }
 
+    public static final List<String> allForeignKey(final Connection con, final String foreignTable) throws SQLException {
+        final DatabaseMetaData metaData = con.getMetaData();
+        ResultSet result = null;
+        try {
+            result = metaData.getImportedKeys(null, null, foreignTable);
+            final Set<String> set = new HashSet<String>();
+            while (result.next()) {
+                final String keyName = result.getString("FK_NAME");
+                if (null != keyName) {
+                    set.add(keyName);
+                }
+            }
+            return new ArrayList<String>(set);
+        } finally {
+            closeSQLStuff(result);
+        }
+    }
+
     /**
      * This method drops the primary key on the table. Beware, this method is vulnerable to SQL injection because table and index name can
      * not be set through a {@link PreparedStatement}.
@@ -237,7 +256,7 @@ public final class Tools {
     /**
      * This method drops an index with the given name. Beware, this method is vulnerable to SQL injection because table and index name can
      * not be set through a {@link PreparedStatement}.
-     * 
+     *
      * @param con writable database connection.
      * @param table table name that index should be dropped.
      * @param index name of the index to drop.
@@ -324,7 +343,7 @@ public final class Tools {
     /**
      * This method creates a new index on a table. Beware, this method is vulnerable to SQL injection because table and column names can not
      * be set through a {@link PreparedStatement}.
-     * 
+     *
      * @param con writable database connection.
      * @param table name of the table that should get a new index.
      * @param name name of the index or <code>null</code> to let the database define the name.
@@ -364,7 +383,7 @@ public final class Tools {
     /**
      * This method creates a new index on a table. Beware, this method is vulnerable to SQL injection because table and column names can not
      * be set through a {@link PreparedStatement}.
-     * 
+     *
      * @param con writable database connection.
      * @param table name of the table that should get a new index.
      * @param columns names of the columns the index should cover.
@@ -413,7 +432,7 @@ public final class Tools {
 
     /**
      * Checks if denoted table has any primary key set.
-     * 
+     *
      * @param con The connection
      * @param table The table name
      * @return <code>true</code> if denoted table has any primary key set; otherwise <code>false</code>
@@ -432,7 +451,7 @@ public final class Tools {
 
     /**
      * Checks if denoted column in given table is of type {@link java.sql.Types#VARCHAR}.
-     * 
+     *
      * @param con The connection
      * @param table The table name
      * @param column The column name
@@ -445,7 +464,7 @@ public final class Tools {
 
     /**
      * Checks if denoted column in given table is of specified type from {@link java.sql.Types}.
-     * 
+     *
      * @param con The connection
      * @param table The table name
      * @param column The column name
@@ -459,7 +478,7 @@ public final class Tools {
 
     /**
      * Gets the type of specified column in given table from {@link java.sql.Types}.
-     * 
+     *
      * @param con The connection
      * @param table The table name
      * @param column The column name
@@ -484,13 +503,31 @@ public final class Tools {
         return type;
     }
 
+    public static final String getColumnTypeName(final Connection con, final String table, final String column) throws SQLException {
+        if (!columnExists(con, table, column)) {
+            return null;
+        }
+        final DatabaseMetaData metaData = con.getMetaData();
+        ResultSet rs = null;
+        String typeName = null;
+        try {
+            rs = metaData.getColumns(null, null, table, column);
+            while (rs.next()) {
+                typeName = rs.getString(6);
+            }
+        } finally {
+            closeSQLStuff(rs);
+        }
+        return typeName;
+    }
+
     public static final boolean tableExists(final Connection con, final String table) throws SQLException {
         final DatabaseMetaData metaData = con.getMetaData();
         ResultSet rs = null;
         boolean retval = false;
         try {
             rs = metaData.getTables(null, null, table, new String[] { TABLE });
-            retval = (rs.next() && rs.getString("TABLE_NAME").equals(table));
+            retval = (rs.next() && rs.getString("TABLE_NAME").equalsIgnoreCase(table));
         } finally {
             closeSQLStuff(rs);
         }
@@ -499,7 +536,7 @@ public final class Tools {
 
     /**
      * Checks if specified column exists.
-     * 
+     *
      * @param con The connection
      * @param table The table name
      * @param column The column name
@@ -513,7 +550,7 @@ public final class Tools {
         try {
             rs = metaData.getColumns(null, null, table, column);
             while (rs.next()) {
-                retval = rs.getString(4).equals(column);
+                retval = rs.getString(4).equalsIgnoreCase(column);
             }
         } finally {
             closeSQLStuff(rs);
@@ -525,12 +562,12 @@ public final class Tools {
 
     private static final String TABLE = "TABLE";
 
-    public static void removeFile(final int cid, final String fileStoreLocation, final Connection con) throws FileStorageException, FilestoreException, ContextException {
+    public static void removeFile(final int cid, final String fileStoreLocation) throws FileStorageException, FilestoreException, ContextException {
         final Context ctx = ContextStorage.getInstance().loadContext(cid);
         final URI fileStorageURI = FilestoreStorage.createURI(ctx);
         final File file = new File(fileStorageURI);
         if (file.exists()) {
-            final FileStorage fs = FileStorage.getInstance(fileStorageURI, ctx, new SimpleDBProvider(con, con));
+            final FileStorage fs = QuotaFileStorage.getInstance(fileStorageURI, ctx);
             fs.deleteFile(fileStoreLocation);
         }
     }
@@ -578,17 +615,15 @@ public final class Tools {
         }
     }
 
-    public static void addColumns(Connection con, String tableName, Column... cols) throws SQLException {
-        StringBuffer sql = new StringBuffer("ALTER TABLE ");
+    public static void addColumns(final Connection con, final String tableName, final Column... cols) throws SQLException {
+        final StringBuffer sql = new StringBuffer("ALTER TABLE ");
         sql.append(tableName);
-        for (Column column : cols) {
-            if (!columnExists(con, tableName, column.getName())) {
-                sql.append(" ADD ");
-                sql.append(column.getName());
-                sql.append(' ');
-                sql.append(column.getDefinition());
-                sql.append(',');
-            }
+        for (final Column column : cols) {
+            sql.append(" ADD ");
+            sql.append(column.getName());
+            sql.append(' ');
+            sql.append(column.getDefinition());
+            sql.append(',');
         }
         if (sql.charAt(sql.length() - 1) == ',') {
             sql.setLength(sql.length() - 1);
@@ -604,4 +639,72 @@ public final class Tools {
             closeSQLStuff(stmt);
         }
     }
+
+    public static void checkAndAddColumns(final Connection con, final String tableName, final Column... cols) throws SQLException {
+        final List<Column> notExisting = new ArrayList<Column>();
+        for (final Column col : cols) {
+            if (!columnExists(con, tableName, col.getName())) {
+                notExisting.add(col);
+            }
+        }
+        if (!notExisting.isEmpty()) {
+            addColumns(con, tableName, notExisting.toArray(new Column[notExisting.size()]));
+        }
+    }
+
+    public static void modifyColumns(final Connection con, final String tableName, final Collection<Column> columns) throws SQLException {
+        modifyColumns(con, tableName, columns.toArray(new Column[columns.size()]));
+    }
+
+    public static void modifyColumns(final Connection con, final String tableName, final Column... cols) throws SQLException {
+        final StringBuffer sql = new StringBuffer("ALTER TABLE ");
+        sql.append(tableName);
+        for (final Column column : cols) {
+            sql.append(" MODIFY COLUMN ");
+            sql.append(column.getName());
+            sql.append(' ');
+            sql.append(column.getDefinition());
+            sql.append(',');
+        }
+        if (sql.charAt(sql.length() - 1) == ',') {
+            sql.setLength(sql.length() - 1);
+        }
+        if (sql.length() == 12 + tableName.length()) {
+            return;
+        }
+        Statement stmt = null;
+        try {
+            stmt = con.createStatement();
+            stmt.execute(sql.toString());
+        } finally {
+            closeSQLStuff(stmt);
+        }
+    }
+
+    public static void checkAndModifyColumns(final Connection con, final String tableName, final Column... cols) throws SQLException {
+        final List<Column> toDo = new ArrayList<Column>();
+        for (final Column col : cols) {
+            if (!col.getDefinition().contains(getColumnTypeName(con, tableName, col.getName()))) {
+                toDo.add(col);
+            }
+        }
+        if (!toDo.isEmpty()) {
+            modifyColumns(con, tableName, toDo.toArray(new Column[toDo.size()]));
+        }
+    }
+
+    public static int count(final Connection con, final String sql) throws SQLException {
+        final Statement stmt = con.createStatement();
+        ResultSet result = null;
+        int retval = 0;
+        try {
+            result = stmt.executeQuery(sql);
+            while (result.next()) {
+                retval += result.getInt(1);
+            }
+        } finally {
+            closeSQLStuff(result, stmt);
+        }
+        return retval;
+    }
 }
