@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,6 +65,7 @@ import java.net.URLConnection;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.BitSet;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
@@ -75,16 +76,21 @@ import java.util.StringTokenizer;
 import java.util.TimeZone;
 import javax.activation.MimetypesFileTypeMap;
 import javax.mail.internet.AddressException;
+import javax.mail.internet.IDNA;
 import javax.mail.internet.InternetAddress;
+import org.apache.commons.codec.DecoderException;
+import org.apache.commons.codec.net.QuotedPrintableCodec;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.RecurringResultsInterface;
 import com.openexchange.groupware.contact.ContactConfig;
+import com.openexchange.groupware.contact.ContactException;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.groupware.container.DistributionListEntryObject;
 import com.openexchange.groupware.container.ExternalUserParticipant;
 import com.openexchange.groupware.container.Participant;
 import com.openexchange.groupware.container.ResourceParticipant;
@@ -97,6 +103,7 @@ import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.java.Strings;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.ImageTypeDetector;
@@ -115,12 +122,16 @@ import com.openexchange.tools.versit.values.RecurrenceValue.Weekday;
 /**
  * This class transforms VersitObjects to OX Contacts, Appointments and Tasks and back. If you want to translate more fields used in ICAL or
  * VCard, you're at the right place - but don't forget to do it in both directions.
- * 
+ * <p>
+ * <a href="http://tools.ietf.org/html/rfc2426">vCard MIME Directory Profile</a>
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a> (adapted Victor's parser for OX6)
  * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a> (bugfixing and refactoring)
  */
 public class OXContainerConverter {
 
+    private static final String P_OPEN_XCHANGE_CTYPE = "X-OPEN-XCHANGE-CTYPE";
+
     private static final String P_ORGANIZER = "ORGANIZER";
 
     private static final String P_TLX = "TLX";
@@ -135,6 +146,8 @@ public class OXContainerConverter {
 
     private static final String PARAM_HOME = "home";
 
+    private static final String PARAM_OTHER = "dom";
+
     private static final String P_TYPE = "TYPE";
 
     private static final String P_DESCRIPTION = "DESCRIPTION";
@@ -153,10 +166,14 @@ public class OXContainerConverter {
 
     private static final String P_CLASS = "CLASS";
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(OXContainerConverter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(OXContainerConverter.class));
 
     private static final String CHARSET_ISO_8859_1 = "ISO-8859-1";
 
+    private static final String CTYPE_CONTACT = "contact";
+
+    private static final String CTYPE_DISTRIBUTION_LIST = "dlist";
+
     private static final String atdomain;
 
     static {
@@ -179,6 +196,8 @@ public class OXContainerConverter {
 
     private boolean sendFloating;
 
+    private boolean addDisplayName4DList;
+
     public OXContainerConverter(final TimeZone timezone, final String organizerMailAddress) {
         super();
         this.timezone = timezone;
@@ -222,6 +241,24 @@ public class OXContainerConverter {
         this.sendFloating = sendFloating;
     }
 
+    /**
+     * Gets the addDisplayName4DList
+     *
+     * @return The addDisplayName4DList
+     */
+    public boolean isAddDisplayName4DList() {
+        return addDisplayName4DList;
+    }
+
+    /**
+     * Sets the addDisplayName4DList
+     *
+     * @param addDisplayName4DList The addDisplayName4DList to set
+     */
+    public void setAddDisplayName4DList(final boolean addDisplayName4DList) {
+        this.addDisplayName4DList = addDisplayName4DList;
+    }
+
     public boolean isSendUTC() {
         return sendUTC;
     }
@@ -577,15 +614,8 @@ public class OXContainerConverter {
         // SOUND is ignored
         // URL
         StringProperty(contactContainer, object, "URL", Contact.URL);
-        // TODO UID
-        // property = object.getProperty("UID");
-        // if (property != null) {
-        // String uid = property.getValue().toString();
-        // if (uid.endsWith(atdomain))
-        // contact.setObjectID(Integer.parseInt(uid.substring(0, uid
-        // .length()
-        // - atdomain.length())));
-        // }
+        // UID
+        StringProperty(contactContainer, object, "UID", Contact.UID);
         // VERSION is ignored
         // TODO CLASS
         // KEY is ignored
@@ -598,6 +628,7 @@ public class OXContainerConverter {
         final int CAR = 3;
         final int ISDN = 4;
         final int PAGER = 5;
+        final int OTHER = 6;
 
         final int VOICE = 0;
         final int FAX = 1;
@@ -617,19 +648,29 @@ public class OXContainerConverter {
 
         final ArrayList<Object> cats = new ArrayList<Object>();
 
+        boolean dlist = false;
+        {
+            final Property oxCtype = object.getProperty(P_OPEN_XCHANGE_CTYPE);
+            if (oxCtype != null && CTYPE_DISTRIBUTION_LIST.equalsIgnoreCase(oxCtype.getValue().toString())) {
+                dlist = true;
+                contactContainer.setMarkAsDistributionlist(true);
+            }
+        }
+
         final int count = object.getPropertyCount();
         for (int i = 0; i < count; i++) {
             property = object.getProperty(i);
             // ADR
             if ("ADR".equals(property.name)) {
-                boolean isHome = false, isWork = true;
+                boolean isHome = false, isWork = false, isOther = true;
                 final Parameter type = property.getParameter(P_TYPE);
                 if (type != null) {
-                    isWork = false;
+                    isOther = false;
                     for (int j = 0; j < type.getValueCount(); j++) {
                         final String value = type.getValue(j).getText();
-                        isHome |= PARAM_HOME.equalsIgnoreCase(value);
-                        isWork |= PARAM_WORK.equalsIgnoreCase(value);
+                        isHome  |= PARAM_HOME.equalsIgnoreCase(value);
+                        isWork  |= PARAM_WORK.equalsIgnoreCase(value);
+                        isOther |= PARAM_OTHER.equalsIgnoreCase(value);
                     }
                 }
                 final ArrayList<?> A = (ArrayList<?>) property.getValue();
@@ -651,6 +692,13 @@ public class OXContainerConverter {
                     ListValue(contactContainer, Contact.POSTAL_CODE_HOME, A.get(5), "\n");
                     ListValue(contactContainer, Contact.COUNTRY_HOME, A.get(6), "\n");
                 }
+                if (isOther) {
+                    ListValue(contactContainer, Contact.STREET_OTHER, A.get(2), "\n");
+                    ListValue(contactContainer, Contact.CITY_OTHER, A.get(3), "\n");
+                    ListValue(contactContainer, Contact.STATE_OTHER, A.get(4), "\n");
+                    ListValue(contactContainer, Contact.POSTAL_CODE_OTHER, A.get(5), "\n");
+                    ListValue(contactContainer, Contact.COUNTRY_OTHER, A.get(6), "\n");
+                }
             }
             // LABEL is ignored
             // TEL
@@ -667,6 +715,8 @@ public class OXContainerConverter {
                                 idx = WORK;
                             } else if (value.equalsIgnoreCase(PARAM_HOME)) {
                                 idx = HOME;
+                            } else if (value.equalsIgnoreCase(PARAM_OTHER)) {
+                                idx = OTHER;
                             } else if (value.equalsIgnoreCase("car")) {
                                 idx = CAR;
                             } else if (value.equalsIgnoreCase("isdn")) {
@@ -695,6 +745,47 @@ public class OXContainerConverter {
                     ComplexProperty(contactContainer, phones[idx][FAX], index[idx][FAX], value);
                 }
             }
+            // IM
+            else if ("IMPP".equals(property.name)) {
+                String value = property.getValue().toString();
+                if (null != value) {
+                    try {
+                        value = java.net.URLDecoder.decode(value, "UTF-8");
+                    } catch (UnsupportedEncodingException e) {
+                        LOG.debug("Error decoding IMPP value", e);
+                    }
+                }                
+                Parameter type = property.getParameter(P_TYPE);
+                boolean set = false;
+                if (null != type) {
+                    for (int j = 0; j < type.getValueCount() && false == set; j++) {
+                        String typeValue = type.getValue(j).getText();
+                        if (PARAM_HOME.equalsIgnoreCase(typeValue)) {
+                            /*
+                             * use IM 2 if possible
+                             */
+                            contactContainer.setInstantMessenger2(value);
+                            set = true;
+                        } else if (PARAM_WORK.equalsIgnoreCase(typeValue)) {
+                            /*
+                             * use IM 1 if possible
+                             */
+                            contactContainer.setInstantMessenger1(value);
+                            set = true;
+                        }
+                    }
+                }
+                /*
+                 * fill first available
+                 */
+                if (false == set) {
+                    if (false == contactContainer.containsInstantMessenger2()) {
+                        contactContainer.setInstantMessenger2(value);
+                    } else if (false == contactContainer.containsInstantMessenger1()) {
+                        contactContainer.setInstantMessenger1(value);
+                    }
+                }
+            }
             // EMAIL
             else if (P_EMAIL.equals(property.name)) {
                 final String value = property.getValue().toString();
@@ -702,20 +793,132 @@ public class OXContainerConverter {
                 boolean isProperEmailAddress = value != null && value.length() > 0;
                 if (isProperEmailAddress) {
                     try {
-                        final InternetAddress ia = new InternetAddress(value);
-                        ia.validate();
+                    	new InternetAddress(QuotedInternetAddress.toACE(value)).validate();
                     } catch (final AddressException e) {
                         isProperEmailAddress = false;
                     }
                 }
                 // fix: end
                 if (isProperEmailAddress) {
-                    ComplexProperty(contactContainer, emails, emailIndex, value);
+                    if (dlist) {
+                        try {
+                            DistributionListEntryObject[] distributionList = contactContainer.getDistributionList();
+                            if (null == distributionList) {
+                                distributionList = new DistributionListEntryObject[1];
+                            } else {
+                                final DistributionListEntryObject[] newDistributionList = new DistributionListEntryObject[distributionList.length + 1];
+                                System.arraycopy(distributionList, 0, newDistributionList, 0, distributionList.length);
+                                distributionList = newDistributionList;
+                            }
+                            /*
+                             * Append new entry
+                             */
+                            final DistributionListEntryObject newEntry = new DistributionListEntryObject();
+                            if (addDisplayName4DList) {
+                                final Parameter displayNameParameter = property.getParameter("FN");
+                                if (null != displayNameParameter) {
+                                    newEntry.setDisplayname(decodeQP(displayNameParameter.getValue(0).getText()));
+                                }
+                            }
+                            newEntry.setEmailaddress(value);
+                            distributionList[distributionList.length - 1] = newEntry;
+                            contactContainer.setDistributionList(distributionList);
+                        } catch (final ContactException e) {
+                            throw new ConverterException(e);
+                        }
+                    } else {
+                        Parameter type = property.getParameter(P_TYPE);
+                        int set = 0;
+                        if (null != type) {
+                            for (int j = 0; j < type.getValueCount() && 0 == set; j++) {
+                                String typeValue = type.getValue(j).getText();
+                                if (PARAM_HOME.equalsIgnoreCase(typeValue)) {
+                                    /*
+                                     * use email 2 if possible
+                                     */
+                                    if (contactContainer.containsEmail2()) {
+                                        // try to move somewhere else
+                                        if (false == contactContainer.containsEmail1()) {
+                                            contactContainer.setEmail1(contactContainer.getEmail2());
+                                        } else if (false == contactContainer.containsEmail3()) {
+                                            contactContainer.setEmail3(contactContainer.getEmail2());
+                                        } else {
+                                            LOG.debug("Can only save one 'home' email address, going to overwrite existing value.");
+                                        }
+                                    }
+                                    contactContainer.setEmail2(value);
+                                    set = 2;
+                                } else if (PARAM_WORK.equalsIgnoreCase(typeValue)) {
+                                    /*
+                                     * use email 1 if possible
+                                     */
+                                    if (contactContainer.containsEmail1()) {
+                                        // try to move somewhere else
+                                        if (false == contactContainer.containsEmail2()) {
+                                            contactContainer.setEmail2(contactContainer.getEmail1());
+                                        } else if (false == contactContainer.containsEmail3()) {
+                                            contactContainer.setEmail3(contactContainer.getEmail1());
+                                        } else {
+                                            LOG.debug("Can only save one 'work' email address, going to overwrite existing value.");                                           
+                                        }
+                                    }
+                                    contactContainer.setEmail1(value);
+                                    set = 1;
+                                } else if ("other".equalsIgnoreCase(typeValue)) {
+                                    /*
+                                     * use email 3 if possible
+                                     */
+                                    if (contactContainer.containsEmail3()) {
+                                        // try to move somewhere else
+                                        if (false == contactContainer.containsEmail1()) {
+                                            contactContainer.setEmail1(contactContainer.getEmail3());
+                                        } else if (false == contactContainer.containsEmail2()) {
+                                            contactContainer.setEmail2(contactContainer.getEmail3());
+                                        } else {
+                                            LOG.debug("Can only save one 'other' email address, going to overwrite existing value.");                                           
+                                        }
+                                    }
+                                    contactContainer.setEmail3(value);
+                                    set = 3;
+                                }
+                            }
+                        }
+                        /*
+                         * fill first available
+                         */
+                        if (0 == set) {
+                            if (false == contactContainer.containsEmail1()) {
+                                contactContainer.setEmail1(value);
+                                set = 1;
+                            } else if (false == contactContainer.containsEmail2()) {
+                                contactContainer.setEmail2(value);
+                                set = 2;
+                            } else if (false == contactContainer.containsEmail3()) {
+                                contactContainer.setEmail3(value);
+                                set = 3;
+                            }
+                        }
+                        /*
+                         * mark default address if defined
+                         */
+                        if (0 < set && null != type) {
+                            for (int j = 0; j < type.getValueCount(); j++) {
+                                if ("pref".equalsIgnoreCase(type.getValue(j).getText())) {
+                                    contactContainer.setDefaultAddress(set);
+                                    break;
+                                }
+                            }
+                        }
+//                        ComplexProperty(contactContainer, emails, emailIndex, value);
+                    }
                 } else {
                     // fix for: 7719
                     final Parameter type = property.getParameter(P_TYPE);
-                    if (type != null && type.getValue(0) != null && type.getValue(0).getText() != null && P_TLX.equals(type.getValue(0).getText())) {
-                        contactContainer.setTelephoneTelex(property.getValue().toString());
+                    if (type != null) {
+                        final ParameterValue parameterValue = type.getValue(0);
+                        if (parameterValue != null && parameterValue.getText() != null && P_TLX.equals(parameterValue.getText())) {
+                            contactContainer.setTelephoneTelex(property.getValue().toString());
+                        }
                     }
                 }
             }
@@ -759,7 +962,7 @@ public class OXContainerConverter {
     /**
      * Open a new {@link URLConnection URL connection} to specified parameter's value which indicates to be an URI/URL. The image's data and
      * its MIME type is then read from opened connection and put into given {@link Contact contact container}.
-     * 
+     *
      * @param contact The contact container to fill
      * @param url The URI parameter's value
      * @throws ConverterException If converting image's data fails
@@ -775,7 +978,7 @@ public class OXContainerConverter {
     /**
      * Open a new {@link URLConnection URL connection} to specified parameter's value which indicates to be an URI/URL. The image's data and
      * its MIME type is then read from opened connection and put into given {@link Contact contact container}.
-     * 
+     *
      * @param contact The contact container to fill
      * @param url The image URL
      * @throws ConverterException If converting image's data fails
@@ -810,14 +1013,15 @@ public class OXContainerConverter {
         } catch (final IOException e) {
             throw new ConverterException("IO problem while reading \"" + url.toString() + "\"", e);
         }
-        if (bytes != null) {
-            contact.setImage1(bytes);
-            if (mimeType == null) {
-                mimeType = ImageTypeDetector.getMimeType(bytes);
-                if ("application/octet-stream".equals(mimeType)) {
-                    mimeType = getMimeType(url.toString());
-                }
+        if (mimeType == null) {
+            mimeType = ImageTypeDetector.getMimeType(bytes);
+            if ("application/octet-stream".equals(mimeType)) {
+                mimeType = getMimeType(url.toString());
             }
+        }
+        if (bytes != null && isValidImage(bytes)) {
+            // Mime type should be of image type. Otherwise web server send some error page instead of 404 error code.
+            contact.setImage1(bytes);
             contact.setImageContentType(mimeType);
         }
     }
@@ -960,7 +1164,7 @@ public class OXContainerConverter {
 
     /**
      * Finds out whether a user is internal, since internal users get treated differently when entering appointments or tasks.
-     * 
+     *
      * @param mail - Mail address as string
      * @return true if is internal user, false otherwise
      */
@@ -1009,7 +1213,7 @@ public class OXContainerConverter {
                 month = cal.get(Calendar.MONTH);
             }
             calContainerObj.setMonth(month);
-            // no break
+            //$FALL-THROUGH$
         case RecurrenceValue.MONTHLY:
             if (recur.ByMonthDay.length > 0) {
                 if (recur.ByDay.size() != 0) {
@@ -1181,19 +1385,8 @@ public class OXContainerConverter {
         }
         // PERCENT-COMPLETE
         addProperty(object, "PERCENT-COMPLETE", Integer.valueOf(task.getPercentComplete()));
-        // PRIORITY
-        final int[] priorities = { 9, 5, 1 };
-        final int priority = task.getPriority();
-        /*
-         * TODO REMOVED DUE REMOVAL OF com.openexchange.groupware.links if (priority >= OXTask.LOW && priority <= OXTask.HIGH)
-         * addProperty(object, "PRIORITY", new Integer(priorities[priority - OXTask.LOW])); else throw new
-         * ConverterException("Invalid priority");
-         */
-        // TODO RECURRENCE-ID
-        // TODO SEQUENCE
-        // STATUS
-        final String[] statuses = { "NEEDS-ACTION", "IN-PROCESS", P_COMPLETED, "NEEDS-ACTION", "CANCELLED" };
-        final int status = task.getStatus();
+        task.getPriority();
+        task.getStatus();
         /*
          * TODO REMOVED DUE REMOVAL OF com.openexchange.groupware.tasks if (status >= OXTask.NOT_STARTED && status <= OXTask.DEFERRED)
          * addProperty(object, "STATUS", statuses[status - OXTask.NOT_STARTED]); else throw new ConverterException("Invlaid status");
@@ -1391,112 +1584,154 @@ public class OXContainerConverter {
         addProperty(object, "N", n);
         // NICKNAME
         addProperty(object, "NICKNAME", getList(contact.getNickname(), ','));
-        // PHOTO
-        if (contact.getImage1() != null) {
-            final byte[] imageData = contact.getImage1();
-            // First try as URI
-            try {
-                addProperty(object, "PHOTO", "VALUE", new String[] { "URI" }, new URI(new String(imageData, CHARSET_ISO_8859_1)));
-            } catch (final UnsupportedEncodingException e2) {
-                LOG.error(e2);
-                throw new ConverterException(e2);
-            } catch (final URISyntaxException e) {
-                // Insert raw base64-encoded image bytes
-                final Parameter type = new Parameter(P_TYPE);
-                {
-                    final String mimeType = contact.getImageContentType();
-                    final String param;
-                    if (mimeType == null) {
-                        param = "JPEG";
-                    } else if (mimeType.indexOf('/') != -1) {
-                        param = mimeType.substring(mimeType.indexOf('/') + 1).toUpperCase();
-                    } else {
-                        param = mimeType.toUpperCase();
+        // Distribution list?
+        if (!contact.containsMarkAsDistributionlist() || !contact.getMarkAsDistribtuionlist()) {
+            addProperty(object, P_OPEN_XCHANGE_CTYPE, CTYPE_CONTACT);
+            // PHOTO
+            if (contact.getImage1() != null) {
+                final byte[] imageData = contact.getImage1();
+                // First try as URI
+                try {
+                    addProperty(object, "PHOTO", "VALUE", new String[] { "URI" }, new URI(new String(imageData, CHARSET_ISO_8859_1)));
+                } catch (final UnsupportedEncodingException e2) {
+                    LOG.error(e2);
+                    throw new ConverterException(e2);
+                } catch (final URISyntaxException e) {
+                    // Insert raw base64-encoded image bytes
+                    final Parameter type = new Parameter(P_TYPE);
+                    {
+                        final String mimeType = contact.getImageContentType();
+                        final String param;
+                        if (mimeType == null) {
+                            param = "JPEG";
+                        } else if (mimeType.indexOf('/') != -1) {
+                            param = mimeType.substring(mimeType.indexOf('/') + 1).toUpperCase();
+                        } else {
+                            param = mimeType.toUpperCase();
+                        }
+                        type.addValue(new ParameterValue(param));
                     }
-                    type.addValue(new ParameterValue(param));
+                    /*
+                     * Add image data as it is since ValueDefinition#write(FoldingWriter fw, Property property)) applies proper encoding
+                     * dependent on "ENCODING" parameter
+                     */
+                    addProperty(object, "PHOTO", "ENCODING", new String[] { "B" }, imageData).addParameter(type);
                 }
-                /*
-                 * Add image data as it is since ValueDefinition#write(FoldingWriter fw, Property property)) applies proper encoding
-                 * dependent on "ENCODING" parameter
-                 */
-                addProperty(object, "PHOTO", "ENCODING", new String[] { "B" }, imageData).addParameter(type);
             }
-        }
-        String s = null;
-        // BDAY
-        addDate(object, "BDAY", contact.getBirthday(), false);
-        // ADR
-        addADR(
-            object,
-            contact,
-            new String[] { PARAM_WORK },
-            Contact.STREET_BUSINESS,
-            Contact.CITY_BUSINESS,
-            Contact.STATE_BUSINESS,
-            Contact.POSTAL_CODE_BUSINESS,
-            Contact.COUNTRY_BUSINESS);
-        // ADR HOME
-        addADR(
-            object,
-            contact,
-            new String[] { PARAM_HOME },
-            Contact.STREET_HOME,
-            Contact.CITY_HOME,
-            Contact.STATE_HOME,
-            Contact.POSTAL_CODE_HOME,
-            Contact.COUNTRY_HOME);
-        // LABEL is ignored
-        // TEL
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, PARAM_VOICE }, contact.getTelephoneBusiness1());
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, PARAM_VOICE }, contact.getTelephoneBusiness2());
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, "fax" }, contact.getFaxBusiness());
-        addProperty(object, P_TEL, P_TYPE, new String[] { "car", PARAM_VOICE }, contact.getTelephoneCar());
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, PARAM_VOICE }, contact.getTelephoneHome1());
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, PARAM_VOICE }, contact.getTelephoneHome2());
-        addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, "fax" }, contact.getFaxHome());
-        addProperty(object, P_TEL, P_TYPE, new String[] { "cell", PARAM_VOICE }, contact.getCellularTelephone1());
-        addProperty(object, P_TEL, P_TYPE, new String[] { "cell", PARAM_VOICE }, contact.getCellularTelephone2());
-        // addProperty(object, "TEL", "TYPE", null, contact
-        // .get(OXContact.PHONE_OTHER));
-        // addProperty(object, "TEL", "TYPE", new String[] { "fax" }, contact
-        // .get(OXContact.FAX_OTHER));
-        addProperty(object, P_TEL, P_TYPE, new String[] { "isdn" }, contact.getTelephoneISDN());
-        addProperty(object, P_TEL, P_TYPE, new String[] { "pager" }, contact.getTelephonePager());
-        // EMAIL
-        addProperty(object, P_EMAIL, contact.getEmail1());
-        addProperty(object, P_EMAIL, contact.getEmail2());
-        addProperty(object, P_EMAIL, contact.getEmail3());
-        // MAILER is ignored
-        // TZ is ignored
-        // GEO is ignored
-        // TITLE
-        addProperty(object, "TITLE", contact.getEmployeeType());
-        // ROLE
-        addProperty(object, "ROLE", contact.getPosition());
-        // LOGO is ignored
-        // TODO AGENT
-        // ORG
-        final ArrayList<String> list = new ArrayList<String>();
-        list.add(s = contact.getCompany());
-        boolean set = (s != null);
-        s = contact.getBranches();
-        if (s != null) {
-            final StringTokenizer st = new StringTokenizer(s, ",");
-            set |= st.hasMoreTokens();
-            while (st.hasMoreTokens()) {
-                list.add(st.nextToken());
+            String s = null;
+            // BDAY
+            addDate(object, "BDAY", contact.getBirthday(), false);
+            // ADR
+            addADR(
+                object,
+                contact,
+                new String[] { PARAM_WORK },
+                Contact.STREET_BUSINESS,
+                Contact.CITY_BUSINESS,
+                Contact.STATE_BUSINESS,
+                Contact.POSTAL_CODE_BUSINESS,
+                Contact.COUNTRY_BUSINESS);
+            // ADR HOME
+            addADR(
+                object,
+                contact,
+                new String[] { PARAM_HOME },
+                Contact.STREET_HOME,
+                Contact.CITY_HOME,
+                Contact.STATE_HOME,
+                Contact.POSTAL_CODE_HOME,
+                Contact.COUNTRY_HOME);
+            // ADR OTHER (as "dom" since there is no equivalent)
+        	addADR(
+                object,
+                contact,
+                new String[] { PARAM_OTHER },
+                Contact.STREET_OTHER,
+                Contact.CITY_OTHER,
+                Contact.STATE_OTHER,
+                Contact.POSTAL_CODE_OTHER,
+                Contact.COUNTRY_OTHER);
+            // LABEL is ignored
+            // TEL
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, PARAM_VOICE }, contact.getTelephoneBusiness1());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, PARAM_VOICE }, contact.getTelephoneBusiness2());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_WORK, "fax" }, contact.getFaxBusiness());
+            addProperty(object, P_TEL, P_TYPE, new String[] { "car", PARAM_VOICE }, contact.getTelephoneCar());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, PARAM_VOICE }, contact.getTelephoneHome1());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, PARAM_VOICE }, contact.getTelephoneHome2());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_HOME, "fax" }, contact.getFaxHome());
+            addProperty(object, P_TEL, P_TYPE, new String[] { "cell", PARAM_VOICE }, contact.getCellularTelephone1());
+            addProperty(object, P_TEL, P_TYPE, new String[] { "cell", PARAM_VOICE }, contact.getCellularTelephone2());
+
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_OTHER, PARAM_VOICE }, contact.getTelephoneOther());
+            addProperty(object, P_TEL, P_TYPE, new String[] { PARAM_OTHER, "fax" }, contact.getFaxOther());
+            addProperty(object, P_TEL, P_TYPE, new String[] { "isdn" }, contact.getTelephoneISDN());
+            addProperty(object, P_TEL, P_TYPE, new String[] { "pager" }, contact.getTelephonePager());
+            // EMAIL
+            addProperty(object, P_EMAIL, P_TYPE, 1 == contact.getDefaultAddress() ? 
+                new String[] { "INTERNET", PARAM_WORK, "pref" } : new String[] { "INTERNET", PARAM_WORK }, contact.getEmail1());
+            addProperty(object, P_EMAIL, P_TYPE, 2 == contact.getDefaultAddress() ? 
+                new String[] { "INTERNET", PARAM_HOME, "pref" } : new String[] { "INTERNET", PARAM_HOME }, contact.getEmail2());
+            addProperty(object, P_EMAIL, P_TYPE, 3 == contact.getDefaultAddress() ? 
+                new String[] { "INTERNET", "pref", "other" } : new String[] { "INTERNET", "other" }, contact.getEmail3());
+            // MAILER is ignored
+            // TZ is ignored
+            // GEO is ignored
+            // TITLE
+            addProperty(object, "TITLE", contact.getProfession());
+            // ROLE
+            addProperty(object, "ROLE", contact.getPosition());
+            // LOGO is ignored
+            // TODO AGENT
+            // ORG
+            final ArrayList<String> list = new ArrayList<String>();
+            list.add(s = contact.getCompany());
+            boolean set = (s != null);
+            s = contact.getBranches();
+            if (s != null) {
+                final StringTokenizer st = new StringTokenizer(s, ",");
+                set |= st.hasMoreTokens();
+                while (st.hasMoreTokens()) {
+                    list.add(st.nextToken());
+                }
+            }
+            s = contact.getDepartment();
+            set |= (s != null);
+            if (s != null) {
+                list.add(s);
+            }
+            if (set) {
+                addProperty(object, "ORG", list);
+            }
+        } else {
+            addProperty(object, P_OPEN_XCHANGE_CTYPE, CTYPE_DISTRIBUTION_LIST);
+            final DistributionListEntryObject[] distributionList = contact.getDistributionList();
+            if (null != distributionList && 0 < distributionList.length) {
+                for (final DistributionListEntryObject distributionListEntry : distributionList) {
+                    final String address = distributionListEntry.getEmailaddress();
+                    if (address != null) {
+                        final Property property = new Property(P_EMAIL);
+                        property.setValue(address);
+                        {
+                            final Parameter parameter = new Parameter(P_TYPE);
+                            parameter.addValue(new ParameterValue("INTERNET"));
+                            property.addParameter(parameter);
+                        }
+                        if (addDisplayName4DList) {
+                            final String displayName = distributionListEntry.getDisplayname();
+                            if (null != displayName) {
+                                final Parameter parameter = new Parameter("FN");
+                                parameter.addValue(new ParameterValue(encodeQP(displayName)));
+                                property.addParameter(parameter);
+                            }
+                        }
+                        object.addProperty(property);
+                    }
+                }
             }
-        }
-        s = contact.getDepartment();
-        set |= (s != null);
-        if (s != null) {
-            list.add(s);
-        }
-        if (set) {
-            addProperty(object, "ORG", list);
         }
         // CATEGORIES
-        s = contact.getCategories();
+        final String s = contact.getCategories();
         if (s != null) {
             addProperty(object, P_CATEGORIES, getList(s, ','));
         }
@@ -1509,7 +1744,10 @@ public class OXContainerConverter {
         // URL
         addProperty(object, "URL", contact.getURL());
         // UID
-        addProperty(object, "UID", contact.getObjectID() + atdomain);
+        addProperty(object, "UID", contact.getUid());
+        // IMPP
+        addProperty(object, "IMPP", P_TYPE, new String[] { PARAM_WORK }, contact.getInstantMessenger1());
+        addProperty(object, "IMPP", P_TYPE, new String[] { PARAM_HOME }, contact.getInstantMessenger2());
         // TODO CLASS
         // KEY is ignored
         return object;
@@ -1752,7 +1990,7 @@ public class OXContainerConverter {
             final String address = userObj.getMail();
             if (address != null) {
                 try {
-                    property.setValue(new URI("mailto:" + address));
+                    property.setValue(new URI("mailto:" + IDNA.toACE(address)));
                 } catch (final URISyntaxException e) {
                     final ConverterException ce = new ConverterException(e.getMessage());
                     ce.initCause(e);
@@ -1861,4 +2099,39 @@ public class OXContainerConverter {
         }
         return (bimg != null);
     }
+
+    private static final BitSet PRINTABLE_CHARS = new BitSet(256);
+    // Static initializer for printable chars collection
+    static {
+        for (int i = '0'; i <= '9'; i++) {
+            PRINTABLE_CHARS.set(i);
+        }
+        for (int i = 'A'; i <= 'Z'; i++) {
+            PRINTABLE_CHARS.set(i);
+        }
+        for (int i = 'a'; i <= 'z'; i++) {
+            PRINTABLE_CHARS.set(i);
+        }
+    }
+
+    private static String encodeQP(final String string) throws ConverterException {
+        try {
+            return new String(QuotedPrintableCodec.encodeQuotedPrintable(PRINTABLE_CHARS, string.getBytes("UTF-8")),"US-ASCII").replaceAll("=", "%");
+        } catch (final UnsupportedEncodingException e) {
+            // Cannot occur
+            throw new ConverterException(e);
+        }
+    }
+
+    private static String decodeQP(final String string) throws ConverterException {
+        try {
+            return new String(QuotedPrintableCodec.decodeQuotedPrintable(string.replaceAll("%", "=").getBytes("US-ASCII")), "UTF-8");
+        } catch (final UnsupportedEncodingException e) {
+            // Cannot occur
+            throw new ConverterException(e);
+        } catch (final DecoderException e) {
+            throw new ConverterException(e);
+        }
+    }
+
 }
