@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -76,12 +76,12 @@ import com.openexchange.tools.versit.converter.OXContainerConverter;
 
 /**
  * {@link VersitUtility}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class VersitUtility {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(VersitUtility.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(VersitUtility.class));
 
     /**
      * No instantiation
@@ -93,7 +93,7 @@ public final class VersitUtility {
     /**
      * Saves specified <code>VCard</code> mail part into corresponding default folder. The resulting instance of {@link CommonObject} is
      * added to given list.
-     * 
+     *
      * @param vcardInputStream The VCard input stream
      * @param baseContentType The VCard's base content type (e.g. <i>text/vcard</i>)
      * @param charset The charset encoding of provided input stream's data
@@ -145,7 +145,7 @@ public final class VersitUtility {
     /**
      * Saves specified <code>ICalendar</code> mail part into corresponding default folders. The resulting instances of {@link CommonObject}
      * are added to given list.
-     * 
+     *
      * @param icalInputStream The ICal input stream
      * @param baseContentType The ICal's base content type (e.g. <i>text/calendar</i>)
      * @param charset The charset encoding of provided input stream's data
