@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,10 +55,13 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.tools.servlet.CountingHttpServletRequest;
 
 /**
  * {@link WebDavServlet} - An abstract class for servlets serving WebDAV requests
- * 
+ *
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public abstract class WebDavServlet extends HttpServlet {
@@ -108,6 +111,8 @@ public abstract class WebDavServlet extends HttpServlet {
                 allow.append("LOCK,");
             } else if ("doUnLock".equals(methods[i].getName()) && !clazz.equals(methods[i].getDeclaringClass())) {
                 allow.append("UNLOCK,");
+            } else if ("doReport".equals(methods[i].getName()) && !clazz.equals(methods[i].getDeclaringClass())) {
+                allow.append("REPORT,");
             }
         }
         allow.append("TRACE,OPTIONS");
@@ -147,13 +152,40 @@ public abstract class WebDavServlet extends HttpServlet {
         resp.sendError(HttpServletResponse.SC_BAD_REQUEST, "Method \"UNLOCK\" is not supported by this servlet");
     }
 
+    protected void doReport(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+        resp.sendError(HttpServletResponse.SC_BAD_REQUEST, "Method \"REPORT\" is not supported by this servlet");
+    }
+
+    private static volatile Boolean disabled;
+
+    private static boolean disabled() {
+        Boolean tmp = disabled;
+        if (null == tmp) {
+            synchronized (WebDavServlet.class) {
+                tmp = disabled;
+                if (null == tmp) {
+                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    tmp = Boolean.valueOf(service != null && !service.getBoolProperty("com.openexchange.webdav.enabled", true));
+                    disabled = tmp;
+                }
+            }
+        }
+        return tmp.booleanValue();
+    }
+
     /**
      * {@inheritDoc}
      */
     @Override
-    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void service(final HttpServletRequest request, final HttpServletResponse resp) throws ServletException, IOException {
+        if (disabled()) {
+            resp.setContentType("text/html; charset=UTF-8");
+            resp.sendError(HttpServletResponse.SC_NOT_FOUND, "The WebDAV interface is disabled.");
+            return;
+        }
         incrementRequests();
         try {
+            final HttpServletRequest req = new CountingHttpServletRequest(request);
             final String method = req.getMethod();
             if ("PROPFIND".equals(method)) {
                 doPropFind(req, resp);
@@ -169,6 +201,8 @@ public abstract class WebDavServlet extends HttpServlet {
                 doLock(req, resp);
             } else if ("UNLOCK".equals(method)) {
                 doUnLock(req, resp);
+            } else if ("REPORT".equals(method)) {
+                doReport(req, resp);
             } else {
                 super.service(req, resp);
             }
