@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import com.openexchange.ajp13.AJPv13RequestHandler;
 import com.openexchange.authentication.LoginException;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
@@ -76,7 +75,7 @@ public class Infostore extends OXServlet {
 
     private static final long serialVersionUID = -2064098724675986123L;
 
-    private static final transient Log LOG = LogFactory.getLog(Infostore.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Infostore.class));
 
     @Override
     protected Interface getInterface() {
@@ -176,7 +175,7 @@ public class Infostore extends OXServlet {
         removeCookie(req, resp);
         try {
             LoginPerformer.getInstance().doLogout(session.getSessionID());
-        } catch (LoginException e) {
+        } catch (final LoginException e) {
             LOG.error(e.getMessage(), e);
         }
     }
@@ -184,7 +183,7 @@ public class Infostore extends OXServlet {
     private static final transient Tools.CookieNameMatcher COOKIE_MATCHER = new Tools.CookieNameMatcher() {
 
         public boolean matches(final String cookieName) {
-            return (COOKIE_SESSIONID.equals(cookieName) || AJPv13RequestHandler.JSESSIONID_COOKIE.equals(cookieName));
+            return (COOKIE_SESSIONID.equals(cookieName) || Tools.JSESSIONID_COOKIE.equals(cookieName));
         }
     };
 
