@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,7 +62,7 @@ import com.openexchange.tools.webdav.OXServlet;
 public abstract class PermissionServlet extends OXServlet {
 
     /**
-	 * 
+	 *
 	 */
     private static final long serialVersionUID = 2572228529208334966L;
 
@@ -83,7 +83,7 @@ public abstract class PermissionServlet extends OXServlet {
 
     @Override
     protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
-        if (!super.doAuth(req, resp)) {
+        if (!super.doAuth(req, resp, getInterface())) {
             return;
         }
         final Session session = getSession(req);
