@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,7 @@ import com.openexchange.groupware.EnumComponent;
 
 /**
  * {@link WebdavException} - Indicates an error while processing a WebDAV/XML request.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class WebdavException extends AbstractOXException {
@@ -94,7 +94,19 @@ public class WebdavException extends AbstractOXException {
         /**
          * Empty passwords are not allowed.
          */
-        EMPTY_PASSWORD("Empty passwords are not allowed.", Category.USER_INPUT, 8);
+        EMPTY_PASSWORD("Empty passwords are not allowed.", Category.USER_INPUT, 8),
+        /**
+         * Unsupported authorization mechanism in "Authorization" header: %1$s.
+         */
+        UNSUPPORTED_AUTH_MECH("Unsupported authorization mechanism in \"Authorization\" header: %1$s.", Category.CODE_ERROR, 9),
+        /**
+         * Resolving user name "%1$s" failed.
+         */
+        RESOLVING_USER_NAME_FAILED("Resolving user name \"%1$s\" failed.", Category.CODE_ERROR, 10),
+        /**
+         * Authentication failed for user name: %1$s
+         */
+        AUTH_FAILED("Authentication failed for user name: %1$s", Category.CODE_ERROR, 11);
 
         private final String message;
 
@@ -123,7 +135,7 @@ public class WebdavException extends AbstractOXException {
 
     /**
      * Initializes a new {@link WebdavException}
-     * 
+     *
      * @param cause The cause
      */
     public WebdavException(final AbstractOXException cause) {
@@ -132,7 +144,7 @@ public class WebdavException extends AbstractOXException {
 
     /**
      * Initializes a new {@link WebdavException}
-     * 
+     *
      * @param code The service error code
      */
     public WebdavException(final Code code) {
@@ -141,7 +153,7 @@ public class WebdavException extends AbstractOXException {
 
     /**
      * Initializes a new {@link WebdavException}
-     * 
+     *
      * @param code The service error code
      * @param messageArgs The message arguments
      */
@@ -151,7 +163,7 @@ public class WebdavException extends AbstractOXException {
 
     /**
      * Initializes a new {@link WebdavException}
-     * 
+     *
      * @param code The service error code
      * @param cause The init cause
      * @param messageArgs The message arguments
@@ -163,7 +175,7 @@ public class WebdavException extends AbstractOXException {
 
     /**
      * Initializes a new {@link WebdavException}
-     * 
+     *
      * @param category The category
      * @param detailNumber The detail number
      * @param message The message
