@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,12 +57,9 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.List;
-
 import javax.servlet.http.HttpServletRequest;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
 import com.openexchange.webdav.protocol.WebdavFactory;
@@ -70,14 +67,14 @@ import com.openexchange.webdav.protocol.WebdavPath;
 
 public class ServletWebdavRequest extends AbstractWebdavRequest implements WebdavRequest {
 	private final HttpServletRequest req;
-	private final String urlPrefix;
+	private String urlPrefix;
 	private final WebdavPath url;
 	private WebdavPath destUrl;
 
 	private ApacheURLDecoder decoder = new ApacheURLDecoder();
-	
-	private static final Log LOG = LogFactory.getLog(ServletWebdavRequest.class);
-	
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletWebdavRequest.class));
+
 	public ServletWebdavRequest(final WebdavFactory factory, final HttpServletRequest req) {
 		super(factory);
 		this.req = req;
@@ -110,6 +107,10 @@ public class ServletWebdavRequest extends AbstractWebdavRequest implements Webda
 		return urlPrefix;
 	}
 
+    public void setUrlPrefix(String urlPrefix) {
+        this.urlPrefix = urlPrefix;
+    }
+
 	public WebdavPath getUrl() {
 		return url;
 	}
@@ -118,22 +119,22 @@ public class ServletWebdavRequest extends AbstractWebdavRequest implements Webda
 		if(destUrl != null) {
 			return destUrl;
 		}
-		
+
 		return destUrl = toWebdavURL(req.getHeader("destination"));
 	}
-	
+
 	protected WebdavPath toWebdavURL(String url) {
 		if(url == null) {
 			return null;
 		}
-		
+
 		try {
 			final URL urlO = new URL(url);
 			url = urlO.getPath();
 		} catch (final MalformedURLException x ){
 			LOG.debug("",x);
 		}
-		
+
 		if(url.startsWith(req.getServletPath())) {
 			url =  url.substring(req.getServletPath().length());
 		}
