@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,7 +58,7 @@ import com.openexchange.webdav.protocol.WebdavProtocolException;
 public class WebdavExistsAction extends AbstractAction {
     private boolean tolerateLockNull = false;
 
-    private static final Log LOG = LogFactory.getLog(WebdavExistsAction.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavExistsAction.class));
 
     private static final String NOT_FOUND = "There is nothing here, sorry.";
 
