@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,17 +67,18 @@ import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
 
 public class WebdavGetAction extends WebdavHeadAction {
-	private static final Log LOG = LogFactory.getLog(WebdavGetAction.class);
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavGetAction.class));
 	private static final Pattern RANGE_PATTERN = Pattern.compile("bytes=(\\S+)");
 
 	@Override
 	public void perform(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
 		final WebdavResource resource = req.getResource();
+		res.setContentType(resource.getContentType());
 		if(!resource.exists()) {
 			throw new WebdavProtocolException(req.getUrl(), HttpServletResponse.SC_NOT_FOUND);
 		}
 		final List<ByteRange> ranges = getRanges(req, res);
-		
+
 		long size = 0;
 		long offset = 0;
 		for(final ByteRange range : ranges) {
@@ -89,7 +90,7 @@ public class WebdavGetAction extends WebdavHeadAction {
 			size++;
 		}
 		head(res,resource,size);
-		
+
 		BufferedOutputStream out = null;
 		InputStream in = null;
 		try {
@@ -105,7 +106,7 @@ public class WebdavGetAction extends WebdavHeadAction {
 				if(offset > range.endOffset) {
 					continue;
 				}
-				int read = 0; 
+				int read = 0;
 				int need = (int) Math.min(chunk.length, range.endOffset - offset + 1);
 				while(need > 0 && (read = in.read(chunk, 0, need)) != -1) {
 					out.write(chunk,0,read);
@@ -113,9 +114,11 @@ public class WebdavGetAction extends WebdavHeadAction {
 					need = (int) Math.min(chunk.length, range.endOffset - offset + 1);
 				}
 			}
-			
+
 		} catch (final IOException e) {
-			throw new WebdavProtocolException(req.getUrl(), HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+			final WebdavProtocolException wpe = new WebdavProtocolException(req.getUrl(), HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+			wpe.initCause(e);
+            throw wpe;
 		} finally {
 			if(out != null) {
 				try {
@@ -130,7 +133,7 @@ public class WebdavGetAction extends WebdavHeadAction {
 					LOG.debug("",e);
 				}*/
 			}
-			
+
 			if(in != null) {
 				try {
 					in.close();
@@ -140,18 +143,18 @@ public class WebdavGetAction extends WebdavHeadAction {
 			}
 		}
 	}
-	
+
 	private List<ByteRange> getRanges(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
 		final String byteRanges = req.getHeader("Bytes");
 		if(req.getResource().isCollection()) {
 			return new ArrayList<ByteRange>();
 		}
-		
+
 		final long length = req.getResource().getLength();
-		
+
 		final List<ByteRange> retVal = new ArrayList<ByteRange>();
 		if(byteRanges != null) {
-			
+
 			for(String range : byteRanges.split("\\s*,\\s*")) {
 				range = range.trim();
 				final ByteRange ro =parseRange(range, length, req.getUrl());
@@ -160,9 +163,9 @@ public class WebdavGetAction extends WebdavHeadAction {
 				}
 			}
 		}
-		
+
 		String range = req.getHeader("Range");
-		
+
 		if(range != null) {
 			final Matcher m = RANGE_PATTERN.matcher(range);
 			while(m.find()){
@@ -176,7 +179,7 @@ public class WebdavGetAction extends WebdavHeadAction {
 				}
 			}
 		}
-		
+
 		if(retVal.size() == 0) {
 			res.setStatus(HttpServletResponse.SC_OK);
 			return Arrays.asList(new ByteRange(0, req.getResource().getLength()-1));
