@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,26 +61,26 @@ import org.jdom.Namespace;
 import org.jdom.output.XMLOutputter;
 import com.openexchange.webdav.protocol.WebdavCollection;
 import com.openexchange.webdav.protocol.WebdavLock;
+import com.openexchange.webdav.protocol.WebdavLock.Scope;
+import com.openexchange.webdav.protocol.WebdavLock.Type;
 import com.openexchange.webdav.protocol.WebdavProperty;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
-import com.openexchange.webdav.protocol.WebdavLock.Scope;
-import com.openexchange.webdav.protocol.WebdavLock.Type;
 import com.openexchange.webdav.xml.resources.PropertiesMarshaller;
 
 public class WebdavLockAction extends AbstractAction {
 
 	private static final Namespace DAV_NS = Namespace.getNamespace("DAV:");
-	
-	private static final Log LOG = LogFactory.getLog(WebdavLockAction.class);
-	
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavLockAction.class));
+
 	public void perform(final WebdavRequest req, final WebdavResponse res)
 			throws WebdavProtocolException {
 		final WebdavLock lock = new WebdavLock();
-		
+
 		lock.setTimeout(getTimeout(req.getHeader("Timeout")));
 		lock.setDepth(getDepth(req.getHeader("Depth")));
-		
+
 		try {
 		    if(req.hasBody()) {
 		        configureLock(req, lock);
@@ -93,39 +93,39 @@ public class WebdavLockAction extends AbstractAction {
 		            lock.setToken(mentionedLocks.get(0));
 		        }
 		    }
-		    
+
 			WebdavResource resource = req.getResource();
-		       
+
             if(null != lock.getToken()) {
                 WebdavLock originalLock = resource.getLock(lock.getToken());
                 copyOldValues(originalLock, lock);
             }
-    
+
             final int status = HttpServletResponse.SC_OK;
-			 
-			
+
+
 			resource.lock(lock);
-			
+
 			// Reload, because it might have been switched to a lock null resource
 			resource = req.getFactory().resolveResource(req.getUrl());
-			
+
 			res.setStatus(status);
 			res.setHeader("Lock-Token",lock.getToken());
 			res.setHeader("content-type", "application/xml");
 			final WebdavProperty lockdiscovery = resource.getProperty("DAV:", "lockdiscovery");
-			
-			final Element lockDiscoveryElement = new PropertiesMarshaller(req.getCharset()).marshalProperty(lockdiscovery);
-			
+
+			final Element lockDiscoveryElement = new PropertiesMarshaller(req.getCharset()).marshalProperty(lockdiscovery, resource.getProtocol());
+
 			final Document responseDoc = new Document();
 			final Element rootElement = new Element("prop",DAV_NS);
-			
+
 			rootElement.addContent(lockDiscoveryElement);
-			
+
 			responseDoc.setContent(rootElement);
-			
+
 	        final XMLOutputter outputter = new XMLOutputter();
 			outputter.output(responseDoc, res.getOutputStream());
-			
+
 		} catch (final JDOMException e) {
 			LOG.error("JDOM Exception",e);
 			throw new WebdavProtocolException(req.getUrl(),HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
@@ -151,7 +151,7 @@ public class WebdavLockAction extends AbstractAction {
     private void configureLock(final WebdavRequest req, final WebdavLock lock) throws JDOMException, IOException {
         final Element root = req.getBodyAsDocument().getRootElement();
         final Element lockscope = (Element) root.getChild("lockscope",DAV_NS).getChildren().get(0);
-        
+
         if(lockscope.getNamespace().equals(DAV_NS)) {
         	if(lockscope.getName().equalsIgnoreCase("shared")) {
         		lock.setScope(Scope.SHARED_LITERAL);
@@ -159,11 +159,11 @@ public class WebdavLockAction extends AbstractAction {
         		lock.setScope(Scope.EXCLUSIVE_LITERAL);
         	}
         }
-        
+
         lock.setType(Type.WRITE_LITERAL);
-        
+
         final Element owner = root.getChild("owner",DAV_NS);
-        
+
         final XMLOutputter outputter = new XMLOutputter();
 
         if(owner != null) {
@@ -178,7 +178,7 @@ public class WebdavLockAction extends AbstractAction {
 		if(header.equalsIgnoreCase("infinity")) {
 			return WebdavCollection.INFINITY;
 		}
-		
+
 		return Integer.parseInt(header);
 	}
 
@@ -192,7 +192,7 @@ public class WebdavLockAction extends AbstractAction {
 		if(header.equalsIgnoreCase("infinite")) {
 			return WebdavLock.NEVER;
 		}
-		
+
 		return Long.parseLong(header.substring(7)) * 1000;
 	}
 
