@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,57 +72,46 @@ import com.openexchange.webdav.xml.resources.ResourceMarshaller;
 
 public class WebdavPropfindAction extends AbstractAction {
 
-	private static final Namespace DAV_NS = Protocol.DAV_NS;
-	
-	private static final Log LOG = LogFactory.getLog(WebdavPropfindAction.class);
-	
-	private final XMLOutputter outputter = new XMLOutputter();
-	
-	
-	
+	protected static final Namespace DAV_NS = Protocol.DAV_NS;
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavPropfindAction.class));
+
+	protected final XMLOutputter outputter = new XMLOutputter();
+
+    protected Protocol protocol;
+
+	public WebdavPropfindAction(Protocol protocol) {
+	    this.protocol = protocol;
+	}
+
 	public void perform(final WebdavRequest req, final WebdavResponse res)
 			throws WebdavProtocolException {
-		
+
 		final Element response = new Element("multistatus",DAV_NS);
+
+        List<Namespace> namespaces = protocol.getAdditionalNamespaces();
+        for (Namespace namespace : namespaces) {
+            response.addNamespaceDeclaration(namespace);
+        }
+
+
 		final Document responseBody = new Document(response);
-		
+
 		boolean forceAllProp = false;
 		Document requestBody = null;
 		try {
 			requestBody = req.getBodyAsDocument();
 		} catch (final JDOMException e1) {
-			
+
 			forceAllProp = true; //Assume All Prop, if all else fails
-			
+
 		} catch (final IOException e1) {
 			throw new WebdavProtocolException(new WebdavPath(),HttpServletResponse.SC_BAD_REQUEST);
 		}
-		
-		ResourceMarshaller marshaller = null;
-		final LoadingHints loadingHints = new LoadingHints();
-		loadingHints.setUrl(req.getUrl());
-		
-		if(null != requestBody && null != requestBody.getRootElement().getChild("propname", DAV_NS)) {
-			marshaller = new PropfindPropNamesMarshaller(req.getURLPrefix(),req.getCharset()); 
-			loadingHints.setProps(LoadingHints.Property.ALL);
-		} 
-		
-		if(null != requestBody && null != requestBody.getRootElement().getChild("allprop", DAV_NS) || forceAllProp) {
-			marshaller = new PropfindAllPropsMarshaller(req.getURLPrefix(), req.getCharset());
-			loadingHints.setProps(LoadingHints.Property.ALL);
-		} 
-		if (null != requestBody && null != requestBody.getRootElement().getChild("prop",DAV_NS)) {
-			marshaller = new PropfindResponseMarshaller(req.getURLPrefix(), req.getCharset());
-			loadingHints.setProps(LoadingHints.Property.SOME);
-			
-			for(final Element props : (List<Element>) requestBody.getRootElement().getChildren("prop", DAV_NS)){
-				for(final Element requested : (List<Element>) props.getChildren()) {
-					((PropfindResponseMarshaller) marshaller).addProperty(requested.getNamespaceURI(), requested.getName());
-					loadingHints.addProperty(requested.getNamespaceURI(), requested.getName());
-				}
-			}
-		}
-		
+
+        final LoadingHints loadingHints = new LoadingHints();
+		ResourceMarshaller marshaller = getMarshaller(req, forceAllProp, requestBody, loadingHints);
+
 		if(null != req.getHeader("Depth")) {
 			int depth = 0;
 			if(req.getHeader("depth").trim().equalsIgnoreCase("infinity")) {
@@ -130,7 +119,7 @@ public class WebdavPropfindAction extends AbstractAction {
 			} else {
 				depth = Integer.parseInt(req.getHeader("Depth"));
 			}
-			
+
 			marshaller = new RecursiveMarshaller(marshaller, depth);
 			loadingHints.setDepth(depth);
 		}
@@ -138,7 +127,7 @@ public class WebdavPropfindAction extends AbstractAction {
 		if (marshaller != null) {
 			response.addContent(marshaller.marshal(req.getResource()));
 		}
-		
+
 		try {
 			res.setStatus(Protocol.SC_MULTISTATUS);
 			res.setContentType("text/xml; charset=UTF-8");
@@ -148,4 +137,34 @@ public class WebdavPropfindAction extends AbstractAction {
 		}
 	}
 
+    protected ResourceMarshaller getMarshaller(final WebdavRequest req, boolean forceAllProp, Document requestBody, LoadingHints loadingHints) {
+        if (loadingHints == null) {
+            loadingHints = new LoadingHints();
+        }
+        ResourceMarshaller marshaller = null;
+		loadingHints.setUrl(req.getUrl());
+
+		if(null != requestBody && null != requestBody.getRootElement().getChild("propname", DAV_NS)) {
+			marshaller = new PropfindPropNamesMarshaller(req.getURLPrefix(),req.getCharset());
+			loadingHints.setProps(LoadingHints.Property.ALL);
+		}
+
+		if(null != requestBody && null != requestBody.getRootElement().getChild("allprop", DAV_NS) || forceAllProp) {
+			marshaller = new PropfindAllPropsMarshaller(req.getURLPrefix(), req.getCharset());
+			loadingHints.setProps(LoadingHints.Property.ALL);
+		}
+		if (null != requestBody && null != requestBody.getRootElement().getChild("prop",DAV_NS)) {
+			marshaller = new PropfindResponseMarshaller(req.getURLPrefix(), req.getCharset());
+			loadingHints.setProps(LoadingHints.Property.SOME);
+
+			for(final Element props : (List<Element>) requestBody.getRootElement().getChildren("prop", DAV_NS)){
+				for(final Element requested : (List<Element>) props.getChildren()) {
+					((PropfindResponseMarshaller) marshaller).addProperty(requested.getNamespaceURI(), requested.getName());
+					loadingHints.addProperty(requested.getNamespaceURI(), requested.getName());
+				}
+			}
+		}
+        return marshaller;
+    }
+
 }
