@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,32 +70,40 @@ import com.openexchange.webdav.protocol.util.Utils;
 public class WebdavProppatchAction extends AbstractAction {
 
 	private static final Namespace DAV_NS = Namespace.getNamespace("DAV:");
-	private static final Log LOG = LogFactory.getLog(WebdavProppatchAction.class);
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavProppatchAction.class));
+
 	private PropertyAction SET = null;
 	private static final PropertyAction REMOVE = new RemoveAction();
-	
+
 	private final XMLOutputter outputter = new XMLOutputter();
+    private Protocol protocol;
 
 	public WebdavProppatchAction(final Protocol protocol) {
 		SET = new SetAction(protocol);
+		this.protocol = protocol;
 	}
-	
-	
+
+
 	public void perform(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
 		try {
 			final Document requestDoc = req.getBodyAsDocument();
 			final Document responseDoc = new Document();
 			final Element multistatus = new Element("multistatus",DAV_NS);
+
+			List<Namespace> namespaces = protocol.getAdditionalNamespaces();
+			for (Namespace namespace : namespaces) {
+                multistatus.addNamespaceDeclaration(namespace);
+            }
+
 			responseDoc.addContent(multistatus);
 			final Element response = new Element("response", DAV_NS);
 			final Element href = new Element("href", DAV_NS);
-			
+
 			href.setText(req.getURLPrefix()+req.getUrl());
 			response.addContent(href);
-			
+
 			multistatus.addContent(response);
-			
+
 			final WebdavResource resource = req.getResource();
 			for(final Element element : (List<Element>) requestDoc.getRootElement().getChildren()) {
 				PropertyAction action = null;
@@ -106,20 +114,21 @@ public class WebdavProppatchAction extends AbstractAction {
 						action = REMOVE;
 					}
 				}
-				
+
 				if(null == action) {
 					continue;
 				}
-				
+
 				for(final Element prop : (List<Element>) element.getChildren("prop", DAV_NS)) {
 					response.addContent(action.perform(prop, resource));
 				}
 			}
 			resource.save();
 			res.setStatus(Protocol.SC_MULTISTATUS);
+			res.setContentType("text/xml");
 			outputter.output(responseDoc, res.getOutputStream());
-			
-			
+
+
 		} catch (final JDOMException e) {
 			LOG.error("JDOMException: ",e);
 			throw new WebdavProtocolException(req.getUrl(),HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
@@ -127,12 +136,12 @@ public class WebdavProppatchAction extends AbstractAction {
 			LOG.debug("Client gone?" ,e);
 		}
 	}
-	
+
 	static interface PropertyAction {
 		// Propstat element
 		public Element perform(Element propElement, WebdavResource resource);
 	}
-	
+
 	private static final class SetAction implements PropertyAction {
 		private final XMLOutputter outputter = new XMLOutputter();
 		private final Protocol protocol;
@@ -140,28 +149,28 @@ public class WebdavProppatchAction extends AbstractAction {
 		public SetAction(final Protocol protocol) {
 			this.protocol = protocol;
 		}
-		
+
 		public Element perform(final Element propElement, final WebdavResource resource) {
 			int status = 200;
-			
+
 			if(propElement.getChildren().isEmpty()) {
 				final Element propstat = new Element("propstat", DAV_NS);
-				
+
 				final Element statusElement = new Element("status", DAV_NS);
 				statusElement.setText("HTTP/1.1 "+status+" "+Utils.getStatusString(status));
 				propstat.addContent(statusElement);
 				return propstat;
 			}
-			
+
 			final Element propertyElement = (Element) propElement.getChildren().get(0);
 			final WebdavProperty property = new WebdavProperty();
 			property.setNamespace(propertyElement.getNamespaceURI());
 			property.setName(propertyElement.getName());
 			if(protocol.isProtected(propertyElement.getNamespaceURI(), propertyElement.getName())) {
-				
+
 				status = HttpServletResponse.SC_FORBIDDEN;
 			} else {
-			
+
 				if(propertyElement.getChildren().size() > 0) {
 					property.setXML(true);
 					try {
@@ -171,73 +180,73 @@ public class WebdavProppatchAction extends AbstractAction {
 					} catch (final IOException e) {
 						status = 500;
 					}
-					
-					
+
+
 				} else {
 					property.setValue(propertyElement.getText());
 				}
-				
+
 				try {
 					resource.putProperty(property);
 				} catch (final WebdavProtocolException e) {
 					status = e.getStatus();
 				}
 			}
-			
+
 			final Element propstat = new Element("propstat", DAV_NS);
-			
+
 			final Element prop = new Element("prop", DAV_NS);
 			final Element propContent = new Element(property.getName(), Namespace.getNamespace(property.getNamespace()));
 			prop.addContent(propContent);
-			
+
 			propstat.addContent(prop);
-			
-			
+
+
 			final Element statusElement = new Element("status", DAV_NS);
 			statusElement.setText("HTTP/1.1 "+status+" "+Utils.getStatusString(status));
 			propstat.addContent(statusElement);
-			
+
 			return propstat;
 		}
-		
+
 	}
-	
+
 	private static final class RemoveAction implements PropertyAction {
 
 		public Element perform(final Element propElement, final WebdavResource resource) {
 			int status = 200;
 			if(propElement.getChildren().isEmpty()) {
 				final Element propstat = new Element("propstat", DAV_NS);
-				
+
 				final Element statusElement = new Element("status", DAV_NS);
 				statusElement.setText("HTTP/1.1 "+status+" "+Utils.getStatusString(status));
 				propstat.addContent(statusElement);
 				return propstat;
 			}
 			final Element propertyElement = (Element) propElement.getChildren().get(0);
-			
+
 			try {
 				resource.removeProperty(propertyElement.getNamespaceURI(), propertyElement.getName());
 			} catch (final WebdavProtocolException e) {
 				status = e.getStatus();
 			}
-			
+
 			final Element propstat = new Element("propstat", DAV_NS);
-			
+
 			final Element prop = new Element("prop", DAV_NS);
 			final Element propContent = new Element(propertyElement.getName(), Namespace.getNamespace(propertyElement.getNamespaceURI()));
 			prop.addContent(propContent);
-			
+
 			propstat.addContent(prop);
-			
-			
+
+
 			final Element statusElement = new Element("status", DAV_NS);
 			statusElement.setText("HTTP/1.1 "+status+" "+Utils.getStatusString(status));
 			propstat.addContent(statusElement);
-			
+
 			return propstat;
 		}
-		
+
 	}
 
 }
