@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,8 +61,8 @@ import com.openexchange.webdav.protocol.WebdavResource;
 
 public class WebdavPutAction extends AbstractAction {
 
-	private static final Log LOG = LogFactory.getLog(WebdavPutAction.class);
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavPutAction.class));
+
 	public void perform(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
 		final WebdavResource resource = req.getResource();
 		if(null != req.getHeader("content-length")) {
@@ -76,7 +76,7 @@ public class WebdavPutAction extends AbstractAction {
 		    contentType = "application/octet-stream";
 		}
 		resource.setContentType(contentType);
-		
+
 		SizeExceededInputStream in = null;
 		try {
 			InputStream data = null;
@@ -85,7 +85,7 @@ public class WebdavPutAction extends AbstractAction {
 			} else {
 				data = req.getBody();
 			}
-				
+
 			resource.putBodyAndGuessLength(data);
 			if(resource.exists() && ! resource.isLockNull()) {
 				resource.save();
@@ -102,14 +102,14 @@ public class WebdavPutAction extends AbstractAction {
 				throw x;
 			}
 		}
-		
+
 	}
 
 	// Override for specific upload quota handling
 	public long getMaxSize() {
-		return -1; 
+		return -1;
 	}
-	
+
 	public static final class SizeExceededInputStream extends SizeAwareInputStream {
 		private boolean exceeded;
 		private final long maxSize;
@@ -118,7 +118,7 @@ public class WebdavPutAction extends AbstractAction {
 			super(delegate);
 			this.maxSize = maxSize;
 		}
-		
+
 		@Override
 		public void size(final long size) throws IOException {
 			if(size > maxSize) {
@@ -126,7 +126,7 @@ public class WebdavPutAction extends AbstractAction {
 				throw new IOException("Exceeded max upload size of "+maxSize);
 			}
 		}
-		
+
 		public boolean hasExceeded(){
 			return exceeded;
 		}
