@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,12 +54,12 @@ import org.apache.commons.logging.LogFactory;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 
 public class WebdavRequestCycleAction extends AbstractAction {
-	private static final Log LOG = LogFactory.getLog(WebdavRequestCycleAction.class);
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavRequestCycleAction.class));
+
 	public void perform(final WebdavRequest req, final WebdavResponse res)
 			throws WebdavProtocolException {
-		
-		
+
+
 		req.getFactory().beginRequest();
 		boolean stopped = false;
 		try {
