@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -72,6 +72,7 @@ import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.OXCalendarException;
 import com.openexchange.groupware.container.Appointment;
+import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.User;
@@ -98,7 +99,7 @@ public final class calendar extends XmlServlet<AppointmentSQLInterface> {
 
     private static final long serialVersionUID = 5779820324953825111L;
 
-    private static final Log LOG = LogFactory.getLog(calendar.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(calendar.class));
 
     /**
      * Initializes a new {@link calendar}.
@@ -189,7 +190,7 @@ public final class calendar extends XmlServlet<AppointmentSQLInterface> {
             appointmentobject.setAlarm(-1);
         }
         // For updates to series when switching from a limited series with until and occurrences to an unlimited series, we have to set "until" to null.
-        if (appointmentobject.containsRecurrenceType() && ! isLimitedSeries(appointmentobject)) {
+        if (appointmentobject.containsRecurrenceType() && appointmentobject.getRecurrenceType() != CalendarObject.NO_RECURRENCE && ! isLimitedSeries(appointmentobject)) {
             appointmentobject.setUntil(null);
         }
         // For removing the sequence information we need to tell the server that the appointment no longer has a recurrence type.
@@ -257,7 +258,7 @@ public final class calendar extends XmlServlet<AppointmentSQLInterface> {
         private final Date lastModified;
 
         private final int inFolder;
-        
+
         private LastModifiedCache lastModifiedCache;
 
         /**
@@ -295,7 +296,7 @@ public final class calendar extends XmlServlet<AppointmentSQLInterface> {
                         if (lastModified == null) {
                             throw new OXMandatoryFieldException(new WebdavException(WebdavException.Code.MISSING_FIELD, DataFields.LAST_MODIFIED));
                         }
-                        
+
                         Date currentLastModified = lastModifiedCache.getLastModified(appointmentobject.getObjectID(), lastModified);
                         lastModifiedCache.update(appointmentobject.getObjectID(), appointmentobject.getRecurrenceID(), lastModified);
                         conflicts = appointmentsSQL.updateAppointmentObject(appointmentobject, inFolder, currentLastModified);
@@ -389,7 +390,7 @@ public final class calendar extends XmlServlet<AppointmentSQLInterface> {
                         + exc.toString(), clientId, os, xo);
             }
         }
-        
+
         public void setLastModifiedCache(final LastModifiedCache lastModifiedCache) {
             this.lastModifiedCache = lastModifiedCache;
         }
