@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -88,14 +88,14 @@ import com.openexchange.webdav.xml.fields.DataFields;
 
 /**
  * contacts
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public final class contacts extends XmlServlet<ContactInterface> {
 
     private static final long serialVersionUID = -3731372041610025543L;
 
-    private static final transient Log LOG = LogFactory.getLog(contacts.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(contacts.class));
 
     /**
      * Initializes a new {@link contacts}.
@@ -224,14 +224,14 @@ public final class contacts extends XmlServlet<ContactInterface> {
         private final Date lastModified;
 
         private final int inFolder;
-        
+
         private LastModifiedCache lastModifiedCache;
 
         private final Session session;
 
         /**
          * Initializes a new {@link QueuedTask}
-         * 
+         *
          * @param contactObject The contact object
          * @param clientId The client ID
          * @param action The desired action
@@ -259,7 +259,7 @@ public final class contacts extends XmlServlet<ContactInterface> {
             try {
                 final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                     ContactInterfaceDiscoveryService.class).newContactInterface(inFolder, session);
-                
+
                 switch (action) {
                 case DataParser.SAVE:
                     if (contactObject.containsObjectID()) {
