@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,8 +85,8 @@ import com.openexchange.webdav.xml.fields.DataFields;
 
 /**
  * folders
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 
 public final class folders extends XmlServlet<FolderSQLInterface> {
@@ -95,7 +95,7 @@ public final class folders extends XmlServlet<FolderSQLInterface> {
 
     private static final String _invalidMethodError = "invalid method!";
 
-    private static final Log LOG = LogFactory.getLog(folders.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(folders.class));
 
     /**
      * Initializes a new {@link folders}
@@ -196,8 +196,7 @@ public final class folders extends XmlServlet<FolderSQLInterface> {
     @Override
     protected void startWriter(final Session sessionObj, final Context ctx, final int objectId, final int folderId,
             final OutputStream os) throws Exception {
-        final FolderWriter folderwriter = new FolderWriter(sessionObj, ctx);
-        folderwriter.startWriter(objectId, os);
+        new FolderWriter(sessionObj, ctx).startWriter(objectId, os);
     }
 
     @Override
@@ -209,8 +208,7 @@ public final class folders extends XmlServlet<FolderSQLInterface> {
     @Override
     protected void startWriter(final Session sessionObj, final Context ctx, final int folderId, final boolean modified,
             final boolean deleted, final boolean bList, final Date lastsync, final OutputStream os) throws Exception {
-        final FolderWriter folderwriter = new FolderWriter(sessionObj, ctx);
-        folderwriter.startWriter(modified, deleted, bList, lastsync, os);
+        new FolderWriter(sessionObj, ctx).startWriter(modified, deleted, bList, lastsync, os);
     }
 
     @Override
@@ -233,7 +231,7 @@ public final class folders extends XmlServlet<FolderSQLInterface> {
 
         /**
          * Initializes a new {@link QueuedTask}
-         * 
+         *
          * @param folderObject The folder object
          * @param clientId The client ID
          * @param action The desired action
@@ -313,7 +311,7 @@ public final class folders extends XmlServlet<FolderSQLInterface> {
                         + exc.toString(), clientId, os, xo);
             }
         }
-        
+
         public void setLastModifiedCache(final LastModifiedCache lastModifiedCache) {
             this.lastModifiedCache = lastModifiedCache;
         }
