@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,31 +56,36 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.UUID;
+import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.AppointmentSQLInterface;
-import com.openexchange.api2.OXException;
+import com.openexchange.context.ContextService;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.Participant;
+import com.openexchange.groupware.container.ResourceParticipant;
+import com.openexchange.groupware.container.UserParticipant;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
-import com.openexchange.groupware.contexts.impl.ContextStorage;
-import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.java.util.TimeZones;
 import com.openexchange.resource.Resource;
-import com.openexchange.resource.storage.ResourceStorage;
+import com.openexchange.resource.ResourceException;
+import com.openexchange.resource.ResourceService;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.impl.SessionObjectWrapper;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
+import com.openexchange.tools.servlet.CountingHttpServletRequest;
+import com.openexchange.user.UserService;
 
 /**
  * Servlet for writing free busy information.
@@ -90,7 +95,7 @@ public class freebusy extends HttpServlet {
 
     private static final long serialVersionUID = 6336387126907903347L;
 
-    private static final Log LOG = LogFactory.getLog(freebusy.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(freebusy.class));
 
     private static final DateFormat inputFormat = new SimpleDateFormat("yyyyMMdd");
 
@@ -100,11 +105,16 @@ public class freebusy extends HttpServlet {
         outputFormat.setTimeZone(TimeZones.UTC);
     }
 
+    @Override
+    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+        super.service(new CountingHttpServletRequest(req), resp);
+    }
+
     @Override
     protected void doGet(final HttpServletRequest request, final HttpServletResponse response) throws IOException {
         final Context context = getContext(request);
         if (null == context) {
-            response.sendError(HttpServletResponse.SC_CONFLICT, "Unable to determine context.");
+            response.sendError(HttpServletResponse.SC_NOT_FOUND, "Unable to determine context.");
             return;
         }
 
@@ -114,12 +124,12 @@ public class freebusy extends HttpServlet {
         if (-1 == period) {
             start = getStart(request);
             if (null == start) {
-                response.sendError(HttpServletResponse.SC_CONFLICT, "Unable to determine start of free busy time frame.");
+                response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Unable to determine start of free busy time frame.");
                 return;
             }
             end = getEnd(request);
             if (null == end) {
-                response.sendError(HttpServletResponse.SC_CONFLICT, "Unable to determine end of free busy time frame.");
+                response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Unable to determine end of free busy time frame.");
                 return;
             }
         } else {
@@ -133,45 +143,19 @@ public class freebusy extends HttpServlet {
 
         final String mailAddress = getMailAddress(request);
         if (null == mailAddress) {
-            response.sendError(HttpServletResponse.SC_CONFLICT, "Unable to determine mail address.");
+            response.sendError(HttpServletResponse.SC_BAD_REQUEST, "Unable to determine mail address.");
             return;
         }
 
-        User user = null;
-        try {
-            // TODO Replace with UserService
-            user = UserStorage.getInstance().searchUser(mailAddress, context);
-        } catch (final LdapException e) {
-            LOG.debug("User '" + mailAddress + "' not found.");
-        }
-        Resource resource = null;
-        try {
-            // TODO Replace with ResourceService
-            if (null == user) {
-                final Resource[] resources = ResourceStorage.getInstance().searchResourcesByMail(mailAddress, context);
-                if (1 == resources.length) {
-                    resource = resources[0];
-                }
-            }
-        } catch (final LdapException e) {
-            LOG.error("Resource '" + mailAddress + "' not found.");
-        }
-        final int principalId;
-        final int type;
-        if (null != user) {
-            type = Participant.USER;
-            principalId = user.getId();
-        } else if (null != resource) {
-            type = Participant.RESOURCE;
-            principalId = resource.getIdentifier();
-        } else {
-            response.sendError(HttpServletResponse.SC_CONFLICT, "Unable to resolve mail address to a user or a resource.");
+        final Participant participant = findParticipant(context, mailAddress);
+        if (null == participant) {
+            response.sendError(HttpServletResponse.SC_NOT_FOUND, "Unable to resolve mail address to a user or a resource.");
             return;
         }
-        
+
         response.setContentType("text/calendar");
         final PrintWriter printWriter = response.getWriter();
-        writeVCalendar(context, start, end, mailAddress, principalId, type, printWriter);
+        writeVCalendar(context, start, end, mailAddress, participant.getIdentifier(), participant.getType(), printWriter);
     }
 
     private String getMailAddress(final HttpServletRequest request) {
@@ -224,11 +208,13 @@ public class freebusy extends HttpServlet {
             LOG.error("Unable to parse context identifier.", e);
             return null;
         }
-        // TODO Replace with ContextService
-        final ContextStorage service = ContextStorage.getInstance();
-        final Context context;
+        Context context;
         try {
+            final ContextService service = ServerServiceRegistry.getInstance().getService(ContextService.class, true);
             context = service.getContext(contextId);
+        } catch (final ServiceException e) {
+            LOG.error(e.getMessage(), e);
+            return null;
         } catch (final ContextException e) {
             LOG.error("Can not load context.", e);
             return null;
@@ -257,30 +243,31 @@ public class freebusy extends HttpServlet {
         printWriter.println("METHOD:PUBLISH");
         printWriter.println("BEGIN:VFREEBUSY");
         printWriter.println("ORGANIZER:" + mailAddress);
+        printWriter.println("UID:" + UUID.randomUUID().toString());
         synchronized (outputFormat) {
             printWriter.println("DTSTART:" + outputFormat.format(start));
             printWriter.println("DTEND:" + outputFormat.format(end));
+            printWriter.println("DTSTAMP:" + outputFormat.format(new Date()));
         }
         try {
-            final Session sessionObj = SessionObjectWrapper.createSessionObject(context.getMailadmin(), context, "freebusysessionobject");
+            final Session sessionObj = SessionObjectWrapper.createSessionObject(Participant.USER == type ? principalId : context.getMailadmin(), context, "freebusysessionobject");
             final AppointmentSQLInterface appointmentInterface = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class, true).createAppointmentSql(sessionObj);
+            /*
+             * Write free-busy elements
+             */
             final SearchIterator<Appointment> it = appointmentInterface.getFreeBusyInformation(principalId, type, start, end);
             try {
-                synchronized (outputFormat) {
-                    while (it.hasNext()) {
-                        writeFreeBusy(it.next(), printWriter, outputFormat);
-                        printWriter.flush();
-                    }
+                while (it.hasNext()) {
+                    writeFreeBusy(it.next(), printWriter, outputFormat);
+                    printWriter.flush();
                 }
             } finally {
                 it.close();
             }
-        } catch (final SearchIteratorException e) {
-            LOG.error("Problem getting free busy information for '" + mailAddress + "'.", e);
-        } catch (final OXException e) {
-            LOG.error("Problem getting free busy information for '" + mailAddress + "'.", e);
         } catch (final ServiceException e) {
-            LOG.error("Calendar service not found.", e);
+                LOG.error("Calendar service not found.", e);
+        } catch (final AbstractOXException e) {
+            LOG.error("Problem getting free busy information for '" + mailAddress + "'.", e);
         }
         printWriter.println("END:VFREEBUSY");
         printWriter.println("END:VCALENDAR");
@@ -308,8 +295,43 @@ public class freebusy extends HttpServlet {
         default:
             pw.print("FBTYPE=BUSY:");
         }
-        pw.print(format.format(appointment.getStartDate()));
-        pw.print('/');
-        pw.println(format.format(appointment.getEndDate()));
+        synchronized (format) {
+            pw.print(format.format(appointment.getStartDate()));
+            pw.print('/');
+            pw.println(format.format(appointment.getEndDate()));
+        }
+    }
+
+    private Participant findParticipant(final Context ctx, final String mailAddress) {
+        User user = null;
+        try {
+            final UserService service = ServerServiceRegistry.getInstance().getService(UserService.class, true);
+            user = service.searchUser(mailAddress, ctx);
+        } catch (final ServiceException e) {
+            LOG.error(e.getMessage(), e);
+        } catch (final UserException e) {
+            LOG.debug("User '" + mailAddress + "' not found.");
+        }
+
+        Resource resource = null;
+        try {
+            final ResourceService service = ServerServiceRegistry.getInstance().getService(ResourceService.class, true);
+            final Resource[] resources = service.searchResourcesByMail(mailAddress, ctx);
+            if (1 == resources.length) {
+                resource = resources[0];
+            }
+        } catch (final ServiceException e) {
+            LOG.error(e.getMessage(), e);
+        } catch (final ResourceException e) {
+            LOG.error("Resource '" + mailAddress + "' not found.");
+        }
+
+        Participant retval = null;
+        if (null != resource && (user == null || !user.getMail().equals(mailAddress))) {
+            retval = new ResourceParticipant(resource.getIdentifier());
+        } else if (null != user) {
+            retval = new UserParticipant(user.getId());
+        }
+        return retval;
     }
 }
