@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -87,8 +87,8 @@ import com.openexchange.webdav.xml.fields.DataFields;
 
 /**
  * groupuser
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public final class groupuser extends PermissionServlet {
 
@@ -106,7 +106,7 @@ public final class groupuser extends PermissionServlet {
 
     private static String DELETED_RESOURCE_SQL = "SELECT id, lastmodified FROM del_resource WHERE cid=? AND lastmodified > ?";
 
-    private static transient final Log LOG = LogFactory.getLog(groupuser.class);
+    private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(groupuser.class));
 
     @Override
     protected Interface getInterface() {
@@ -233,9 +233,9 @@ public final class groupuser extends PermissionServlet {
 
         if (lastsync == null) {
             if (s_groups == null || s_groups.equals("*")) {
-                group = groupstorage.getGroups(ctx);
+                group = groupstorage.getGroups(true, ctx);
             } else {
-                group = groupstorage.searchGroups(s_groups, ctx);
+                group = groupstorage.searchGroups(s_groups, true, ctx);
             }
         } else {
             group = groupstorage.listModifiedGroups(lastsync, ctx);
