@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,8 @@
 
 package com.openexchange.webdav;
 
-import gnu.trove.TIntObjectHashMap;
-import gnu.trove.TObjectProcedure;
+import gnu.trove.map.hash.TIntObjectHashMap;
+import gnu.trove.procedure.TObjectProcedure;
 import java.io.IOException;
 import java.io.Writer;
 import java.sql.Connection;
@@ -76,9 +76,10 @@ import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.data.conversion.ical.ICalItem;
 import com.openexchange.data.conversion.ical.ICalSession;
 import com.openexchange.database.DBPoolingException;
+import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.Types;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.container.Appointment;
@@ -104,13 +105,12 @@ import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
  * ical
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.org">Sebastian Kauss</a>
  */
 public final class ical extends PermissionServlet {
@@ -120,10 +120,14 @@ public final class ical extends PermissionServlet {
      */
     private static final long serialVersionUID = 8198514314235297665L;
 
+    /**
+     * Determines how often data is flushed into the output stream
+     */
+    public static final int BATCH_SIZE = 100;
     /**
      * Logger.
      */
-    private static final transient Log LOG = LogFactory.getLog(ical.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ical.class));
 
     private final static int[] APPOINTMENT_FIELDS = {
         DataObject.OBJECT_ID, DataObject.CREATED_BY, DataObject.MODIFIED_BY, DataObject.CREATION_DATE, DataObject.LAST_MODIFIED,
@@ -180,25 +184,20 @@ public final class ical extends PermissionServlet {
 
             int calendarfolderId = getCalendarFolderID(req);
             int taskfolderId = getTaskFolderID(req);
+            boolean doTasks = taskfolderId != 0;
+            boolean doAppointments = calendarfolderId != 0;
+            
             if (calendarfolderId == 0 && taskfolderId == 0) {
                 final OXFolderAccess oAccess = new OXFolderAccess(context);
                 calendarfolderId = oAccess.getDefaultFolder(user.getId(), FolderObject.CALENDAR).getObjectID();
                 taskfolderId = oAccess.getDefaultFolder(user.getId(), FolderObject.TASK).getObjectID();
+                doTasks = doAppointments = true;
             }
 
             final String user_agent = getUserAgent(req);
             final String principalS = user_agent + '_' + sessionObj.getUserId();
             Principal principal = loadPrincipal(context, principalS);
 
-            // final Mapping mapping;
-            // final Map<String, Integer> entriesApp = new HashMap<String, Integer>();
-            // final Map<String, Integer> entriesTask = new HashMap<String, Integer>();
-            // if (null != principal) {
-            // mapping = loadDBEntriesNew(context, principal);
-            // } else {
-            // mapping = new Mapping();
-            // }
-
             final ICalEmitter emitter = ServerServiceRegistry.getInstance().getService(ICalEmitter.class);
             if (null == emitter) {
                 throw new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, ICalEmitter.class.getName());
@@ -206,94 +205,11 @@ public final class ical extends PermissionServlet {
             final ICalSession iSession = emitter.createSession();
             final List<ConversionWarning> warnings = new ArrayList<ConversionWarning>();
             final List<ConversionError> errors = new ArrayList<ConversionError>();
-
-            final AppointmentSQLInterface appointmentSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(sessionObj);
-            final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
-            SearchIterator<Appointment> iter = null;
-            try {
-                final TIntObjectHashMap<SeriesUIDPatcher> patchers = new TIntObjectHashMap<SeriesUIDPatcher>();
-                iter = appointmentSql.getModifiedAppointmentsInFolder(calendarfolderId, APPOINTMENT_FIELDS, new Date(0));
-                while (iter.hasNext()) {
-                    final Appointment appointment = iter.next();
-                    if (CalendarObject.NO_RECURRENCE != appointment.getRecurrenceType()) {
-                        if (!appointment.containsTimezone()) {
-                            appointment.setTimezone(user.getTimeZone());
-                        }
-                        recColl.replaceDatesWithFirstOccurence(appointment);
-                    }
-                    final ICalItem item = emitter.writeAppointment(iSession, appointment, context, errors, warnings);
-                    // // First check if the appointment has been synchronized before.
-                    // final int appId = appointment.getObjectID();
-                    // String clientId = mapping.getClientAppId(appId);
-                    // if (null == clientId) {
-                    // clientId = item.getUID();
-                    // entriesApp.put(clientId, Integer.valueOf(appId));
-                    // } else {
-                    // item.setUID(clientId);
-                    // }
-                    // Patch UID if change exceptions to be the same ID as of the series.
-                    if (appointment.isMaster() || appointment.isException()) {
-                        final int recurrenceId = appointment.getRecurrenceID();
-                        SeriesUIDPatcher patcher = patchers.get(recurrenceId);
-                        if (null == patcher) {
-                            patcher = new SeriesUIDPatcher();
-                            patchers.put(recurrenceId, patcher);
-                        }
-                        if (appointment.isMaster()) {
-                            patcher.setSeries(item);
-                        } else if (appointment.isException()) {
-                            patcher.addChangeException(item);
-                        }
-                    }
-                }
-                patchers.forEachValue(PATCH_PROCEDURE);
-            } catch (final SearchIteratorException e) {
-                LOG.error(e.getMessage(), e);
-            } catch (final OXException e) {
-                LOG.error(e.getMessage(), e);
-            } catch (final ConversionError e) {
-                LOG.error(e.getMessage(), e);
-            } finally {
-                if (null != iter) {
-                    try {
-                        iter.close();
-                    } catch (final SearchIteratorException e) {
-                        LOG.error(e.getMessage(), e);
-                    }
-                }
+            if(doAppointments) {
+	            doAppointments(sessionObj, context, user, calendarfolderId,	emitter, iSession, warnings, errors, resp);
             }
-            final TasksSQLInterface taskInterface = new TasksSQLImpl(sessionObj);
-            SearchIterator<Task> itTask = null;
-            try {
-                itTask = taskInterface.getModifiedTasksInFolder(taskfolderId, TASK_FIELDS, new Date(0));
-                while (itTask.hasNext()) {
-                    final Task task = itTask.next();
-                    emitter.writeTask(iSession, task, context, errors, warnings);
-                    // final ICalItem item = emitter.writeTask(iSession, task,
-                    // context, errors, warnings);
-                    // final int taskId = task.getObjectID();
-                    // String clientId = mapping.getClientTaskId(taskId);
-                    // if (null == clientId) {
-                    // clientId = item.getUID();
-                    // entriesTask.put(clientId, Integer.valueOf(taskId));
-                    // } else {
-                    // item.setUID(clientId);
-                    // }
-                }
-            } catch (final SearchIteratorException e) {
-                LOG.error(e.getMessage(), e);
-            } catch (final OXException e) {
-                LOG.error(e.getMessage(), e);
-            } catch (final ConversionError e) {
-                LOG.error(e.getMessage(), e);
-            } finally {
-                if (null != itTask) {
-                    try {
-                        itTask.close();
-                    } catch (final SearchIteratorException e) {
-                        LOG.error(e.getMessage(), e);
-                    }
-                }
+            if(doTasks) {
+	            doTasks(sessionObj, context, taskfolderId, emitter, iSession, warnings, errors, resp);
             }
 
             resp.setStatus(HttpServletResponse.SC_OK);
@@ -335,8 +251,86 @@ public final class ical extends PermissionServlet {
         }
     }
 
+	private void doTasks(final Session sessionObj, final Context context,
+			int taskfolderId, final ICalEmitter emitter,
+			final ICalSession iSession, final List<ConversionWarning> warnings,
+			final List<ConversionError> errors, HttpServletResponse resp) {
+		final TasksSQLInterface taskInterface = new TasksSQLImpl(sessionObj);
+		SearchIterator<Task> itTask = null;
+		try {
+		    itTask = taskInterface.getModifiedTasksInFolder(taskfolderId, TASK_FIELDS, new Date(0));
+		    while (itTask.hasNext()) {
+		        final Task task = itTask.next();
+		        emitter.writeTask(iSession, task, context, errors, warnings);
+		    }
+		} catch (final AbstractOXException e) {
+		    LOG.error(e.getMessage(), e);
+		} finally {
+		    if (null != itTask) {
+		        try {
+		            itTask.close();
+		        } catch (final AbstractOXException e) {
+		            LOG.error(e.getMessage(), e);
+		        }
+		    }
+		}
+	}
+
+	private void doAppointments(final Session sessionObj,
+			final Context context, final User user, int calendarfolderId,
+			final ICalEmitter emitter, final ICalSession iSession,
+			final List<ConversionWarning> warnings,
+			final List<ConversionError> errors, HttpServletResponse resp) throws IOException {
+		final AppointmentSQLInterface appointmentSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(sessionObj);
+		final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
+		SearchIterator<Appointment> iter = null;
+		int elements = 0;
+		try {
+		    final TIntObjectHashMap<SeriesUIDPatcher> patchers = new TIntObjectHashMap<SeriesUIDPatcher>();
+		    iter = appointmentSql.getModifiedAppointmentsInFolder(calendarfolderId, APPOINTMENT_FIELDS, new Date(0));
+		    while (iter.hasNext()) {
+		        final Appointment appointment = iter.next();
+		        if (CalendarObject.NO_RECURRENCE != appointment.getRecurrenceType()) {
+		            if (!appointment.containsTimezone()) {
+		                appointment.setTimezone(user.getTimeZone());
+		            }
+		            recColl.replaceDatesWithFirstOccurence(appointment);
+		        }
+		        final ICalItem item = emitter.writeAppointment(iSession, appointment, context, errors, warnings);
+		        if (appointment.isMaster() || appointment.isException()) {
+		            final int recurrenceId = appointment.getRecurrenceID();
+		            SeriesUIDPatcher patcher = patchers.get(recurrenceId);
+		            if (null == patcher) {
+		                patcher = new SeriesUIDPatcher();
+		                patchers.put(recurrenceId, patcher);
+		            }
+		            if (appointment.isMaster()) {
+		                patcher.setSeries(item);
+		            } else if (appointment.isException()) {
+		                patcher.addChangeException(item);
+		            }
+		        }
+		        if(elements > 0 && elements % BATCH_SIZE == 0){
+		        	emitter.flush(iSession, resp.getOutputStream());
+		        }
+		        elements++;
+		    }
+		    patchers.forEachValue(PATCH_PROCEDURE);
+		} catch (final AbstractOXException e) {
+		    LOG.error(e.getMessage(), e);
+		} finally {
+		    if (null != iter) {
+		        try {
+		            iter.close();
+		        } catch (final AbstractOXException e) {
+		            LOG.error(e.getMessage(), e);
+		        }
+		    }
+		}
+	}
+
     private static final TObjectProcedure<SeriesUIDPatcher> PATCH_PROCEDURE = new TObjectProcedure<SeriesUIDPatcher>() {
-        
+
         public boolean execute(final SeriesUIDPatcher patcher) {
             patcher.patchUIDs();
             return true;
@@ -376,296 +370,7 @@ public final class ical extends PermissionServlet {
         }
     }
 
-    // @Override
-    // public void doPut(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
-    // if (LOG.isDebugEnabled()) {
-    // LOG.debug("PUT");
-    // }
-    //
-    // int calendarfolder_id = 0;
-    // int taskfolder_id = 0;
-    //
-    // String user_agent = null;
-    // String principal = null;
-    //
-    // String content_type = null;
-    //
-    // final Session sessionObj = getSession(req);
-    //
-    // try {
-    // final Context context = ContextStorage.getInstance().getContext(sessionObj.getContextId());
-    //
-    // user_agent = getUserAgent(req);
-    // content_type = req.getContentType();
-    //
-    // if (LOG.isDebugEnabled()) {
-    // LOG.debug("read ical content_type: " + content_type);
-    // }
-    //
-    // calendarfolder_id = getCalendarFolderID(req);
-    // taskfolder_id = getTaskFolderID(req);
-    //
-    // if (calendarfolder_id == 0 && taskfolder_id == 0) {
-    // final OXFolderAccess oAccess = new OXFolderAccess(context);
-    // calendarfolder_id = oAccess.getDefaultFolder(sessionObj.getUserId(), FolderObject.CALENDAR).getObjectID();
-    // taskfolder_id = oAccess.getDefaultFolder(sessionObj.getUserId(), FolderObject.TASK).getObjectID();
-    // /*calendarfolder_id = OXFolderTools.getCalendarDefaultFolder(sessionObj.getUserObject().getId(), context);
-    // taskfolder_id = OXFolderTools.getTaskDefaultFolder(sessionObj.getUserObject().getId(), context);*/
-    // }
-    //
-    // if (content_type == null) {
-    // content_type = "text/calendar";
-    // }
-    //
-    // if (user_agent == null) {
-    // throw new OXConflictException("missing header field: user-agent");
-    // }
-    //
-    // principal = user_agent + '_' + sessionObj.getUserId();
-    //
-    // calendarfolder_id = getCalendarFolderID(req);
-    // taskfolder_id = getTaskFolderID(req);
-    //
-    // if (calendarfolder_id == 0 && taskfolder_id == 0) {
-    // final OXFolderAccess oAccess = new OXFolderAccess(context);
-    // calendarfolder_id = oAccess.getDefaultFolder(sessionObj.getUserId(), FolderObject.CALENDAR).getObjectID();
-    // taskfolder_id = oAccess.getDefaultFolder(sessionObj.getUserId(), FolderObject.TASK).getObjectID();
-    // /*calendarfolder_id = OXFolderTools.getCalendarDefaultFolder(sessionObj.getUserObject().getId(), context);
-    // taskfolder_id = OXFolderTools.getTaskDefaultFolder(sessionObj.getUserObject().getId(), context);*/
-    // }
-    //
-    // final boolean enabledelete = getEnableDelete(req);
-    //
-    // Map<String, String> entries_db = new HashMap<String, String>();
-    // Map<String, String> entries_module = new HashMap<String, String>();
-    // final HashSet<String> entries = new HashSet<String>();
-    //
-    // Connection readCon = null;
-    // PreparedStatement ps = null;
-    // ResultSet rs = null;
-    //
-    // int principal_id = 0;
-    //
-    // try {
-    // readCon = DBPool.pickup(context);
-    // ps = readCon.prepareStatement(SQL_PRINCIPAL_SELECT);
-    // ps.setInt(1, context.getContextId());
-    // ps.setString(2, principal);
-    // rs = ps.executeQuery();
-    //
-    // int db_calendarfolder_id = 0;
-    // int db_taskfolder_id = 0;
-    //
-    // final boolean exists = rs.next();
-    //
-    // if (exists) {
-    // principal_id = rs.getInt(1);
-    // db_calendarfolder_id = rs.getInt(2);
-    // db_taskfolder_id = rs.getInt(3);
-    //
-    // if (!(db_calendarfolder_id == calendarfolder_id && db_taskfolder_id == taskfolder_id)) {
-    // throw new OXConflictException("no principal found for the given folders: " + principal);
-    // }
-    //
-    // final Map<String, String>[] h = loadDBEntries(context, principal_id);
-    // entries_db = h[0];
-    // entries_module = h[1];
-    // } else {
-    // throw new OXConflictException("no principal found: " + principal);
-    // }
-    // } finally {
-    // if (rs != null) {
-    // rs.close();
-    // }
-    //
-    // if (ps != null) {
-    // ps.close();
-    // }
-    //
-    // if (readCon != null) {
-    // DBPool.closeReaderSilent(context, readCon);
-    // }
-    // }
-    //
-    // final VersitDefinition def = Versit.getDefinition(content_type);
-    // final VersitDefinition.Reader r = def.getReader(req.getInputStream(), "UTF-8");
-    // final OXContainerConverter oxc = new OXContainerConverter(sessionObj);
-    //
-    // final AppointmentSQLInterface appointmentInterface = new CalendarSql(sessionObj);
-    // final TasksSQLInterface taskInterface = new TasksSQLInterfaceImpl(sessionObj);
-    //
-    // final Date timestamp = new Date();
-    //
-    // try {
-    // final VersitObject root_vo = def.parseBegin(r);
-    // VersitObject vo = def.parseChild(r, root_vo);
-    // while (vo != null) {
-    // int object_id = 0;
-    //
-    // try {
-    // final Property property = vo.getProperty("UID");
-    //
-    // String client_id = null;
-    //
-    //
-    // if (property != null) {
-    // client_id = property.getValue().toString();
-    // }
-    //
-    // if ("VEVENT".equals(vo.name)) {
-    // final CalendarDataObject appointmentObj = oxc.convertAppointment(vo);
-    // appointmentObj.setContext(context);
-    //
-    // if (client_id != null && entries_db.containsKey(client_id)) {
-    // try {
-    // object_id = Integer.parseInt(entries_db.get(client_id).toString());
-    // } catch (final NumberFormatException exc) {
-    // if (LOG.isDebugEnabled()) {
-    // LOG.debug("object id is not an int");
-    // }
-    // }
-    //
-    // if (object_id > 0) {
-    // appointmentObj.setObjectID(object_id);
-    // }
-    //
-    // appointmentObj.setParentFolderID(calendarfolder_id);
-    //
-    // if (appointmentObj.containsObjectID()) {
-    // appointmentInterface.updateAppointmentObject(appointmentObj, calendarfolder_id, timestamp);
-    // } else {
-    // appointmentInterface.insertAppointmentObject(appointmentObj);
-    // }
-    //
-    // entries.add(client_id);
-    // } else {
-    // appointmentObj.setParentFolderID(calendarfolder_id);
-    //
-    // if (appointmentObj.containsObjectID()) {
-    // appointmentInterface.updateAppointmentObject(appointmentObj, calendarfolder_id, timestamp);
-    // } else {
-    // appointmentInterface.insertAppointmentObject(appointmentObj);
-    // }
-    //
-    // if (client_id != null) {
-    // entries.add(client_id);
-    // object_id = appointmentObj.getObjectID();
-    // addEntry(context, principal_id, object_id, client_id, Types.APPOINTMENT);
-    //
-    // if (!entries_module.containsKey(String.valueOf(object_id))) {
-    // entries_module.put(String.valueOf(object_id), String.valueOf(Types.APPOINTMENT));
-    // }
-    // }
-    // }
-    //
-    // LOG.debug("STATUS: OK");
-    // } else if ("VTODO".equals(vo.name)) {
-    // final Task taskObj = oxc.convertTask(vo);
-    //
-    // if (client_id != null && entries_db.containsKey(client_id)) {
-    // try {
-    // object_id = Integer.parseInt(entries_db.get(client_id).toString());
-    // } catch (final NumberFormatException exc) {
-    // LOG.debug("object id is not an int");
-    // }
-    //
-    // if (object_id > 0) {
-    // taskObj.setObjectID(object_id);
-    // }
-    //
-    // taskObj.setParentFolderID(taskfolder_id);
-    //
-    // if (taskObj.containsObjectID()) {
-    // taskInterface.updateTaskObject(taskObj, taskfolder_id, timestamp);
-    // } else {
-    // taskInterface.insertTaskObject(taskObj);
-    // }
-    //
-    // entries.add(client_id);
-    // } else {
-    // taskObj.setParentFolderID(taskfolder_id);
-    //
-    // if (taskObj.containsObjectID()) {
-    // taskInterface.updateTaskObject(taskObj, taskfolder_id, timestamp);
-    // } else {
-    // taskInterface.insertTaskObject(taskObj);
-    // }
-    //
-    // if (client_id != null) {
-    // entries.add(client_id);
-    // object_id = taskObj.getObjectID();
-    // addEntry(context, principal_id, object_id, client_id, Types.TASK);
-    //
-    // if (!entries_module.containsKey(String.valueOf(object_id))) {
-    // entries_module.put(String.valueOf(object_id), String.valueOf(Types.TASK));
-    // }
-    // }
-    // }
-    //
-    // LOG.debug("STATUS: OK");
-    // } else {
-    // LOG.warn("invalid versit object: " + vo.name);
-    // }
-    // } catch (final OXObjectNotFoundException exc) {
-    // LOG.debug("object was already delete", exc);
-    // }
-    //
-    // vo = def.parseChild(r, root_vo);
-    // }
-    // } finally {
-    // oxc.close();
-    // }
-    //
-    // final CalendarDataObject appointmentObject = new CalendarDataObject();
-    //
-    // final Iterator<String> it = entries_db.keySet().iterator();
-    // while (it.hasNext()) {
-    // final String tmp = it.next();
-    // if (!entries.contains(tmp)) {
-    // final int object_id = Integer.parseInt(entries_db.get(tmp).toString());
-    // final int i_module = Integer.parseInt(entries_module.get(String.valueOf(object_id)));
-    //
-    // deleteEntry(context, principal_id, object_id, i_module);
-    //
-    // if (enabledelete) {
-    // try {
-    // if (i_module == Types.APPOINTMENT) {
-    // appointmentObject.reset();
-    // appointmentObject.setObjectID(object_id);
-    // appointmentObject.setParentFolderID(calendarfolder_id);
-    // appointmentInterface.deleteAppointmentObject(appointmentObject, calendarfolder_id, timestamp);
-    // } else if (i_module == Types.TASK) {
-    // taskInterface.deleteTaskObject(object_id, taskfolder_id, timestamp);
-    // } else {
-    // throw new OXConflictException("unknown module: " + i_module);
-    // }
-    // } catch (final OXObjectNotFoundException exc) {
-    // LOG.debug("object was already delete", exc);
-    // }
-    // }
-    // }
-    // }
-    //
-    // resp.setStatus(HttpServletResponse.SC_OK);
-    // } catch (final OXMandatoryFieldException exc) {
-    // LOG.debug(_doPut, exc);
-    // doError(resp, HttpServletResponse.SC_CONFLICT, exc.getMessage());
-    // } catch (final OXPermissionException exc) {
-    // LOG.debug(_doPut, exc);
-    // doError(resp, HttpServletResponse.SC_FORBIDDEN, exc.getMessage());
-    // } catch (final OXConflictException exc) {
-    // LOG.debug(_doPut, exc);
-    // doError(resp, HttpServletResponse.SC_CONFLICT, exc.getMessage());
-    // } catch (final Exception exc) {
-    // LOG.error(_doPut, exc);
-    // doError(resp);
-    // }
-    // }
-
-    // private void doError(final HttpServletResponse resp) throws IOException {
-    // doError(resp, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, "Server Error");
-    // }
-
+ 
     private void doError(final HttpServletResponse resp, final int code, final String msg) throws IOException {
         resp.setStatus(code);
         resp.setContentType("text/html; ; charset=UTF-8");
