@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,7 +63,7 @@ import com.openexchange.config.ConfigurationService;
  */
 public class WebdavWhiteList {
     private static WebdavWhiteList INSTANCE = new WebdavWhiteList();
-    private static final Log LOG = LogFactory.getLog(WebdavWhiteList.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(WebdavWhiteList.class));
 
 
     private List<Pattern> patterns = Collections.emptyList();
@@ -92,7 +92,7 @@ public class WebdavWhiteList {
             }
 
         }
-        
+
     }
 
     public boolean acceptClient(final HttpServletRequest req) {
