@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -100,8 +100,8 @@ import com.openexchange.tools.versit.converter.OXContainerConverter;
 
 /**
  * vcard
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public final class vcard extends PermissionServlet {
 
@@ -147,7 +147,7 @@ public final class vcard extends PermissionServlet {
 
     private static String SQL_ENTRY_DELETE = "DELETE FROM vcard_ids WHERE target_object_id = ? AND principal_id = ?";
 
-    private static transient final Log LOG = LogFactory.getLog(vcard.class);
+    private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(vcard.class));
 
     public void oxinit() {
         // Nothing to do
@@ -233,7 +233,7 @@ public final class vcard extends PermissionServlet {
 
                 final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                     ContactInterfaceDiscoveryService.class).newContactInterface(contactfolder_id, sessionObj);
-                
+
                 //final ContactSQLInterface contactInterface = new RdbContactSQLInterface(sessionObj);
                 it = contactInterface.getModifiedContactsInFolder(contactfolder_id, _contactFields, new Date(0));
 
