@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,6 +67,7 @@ import org.jdom.output.XMLOutputter;
 import com.openexchange.api.OXObjectNotFoundException;
 import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
@@ -88,24 +89,24 @@ import com.openexchange.webdav.xml.fields.CalendarFields;
 
 /**
  * The WebDAV/XML writer for calendar module.
- * 
+ *
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class AppointmentWriter extends CalendarWriter {
 
     protected final static int[] changeFields = { DataObject.OBJECT_ID, DataObject.CREATED_BY,
-            DataObject.CREATION_DATE, DataObject.LAST_MODIFIED, DataObject.MODIFIED_BY, FolderChildObject.FOLDER_ID,
-            CommonObject.PRIVATE_FLAG, CommonObject.CATEGORIES, CalendarObject.TITLE, Appointment.LOCATION,
-            CalendarObject.START_DATE, CalendarObject.END_DATE, CalendarObject.NOTE, CalendarObject.RECURRENCE_TYPE,
-            CalendarObject.PARTICIPANTS, CalendarObject.USERS, Appointment.SHOWN_AS, Appointment.FULL_TIME,
-            Appointment.COLOR_LABEL, Appointment.NUMBER_OF_ATTACHMENTS,
-            Appointment.CHANGE_EXCEPTIONS, Appointment.DELETE_EXCEPTIONS, Appointment.RECURRENCE_ID,
-            Appointment.RECURRENCE_POSITION, Appointment.RECURRENCE_CALCULATOR, Appointment.TIMEZONE, Appointment.UID };
+        DataObject.CREATION_DATE, DataObject.LAST_MODIFIED, DataObject.MODIFIED_BY, FolderChildObject.FOLDER_ID,
+        CommonObject.PRIVATE_FLAG, CommonObject.CATEGORIES, CalendarObject.TITLE, Appointment.LOCATION,
+        CalendarObject.START_DATE, CalendarObject.END_DATE, CalendarObject.NOTE, CalendarObject.RECURRENCE_TYPE,
+        CalendarObject.PARTICIPANTS, CalendarObject.USERS, Appointment.SHOWN_AS, Appointment.FULL_TIME,
+        Appointment.COLOR_LABEL, Appointment.NUMBER_OF_ATTACHMENTS,
+        Appointment.CHANGE_EXCEPTIONS, Appointment.DELETE_EXCEPTIONS, Appointment.RECURRENCE_ID,
+        Appointment.RECURRENCE_POSITION, Appointment.RECURRENCE_CALCULATOR, Appointment.TIMEZONE, Appointment.UID };
 
     protected final static int[] deleteFields = { DataObject.OBJECT_ID, DataObject.LAST_MODIFIED,
-            Appointment.RECURRENCE_ID };
+        Appointment.RECURRENCE_ID };
 
-    private static final Log LOG = LogFactory.getLog(AppointmentWriter.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AppointmentWriter.class));
 
     /**
      * Initializes a new {@link AppointmentWriter}.
@@ -119,7 +120,7 @@ public class AppointmentWriter extends CalendarWriter {
 
     /**
      * Initializes a new {@link AppointmentWriter}.
-     * 
+     *
      * @param userObj The user
      * @param ctx The context
      * @param sessionObj The session providing needed user data
@@ -140,16 +141,16 @@ public class AppointmentWriter extends CalendarWriter {
             writeObject(appointmentobject, eProp, false, xo, os);
         } catch (final OXObjectNotFoundException exc) {
             writeResponseElement(eProp, 0, HttpServletResponse.SC_NOT_FOUND, XmlServlet.OBJECT_NOT_FOUND_EXCEPTION, xo,
-                    os);
+                os);
         } catch (final Exception ex) {
             LOG.error("AppointmentWriter.startWriter()", ex);
             writeResponseElement(eProp, 0, HttpServletResponse.SC_INTERNAL_SERVER_ERROR,
-                    XmlServlet.SERVER_ERROR_EXCEPTION, xo, os);
+                XmlServlet.SERVER_ERROR_EXCEPTION, xo, os);
         }
     }
 
     public void startWriter(final boolean bModified, final boolean bDeleted, final boolean bList, final int folder_id,
-            final Date lastsync, final OutputStream os) throws Exception {
+        final Date lastsync, final OutputStream os) throws Exception {
         final AppointmentSQLInterface appointmentsql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(sessionObj);
         final XMLOutputter xo = new XMLOutputter();
         SearchIterator<? extends Appointment> it = null;
@@ -197,9 +198,9 @@ public class AppointmentWriter extends CalendarWriter {
                                     /*
                                      * Load withheld change exceptions by IDs
                                      */
-                                    CalendarCollectionService calColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
+                                    final CalendarCollectionService calColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
                                     final Appointment[] ces = calColl.getAppointmentsByID(
-                                            folder_id, ids, deleteFields, sessionObj);
+                                        folder_id, ids, deleteFields, sessionObj);
                                     for (final Appointment ce : ces) {
                                         if (null != ce) {
                                             /*
@@ -247,19 +248,19 @@ public class AppointmentWriter extends CalendarWriter {
     }
 
     public void writeIterator(final SearchIterator<? extends Appointment> it, final boolean delete,
-            final XMLOutputter xo, final OutputStream os) throws Exception {
+        final XMLOutputter xo, final OutputStream os) throws Exception {
         while (it.hasNext()) {
             writeObject(it.next(), delete, xo, os);
         }
     }
 
     public void writeObject(final Appointment appointmentobject, final boolean delete, final XMLOutputter xo,
-            final OutputStream os) throws Exception {
+        final OutputStream os) throws Exception {
         writeObject(appointmentobject, new Element("prop", "D", "DAV:"), delete, xo, os);
     }
 
     public void writeObject(final Appointment appointmentobject, final Element e_prop, final boolean delete,
-            final XMLOutputter xo, final OutputStream os) throws Exception {
+        final XMLOutputter xo, final OutputStream os) throws Exception {
         int status = 200;
         String description = "OK";
         int object_id = 0;
@@ -276,12 +277,12 @@ public class AppointmentWriter extends CalendarWriter {
     }
 
     protected void addContent2PropElement(final Element e_prop, final Appointment ao, final boolean delete)
-            throws Exception {
+    throws Exception {
         addContent2PropElement(e_prop, ao, delete, false);
     }
 
     public void addContent2PropElement(final Element e_prop, final Appointment ao, final boolean delete,
-            final boolean externalUse) throws OXException, SearchIteratorException, UnsupportedEncodingException {
+        final boolean externalUse) throws AbstractOXException, SearchIteratorException, UnsupportedEncodingException {
         if (delete) {
             addElement(AppointmentFields.OBJECT_ID, ao.getObjectID(), e_prop);
             addElement(AppointmentFields.LAST_MODIFIED, ao.getLastModified(), e_prop);
@@ -303,19 +304,19 @@ public class AppointmentWriter extends CalendarWriter {
                 if (!externalUse) {
                     RecurringResultsInterface recuResults = null;
                     try {
-                        CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
+                        final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
                         recuResults = recColl.calculateFirstRecurring(ao);
                     } catch (final OXException x) {
                         LOG.error(new StringBuilder("Can not calculate recurrence ").append(ao.getObjectID()).append(
-                                ':').append(sessionObj.getContextId()).toString(), x);
+                        ':').append(sessionObj.getContextId()).toString(), x);
                     }
                     if (recuResults != null && recuResults.size() == 1) {
                         ao.setStartDate(new Date(recuResults.getRecurringResult(0).getStart()));
                         ao.setEndDate(new Date(recuResults.getRecurringResult(0).getEnd()));
                     } else {
                         LOG.warn(new StringBuilder("Cannot load first recurring appointment from appointment object: ")
-                                .append(ao.getRecurrenceType()).append(" / ").append(+ao.getObjectID())
-                                .append("\n\n\n").toString());
+                        .append(ao.getRecurrenceType()).append(" / ").append(+ao.getObjectID())
+                        .append("\n").toString());
                     }
                 }
                 addElement(CalendarFields.START_DATE, ao.getStartDate(), e_prop);
@@ -370,7 +371,7 @@ public class AppointmentWriter extends CalendarWriter {
             if (ao.getIgnoreConflicts()) {
                 addElement(AppointmentFields.IGNORE_CONFLICTS, true, e_prop);
             }
-            
+
             if (ao.containsUid()) {
                 addElement(AppointmentFields.UID, ao.getUid(), e_prop);
             }
@@ -387,7 +388,7 @@ public class AppointmentWriter extends CalendarWriter {
     }
 
     private static int[] checkChangeExceptions(final int folderId, final Appointment master, final Session session)
-            throws OXException {
+    throws OXException {
         final Date[] changeExceptions = master.getChangeException();
         if (null == changeExceptions || changeExceptions.length == 0) {
             return new int[0];
@@ -398,16 +399,16 @@ public class AppointmentWriter extends CalendarWriter {
          */
         final Date[] deleteExceptions = master.getDeleteException();
         final List<Date> dlist = null == deleteExceptions ? new ArrayList<Date>(changeExceptions.length)
-                : new ArrayList<Date>(Arrays.asList(deleteExceptions));
+            : new ArrayList<Date>(Arrays.asList(deleteExceptions));
         final List<Date> clist = new ArrayList<Date>(Arrays.asList(changeExceptions));
         final int[] ids = new int[changeExceptions.length];
         int c = 0;
         boolean applyNewExceptions = false;
         for (final Iterator<Date> iterator = clist.iterator(); iterator.hasNext();) {
             final Date changeException = iterator.next();
-            CalendarCollectionService calColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
+            final CalendarCollectionService calColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
             final Appointment app = calColl.getChangeExceptionByDate(folderId, master
-                    .getRecurrenceID(), changeException, changeFields, session);
+                .getRecurrenceID(), changeException, changeFields, session);
             if (null != app && !isVisibleAsParticipantOrOwner(app, session.getUserId())) {
                 // Remove from change exceptions
                 iterator.remove();
