@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import java.io.UnsupportedEncodingException;
 import java.util.Arrays;
 import org.jdom.Element;
 import com.openexchange.api.OXConflictException;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.Participant;
 import com.openexchange.groupware.container.UserParticipant;
@@ -62,7 +62,7 @@ import com.openexchange.webdav.xml.fields.CalendarFields;
 
 /**
  * WebDAV/XML writer for common appointment and task attributes.
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public abstract class CalendarWriter extends CommonWriter {
 
@@ -75,7 +75,7 @@ public abstract class CalendarWriter extends CommonWriter {
         super();
     }
 
-    protected void writeCalendarElements(final CalendarObject calendarobject, final Element e_prop) throws OXException, SearchIteratorException, UnsupportedEncodingException {
+    protected void writeCalendarElements(final CalendarObject calendarobject, final Element e_prop) throws AbstractOXException, SearchIteratorException, UnsupportedEncodingException {
         addElement(CalendarFields.TITLE, calendarobject.getTitle(), e_prop);
         addElement(CalendarFields.NOTE, calendarobject.getNote(), e_prop);
 
