@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,7 @@ package com.openexchange.webdav.xml;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
 import org.jdom.Element;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.attach.AttachmentMetadata;
 import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.results.TimedResult;
@@ -63,11 +63,11 @@ import com.openexchange.tools.iterator.SearchIteratorException;
 /**
  * CommonWriter
  *
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public abstract class CommonWriter extends FolderChildWriter {
 
-    protected void writeCommonElements(final CommonObject commonobject, final Element e_prop) throws OXException, SearchIteratorException, UnsupportedEncodingException {
+    protected void writeCommonElements(final CommonObject commonobject, final Element e_prop) throws AbstractOXException, SearchIteratorException, UnsupportedEncodingException {
 
         if (commonobject.containsParentFolderID() && commonobject.getParentFolderID() == 0) {
             addElement("personal_folder_id", commonobject.getParentFolderID(), e_prop);
@@ -84,7 +84,7 @@ public abstract class CommonWriter extends FolderChildWriter {
         addElement("private_flag", commonobject.getPrivateFlag(), e_prop);
     }
 
-    protected void writeElementAttachments(final CommonObject commonobject, final Element e_prop) throws OXException, SearchIteratorException, UnsupportedEncodingException {
+    protected void writeElementAttachments(final CommonObject commonobject, final Element e_prop) throws AbstractOXException, SearchIteratorException, UnsupportedEncodingException {
         final Element e_attachments = new Element("attachments", XmlServlet.NS);
         SearchIterator it = null;
         try {
