@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,7 @@ import org.jdom.Namespace;
 import org.jdom.Text;
 import org.jdom.output.XMLOutputter;
 import com.openexchange.api.OXObjectNotFoundException;
-import com.openexchange.api2.OXException;
+import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
@@ -86,8 +86,8 @@ import com.openexchange.webdav.xml.fields.ContactFields;
 
 /**
  * ContactWriter
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 
 public class ContactWriter extends CommonWriter {
@@ -119,7 +119,7 @@ public class ContactWriter extends CommonWriter {
 
     protected final static int[] deleteFields = { DataObject.OBJECT_ID, DataObject.LAST_MODIFIED };
 
-    private static final Log LOG = LogFactory.getLog(ContactWriter.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactWriter.class));
 
     public ContactWriter() {
 
@@ -144,6 +144,7 @@ public class ContactWriter extends CommonWriter {
         } catch (final OXObjectNotFoundException exc) {
             writeResponseElement(eProp, 0, HttpServletResponse.SC_NOT_FOUND, XmlServlet.OBJECT_NOT_FOUND_EXCEPTION, xo, os);
         } catch (final Exception ex) {
+            LOG.error(ex.getMessage(), ex);
             writeResponseElement(eProp, 0, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, XmlServlet.SERVER_ERROR_EXCEPTION, xo, os);
         }
     }
@@ -186,7 +187,7 @@ public class ContactWriter extends CommonWriter {
             try {
                 final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                     ContactInterfaceDiscoveryService.class).newContactInterface(folder_id, sessionObj);
-                it = contactInterface.getContactsInFolder(folder_id, 0, 50000, 0, null, deleteFields);
+                it = contactInterface.getContactsInFolder(folder_id, 0, 50000, 0, null, null,  deleteFields);
                 writeList(it, xo, os);
             } finally {
                 if (it != null) {
@@ -235,7 +236,7 @@ public class ContactWriter extends CommonWriter {
         addContent2PropElement(e, contactobject, delete, false);
     }
 
-    public void addContent2PropElement(final Element e, final Contact contactobject, final boolean delete, final boolean externalUser) throws OXException, SearchIteratorException, UnsupportedEncodingException, AddressException {
+    public void addContent2PropElement(final Element e, final Contact contactobject, final boolean delete, final boolean externalUser) throws AbstractOXException, SearchIteratorException, UnsupportedEncodingException, AddressException {
         if (delete) {
             addElement(ContactFields.OBJECT_ID, contactobject.getObjectID(), e);
             addElement(ContactFields.LAST_MODIFIED, contactobject.getLastModified(), e);
@@ -304,7 +305,7 @@ public class ContactWriter extends CommonWriter {
         addElement(ContactFields.FAX_BUSINESS, contactobject.getFaxBusiness(), e);
         addElement(ContactFields.FAX_HOME, contactobject.getFaxHome(), e);
         addElement(ContactFields.FAX_OTHER, contactobject.getFaxOther(), e);
-        addElement("fileas", contactobject.getFileAs(), e);
+        addElement(ContactFields.FILE_AS, contactobject.getFileAs(), e);
         addElement(ContactFields.NOTE, contactobject.getNote(), e);
         addElement(ContactFields.MORE_INFO, contactobject.getInfo(), e);
         addElement(ContactFields.INSTANT_MESSENGER, contactobject.getInstantMessenger1(), e);
