@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,34 +64,34 @@ import com.openexchange.webdav.xml.fields.DataFields;
 /**
  * FolderChildWriter
  *
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class FolderChildWriter extends DataWriter {
-	
-	private static final Log LOG = LogFactory.getLog(FolderChildWriter.class);
-	
+
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(FolderChildWriter.class));
+
 	protected void writeFolderChildElements(final FolderChildObject folderchildobject, final Element e_prop) {
 		writeDataElements(folderchildobject, e_prop);
-		
+
 		if (folderchildobject.containsParentFolderID()) {
 			addElement("folder_id", folderchildobject.getParentFolderID(), e_prop);
-		} 
+		}
 	}
-	
+
 	public void writeList(final SearchIterator<? extends DataObject> searchIterator, final XMLOutputter xo, final OutputStream os) throws Exception {
 		int status = 200;
 		String description = "OK";
 		int object_id = 0;
-		
+
 		final Element eProp = new Element("prop", "D", "DAV:");
-		
+
 		try {
 			addElement("object_status", "LIST", eProp);
 			final Element eIds = new Element("object_list", namespace);
 			while (searchIterator.hasNext()) {
 				addElement(DataFields.ID, searchIterator.next().getObjectID(), eIds);
 			}
-			
+
 			eProp.addContent(eIds);
 		} catch (final Exception exc) {
 			LOG.error("writeList", exc);
