@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,6 +69,7 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.search.Order;
+import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
@@ -77,8 +78,8 @@ import com.openexchange.webdav.xml.fields.DataFields;
 
 /**
  * AppointmentWriter
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public class GroupUserWriter extends ContactWriter {
 
@@ -144,7 +145,7 @@ public class GroupUserWriter extends ContactWriter {
 
     protected Element parent = null;
 
-    private static final Log LOG = LogFactory.getLog(GroupUserWriter.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GroupUserWriter.class));
 
     public GroupUserWriter(final User userObj, final Context ctx, final Session sessionObj, final Element parent) {
         super(userObj, ctx, sessionObj);
@@ -269,14 +270,14 @@ public class GroupUserWriter extends ContactWriter {
             final String[] aliases = u.getAliases();
             if (null != aliases && aliases.length > 0) {
                 internalAddresses = new HashSet<InternetAddress>(aliases.length + 1);
-                internalAddresses.add(new InternetAddress(primaryAddress));
+                internalAddresses.add(new QuotedInternetAddress(primaryAddress));
 
                 for (final String alias : aliases) {
-                    internalAddresses.add(new InternetAddress(alias));
+                    internalAddresses.add(new QuotedInternetAddress(alias));
                 }
             } else {
                 internalAddresses = new HashSet<InternetAddress>(1);
-                internalAddresses.add(new InternetAddress(primaryAddress));
+                internalAddresses.add(new QuotedInternetAddress(primaryAddress));
             }
 
             addElement(DataFields.LAST_MODIFIED, contactobject.getLastModified(), e);
@@ -312,7 +313,7 @@ public class GroupUserWriter extends ContactWriter {
 
     /**
      * Tests if specified string is empty; either <code>null</code>, zero length, or only consists of white space characters.
-     * 
+     *
      * @param str The string to test
      * @return <code>true</code> if specified string is empty; otherwise <code>false</code>.
      */
