@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,8 +69,10 @@ import com.openexchange.api.OXConflictException;
 import com.openexchange.api.OXPermissionException;
 import com.openexchange.api2.OXException;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.attach.AttachmentBase;
 import com.openexchange.groupware.attach.Attachments;
+import com.openexchange.groupware.contact.ContactExceptionCodes;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.DataObject;
@@ -89,8 +91,8 @@ import com.openexchange.webdav.xml.fields.DataFields;
 
 /**
  * {@link XmlServlet} - The XML servlet.
- * 
- * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  */
 public abstract class XmlServlet<I> extends PermissionServlet {
 
@@ -138,6 +140,8 @@ public abstract class XmlServlet<I> extends PermissionServlet {
 
     public static final String OK = "[" + OK_STATUS + "] OK";
 
+    public static final String INDIVIDUAL_ERROR = "[%s] [%s]";
+
     public static final String _contentType = "text/xml; charset=UTF-8";
 
     public static final String NAMESPACE = "http://www.open-xchange.org";
@@ -154,7 +158,7 @@ public abstract class XmlServlet<I> extends PermissionServlet {
 
     private static final Namespace dav = Namespace.getNamespace("D", davUri);
 
-    private static transient final Log LOG = LogFactory.getLog(XmlServlet.class);
+    private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(XmlServlet.class));
 
     @Override
     public void doPut(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException {
@@ -191,22 +195,22 @@ public abstract class XmlServlet<I> extends PermissionServlet {
 
                     commit(resp.getOutputStream(), getSession(req), pendingInvocations);
                 } else {
-                    doError(req, resp, HttpServletResponse.SC_BAD_REQUEST, "XML ERROR");
+                    doOXError(req, resp, HttpServletResponse.SC_BAD_REQUEST, BAD_REQUEST_EXCEPTION, parser);
                     return;
                 }
             } else {
-                doError(req, resp, HttpServletResponse.SC_BAD_REQUEST, "XML ERROR");
+                doOXError(req, resp, HttpServletResponse.SC_BAD_REQUEST, BAD_REQUEST_EXCEPTION, parser);
                 return;
             }
         } catch (final IOException e) {
             LOG.error("doPropPatch", e);
-            doError(req, resp);
+            doOXError(req, resp, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, e, parser);
         } catch (final XmlPullParserException e) {
             LOG.error("doPropPatch", e);
-            doError(req, resp);
+            doOXError(req, resp, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, e, parser);
         } catch (final AbstractOXException e) {
             LOG.error("doPropPatch", e);
-            doError(req, resp);
+            doOXError(req, resp, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, e, parser);
         }
     }
 
@@ -385,6 +389,66 @@ public abstract class XmlServlet<I> extends PermissionServlet {
         }
     }
 
+    private void doOXError(final HttpServletRequest req, final HttpServletResponse resp, final int httpErrorCode, final String description, final XmlPullParser parser) throws ServletException {
+        final DataObject dataObject = new DataObject() {
+            @Override
+            public int getObjectID() {
+                return 0;
+            }
+        };
+        try {
+            String clientId = "not found";
+
+            while (!(parser.getEventType() == XmlPullParser.END_DOCUMENT)) {
+                if (isTag(parser, "client_id", "ox")) {
+                    clientId = parser.nextText();
+                    break;
+                } else {
+                    parser.next();
+                }
+            }
+
+            final OutputStream os = resp.getOutputStream();
+            os.write(("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n").getBytes());
+            os.write(("<D:multistatus xmlns:D=\"DAV:\" version=\"" + Version.getVersionString() + "\" buildname=\"" + Version.NAME + "\">").getBytes());
+            os.flush();
+
+            writeResponse(dataObject, httpErrorCode, description, clientId, resp.getOutputStream(), new XMLOutputter());
+
+            os.write(("</D:multistatus>").getBytes());
+        } catch (IOException e) {
+            LOG.error("doOXError", e);
+            doError(req, resp, httpErrorCode, description);
+        } catch (XmlPullParserException e) {
+            LOG.error("doOXError", e);
+            doError(req, resp, httpErrorCode, description);
+        }
+    }
+
+    private void doOXError(final HttpServletRequest req, final HttpServletResponse resp, final int httpErrorCode, final Exception exception, final XmlPullParser parser) throws ServletException {
+        doOXError(req, resp, httpErrorCode, createResponseErrorMessage(exception), parser);
+    }
+
+    private String createResponseErrorMessage(final Exception e) {
+        final int descriptionCode;
+        final String message;
+        if (e instanceof AbstractOXException) {
+            final AbstractOXException o = (AbstractOXException) e;
+            if (o.getComponent().equals(EnumComponent.CONTACT) && o.getDetailNumber() == ContactExceptionCodes.INVALID_EMAIL.getDetailNumber()) {
+                descriptionCode = 1500;
+                message = o.getMessage();
+            } else {
+                descriptionCode = 1400;
+                message = o.getMessage();
+            }
+        } else {
+            descriptionCode = 1400;
+            message = e.getMessage();
+        }
+
+        return String.format(INDIVIDUAL_ERROR, descriptionCode, message);
+    }
+
     protected void parsePropertyUpdate(final HttpServletRequest req, final HttpServletResponse resp,
             final XmlPullParser parser, final PendingInvocations<I> pendingInvocations) throws XmlPullParserException, IOException, AbstractOXException {
 
@@ -535,7 +599,7 @@ public abstract class XmlServlet<I> extends PermissionServlet {
     /**
      * This method is invoked when XML input could be successfully parsed and
      * pending actions are supposed to be performed
-     * 
+     *
      * @param os
      *            The output stream to write response to
      * @param session
@@ -557,7 +621,7 @@ public abstract class XmlServlet<I> extends PermissionServlet {
 
     /**
      * Performs pending actions gathered through parsing XML input
-     * 
+     *
      * @param os
      *            The output stream to write response to
      * @param session
