@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,9 @@ import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
 import java.util.Arrays;
 import java.util.List;
+
+import javax.servlet.http.HttpServletResponse;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.jdom.Document;
@@ -67,6 +70,7 @@ import com.openexchange.webdav.protocol.Multistatus;
 import com.openexchange.webdav.protocol.Protocol;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProperty;
+import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
 import com.openexchange.webdav.protocol.WebdavStatus;
 import com.openexchange.webdav.protocol.util.Utils;
@@ -75,7 +79,7 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 
 	protected static final Namespace DAV_NS = Protocol.DAV_NS;
 	protected static final Namespace DATE_NS = Namespace.getNamespace("b",  "urn:uuid:c2f41010-65b3-11d1-a29f-00aa00c14882/");
-	
+
 	private String uriPrefix;
 
 	private final String charset;
@@ -84,12 +88,12 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 		return new Multistatus<Iterable<WebdavProperty>>();
 	}
 
-	private static final Log LOG = LogFactory.getLog(PropertiesMarshaller.class);
-	
+	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PropertiesMarshaller.class));
+
 	public PropertiesMarshaller(final String charset){
 		this.charset = charset;
 	}
-	
+
 	public PropertiesMarshaller(final String uriPrefix, final String charset) {
 		this.uriPrefix = uriPrefix;
 		if(!this.uriPrefix.endsWith("/")) {
@@ -98,29 +102,33 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 		this.charset = charset;
 	}
 
-	public List<Element> marshal(final WebdavResource resource) {
+	public List<Element> marshal(final WebdavResource resource) throws WebdavProtocolException {
 		final Element response =  new Element("response",DAV_NS);
-		response.addContent(marshalHREF(resource.getUrl())); //TODO: Fix the new bug here
-		final Multistatus<Iterable<WebdavProperty>> multistatus = getProps(resource);
-		for(final int statusCode : multistatus.getStatusCodes()) {
-			for(final WebdavStatus<Iterable<WebdavProperty>> status : multistatus.toIterable(statusCode)) {
-				final Element propstat = new Element("propstat",DAV_NS);
-				final Element prop = new Element("prop", DAV_NS);
-				
-				for(final WebdavProperty p : status.getAdditional()) {
-					if(p != null) {
-						prop.addContent(marshalProperty(p));
+		response.addContent(marshalHREF(resource.getUrl(), resource.getResourceType() != null)); //TODO: Fix the new bug here
+		if (resource.exists()) {
+			final Multistatus<Iterable<WebdavProperty>> multistatus = getProps(resource);
+			for(final int statusCode : multistatus.getStatusCodes()) {
+				for(final WebdavStatus<Iterable<WebdavProperty>> status : multistatus.toIterable(statusCode)) {
+					final Element propstat = new Element("propstat",DAV_NS);
+					final Element prop = new Element("prop", DAV_NS);
+
+					for(final WebdavProperty p : status.getAdditional()) {
+						if(p != null) {
+							prop.addContent(marshalProperty(p, resource.getProtocol()));
+						}
 					}
+					propstat.addContent(prop);
+					propstat.addContent(marshalStatus(statusCode));
+					response.addContent(propstat);
 				}
-				propstat.addContent(prop);
-				propstat.addContent(marshalStatus(statusCode));
-				response.addContent(propstat);
 			}
+		} else {
+			response.addContent(this.marshalStatus(HttpServletResponse.SC_NOT_FOUND));
 		}
 		return Arrays.asList(response);
 	}
-	
-	public Element marshalHREF(final WebdavPath uri) {
+
+	public Element marshalHREF(final WebdavPath uri, boolean trailingSlash) {
 		final Element href = new Element("href", DAV_NS);
         final StringBuilder builder = new StringBuilder(uriPrefix);
         if(builder.charAt(builder.length()-1) != '/') {
@@ -129,11 +137,13 @@ public class PropertiesMarshaller implements ResourceMarshaller {
         for(final String component : uri) {
             builder.append(escape(component)).append("/");
         }
-        builder.setLength(builder.length()-1);
+        if (!trailingSlash) {
+            builder.setLength(builder.length()-1);
+        }
         href.setText(builder.toString());
 		return href;
 	}
-	
+
 	private String escape(final String string) {
 		final PropfindResponseUrlEncoder encoder = BehaviourLookup.getInstance().get(PropfindResponseUrlEncoder.class);
 		if(null != encoder) {
@@ -144,7 +154,7 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 		} catch (final UnsupportedEncodingException e) {
 			LOG.fatal(e);
 			return string;
-		} 
+		}
 	}
 
 	public Element marshalStatus(final int s) {
@@ -157,7 +167,7 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 		return status;
 	}
 
-	public Element marshalProperty(final WebdavProperty property) {
+	public Element marshalProperty(final WebdavProperty property, Protocol protocol) {
 		final Element propertyElement = new Element(property.getName(), getNamespace(property));
 		if(property.getValue() == null) {
 			return propertyElement;
@@ -166,9 +176,21 @@ public class PropertiesMarshaller implements ResourceMarshaller {
 			try {
 				String asXML = null;
 				if("DAV:".equals(property.getNamespace())) {
-					asXML = "<FKR:fakeroot xmlns:FKR=\"http://www.open-xchange.com/webdav/fakeroot\" xmlns:D=\""+property.getNamespace()+"\">"+property.getValue()+"</FKR:fakeroot>";
+					StringBuilder xmlBuilder = new StringBuilder("<FKR:fakeroot xmlns:FKR=\"http://www.open-xchange.com/webdav/fakeroot\" xmlns:D=\"DAV:\"");
+                    List<Namespace> namespaces = protocol.getAdditionalNamespaces();
+                    for (Namespace namespace : namespaces) {
+                        xmlBuilder.append(" xmlns:").append(namespace.getPrefix()).append("=\"").append(namespace.getURI()).append('"');
+                    }
+                    xmlBuilder.append('>').append(property.getValue()).append("</FKR:fakeroot>");
+                    asXML = xmlBuilder.toString();
 				} else {
-					asXML = "<FKR:fakeroot xmlns:FKR=\"http://www.open-xchange.com/webdav/fakeroot\" xmlns=\""+property.getNamespace()+"\">"+property.getValue()+"</FKR:fakeroot>";
+					StringBuilder xmlBuilder = new StringBuilder("<FKR:fakeroot xmlns:FKR=\"http://www.open-xchange.com/webdav/fakeroot\" xmlns:D=\"DAV:\" xmlns=\"").append(property.getNamespace()).append('"');
+					List<Namespace> namespaces = protocol.getAdditionalNamespaces();
+					for (Namespace namespace : namespaces) {
+                        xmlBuilder.append(" xmlns:").append(namespace.getPrefix()).append("=\"").append(namespace.getURI()).append('"');
+                    }
+					xmlBuilder.append('>').append(property.getValue()).append("</FKR:fakeroot>");
+					asXML = xmlBuilder.toString();
 				}
 				final Document doc = new SAXBuilder().build(new StringReader(asXML));
 				propertyElement.setContent(doc.getRootElement().cloneContent());
