@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,8 +52,9 @@ package com.openexchange.webdav.xml.resources;
 
 import java.util.List;
 import org.jdom.Element;
+import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
 
 public interface ResourceMarshaller {
-	public List<Element> marshal(WebdavResource resource);
+	public List<Element> marshal(WebdavResource resource) throws WebdavProtocolException;
 }
