@@ -84,7 +84,7 @@ public class KXmlParser implements XmlPullParser {
     private int stackMismatch;
     private String error;
 
-    /** 
+    /**
      * A separate peek buffer seems simpler than managing
      * wrap around in the first level read buffer */
 
@@ -252,8 +252,8 @@ public class KXmlParser implements XmlPullParser {
             null);
     }
 
-    /** 
-     * common base for next and nextToken. Clears the state, except from 
+    /**
+     * common base for next and nextToken. Clears the state, except from
      * txtPos and whitespace. Does not set the type variable */
 
     private final void nextImpl() throws IOException, XmlPullParserException {
@@ -336,7 +336,7 @@ public class KXmlParser implements XmlPullParser {
                         // if (isWhitespace) {
 							type = IGNORABLE_WHITESPACE;
                         // make exception switchable for instances.chg... !!!!
-                        //	else 
+                        //	else
                         //    exception ("text '"+getText ()+"' not allowed outside root element");
 						// }
                     }
@@ -691,7 +691,7 @@ public class KXmlParser implements XmlPullParser {
                 } else {
 					read();
 				}
-				
+
                 final int p = txtPos;
                 pushText(delimiter, true);
 
@@ -761,7 +761,7 @@ public class KXmlParser implements XmlPullParser {
                 && c != '-'
                 && c != '#') {
                 error("unterminated entity ref");
-                //; ends with:"+(char)c);           
+                //; ends with:"+(char)c);
                 if (c != -1) {
 					push(c);
 				}
@@ -870,7 +870,7 @@ public class KXmlParser implements XmlPullParser {
             peek[0] = peek[1];
         }
         //		else {
-        //			result = peek[0]; 
+        //			result = peek[0];
         //			System.arraycopy (peek, 1, peek, 0, peekCount-1);
         //		}
         peekCount--;
@@ -1023,7 +1023,7 @@ public class KXmlParser implements XmlPullParser {
         try {
 
             if (enc == null) {
-                // read four bytes 
+                // read four bytes
 
                 int chk = 0;
 
@@ -1296,6 +1296,11 @@ public class KXmlParser implements XmlPullParser {
     public char[] getTextCharacters(final int[] poslen) {
         if (type >= TEXT) {
             if (type == ENTITY_REF) {
+                if (null == name) {
+                    poslen[0] = -1;
+                    poslen[1] = -1;
+                    return null;
+                }
                 poslen[0] = 0;
                 poslen[1] = name.length();
                 return name.toCharArray();
@@ -1396,7 +1401,7 @@ public class KXmlParser implements XmlPullParser {
             nextImpl();
             if (type < minType) {
 				minType = type;
-            //	    if (curr <= TEXT) type = curr; 
+            //	    if (curr <= TEXT) type = curr;
 			}
         }
         while (minType > ENTITY_REF // ignorable
@@ -1496,10 +1501,10 @@ public class KXmlParser implements XmlPullParser {
     /**
       * Skip sub tree that is currently porser positioned on.
       * <br>NOTE: parser must be on START_TAG and when funtion returns
-      * parser will be positioned on corresponding END_TAG. 
+      * parser will be positioned on corresponding END_TAG.
       */
 
-    //	Implementation copied from Alek's mail... 
+    //	Implementation copied from Alek's mail...
 
     public void skipSubTree() throws XmlPullParserException, IOException {
         require(START_TAG, null, null);
