@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,7 +73,7 @@ public abstract class JDBC3ConnectionReturner implements Connection {
 
     private final Assignment assign;
 
-    protected final Connection delegate;
+    protected Connection delegate;
 
     private final boolean noTimeout;
 
@@ -81,7 +81,7 @@ public abstract class JDBC3ConnectionReturner implements Connection {
 
     private final boolean usedAsRead;
 
-    public JDBC3ConnectionReturner(Pools pools, Assignment assign, Connection delegate, boolean noTimeout, boolean write, boolean usedAsRead) {
+    public JDBC3ConnectionReturner(final Pools pools, final Assignment assign, final Connection delegate, final boolean noTimeout, final boolean write, final boolean usedAsRead) {
         super();
         this.pools = pools;
         this.assign = assign;
@@ -92,146 +92,191 @@ public abstract class JDBC3ConnectionReturner implements Connection {
     }
 
     public void clearWarnings() throws SQLException {
+        checkForAlreadyClosed();
         delegate.clearWarnings();
     }
 
     public void close() throws SQLException {
-        ReplicationMonitor.backAndIncrementTransaction(pools, assign, delegate, noTimeout, write, usedAsRead);
+        if (null == delegate) {
+            throw new SQLException("Connection is already closed.");
+        }
+        final Connection toReturn = delegate;
+        delegate = null;
+        ReplicationMonitor.backAndIncrementTransaction(pools, assign, toReturn, noTimeout, write, usedAsRead);
     }
 
     public void commit() throws SQLException {
+        checkForAlreadyClosed();
         delegate.commit();
     }
 
     public Statement createStatement() throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4StatementWrapper(delegate.createStatement(), this);
     }
 
-    public Statement createStatement(int resultSetType, int resultSetConcurrency) throws SQLException {
+    public Statement createStatement(final int resultSetType, final int resultSetConcurrency) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4StatementWrapper(delegate.createStatement(resultSetType, resultSetConcurrency), this);
     }
 
-    public Statement createStatement(int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
+    public Statement createStatement(final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4StatementWrapper(delegate.createStatement(resultSetType, resultSetConcurrency, resultSetHoldability), this);
     }
 
     public boolean getAutoCommit() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getAutoCommit();
     }
 
     public String getCatalog() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getCatalog();
     }
 
     public int getHoldability() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getHoldability();
     }
 
     public DatabaseMetaData getMetaData() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getMetaData();
     }
 
     public int getTransactionIsolation() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getTransactionIsolation();
     }
 
     public Map<String, Class<?>> getTypeMap() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getTypeMap();
     }
 
     public SQLWarning getWarnings() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.getWarnings();
     }
 
     public boolean isClosed() throws SQLException {
-        return delegate.isClosed();
+        return delegate == null || delegate.isClosed();
     }
 
     public boolean isReadOnly() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.isReadOnly();
     }
 
-    public String nativeSQL(String sql) throws SQLException {
+    public String nativeSQL(final String sql) throws SQLException {
+        checkForAlreadyClosed();
         return delegate.nativeSQL(sql);
     }
 
-    public CallableStatement prepareCall(String sql) throws SQLException {
+    public CallableStatement prepareCall(final String sql) throws SQLException {
+        checkForAlreadyClosed();
         return delegate.prepareCall(sql);
     }
 
-    public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
+    public CallableStatement prepareCall(final String sql, final int resultSetType, final int resultSetConcurrency) throws SQLException {
+        checkForAlreadyClosed();
         return delegate.prepareCall(sql, resultSetType, resultSetConcurrency);
     }
 
-    public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
+    public CallableStatement prepareCall(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
+        checkForAlreadyClosed();
         return delegate.prepareCall(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
     }
 
-    public PreparedStatement prepareStatement(String sql) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql), this);
     }
 
-    public PreparedStatement prepareStatement(String sql, int autoGeneratedKeys) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql, final int autoGeneratedKeys) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql, autoGeneratedKeys), this);
     }
 
-    public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql, resultSetType, resultSetConcurrency), this);
     }
 
-    public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql, resultSetType, resultSetConcurrency, resultSetHoldability), this);
     }
 
-    public PreparedStatement prepareStatement(String sql, int[] columnIndexes) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql, final int[] columnIndexes) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql, columnIndexes), this);
     }
 
-    public PreparedStatement prepareStatement(String sql, String[] columnNames) throws SQLException {
+    public PreparedStatement prepareStatement(final String sql, final String[] columnNames) throws SQLException {
+        checkForAlreadyClosed();
         return new JDBC4PreparedStatementWrapper(delegate.prepareStatement(sql, columnNames), this);
     }
 
-    public void releaseSavepoint(Savepoint savepoint) throws SQLException {
+    public void releaseSavepoint(final Savepoint savepoint) throws SQLException {
+        checkForAlreadyClosed();
         delegate.releaseSavepoint(savepoint);
     }
 
     public void rollback() throws SQLException {
+        checkForAlreadyClosed();
         delegate.rollback();
     }
 
-    public void rollback(Savepoint savepoint) throws SQLException {
+    public void rollback(final Savepoint savepoint) throws SQLException {
+        checkForAlreadyClosed();
         delegate.rollback(savepoint);
     }
 
-    public void setAutoCommit(boolean autoCommit) throws SQLException {
+    public void setAutoCommit(final boolean autoCommit) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setAutoCommit(autoCommit);
     }
 
-    public void setCatalog(String catalog) throws SQLException {
+    public void setCatalog(final String catalog) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setCatalog(catalog);
     }
 
-    public void setHoldability(int holdability) throws SQLException {
+    public void setHoldability(final int holdability) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setHoldability(holdability);
     }
 
-    public void setReadOnly(boolean readOnly) throws SQLException {
+    public void setReadOnly(final boolean readOnly) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setReadOnly(readOnly);
     }
 
     public Savepoint setSavepoint() throws SQLException {
+        checkForAlreadyClosed();
         return delegate.setSavepoint();
     }
 
-    public Savepoint setSavepoint(String name) throws SQLException {
+    public Savepoint setSavepoint(final String name) throws SQLException {
+        checkForAlreadyClosed();
         return delegate.setSavepoint(name);
     }
 
-    public void setTransactionIsolation(int level) throws SQLException {
+    public void setTransactionIsolation(final int level) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setTransactionIsolation(level);
     }
 
-    public void setTypeMap(Map<String, Class<?>> map) throws SQLException {
+    public void setTypeMap(final Map<String, Class<?>> map) throws SQLException {
+        checkForAlreadyClosed();
         delegate.setTypeMap(map);
     }
+
+    private void checkForAlreadyClosed() throws SQLException {
+        if (null == delegate) {
+            throw new SQLException("Connection was already closed.");
+        }
+    }
 }
