@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,8 @@ import java.sql.SQLException;
 import java.sql.Time;
 import java.sql.Timestamp;
 import java.util.Calendar;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 
 /**
  * {@link JDBC3PreparedStatementWrapper}
@@ -76,9 +78,11 @@ public abstract class JDBC3PreparedStatementWrapper extends JDBC3StatementWrappe
 
     private final PreparedStatement delegate;
 
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(JDBC3PreparedStatementWrapper.class));
+
     /**
      * Initializes a new {@link JDBC3PreparedStatementWrapper}.
-     * 
+     *
      * @param delegate The delegate statement
      * @param con The connection returner instance
      */
@@ -96,14 +100,23 @@ public abstract class JDBC3PreparedStatementWrapper extends JDBC3StatementWrappe
     }
 
     public boolean execute() throws SQLException {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug(Thread.currentThread()+" executes: "+delegate.toString());
+        }
         return delegate.execute();
     }
 
     public ResultSet executeQuery() throws SQLException {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug(Thread.currentThread()+" executes: "+delegate.toString());
+        }
         return new JDBC4ResultSetWrapper(delegate.executeQuery(), this);
     }
 
     public int executeUpdate() throws SQLException {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug(Thread.currentThread()+" executes: "+delegate.toString());
+        }
         return delegate.executeUpdate();
     }
 
@@ -231,6 +244,7 @@ public abstract class JDBC3PreparedStatementWrapper extends JDBC3StatementWrappe
         delegate.setURL(parameterIndex, x);
     }
 
+    @Deprecated
     public void setUnicodeStream(final int parameterIndex, final InputStream x, final int length) throws SQLException {
         delegate.setUnicodeStream(parameterIndex, x, length);
     }
