@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,7 +80,7 @@ public abstract class JDBC3ResultSetWrapper implements ResultSet {
 
     /**
      * Initializes a new {@link JDBC3ResultSetWrapper}.
-     * 
+     *
      * @param delegate The delegate result set
      * @param stmt The statement wrapper
      */
@@ -150,10 +150,12 @@ public abstract class JDBC3ResultSetWrapper implements ResultSet {
         return delegate.getBigDecimal(columnName);
     }
 
+    @Deprecated
     public BigDecimal getBigDecimal(final int columnIndex, final int scale) throws SQLException {
         return delegate.getBigDecimal(columnIndex, scale);
     }
 
+    @Deprecated
     public BigDecimal getBigDecimal(final String columnName, final int scale) throws SQLException {
         return delegate.getBigDecimal(columnName, scale);
     }
@@ -318,7 +320,7 @@ public abstract class JDBC3ResultSetWrapper implements ResultSet {
         return delegate.getShort(columnName);
     }
 
-    public JDBC3StatementWrapper getStatement() throws SQLException {
+    public JDBC3StatementWrapper getStatement() {
         return stmt;
     }
 
@@ -374,10 +376,12 @@ public abstract class JDBC3ResultSetWrapper implements ResultSet {
         return delegate.getURL(columnName);
     }
 
+    @Deprecated
     public InputStream getUnicodeStream(final int columnIndex) throws SQLException {
         return delegate.getUnicodeStream(columnIndex);
     }
 
+    @Deprecated
     public InputStream getUnicodeStream(final String columnName) throws SQLException {
         return delegate.getUnicodeStream(columnName);
     }
