@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import java.sql.Statement;
 
 /**
  * The method {@link #getConnection()} must be overwritten to return the {@link JDBC3ConnectionReturner}.
- * 
+ *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public abstract class JDBC3StatementWrapper implements Statement {
@@ -68,7 +68,7 @@ public abstract class JDBC3StatementWrapper implements Statement {
 
     /**
      * Initializes a new {@link JDBC3StatementWrapper}.
-     * 
+     *
      * @param delegate The delegate statement
      * @param con The connection returner
      */
@@ -138,7 +138,7 @@ public abstract class JDBC3StatementWrapper implements Statement {
         return delegate.executeUpdate(sql, columnNames);
     }
 
-    public Connection getConnection() throws SQLException {
+    public Connection getConnection() {
         return con;
     }
 
