@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,9 +64,9 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.groupware.tx.ConfigurableDBProvider;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.TransactionException;
 import junit.framework.TestCase;
 
 /**
@@ -79,6 +79,7 @@ public abstract class SQLTestCase extends TestCase {
     private ConfigurableDBProvider dbProvider;
     protected Properties properties;
 
+    @Override
     public void setUp() throws Exception {
         loadProperties();
         dbProvider = new ConfigurableDBProvider();
@@ -93,7 +94,7 @@ public abstract class SQLTestCase extends TestCase {
     }
 
     protected void loadProperties() throws IOException {
-        String filename = System.getProperty("com.openexchange.test.sql.properties", "conf/sql.properties");
+        String filename = System.getProperty("com.openexchange.test.sql.properties", "testconf/sql.properties");
         properties = new Properties();
         InputStream input = null;
         try {
@@ -122,7 +123,7 @@ public abstract class SQLTestCase extends TestCase {
         return properties.getProperty("url");
     }
 
-    public void assertResult(String sql) throws TransactionException, SQLException {
+    public void assertResult(String sql) throws DBPoolingException, SQLException {
         Connection con = null;
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -145,7 +146,7 @@ public abstract class SQLTestCase extends TestCase {
         }
     }
 
-    public void assertNoResult(String sql) throws TransactionException, SQLException {
+    public void assertNoResult(String sql) throws DBPoolingException, SQLException {
         Connection con = null;
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -168,15 +169,15 @@ public abstract class SQLTestCase extends TestCase {
         }
     }
 
-    public void exec(String sql, Object...substitutes) throws TransactionException, SQLException {
+    public void exec(String sql, Object...substitutes) throws DBPoolingException, SQLException {
         exec(sql, Arrays.asList(substitutes));
     }
-    
-    public void exec(String sql) throws TransactionException, SQLException {
+
+    public void exec(String sql) throws DBPoolingException, SQLException {
         exec(sql, new ArrayList<Object>(0));
     }
-    
-    public void exec(String sql, List<Object> substitues) throws SQLException, TransactionException {
+
+    public void exec(String sql, List<Object> substitues) throws SQLException, DBPoolingException {
         Connection con = null;
         PreparedStatement stmt = null;
 
@@ -197,14 +198,14 @@ public abstract class SQLTestCase extends TestCase {
             }
         }
     }
-    
-    public List<Map<String, Object>> query(String sql) throws TransactionException, SQLException {
+
+    public List<Map<String, Object>> query(String sql) throws DBPoolingException, SQLException {
         Connection con = null;
         PreparedStatement stmt = null;
         ResultSet rs = null;
-        
+
         List<Map<String, Object>> results = new LinkedList<Map<String, Object>>();
-        
+
         try {
             con = getDBProvider().getReadConnection(null);
             stmt = con.prepareStatement(sql);
@@ -219,7 +220,7 @@ public abstract class SQLTestCase extends TestCase {
                 }
                 results.add(row);
             }
-            
+
         } finally {
             if (stmt != null) {
                 stmt.close();
@@ -233,25 +234,25 @@ public abstract class SQLTestCase extends TestCase {
         }
         return results;
     }
-    
-    protected void copyTableStructure(String origName, String newName) throws TransactionException, SQLException {
+
+    protected void copyTableStructure(String origName, String newName) throws DBPoolingException, SQLException {
         Map<String, Object> createTableRow = query("SHOW CREATE TABLE "+origName).get(0);
         String createStatement = (String) createTableRow.get("Create Table");
         createStatement = createStatement.replaceAll(origName, newName);
         exec(createStatement);
     }
-    
-    protected void dropTable(String tableName) throws TransactionException, SQLException {
+
+    protected void dropTable(String tableName) throws DBPoolingException, SQLException {
         exec("DROP TABLE IF EXISTS "+tableName);
     }
-    
-    protected void insert(String tableName, Object...attrs) throws TransactionException, SQLException {
+
+    protected void insert(String tableName, Object...attrs) throws DBPoolingException, SQLException {
         StringBuilder builder = new StringBuilder("INSERT INTO ").append(tableName).append(" (");
         StringBuilder questionMarks = new StringBuilder();
-        
+
         String key = null;
         List<Object> values = new ArrayList<Object>();
-        
+
         for(Object attr : attrs) {
             if(key == null) {
                 key = (String) attr;
@@ -262,15 +263,16 @@ public abstract class SQLTestCase extends TestCase {
                 key = null;
             }
         }
-        
+
         builder.setLength(builder.length()-2);
         questionMarks.setLength(questionMarks.length()-2);
         builder.append(") VALUES (").append(questionMarks).append(")");
-        
+
         exec(builder.toString(), values);
     }
-    
-    protected void assertEntry(String tableName, Object...attrs) throws TransactionException, SQLException {
+
+
+    protected void assertEntry(String tableName, Object...attrs) throws DBPoolingException, SQLException {
         StringBuilder builder = new StringBuilder("SELECT 1 FROM ").append(tableName).append(" WHERE ");
         String key = null;
         for(Object object : attrs) {
